/* ----------------------------------------------------------------------------
 * This file was automatically generated by SWIG (https://www.swig.org).
 * Version 4.4.1
 *
 * Do not make changes to this file unless you know what you are doing - modify
 * the SWIG interface file instead.
 * ----------------------------------------------------------------------------- */


#define SWIG_VERSION 0x040401
#define SWIGPYTHON
#define SWIG_PYTHON_DIRECTOR_NO_VTABLE

#define SWIG_name    "_pywsman"
/* -----------------------------------------------------------------------------
 *  This section contains generic SWIG labels for method/variable
 *  declarations/attributes, and other compiler dependent labels.
 * ----------------------------------------------------------------------------- */

/* template workaround for compilers that cannot correctly implement the C++ standard */
#ifndef SWIGTEMPLATEDISAMBIGUATOR
# if defined(__SUNPRO_CC) && (__SUNPRO_CC <= 0x560)
#  define SWIGTEMPLATEDISAMBIGUATOR template
# elif defined(__HP_aCC)
/* Needed even with `aCC -AA' when `aCC -V' reports HP ANSI C++ B3910B A.03.55 */
/* If we find a maximum version that requires this, the test would be __HP_aCC <= 35500 for A.03.55 */
#  define SWIGTEMPLATEDISAMBIGUATOR template
# else
#  define SWIGTEMPLATEDISAMBIGUATOR
# endif
#endif

/* inline attribute */
#ifndef SWIGINLINE
# if defined(__cplusplus) || (defined(__GNUC__) && !defined(__STRICT_ANSI__))
#   define SWIGINLINE inline
# else
#   define SWIGINLINE
# endif
#endif

/* attribute recognised by some compilers to avoid 'unused' warnings */
#ifndef SWIGUNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define SWIGUNUSED __attribute__ ((__unused__))
#   else
#     define SWIGUNUSED
#   endif
# elif defined(__ICC)
#   define SWIGUNUSED __attribute__ ((__unused__))
# else
#   define SWIGUNUSED
# endif
#endif

#ifndef SWIG_MSC_UNSUPPRESS_4505
# if defined(_MSC_VER)
#   pragma warning(disable : 4505) /* unreferenced local function has been removed */
# endif
#endif

#ifndef SWIGUNUSEDPARM
# ifdef __cplusplus
#   define SWIGUNUSEDPARM(p)
# else
#   define SWIGUNUSEDPARM(p) p SWIGUNUSED
# endif
#endif

/* internal SWIG method */
#ifndef SWIGINTERN
# define SWIGINTERN static SWIGUNUSED
#endif

/* internal inline SWIG method */
#ifndef SWIGINTERNINLINE
# define SWIGINTERNINLINE SWIGINTERN SWIGINLINE
#endif

/* exporting methods */
#if defined(__GNUC__)
#  if (__GNUC__ >= 4) || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4)
#    ifndef GCC_HASCLASSVISIBILITY
#      define GCC_HASCLASSVISIBILITY
#    endif
#  endif
#endif

#ifndef SWIGEXPORT
# if defined(_WIN32) || defined(__WIN32__) || defined(__CYGWIN__)
#   if defined(STATIC_LINKED)
#     define SWIGEXPORT
#   else
#     define SWIGEXPORT __declspec(dllexport)
#   endif
# else
#   if defined(__GNUC__) && defined(GCC_HASCLASSVISIBILITY)
#     define SWIGEXPORT __attribute__ ((visibility("default")))
#   else
#     define SWIGEXPORT
#   endif
# endif
#endif

/* calling conventions for Windows */
#ifndef SWIGSTDCALL
# if defined(_WIN32) || defined(__WIN32__)
#   define SWIGSTDCALL __stdcall
# else
#   define SWIGSTDCALL
# endif
#endif

/* Deal with Microsoft's attempt at deprecating C standard runtime functions */
#if !defined(SWIG_NO_CRT_SECURE_NO_DEPRECATE) && defined(_MSC_VER) && !defined(_CRT_SECURE_NO_DEPRECATE)
# define _CRT_SECURE_NO_DEPRECATE
#endif

/* Deal with Microsoft's attempt at deprecating methods in the standard C++ library */
#if !defined(SWIG_NO_SCL_SECURE_NO_DEPRECATE) && defined(_MSC_VER) && !defined(_SCL_SECURE_NO_DEPRECATE)
# define _SCL_SECURE_NO_DEPRECATE
#endif

/* Deal with Apple's deprecated 'AssertMacros.h' from Carbon-framework */
#if defined(__APPLE__) && !defined(__ASSERT_MACROS_DEFINE_VERSIONS_WITHOUT_UNDERSCORES)
# define __ASSERT_MACROS_DEFINE_VERSIONS_WITHOUT_UNDERSCORES 0
#endif

/* Intel's compiler complains if a variable which was never initialised is
 * cast to void, which is a common idiom which we use to indicate that we
 * are aware a variable isn't used.  So we just silence that warning.
 * See: https://github.com/swig/swig/issues/192 for more discussion.
 */
#ifdef __INTEL_COMPILER
# pragma warning disable 592
#endif

#if defined(__cplusplus) && __cplusplus >=201103L
# define SWIG_NOEXCEPT noexcept
#else
# define SWIG_NOEXCEPT throw()
#endif 

/* -----------------------------------------------------------------------------
 * swigcompat.swg
 *
 * Macros to provide support compatibility with older C and C++ standards.
 *
 * Note that SWIG expects __cplusplus to be defined to the appropriate C++ standard.
 * MSVC users are urged to check and examine the /Zc:__cplusplus compiler option.
 * See https://learn.microsoft.com/en-us/cpp/build/reference/zc-cplusplus.
 * ----------------------------------------------------------------------------- */

/* C99 and C++11 should provide snprintf, but define SWIG_NO_SNPRINTF
 * if you're missing it.
 */
#if ((defined __STDC_VERSION__ && __STDC_VERSION__ >= 199901L) || \
     (defined __cplusplus && __cplusplus >= 201103L) || \
     defined SWIG_HAVE_SNPRINTF) && \
    !defined SWIG_NO_SNPRINTF
# define SWIG_snprintf(O,S,F,A) snprintf(O,S,F,A)
# define SWIG_snprintf2(O,S,F,A,B) snprintf(O,S,F,A,B)
#else
/* Fallback versions ignore the buffer size, but most of our uses either have a
 * fixed maximum possible size or dynamically allocate a buffer that's large
 * enough.
 */
# define SWIG_snprintf(O,S,F,A) sprintf(O,F,A)
# define SWIG_snprintf2(O,S,F,A,B) sprintf(O,F,A,B)
#endif


#if defined(__GNUC__) && defined(_WIN32) && !defined(SWIG_PYTHON_NO_HYPOT_WORKAROUND)
/* Workaround for '::hypot' has not been declared', see https://bugs.python.org/issue11566 */
# include <math.h>
#endif

#if !defined(PY_SSIZE_T_CLEAN) && !defined(SWIG_NO_PY_SSIZE_T_CLEAN)
#define PY_SSIZE_T_CLEAN
#endif

#if __GNUC__ >= 7
#pragma GCC diagnostic push
#if defined(__cplusplus) && __cplusplus >=201703L
#pragma GCC diagnostic ignored "-Wregister" /* For python-2.7 headers that use register */
#endif
#endif

#if defined(_DEBUG) && defined(SWIG_PYTHON_INTERPRETER_NO_DEBUG)
/* Use debug wrappers with the Python release dll */

#if defined(_MSC_VER) && _MSC_VER >= 1929
/* Workaround compilation errors when redefining _DEBUG in MSVC 2019 version 16.10 and later
 * See https://github.com/swig/swig/issues/2090 */
# include <corecrt.h>
#endif

# undef _DEBUG
# include <Python.h>
# define _DEBUG 1
#else
# include <Python.h>
#endif


#if __GNUC__ >= 7
#pragma GCC diagnostic pop
#endif

#include <stdio.h>
#include <stdlib.h>

/* -----------------------------------------------------------------------------
 * swigrun.swg
 *
 * This file contains generic C API SWIG runtime support for pointer
 * type checking.
 * ----------------------------------------------------------------------------- */

/* This should only be incremented when either the layout of swig_type_info changes,
   or for whatever reason, the runtime changes incompatibly */
#define SWIG_RUNTIME_VERSION "5"

/* define SWIG_TYPE_TABLE_NAME as "SWIG_TYPE_TABLE" */
#ifdef SWIG_TYPE_TABLE
# define SWIG_QUOTE_STRING(x) #x
# define SWIG_EXPAND_AND_QUOTE_STRING(x) SWIG_QUOTE_STRING(x)
# define SWIG_TYPE_TABLE_NAME SWIG_EXPAND_AND_QUOTE_STRING(SWIG_TYPE_TABLE)
#else
# define SWIG_TYPE_TABLE_NAME
#endif

/*
  You can use the SWIGRUNTIME and SWIGRUNTIMEINLINE macros for
  creating a static or dynamic library from the SWIG runtime code.
  In 99.9% of the cases, SWIG just needs to declare them as 'static'.

  But only do this if strictly necessary, ie, if you have problems
  with your compiler or suchlike.
*/

#ifndef SWIGRUNTIME
# define SWIGRUNTIME SWIGINTERN
#endif

#ifndef SWIGRUNTIMEINLINE
# define SWIGRUNTIMEINLINE SWIGRUNTIME SWIGINLINE
#endif

/*  Generic buffer size */
#ifndef SWIG_BUFFER_SIZE
# define SWIG_BUFFER_SIZE 1024
#endif

/* Flags for pointer conversions */
#define SWIG_POINTER_DISOWN        0x1
#define SWIG_CAST_NEW_MEMORY       0x2
#define SWIG_POINTER_NO_NULL       0x4
#define SWIG_POINTER_CLEAR         0x8
#define SWIG_POINTER_RELEASE       (SWIG_POINTER_CLEAR | SWIG_POINTER_DISOWN)

/* Flags for new pointer objects */
#define SWIG_POINTER_OWN           0x1


/*
   Flags/methods for returning states.

   The SWIG conversion methods, as ConvertPtr, return an integer
   that tells if the conversion was successful or not. And if not,
   an error code can be returned (see swigerrors.swg for the codes).

   Use the following macros/flags to set or process the returning
   states.

   In old versions of SWIG, code such as the following was usually written:

     if (SWIG_ConvertPtr(obj,vptr,ty.flags) != -1) {
       // success code
     } else {
       //fail code
     }

   Now you can be more explicit:

    int res = SWIG_ConvertPtr(obj,vptr,ty.flags);
    if (SWIG_IsOK(res)) {
      // success code
    } else {
      // fail code
    }

   which is the same really, but now you can also do

    Type *ptr;
    int res = SWIG_ConvertPtr(obj,(void **)(&ptr),ty.flags);
    if (SWIG_IsOK(res)) {
      // success code
      if (SWIG_IsNewObj(res) {
        ...
	delete *ptr;
      } else {
        ...
      }
    } else {
      // fail code
    }

   I.e., now SWIG_ConvertPtr can return new objects and you can
   identify the case and take care of the deallocation. Of course that
   also requires SWIG_ConvertPtr to return new result values, such as

      int SWIG_ConvertPtr(obj, ptr,...) {
        if (<obj is ok>) {
          if (<need new object>) {
            *ptr = <ptr to new allocated object>;
            return SWIG_NEWOBJ;
          } else {
            *ptr = <ptr to old object>;
            return SWIG_OLDOBJ;
          }
        } else {
          return SWIG_BADOBJ;
        }
      }

   Of course, returning the plain '0(success)/-1(fail)' still works, but you can be
   more explicit by returning SWIG_BADOBJ, SWIG_ERROR or any of the
   SWIG errors code.

   Finally, if the SWIG_CASTRANK_MODE is enabled, the result code
   allows returning the 'cast rank', for example, if you have this

       int food(double)
       int fooi(int);

   and you call

      food(1)   // cast rank '1'  (1 -> 1.0)
      fooi(1)   // cast rank '0'

   just use the SWIG_AddCast()/SWIG_CheckState()
*/

#define SWIG_OK                    (0)
/* Runtime errors are < 0 */
#define SWIG_ERROR                 (-1)
/* Errors in range -1 to -99 are in swigerrors.swg (errors for all languages including those not using the runtime) */
/* Errors in range -100 to -199 are language specific errors defined in *errors.swg */
/* Errors < -200 are generic runtime specific errors */
#define SWIG_ERROR_RELEASE_NOT_OWNED (-200)

#define SWIG_IsOK(r)               (r >= 0)
#define SWIG_ArgError(r)           ((r != SWIG_ERROR) ? r : SWIG_TypeError)

/* The CastRankLimit says how many bits are used for the cast rank */
#define SWIG_CASTRANKLIMIT         (1 << 8)
/* The NewMask denotes the object was created (using new/malloc) */
#define SWIG_NEWOBJMASK            (SWIG_CASTRANKLIMIT  << 1)
/* The TmpMask is for in/out typemaps that use temporary objects */
#define SWIG_TMPOBJMASK            (SWIG_NEWOBJMASK << 1)
/* Simple returning values */
#define SWIG_BADOBJ                (SWIG_ERROR)
#define SWIG_OLDOBJ                (SWIG_OK)
#define SWIG_NEWOBJ                (SWIG_OK | SWIG_NEWOBJMASK)
#define SWIG_TMPOBJ                (SWIG_OK | SWIG_TMPOBJMASK)
/* Check, add and del object mask methods */
#define SWIG_AddNewMask(r)         (SWIG_IsOK(r) ? (r | SWIG_NEWOBJMASK) : r)
#define SWIG_DelNewMask(r)         (SWIG_IsOK(r) ? (r & ~SWIG_NEWOBJMASK) : r)
#define SWIG_IsNewObj(r)           (SWIG_IsOK(r) && (r & SWIG_NEWOBJMASK))
#define SWIG_AddTmpMask(r)         (SWIG_IsOK(r) ? (r | SWIG_TMPOBJMASK) : r)
#define SWIG_DelTmpMask(r)         (SWIG_IsOK(r) ? (r & ~SWIG_TMPOBJMASK) : r)
#define SWIG_IsTmpObj(r)           (SWIG_IsOK(r) && (r & SWIG_TMPOBJMASK))

/* Cast-Rank Mode */
#if defined(SWIG_CASTRANK_MODE)
#  ifndef SWIG_TypeRank
#    define SWIG_TypeRank             unsigned long
#  endif
#  ifndef SWIG_MAXCASTRANK            /* Default cast allowed */
#    define SWIG_MAXCASTRANK          (2)
#  endif
#  define SWIG_CASTRANKMASK          ((SWIG_CASTRANKLIMIT) -1)
#  define SWIG_CastRank(r)           (r & SWIG_CASTRANKMASK)
SWIGINTERNINLINE int SWIG_AddCast(int r) {
  return SWIG_IsOK(r) ? ((SWIG_CastRank(r) < SWIG_MAXCASTRANK) ? (r + 1) : SWIG_ERROR) : r;
}
SWIGINTERNINLINE int SWIG_CheckState(int r) {
  return SWIG_IsOK(r) ? SWIG_CastRank(r) + 1 : 0;
}
#else /* no cast-rank mode */
#  define SWIG_AddCast(r) (r)
#  define SWIG_CheckState(r) (SWIG_IsOK(r) ? 1 : 0)
#endif


#include <string.h>

#ifdef __cplusplus
extern "C" {
#endif

typedef void *(*swig_converter_func)(void *, int *);
typedef struct swig_type_info *(*swig_dycast_func)(void **);

/* Structure to store information on one type */
typedef struct swig_type_info {
  const char             *name;			/* mangled name of this type */
  const char             *str;			/* human readable name of this type */
  swig_dycast_func        dcast;		/* dynamic cast function down a hierarchy */
  struct swig_cast_info  *cast;			/* linked list of types that can cast into this type */
  void                   *clientdata;		/* language specific type data */
  int                    owndata;		/* flag if the structure owns the clientdata */
} swig_type_info;

/* Structure to store a type and conversion function used for casting */
typedef struct swig_cast_info {
  swig_type_info         *type;			/* pointer to type that is equivalent to this type */
  swig_converter_func     converter;		/* function to cast the void pointers */
  struct swig_cast_info  *next;			/* pointer to next array of casts | pointer to cast hashed by value */
  unsigned int            value;		/* index of the last valid element in the array | typename hash value */
} swig_cast_info;

/* Structure used to store module information
 * Each module generates one structure like this, and the runtime collects
 * all of these structures and stores them in a circularly linked list.*/
typedef struct swig_module_info {
  swig_type_info         **types;		/* Array of pointers to swig_type_info structures that are in this module */
  size_t                 size;		        /* Number of types in this module */
  struct swig_module_info *next;		/* Pointer to next element in circularly linked list */
  swig_type_info         **type_initial;	/* Array of initially generated type structures */
  swig_cast_info         **cast_initial;	/* Array of initially generated casting structures */
  void                    *clientdata;		/* Language specific module data */
} swig_module_info;

/*
  Compare two type names skipping the space characters, therefore
  "char*" == "char *" and "Class<int>" == "Class<int >", etc.

  Return 0 when the two name types are equivalent, as in
  strncmp, but skipping ' '.
*/
SWIGRUNTIME int
SWIG_TypeNameComp(const char *f1, const char *l1,
		  const char *f2, const char *l2) {
  for (;(f1 != l1) && (f2 != l2); ++f1, ++f2) {
    while ((*f1 == ' ') && (f1 != l1)) ++f1;
    while ((*f2 == ' ') && (f2 != l2)) ++f2;
    if (*f1 != *f2) return (*f1 > *f2) ? 1 : -1;
  }
  return (int)((l1 - f1) - (l2 - f2));
}

/*
  Check type equivalence in a name list like <name1>|<name2>|...
  Return 0 if equal, -1 if nb < tb, 1 if nb > tb
*/
SWIGRUNTIME int
SWIG_TypeCmp(const char *nb, const char *tb) {
  int equiv = 1;
  const char* te = tb + strlen(tb);
  const char* ne = nb;
  while (equiv != 0 && *ne) {
    for (nb = ne; *ne; ++ne) {
      if (*ne == '|') break;
    }
    equiv = SWIG_TypeNameComp(nb, ne, tb, te);
    if (*ne) ++ne;
  }
  return equiv;
}

/*
  Check type equivalence in a name list like <name1>|<name2>|...
  Return 0 if not equal, 1 if equal
*/
SWIGRUNTIME int
SWIG_TypeEquiv(const char *nb, const char *tb) {
  return SWIG_TypeCmp(nb, tb) == 0 ? 1 : 0;
}

/*
 * Hash function for type name strings, based on maRushPrime1Hash (http://amsoftware.narod.ru/algo2.html)
 */
SWIGRUNTIME unsigned int SWIG_Hash(const char *str, unsigned int len) {
  const unsigned char *data = (const unsigned char *)str;
  unsigned int hash = len, i = 0, k;
  int rem = (int)len;

  while (rem >= (int)sizeof(unsigned int)) {
    memcpy(&k, data, sizeof(unsigned int));
    k += i++;
    hash ^= k;
    hash *= 171717;
    data += sizeof(unsigned int);
    rem -= sizeof(unsigned int);
  }

  switch (rem) {
    case 3: k = (unsigned int)(data[2]) << 16;
            k |= (unsigned int)(data[1]) << 8;
            k |= (unsigned int)(data[0]);
            k += i++;
            hash ^= k;
            hash *= 171717;
            break;
    case 2: k = (unsigned int)(data[1]) << 8;
            k |= (unsigned int)(data[0]);
            k += i++;
            hash ^= k;
            hash *= 171717;
            break;
    case 1: k = (unsigned int)(data[0]);
            k += i++;
            hash ^= k;
            hash *= 171717;
            break;
  }
  return hash;
}

/*
  Check the typename
*/
SWIGRUNTIME swig_cast_info *
SWIG_TypeCheck(const char *c, swig_type_info *ty) {
  static const unsigned int scan_threshold = 4;
  if (ty) {
    swig_cast_info *head = ty->cast;
    unsigned int hash_value = 0;
    int hashed = 0;

    while (head) {

      if (strcmp(head->type->name, c) == 0) {
        return head;
      }

      if (head->value) {
        swig_cast_info *iter;
        swig_cast_info *last = head + head->value;
        swig_cast_info *first = head + 1;
        int search = 1;

        if (!hashed) {
          if (head->value < scan_threshold) {
            for (iter = first; iter <= last; iter++) {
              if (strcmp(iter->type->name, c) == 0) {
                return iter;
              }
            }
            search = 0;
          } else {
            hashed = 1;
            hash_value = SWIG_Hash(c, (unsigned int)strlen(c));
          }
        }

        if (search) {
          /* Binary search over sorted <'next'|'value'> pairs */
          do {
            iter = first + ((last - first) >> 1);
            if (iter->value < hash_value) {
              first = iter + 1;
            } else if (iter->value == hash_value) {

              if (strcmp(iter->next->type->name, c) == 0) {
                return iter->next;
              }

              /* Hash collision check */
              for (last = iter + 1; last->next && last->value == hash_value; last++) {
                if (strcmp(last->next->type->name, c) == 0) {
                  return last->next;
                }
              }
              for (first = iter - 1; first != head && first->value == hash_value; first--) {
                if (strcmp(first->next->type->name, c) == 0) {
                  return first->next;
                }
              }
              break;
            } else
              last = iter - 1;
          } while (first <= last);
        }
      }
      head = head->next;
    }
  }
  return 0;
}

/*
  Check the type by type address
*/
SWIGRUNTIME swig_cast_info *
SWIG_TypeCheckStruct(const swig_type_info *from, swig_type_info *ty) {
  if (ty) {
    swig_cast_info *head = ty->cast;
    while (head) {
      if (head->type == from) {
        return head;
      }

      if (head->value) {
        swig_cast_info *iter;
        swig_cast_info *last = head + head->value;
        swig_cast_info *first = head + 1;

        /* Binary search over sorted array of casts */
        do {
          iter = first + ((last - first) >> 1);
          if (iter->type < from) {
            first = iter + 1;
          } else if (iter->type == from) {
            return iter;
          } else
            last = iter - 1;
        } while (first <= last);
      }
      head = head->next;
    }
  }
  return 0;
}

/*
  Cast a pointer up an inheritance hierarchy
*/
SWIGRUNTIMEINLINE void *
SWIG_TypeCast(swig_cast_info *ty, void *ptr, int *newmemory) {
  return ((!ty) || (!ty->converter)) ? ptr : (*ty->converter)(ptr, newmemory);
}

/*
   Dynamic pointer casting. Down an inheritance hierarchy
*/
SWIGRUNTIME swig_type_info *
SWIG_TypeDynamicCast(swig_type_info *ty, void **ptr) {
  swig_type_info *lastty = ty;
  if (!ty || !ty->dcast) return ty;
  while (ty && (ty->dcast)) {
    ty = (*ty->dcast)(ptr);
    if (ty) lastty = ty;
  }
  return lastty;
}

/*
  Return the name associated with this type
*/
SWIGRUNTIMEINLINE const char *
SWIG_TypeName(const swig_type_info *ty) {
  return ty->name;
}

/*
  Return the pretty name associated with this type,
  that is an unmangled type name in a form presentable to the user.
*/
SWIGRUNTIME const char *
SWIG_TypePrettyName(const swig_type_info *type) {
  /* The "str" field contains the equivalent pretty names of the
     type, separated by vertical-bar characters.  Choose the last
     name. It should be the most specific; a fully resolved name
     but not necessarily with default template parameters expanded. */
  if (!type) return NULL;
  if (type->str != NULL) {
    const char *last_name = type->str;
    const char *s;
    for (s = type->str; *s; s++)
      if (*s == '|') last_name = s+1;
    return last_name;
  }
  else
    return type->name;
}

/*
   Set the clientdata field for a type
*/
SWIGRUNTIME void
SWIG_TypeClientData(swig_type_info *ti, void *clientdata) {
  swig_cast_info *head = ti->cast;
  /* if (ti->clientdata == clientdata) return; */
  ti->clientdata = clientdata;

  while (head) {
    swig_cast_info *cast;
    for (cast = head; (cast - head) <= head->value; cast++) {
      if (!cast->converter) {
        swig_type_info *tc = cast->type;
        if (!tc->clientdata) {
          SWIG_TypeClientData(tc, clientdata);
        }
      }
    }
    head = head->next;
  }
}

SWIGRUNTIME void
SWIG_TypeNewClientData(swig_type_info *ti, void *clientdata) {
  SWIG_TypeClientData(ti, clientdata);
  ti->owndata = 1;
}

/*
  Search for a swig_type_info structure only by mangled name
  Search is a O(log #types)

  We start searching at module start, and finish searching when start == end.
  Note: if start == end at the beginning of the function, we go all the way around
  the circular list.
*/
SWIGRUNTIME swig_type_info *
SWIG_MangledTypeQueryModule(swig_module_info *start,
                            swig_module_info *end,
		            const char *name) {
  swig_module_info *iter = start;
  do {
    if (iter->size) {
      size_t l = 0;
      size_t r = iter->size - 1;
      do {
	/* since l+r >= 0, we can (>> 1) instead (/ 2) */
	size_t i = (l + r) >> 1;
	const char *iname = iter->types[i]->name;
	if (iname) {
	  int compare = strcmp(name, iname);
	  if (compare == 0) {
	    return iter->types[i];
	  } else if (compare < 0) {
	    if (i) {
	      r = i - 1;
	    } else {
	      break;
	    }
	  } else if (compare > 0) {
	    l = i + 1;
	  }
	} else {
	  break; /* should never happen */
	}
      } while (l <= r);
    }
    iter = iter->next;
  } while (iter != end);
  return 0;
}

/*
  Search for a swig_type_info structure for either a mangled name or a human readable name.
  It first searches the mangled names of the types, which is a O(log #types)
  If a type is not found it then searches the human readable names, which is O(#types).

  We start searching at module start, and finish searching when start == end.
  Note: if start == end at the beginning of the function, we go all the way around
  the circular list.
*/
SWIGRUNTIME swig_type_info *
SWIG_TypeQueryModule(swig_module_info *start,
                     swig_module_info *end,
		     const char *name) {
  /* STEP 1: Search the name field using binary search */
  swig_type_info *ret = SWIG_MangledTypeQueryModule(start, end, name);
  if (ret) {
    return ret;
  } else {
    /* STEP 2: If the type hasn't been found, do a complete search
       of the str field (the human readable name) */
    swig_module_info *iter = start;
    do {
      size_t i = 0;
      for (; i < iter->size; ++i) {
	if (iter->types[i]->str && (SWIG_TypeEquiv(iter->types[i]->str, name)))
	  return iter->types[i];
      }
      iter = iter->next;
    } while (iter != end);
  }

  /* neither found a match */
  return 0;
}

/*
   Pack binary data into a string
*/
SWIGRUNTIME char *
SWIG_PackData(char *c, void *ptr, size_t sz) {
  static const char hex[17] = "0123456789abcdef";
  const unsigned char *u = (unsigned char *) ptr;
  const unsigned char *eu =  u + sz;
  for (; u != eu; ++u) {
    unsigned char uu = *u;
    *(c++) = hex[(uu & 0xf0) >> 4];
    *(c++) = hex[uu & 0xf];
  }
  return c;
}

/*
   Unpack binary data from a string
*/
SWIGRUNTIME const char *
SWIG_UnpackData(const char *c, void *ptr, size_t sz) {
  unsigned char *u = (unsigned char *) ptr;
  const unsigned char *eu = u + sz;
  for (; u != eu; ++u) {
    char d = *(c++);
    unsigned char uu;
    if ((d >= '0') && (d <= '9'))
      uu = (unsigned char)((d - '0') << 4);
    else if ((d >= 'a') && (d <= 'f'))
      uu = (unsigned char)((d - ('a'-10)) << 4);
    else
      return (char *) 0;
    d = *(c++);
    if ((d >= '0') && (d <= '9'))
      uu |= (unsigned char)(d - '0');
    else if ((d >= 'a') && (d <= 'f'))
      uu |= (unsigned char)(d - ('a'-10));
    else
      return (char *) 0;
    *u = uu;
  }
  return c;
}

/*
   Pack 'void *' into a string buffer.
*/
SWIGRUNTIME char *
SWIG_PackVoidPtr(char *buff, void *ptr, const char *name, size_t bsz) {
  char *r = buff;
  if ((2*sizeof(void *) + 2) > bsz) return 0;
  *(r++) = '_';
  r = SWIG_PackData(r,&ptr,sizeof(void *));
  if (strlen(name) + 1 > (bsz - (r - buff))) return 0;
  strcpy(r,name);
  return buff;
}

SWIGRUNTIME const char *
SWIG_UnpackVoidPtr(const char *c, void **ptr, const char *name) {
  if (*c != '_') {
    if (strcmp(c,"NULL") == 0) {
      *ptr = (void *) 0;
      return name;
    } else {
      return 0;
    }
  }
  return SWIG_UnpackData(++c,ptr,sizeof(void *));
}

SWIGRUNTIME char *
SWIG_PackDataName(char *buff, void *ptr, size_t sz, const char *name, size_t bsz) {
  char *r = buff;
  size_t lname = (name ? strlen(name) : 0);
  if ((2*sz + 2 + lname) > bsz) return 0;
  *(r++) = '_';
  r = SWIG_PackData(r,ptr,sz);
  if (lname) {
    strncpy(r,name,lname+1);
  } else {
    *r = 0;
  }
  return buff;
}

SWIGRUNTIME const char *
SWIG_UnpackDataName(const char *c, void *ptr, size_t sz, const char *name) {
  if (*c != '_') {
    if (strcmp(c,"NULL") == 0) {
      memset(ptr,0,sz);
      return name;
    } else {
      return 0;
    }
  }
  return SWIG_UnpackData(++c,ptr,sz);
}

#ifdef __cplusplus
}
#endif

/* SWIG Errors applicable to all language modules, values are reserved from -1 to -99 */
#define  SWIG_UnknownError    	   -1
#define  SWIG_IOError        	   -2
#define  SWIG_RuntimeError   	   -3
#define  SWIG_IndexError     	   -4
#define  SWIG_TypeError      	   -5
#define  SWIG_DivisionByZero 	   -6
#define  SWIG_OverflowError  	   -7
#define  SWIG_SyntaxError    	   -8
#define  SWIG_ValueError     	   -9
#define  SWIG_SystemError    	   -10
#define  SWIG_AttributeError 	   -11
#define  SWIG_MemoryError    	   -12
#define  SWIG_NullReferenceError   -13


#if PY_VERSION_HEX >= 0x03030000 && !defined(SWIG_NO_HEAPTYPES)
#if !defined(SWIG_HEAPTYPES)
#define SWIG_HEAPTYPES
#endif
#endif

/* Compatibility macros for Python 3 */
#if PY_VERSION_HEX >= 0x03000000

#define PyClass_Check(obj) PyObject_IsInstance(obj, (PyObject *)&PyType_Type)
#define PyInt_Check(x) PyLong_Check(x)
#define PyInt_AsLong(x) PyLong_AsLong(x)
#define PyInt_FromLong(x) PyLong_FromLong(x)
#define PyInt_FromSize_t(x) PyLong_FromSize_t(x)
#define PyString_Check(name) PyBytes_Check(name)
#define PyString_FromString(x) PyUnicode_FromString(x)
#define PyString_Format(fmt, args)  PyUnicode_Format(fmt, args)
#define PyString_AsString(str) PyBytes_AsString(str)
#define PyString_Size(str) PyBytes_Size(str)	
#define PyString_InternFromString(key) PyUnicode_InternFromString(key)
#define Py_TPFLAGS_HAVE_CLASS Py_TPFLAGS_BASETYPE
#define _PyLong_FromSsize_t(x) PyLong_FromSsize_t(x)

#endif

/* SWIG APIs for compatibility of both Python 2 & 3 */

#if PY_VERSION_HEX >= 0x03000000
#  define SWIG_Python_str_FromFormat PyUnicode_FromFormat
#else
#  define SWIG_Python_str_FromFormat PyString_FromFormat
#endif

#if defined(SWIG_HEAPTYPES)
#if PY_VERSION_HEX < 0x030c0000
#include <structmember.h>
#define Py_READONLY READONLY
#define Py_T_PYSSIZET T_PYSSIZET
#endif
#endif

#include <stddef.h> /* For offsetof */


/* Wrapper around PyUnicode_AsUTF8AndSize - call Py_XDECREF on the returned pbytes when finished with the returned string */
SWIGINTERN const char *
SWIG_PyUnicode_AsUTF8AndSize(PyObject *str, Py_ssize_t *psize, PyObject **pbytes)
{
#if PY_VERSION_HEX >= 0x03030000
# if !defined(Py_LIMITED_API) || Py_LIMITED_API+0 >= 0x030A0000
  *pbytes = NULL;
  return PyUnicode_AsUTF8AndSize(str, psize);
# else
  const char *chars;
  *pbytes = PyUnicode_AsUTF8String(str);
  chars = *pbytes ? PyBytes_AsString(*pbytes) : NULL;
  if (chars && psize)
    *psize = PyBytes_Size(*pbytes);
  return chars;
# endif
#else
  char *chars = NULL;
  *pbytes = NULL;
  PyString_AsStringAndSize(str, &chars, psize);
  return chars;
#endif
}

SWIGINTERN PyObject *
SWIG_Python_str_FromChar(const char *c)
{
#if PY_VERSION_HEX >= 0x03000000
  return PyUnicode_FromString(c); 
#else
  return PyString_FromString(c);
#endif
}

#define SWIG_RUNTIME_MODULE "swig_runtime_data" SWIG_RUNTIME_VERSION

/* SWIGPY_USE_CAPSULE is no longer used within SWIG itself, but some user interface files check for it. */
# define SWIGPY_USE_CAPSULE
#ifdef SWIGPYTHON_BUILTIN
# define SWIGPY_CAPSULE_ATTR_NAME "type_pointer_capsule_builtin" SWIG_TYPE_TABLE_NAME
#else
# define SWIGPY_CAPSULE_ATTR_NAME "type_pointer_capsule" SWIG_TYPE_TABLE_NAME
#endif
#define SWIGPY_CAPSULE_NAME SWIG_RUNTIME_MODULE "." SWIGPY_CAPSULE_ATTR_NAME

#if PY_VERSION_HEX < 0x03020000
#define PyDescr_TYPE(x) (((PyDescrObject *)(x))->d_type)
#define PyDescr_NAME(x) (((PyDescrObject *)(x))->d_name)
#define Py_hash_t long
#endif

#if defined(Py_LIMITED_API)
# define PyTuple_GET_ITEM PyTuple_GetItem
/* Note that PyTuple_SetItem() has different semantics from PyTuple_SET_ITEM as it decref's the original tuple item, so in general they cannot be used
  interchangeably. However in SWIG-generated code PyTuple_SET_ITEM is only used with newly initialized tuples without any items and for them this does work. */
# define PyTuple_SET_ITEM PyTuple_SetItem
# define PyTuple_GET_SIZE PyTuple_Size
# define PyCFunction_GET_FLAGS PyCFunction_GetFlags
# define PyCFunction_GET_FUNCTION PyCFunction_GetFunction
# define PyCFunction_GET_SELF PyCFunction_GetSelf
# define PyList_GET_ITEM PyList_GetItem
# define PyList_SET_ITEM PyList_SetItem
# define PySliceObject PyObject
#endif

/* Increment and Decrement wrappers - for portability when using the stable abi and for performance otherwise */
#ifdef Py_LIMITED_API
# define SWIG_Py_INCREF Py_IncRef
# define SWIG_Py_XINCREF Py_IncRef
# define SWIG_Py_DECREF Py_DecRef
# define SWIG_Py_XDECREF Py_DecRef
#else
# define SWIG_Py_INCREF Py_INCREF
# define SWIG_Py_XINCREF Py_XINCREF
# define SWIG_Py_DECREF Py_DECREF
# define SWIG_Py_XDECREF Py_XDECREF
#endif

#if PY_VERSION_HEX >= 0x03000000
#if (PY_VERSION_HEX >= 0x030d00a6) && (!defined(Py_LIMITED_API) || Py_LIMITED_API+0 >= 0x030d00a6)
# define SWIG_PyType_GetFullyQualifiedName PyType_GetFullyQualifiedName
#else
SWIGINTERN PyObject *
SWIG_PyType_GetFullyQualifiedName(PyTypeObject *type) {
  PyObject *result = NULL;
  PyObject *qualname = PyObject_GetAttrString((PyObject *)type, "__qualname__");
  if (qualname) {
    PyObject *mod = PyObject_GetAttrString((PyObject *)type, "__module__");
    if (mod) {
      if (PyUnicode_Check(mod) && PyUnicode_CompareWithASCIIString(mod, "builtins") && PyUnicode_CompareWithASCIIString(mod, "__main__")) {
        result = PyUnicode_FromFormat("%U%c%U", mod, '.', qualname);
        SWIG_Py_DECREF(qualname);
      } else {
        result = qualname;
      }
      SWIG_Py_DECREF(mod);
    } else {
      result = qualname;
    }
  }

  return result;
}
#endif
#endif

/* gh-114329 added PyList_GetItemRef() to Python 3.13.0a4 */
#if (PY_VERSION_HEX >= 0x030d00a4) && (!defined(Py_LIMITED_API) || Py_LIMITED_API+0 >= 0x030d00a4)
# define SWIG_PyList_GetItemRef PyList_GetItemRef
#else
SWIGINTERN PyObject *
SWIG_PyList_GetItemRef(PyObject *op, Py_ssize_t index) {
  PyObject *item = PyList_GetItem(op, index);
  Py_XINCREF(item);
  return item;
}
#endif

/* gh-106004 added PyDict_GetItemRef() and PyDict_GetItemStringRef() to Python 3.13.0a1
   functions are renamed here for compatibility with abi3audit */
#if (PY_VERSION_HEX >= 0x030d00a1) && (!defined(Py_LIMITED_API) || Py_LIMITED_API+0 >= 0x030d00a1)
# define SWIG_PyDict_GetItemRef PyDict_GetItemRef
# define SWIG_PyDict_GetItemStringRef PyDict_GetItemStringRef
#else
SWIGINTERN int
SWIG_PyDict_GetItemRef(PyObject *mp, PyObject *key, PyObject **result) {
#if PY_VERSION_HEX >= 0x03000000
  PyObject *item = PyDict_GetItemWithError(mp, key);
#else
  PyObject *item = _PyDict_GetItemWithError(mp, key);
#endif
  if (item != NULL) {
    *result = (PyObject *)(item);
    SWIG_Py_INCREF(*result);
    return 1;
  }
  if (!PyErr_Occurred()) {
    *result = NULL;
    return 0;
  }
  *result = NULL;
  return -1;
}

SWIGINTERN int
SWIG_PyDict_GetItemStringRef(PyObject *mp, const char *key, PyObject **result) {
  int res;
#if PY_VERSION_HEX >= 0x03000000
  PyObject *key_obj = PyUnicode_FromString(key);
#else
  PyObject *key_obj = PyString_FromString(key);
#endif
  if (key_obj == NULL) {
    *result = NULL;
    return -1;
  }
  res = SWIG_PyDict_GetItemRef(mp, key_obj, result);
  Py_DECREF(key_obj);
  return res;
}
#endif

/* -----------------------------------------------------------------------------
 * error manipulation
 * ----------------------------------------------------------------------------- */

SWIGRUNTIME PyObject*
SWIG_Python_ErrorType(int code) {
  PyObject* type = 0;
  switch(code) {
  case SWIG_MemoryError:
    type = PyExc_MemoryError;
    break;
  case SWIG_IOError:
    type = PyExc_IOError;
    break;
  case SWIG_RuntimeError:
    type = PyExc_RuntimeError;
    break;
  case SWIG_IndexError:
    type = PyExc_IndexError;
    break;
  case SWIG_TypeError:
    type = PyExc_TypeError;
    break;
  case SWIG_DivisionByZero:
    type = PyExc_ZeroDivisionError;
    break;
  case SWIG_OverflowError:
    type = PyExc_OverflowError;
    break;
  case SWIG_SyntaxError:
    type = PyExc_SyntaxError;
    break;
  case SWIG_ValueError:
    type = PyExc_ValueError;
    break;
  case SWIG_SystemError:
    type = PyExc_SystemError;
    break;
  case SWIG_AttributeError:
    type = PyExc_AttributeError;
    break;
  case SWIG_NullReferenceError:
    type = PyExc_TypeError;
    break;
  default:
    type = PyExc_RuntimeError;
  }
  return type;
}


SWIGRUNTIME void
SWIG_Python_AddErrorMsg(const char* mesg)
{
  PyObject *type = 0;
  PyObject *value = 0;
  PyObject *traceback = 0;

  if (PyErr_Occurred())
    PyErr_Fetch(&type, &value, &traceback);
  if (value) {
    PyObject *old_str = PyObject_Str(value);
    PyObject *bytes = NULL;
    const char *tmp = SWIG_PyUnicode_AsUTF8AndSize(old_str, NULL, &bytes);
    PyErr_Clear();
    SWIG_Py_XINCREF(type);
    if (tmp)
      PyErr_Format(type, "%s %s", tmp, mesg);
    else
      PyErr_Format(type, "%s", mesg);
    SWIG_Py_XDECREF(bytes);
    SWIG_Py_DECREF(old_str);
    SWIG_Py_DECREF(value);
  } else {
    PyErr_SetString(PyExc_RuntimeError, mesg);
  }
}

SWIGRUNTIME int
SWIG_Python_TypeErrorOccurred(PyObject *obj)
{
  PyObject *error;
  if (obj)
    return 0;
  error = PyErr_Occurred();
  return error && PyErr_GivenExceptionMatches(error, PyExc_TypeError);
}

SWIGRUNTIME void
SWIG_Python_RaiseOrModifyTypeError(const char *message)
{
  if (SWIG_Python_TypeErrorOccurred(NULL)) {
    /* Use existing TypeError to preserve stacktrace and enhance with given message */
    PyObject *newvalue;
    PyObject *type = NULL, *value = NULL, *traceback = NULL;
    PyErr_Fetch(&type, &value, &traceback);
#if PY_VERSION_HEX >= 0x03000000
    newvalue = PyUnicode_FromFormat("%S\nAdditional information:\n%s", value, message);
#else
    newvalue = PyString_FromFormat("%s\nAdditional information:\n%s", PyString_AsString(value), message);
#endif
    if (newvalue) {
      SWIG_Py_XDECREF(value);
      PyErr_Restore(type, newvalue, traceback);
    } else {
      PyErr_Restore(type, value, traceback);
    }
  } else {
    /* Raise TypeError using given message */
    PyErr_SetString(PyExc_TypeError, message);
  }
}

#if defined(SWIG_PYTHON_NO_THREADS)
#  if defined(SWIG_PYTHON_THREADS)
#    undef SWIG_PYTHON_THREADS
#  endif
#endif
#if defined(SWIG_PYTHON_THREADS) /* Threading support is enabled */
#  if !defined(SWIG_PYTHON_USE_GIL) && !defined(SWIG_PYTHON_NO_USE_GIL)
#    define SWIG_PYTHON_USE_GIL
#  endif
#  if defined(SWIG_PYTHON_USE_GIL) /* Use PyGILState threads calls */
#    if !defined(SWIG_PYTHON_INITIALIZE_THREADS)
#      if PY_VERSION_HEX < 0x03070000
#        define SWIG_PYTHON_INITIALIZE_THREADS PyEval_InitThreads()
#      else
#        define SWIG_PYTHON_INITIALIZE_THREADS
#      endif
#    endif
#    ifdef __cplusplus /* C++ code */
       class SWIG_Python_Thread_Block {
         bool status;
         PyGILState_STATE state;
       public:
         void end() { if (status) { PyGILState_Release(state); status = false;} }
         SWIG_Python_Thread_Block() : status(true), state(PyGILState_Ensure()) {}
         ~SWIG_Python_Thread_Block() { end(); }
       };
       class SWIG_Python_Thread_Allow {
         bool status;
         PyThreadState *save;
       public:
         void end() { if (status) { status = false; PyEval_RestoreThread(save); }}
         SWIG_Python_Thread_Allow() : status(true), save(PyEval_SaveThread()) {}
         ~SWIG_Python_Thread_Allow() { end(); }
       };
#      define SWIG_PYTHON_THREAD_BEGIN_BLOCK   SWIG_Python_Thread_Block _swig_thread_block
#      define SWIG_PYTHON_THREAD_END_BLOCK     _swig_thread_block.end()
#      define SWIG_PYTHON_THREAD_BEGIN_ALLOW   SWIG_Python_Thread_Allow _swig_thread_allow
#      define SWIG_PYTHON_THREAD_END_ALLOW     _swig_thread_allow.end()
#    else /* C code */
#      define SWIG_PYTHON_THREAD_BEGIN_BLOCK   PyGILState_STATE _swig_thread_block = PyGILState_Ensure()
#      define SWIG_PYTHON_THREAD_END_BLOCK     PyGILState_Release(_swig_thread_block)
#      define SWIG_PYTHON_THREAD_BEGIN_ALLOW   PyThreadState *_swig_thread_allow = PyEval_SaveThread()
#      define SWIG_PYTHON_THREAD_END_ALLOW     PyEval_RestoreThread(_swig_thread_allow)
#    endif
#  else /* Old thread way, not implemented, user must provide it */
#    if !defined(SWIG_PYTHON_INITIALIZE_THREADS)
#      define SWIG_PYTHON_INITIALIZE_THREADS
#    endif
#    if !defined(SWIG_PYTHON_THREAD_BEGIN_BLOCK)
#      define SWIG_PYTHON_THREAD_BEGIN_BLOCK
#    endif
#    if !defined(SWIG_PYTHON_THREAD_END_BLOCK)
#      define SWIG_PYTHON_THREAD_END_BLOCK
#    endif
#    if !defined(SWIG_PYTHON_THREAD_BEGIN_ALLOW)
#      define SWIG_PYTHON_THREAD_BEGIN_ALLOW
#    endif
#    if !defined(SWIG_PYTHON_THREAD_END_ALLOW)
#      define SWIG_PYTHON_THREAD_END_ALLOW
#    endif
#  endif
#else /* No thread support */
#  define SWIG_PYTHON_INITIALIZE_THREADS
#  define SWIG_PYTHON_THREAD_BEGIN_BLOCK
#  define SWIG_PYTHON_THREAD_END_BLOCK
#  define SWIG_PYTHON_THREAD_BEGIN_ALLOW
#  define SWIG_PYTHON_THREAD_END_ALLOW
#endif

/* -----------------------------------------------------------------------------
 * Python API portion that goes into the runtime
 * ----------------------------------------------------------------------------- */

#ifdef __cplusplus
extern "C" {
#endif

/* -----------------------------------------------------------------------------
 * Constant declarations
 * ----------------------------------------------------------------------------- */

/* Constant Types */
#define SWIG_PY_POINTER 4
#define SWIG_PY_BINARY  5

/* Constant information structure */
typedef struct swig_const_info {
  int type;
  const char *name;
  long lvalue;
  double dvalue;
  void   *pvalue;
  swig_type_info **ptype;
} swig_const_info;

#ifdef __cplusplus
}
#endif


/* -----------------------------------------------------------------------------
 * pyrun.swg
 *
 * This file contains the runtime support for Python modules
 * and includes code for managing global variables and pointer
 * type checking.
 *
 * ----------------------------------------------------------------------------- */

#if PY_VERSION_HEX < 0x02070000 /* 2.7.0 */
# error "This version of SWIG only supports Python >= 2.7"
#endif

#if PY_VERSION_HEX >= 0x03000000 && PY_VERSION_HEX < 0x03050000
# error "This version of SWIG only supports Python 3 >= 3.5"
#endif

/* Common SWIG API */

/* for raw pointers */
#define SWIG_Python_ConvertPtr(obj, pptr, type, flags)  SWIG_Python_ConvertPtrAndOwn(obj, pptr, type, flags, 0)
#define SWIG_ConvertPtr(obj, pptr, type, flags)         SWIG_Python_ConvertPtr(obj, pptr, type, flags)
#define SWIG_ConvertPtrAndOwn(obj,pptr,type,flags,own)  SWIG_Python_ConvertPtrAndOwn(obj, pptr, type, flags, own)

#ifdef SWIGPYTHON_BUILTIN
#define SWIG_NewPointerObj(ptr, type, flags)            SWIG_Python_NewPointerObj(self, ptr, type, flags)
#else
#define SWIG_NewPointerObj(ptr, type, flags)            SWIG_Python_NewPointerObj(NULL, ptr, type, flags)
#endif

#define SWIG_InternalNewPointerObj(ptr, type, flags)	SWIG_Python_NewPointerObj(NULL, ptr, type, flags)

#define SWIG_CheckImplicit(ty)                          SWIG_Python_CheckImplicit(ty) 
#define SWIG_AcquirePtr(ptr, src)                       SWIG_Python_AcquirePtr(ptr, src)
#define swig_owntype                                    int

/* for raw packed data */
#define SWIG_ConvertPacked(obj, ptr, sz, ty)            SWIG_Python_ConvertPacked(obj, ptr, sz, ty)
#define SWIG_NewPackedObj(ptr, sz, type)                SWIG_Python_NewPackedObj(ptr, sz, type)

/* for class or struct pointers */
#define SWIG_ConvertInstance(obj, pptr, type, flags)    SWIG_ConvertPtr(obj, pptr, type, flags)
#define SWIG_NewInstanceObj(ptr, type, flags)           SWIG_NewPointerObj(ptr, type, flags)

/* for C or C++ function pointers */
#define SWIG_ConvertFunctionPtr(obj, pptr, type)        SWIG_Python_ConvertFunctionPtr(obj, pptr, type)
#define SWIG_NewFunctionPtrObj(ptr, type)               SWIG_Python_NewPointerObj(NULL, ptr, type, 0)

/* for C++ member pointers, ie, member methods */
#define SWIG_ConvertMember(obj, ptr, sz, ty)            SWIG_Python_ConvertPacked(obj, ptr, sz, ty)
#define SWIG_NewMemberObj(ptr, sz, type)                SWIG_Python_NewPackedObj(ptr, sz, type)


/* Runtime API */

#define SWIG_GetModule(clientdata)                      SWIG_Python_GetModule(clientdata)
#define SWIG_SetModule(clientdata, pointer)             SWIG_Python_SetModule(pointer)
#define SWIG_NewClientData(obj)                         SwigPyClientData_New(obj)

#define SWIG_SetErrorObj                                SWIG_Python_SetErrorObj                            
#define SWIG_SetErrorMsg                        	SWIG_Python_SetErrorMsg				   
#define SWIG_ErrorType(code)                    	SWIG_Python_ErrorType(code)                        
#define SWIG_Error(code, msg)            		SWIG_Python_SetErrorMsg(SWIG_ErrorType(code), msg) 
#define SWIG_fail                        		goto fail					   

/* Runtime API implementation */

/* Error manipulation */

SWIGINTERN void 
SWIG_Python_SetErrorObj(PyObject *errtype, PyObject *obj) {
  SWIG_PYTHON_THREAD_BEGIN_BLOCK; 
  PyErr_SetObject(errtype, obj);
  SWIG_Py_DECREF(obj);
  SWIG_PYTHON_THREAD_END_BLOCK;
}

SWIGINTERN void 
SWIG_Python_SetErrorMsg(PyObject *errtype, const char *msg) {
  SWIG_PYTHON_THREAD_BEGIN_BLOCK;
  PyErr_SetString(errtype, msg);
  SWIG_PYTHON_THREAD_END_BLOCK;
}

#define SWIG_Python_Raise(obj, type, desc)  SWIG_Python_SetErrorObj(SWIG_Python_ExceptionType(desc), obj)

/* Set a constant value */

#if defined(SWIGPYTHON_BUILTIN)

SWIGINTERN void
SwigPyBuiltin_AddPublicSymbol(PyObject *seq, const char *key) {
  PyObject *s = PyString_InternFromString(key);
  PyList_Append(seq, s);
  SWIG_Py_DECREF(s);
}

SWIGINTERN void
SWIG_Python_SetConstant(PyObject *d, PyObject *public_interface, const char *name, PyObject *obj) {   
  PyDict_SetItemString(d, name, obj);
  SWIG_Py_DECREF(obj);
  if (public_interface)
    SwigPyBuiltin_AddPublicSymbol(public_interface, name);
}

#else

SWIGINTERN void
SWIG_Python_SetConstant(PyObject *d, const char *name, PyObject *obj) {   
  PyDict_SetItemString(d, name, obj);
  SWIG_Py_DECREF(obj);
}

#endif

/* SWIG runtime data Python module */
static PyObject *Swig_runtime_data_module_global = NULL;

/* Create/obtain the single swig_runtime_data module which is used across different SWIG generated modules */
SWIGINTERN PyObject *
SWIG_runtime_data_module(void) {
  if (!Swig_runtime_data_module_global) {
#if (PY_VERSION_HEX >= 0x030d0000) && (!defined(Py_LIMITED_API) || Py_LIMITED_API+0 >= 0x030d0000)
    /* free-threading note: the GIL is always enabled when this function is first called
       by SWIG_init, so there's no risk of race conditions */
    Swig_runtime_data_module_global = PyImport_AddModuleRef(SWIG_RUNTIME_MODULE);
#elif PY_VERSION_HEX >= 0x03000000
    Swig_runtime_data_module_global = PyImport_AddModule(SWIG_RUNTIME_MODULE);
    SWIG_Py_XINCREF(Swig_runtime_data_module_global);
#else
    static PyMethodDef swig_empty_runtime_method_table[] = { {NULL, NULL, 0, NULL} }; /* Sentinel */
    Swig_runtime_data_module_global = Py_InitModule(SWIG_RUNTIME_MODULE, swig_empty_runtime_method_table);
    SWIG_Py_XINCREF(Swig_runtime_data_module_global);
#endif
  }
  assert(Swig_runtime_data_module_global);
  return Swig_runtime_data_module_global;
}

/* Append a value to the result obj */
SWIGINTERN PyObject*
SWIG_Python_AppendOutput(PyObject* result, PyObject* obj, int is_void) {
  if (!result) {
    result = obj;
  } else if (result == Py_None && is_void) {
    SWIG_Py_DECREF(result);
    result = obj;
  } else {
    if (!PyList_Check(result)) {
      PyObject *o2 = result;
      result = PyList_New(1);
      if (result) {
        PyList_SET_ITEM(result, 0, o2);
      } else {
        SWIG_Py_DECREF(obj);
        return o2;
      }
    }
    PyList_Append(result,obj);
    SWIG_Py_DECREF(obj);
  }
  return result;
}

/* Unpack the argument tuple */

SWIGINTERN Py_ssize_t
SWIG_Python_UnpackTuple(PyObject *args, const char *name, Py_ssize_t min, Py_ssize_t max, PyObject **objs)
{
  if (!args) {
    if (!min && !max) {
      return 1;
    } else {
      PyErr_Format(PyExc_TypeError, "%s expected %s%d arguments, got none", 
		   name, (min == max ? "" : "at least "), (int)min);
      return 0;
    }
  }  
  if (!PyTuple_Check(args)) {
    if (min <= 1 && max >= 1) {
      Py_ssize_t i;
      objs[0] = args;
      for (i = 1; i < max; ++i) {
	objs[i] = 0;
      }
      return 2;
    }
    PyErr_SetString(PyExc_SystemError, "UnpackTuple() argument list is not a tuple");
    return 0;
  } else {
    Py_ssize_t l = PyTuple_GET_SIZE(args);
    if (l < min) {
      PyErr_Format(PyExc_TypeError, "%s expected %s%d arguments, got %d", 
		   name, (min == max ? "" : "at least "), (int)min, (int)l);
      return 0;
    } else if (l > max) {
      PyErr_Format(PyExc_TypeError, "%s expected %s%d arguments, got %d", 
		   name, (min == max ? "" : "at most "), (int)max, (int)l);
      return 0;
    } else {
      Py_ssize_t i;
      for (i = 0; i < l; ++i) {
	objs[i] = PyTuple_GET_ITEM(args, i);
      }
      for (; l < max; ++l) {
	objs[l] = 0;
      }
      return i + 1;
    }    
  }
}

SWIGINTERN int
SWIG_Python_CheckNoKeywords(PyObject *kwargs, const char *name) {
  int no_kwargs = 1;
  if (kwargs) {
    assert(PyDict_Check(kwargs));
    if (PyDict_Size(kwargs) > 0) {
      PyErr_Format(PyExc_TypeError, "%s() does not take keyword arguments", name);
      no_kwargs = 0;
    }
  }
  return no_kwargs;
}

/* A functor is a function object with one single object argument */
#define SWIG_Python_CallFunctor(functor, obj)	        PyObject_CallFunctionObjArgs(functor, obj, NULL);

/*
  Helper for static pointer initialization for both C and C++ code, for example
  static PyObject *SWIG_STATIC_POINTER(MyVar) = NewSomething(...);
*/
#ifdef __cplusplus
#define SWIG_STATIC_POINTER(var)  var
#else
#define SWIG_STATIC_POINTER(var)  var = 0; if (!var) var
#endif

#ifdef __cplusplus
extern "C" {
#endif

/* Python-specific SWIG API */
#define SWIG_newvarlink()                             SWIG_Python_newvarlink()
#define SWIG_addvarlink(p, name, get_attr, set_attr)  SWIG_Python_addvarlink(p, name, get_attr, set_attr)
#define SWIG_InstallConstants(d, constants)           SWIG_Python_InstallConstants(d, constants)
 
/* -----------------------------------------------------------------------------
 * global variable support code.
 * ----------------------------------------------------------------------------- */
 
typedef struct swig_globalvar {   
  char       *name;                  /* Name of global variable */
  PyObject *(*get_attr)(void);       /* Return the current value */
  int       (*set_attr)(PyObject *); /* Set the value */
  struct swig_globalvar *next;
} swig_globalvar;

typedef struct swig_varlinkobject {
  PyObject_HEAD
  swig_globalvar *vars;
} swig_varlinkobject;

SWIGINTERN PyObject *
SwigVarLink_repr(PyObject *SWIGUNUSEDPARM(v)) {
#if PY_VERSION_HEX >= 0x03000000
  return PyUnicode_InternFromString("<Swig global variables>");
#else
  return PyString_FromString("<Swig global variables>");
#endif
}

SWIGINTERN PyObject *
SwigVarLink_str(PyObject *o) {
  swig_varlinkobject *v = (swig_varlinkobject *) o;
#if PY_VERSION_HEX >= 0x03000000
  PyObject *str = PyUnicode_InternFromString("(");
  PyObject *tail;
  PyObject *joined;
  swig_globalvar *var;
  for (var = v->vars; var; var=var->next) {
    tail = PyUnicode_FromString(var->name);
    joined = PyUnicode_Concat(str, tail);
    SWIG_Py_DECREF(str);
    SWIG_Py_DECREF(tail);
    str = joined;
    if (var->next) {
        tail = PyUnicode_InternFromString(", ");
        joined = PyUnicode_Concat(str, tail);
        SWIG_Py_DECREF(str);
        SWIG_Py_DECREF(tail);
        str = joined;
    }
  }
  tail = PyUnicode_InternFromString(")");
  joined = PyUnicode_Concat(str, tail);
  SWIG_Py_DECREF(str);
  SWIG_Py_DECREF(tail);
  str = joined;
#else
  PyObject *str = PyString_FromString("(");
  swig_globalvar *var;
  for (var = v->vars; var; var=var->next) {
    PyString_ConcatAndDel(&str,PyString_FromString(var->name));
    if (var->next) PyString_ConcatAndDel(&str,PyString_FromString(", "));
  }
  PyString_ConcatAndDel(&str,PyString_FromString(")"));
#endif
  return str;
}

SWIGINTERN void
SwigVarLink_dealloc(PyObject *o) {
  swig_varlinkobject *v = (swig_varlinkobject *) o;
  swig_globalvar *var = v->vars;
  while (var) {
    swig_globalvar *n = var->next;
    free(var->name);
    free(var);
    var = n;
  }
}

SWIGINTERN PyObject *
SwigVarLink_getattr(PyObject *o, char *n) {
  swig_varlinkobject *v = (swig_varlinkobject *) o;
  PyObject *res = NULL;
  swig_globalvar *var = v->vars;
  while (var) {
    if (strcmp(var->name,n) == 0) {
      res = (*var->get_attr)();
      break;
    }
    var = var->next;
  }
  if (res == NULL && !PyErr_Occurred()) {
    PyErr_Format(PyExc_AttributeError, "Unknown C global variable '%s'", n);
  }
  return res;
}

SWIGINTERN int
SwigVarLink_setattr(PyObject *o, char *n, PyObject *p) {
  swig_varlinkobject *v = (swig_varlinkobject *) o;
  int res = 1;
  swig_globalvar *var = v->vars;
  while (var) {
    if (strcmp(var->name,n) == 0) {
      res = (*var->set_attr)(p);
      break;
    }
    var = var->next;
  }
  if (res == 1 && !PyErr_Occurred()) {
    PyErr_Format(PyExc_AttributeError, "Unknown C global variable '%s'", n);
  }
  return res;
}

SWIGINTERN PyTypeObject*
SwigVarLink_TypeOnce(void) {
  static char SwigVarLink_doc[] = "Swig variable link object";
#ifndef SWIG_HEAPTYPES
  static PyTypeObject varlink_type;
  static int type_init = 0;
  if (!type_init) {
    const PyTypeObject tmp = {
#if PY_VERSION_HEX >= 0x03000000
      PyVarObject_HEAD_INIT(NULL, 0)
#else
      PyObject_HEAD_INIT(NULL)
      0,                                  /* ob_size */
#endif
      SWIG_RUNTIME_MODULE ".SwigVarLink", /* tp_name */
      sizeof(swig_varlinkobject),         /* tp_basicsize */
      0,                                  /* tp_itemsize */
      (destructor) SwigVarLink_dealloc,   /* tp_dealloc */
#if PY_VERSION_HEX < 0x030800b4
      (printfunc)0,                       /* tp_print */
#else
      (Py_ssize_t)0,                      /* tp_vectorcall_offset */
#endif
      (getattrfunc) SwigVarLink_getattr,  /* tp_getattr */
      (setattrfunc) SwigVarLink_setattr,  /* tp_setattr */
      0,                                  /* tp_compare */
      (reprfunc) SwigVarLink_repr,        /* tp_repr */
      0,                                  /* tp_as_number */
      0,                                  /* tp_as_sequence */
      0,                                  /* tp_as_mapping */
      0,                                  /* tp_hash */
      0,                                  /* tp_call */
      (reprfunc) SwigVarLink_str,         /* tp_str */
      0,                                  /* tp_getattro */
      0,                                  /* tp_setattro */
      0,                                  /* tp_as_buffer */
      0,                                  /* tp_flags */
      SwigVarLink_doc,                    /* tp_doc */
      0,                                  /* tp_traverse */
      0,                                  /* tp_clear */
      0,                                  /* tp_richcompare */
      0,                                  /* tp_weaklistoffset */
      0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0, /* tp_iter -> tp_weaklist */
      0,                                  /* tp_del */
      0,                                  /* tp_version_tag */
#if PY_VERSION_HEX >= 0x03040000
      0,                                  /* tp_finalize */
#endif
#if PY_VERSION_HEX >= 0x03080000
      0,                                  /* tp_vectorcall */
#endif
#if (PY_VERSION_HEX >= 0x03080000) && (PY_VERSION_HEX < 0x03090000)
      0,                                  /* tp_print */
#endif
#if PY_VERSION_HEX >= 0x030c0000
      0,                                  /* tp_watched */
#endif
#if PY_VERSION_HEX >= 0x030d00a4
      0,                                  /* tp_versions_used */
#endif
#ifdef COUNT_ALLOCS
      0,                                  /* tp_allocs */
      0,                                  /* tp_frees */
      0,                                  /* tp_maxalloc */
      0,                                  /* tp_prev */
      0                                   /* tp_next */
#endif
    };
    PyObject *runtime_data_module = SWIG_runtime_data_module();
    varlink_type = tmp;
    type_init = 1;
    if (PyType_Ready(&varlink_type) < 0)
      return NULL;
    if (PyModule_AddObject(runtime_data_module, "SwigVarLink", (PyObject *)&varlink_type) == 0)
      SWIG_Py_INCREF((PyObject *)&varlink_type);
  }
  return &varlink_type;
#else
  PyType_Slot slots[] = {
    { Py_tp_dealloc, (void *)SwigVarLink_dealloc },
    { Py_tp_repr, (void *)SwigVarLink_repr },
    { Py_tp_getattr, (void *)SwigVarLink_getattr },
    { Py_tp_setattr, (void *)SwigVarLink_setattr },
    { Py_tp_str, (void *)SwigVarLink_str },
    { Py_tp_doc, (void *)SwigVarLink_doc },
    { 0, NULL }
  };
  PyType_Spec spec = {
    SWIG_RUNTIME_MODULE ".SwigVarLink",
    sizeof(swig_varlinkobject),
    0,
    Py_TPFLAGS_DEFAULT,
    slots
  };
  PyObject *pytype = PyType_FromSpec(&spec);
  PyObject *runtime_data_module = SWIG_runtime_data_module();
  if (pytype && PyModule_AddObject(runtime_data_module, "SwigVarLink", pytype) == 0)
    SWIG_Py_INCREF(pytype);
  return (PyTypeObject *)pytype;
#endif
}

SWIGRUNTIME PyTypeObject*
SwigVarLink_Type(void) {
  static PyTypeObject *SWIG_STATIC_POINTER(type) = SwigVarLink_TypeOnce();
  return type;
}

/* Create a variable linking object for use later */
SWIGINTERN PyObject *
SWIG_Python_newvarlink(void) {
  swig_varlinkobject *result = PyObject_New(swig_varlinkobject, SwigVarLink_Type());
  if (result) {
    result->vars = 0;
  }
  return ((PyObject*) result);
}

SWIGINTERN void 
SWIG_Python_addvarlink(PyObject *p, const char *name, PyObject *(*get_attr)(void), int (*set_attr)(PyObject *p)) {
  swig_varlinkobject *v = (swig_varlinkobject *) p;
  swig_globalvar *gv = (swig_globalvar *) malloc(sizeof(swig_globalvar));
  if (gv) {
    size_t size = strlen(name)+1;
    gv->name = (char *)malloc(size);
    if (gv->name) {
      memcpy(gv->name, name, size);
      gv->get_attr = get_attr;
      gv->set_attr = set_attr;
      gv->next = v->vars;
    }
  }
  v->vars = gv;
}


static PyObject *Swig_Globals_global = NULL;
  
SWIGINTERN PyObject *
SWIG_globals(void) {
  if (Swig_Globals_global == NULL) {
    Swig_Globals_global = SWIG_newvarlink();
  }
  return Swig_Globals_global;
}

#ifdef __cplusplus
}
#endif

/* -----------------------------------------------------------------------------
 * Pointer declarations
 * ----------------------------------------------------------------------------- */

/* Flags for new pointer objects */
#define SWIG_POINTER_NOSHADOW       (SWIG_POINTER_OWN      << 1)
#define SWIG_POINTER_NEW            (SWIG_POINTER_NOSHADOW | SWIG_POINTER_OWN)

#define SWIG_POINTER_IMPLICIT_CONV  (SWIG_POINTER_DISOWN   << 1)

#define SWIG_BUILTIN_TP_INIT	    (SWIG_POINTER_OWN << 2)
#define SWIG_BUILTIN_INIT	    (SWIG_BUILTIN_TP_INIT | SWIG_POINTER_OWN)

#ifdef __cplusplus
extern "C" {
#endif

/* The python void return value */

SWIGRUNTIMEINLINE PyObject * 
SWIG_Py_Void(void)
{
  PyObject *none = Py_None;
  SWIG_Py_INCREF(none);
  return none;
}

/* SwigPyClientData */

typedef struct {
  PyObject *klass;
  PyObject *newraw;
  PyObject *newargs;
  PyObject *destroy;
  int delargs;
  int implicitconv;
  PyTypeObject *pytype;
} SwigPyClientData;

SWIGRUNTIMEINLINE int 
SWIG_Python_CheckImplicit(swig_type_info *ty)
{
  SwigPyClientData *data = (SwigPyClientData *)ty->clientdata;
  int fail = data ? data->implicitconv : 0;
  if (fail)
    PyErr_SetString(PyExc_TypeError, "Implicit conversion is prohibited for explicit constructors.");
  return fail;
}

SWIGRUNTIMEINLINE PyObject *
SWIG_Python_ExceptionType(swig_type_info *desc) {
  SwigPyClientData *data = desc ? (SwigPyClientData *) desc->clientdata : 0;
  PyObject *klass = data ? data->klass : 0;
  return (klass ? klass : PyExc_RuntimeError);
}


SWIGRUNTIME SwigPyClientData * 
SwigPyClientData_New(PyObject* obj)
{
  if (!obj) {
    return 0;
  } else {
    SwigPyClientData *data = (SwigPyClientData *)malloc(sizeof(SwigPyClientData));
    /* the klass element */
    data->klass = obj;
    SWIG_Py_INCREF(data->klass);
    /* the newraw method and newargs arguments used to create a new raw instance */
    if (PyClass_Check(obj)) {
      data->newraw = 0;
      SWIG_Py_INCREF(obj);
      data->newargs = obj;
    } else {
      data->newraw = PyObject_GetAttrString(data->klass, "__new__");
      if (data->newraw) {
        data->newargs = PyTuple_New(1);
        if (data->newargs) {
          SWIG_Py_INCREF(obj);
          PyTuple_SET_ITEM(data->newargs, 0, obj);
        } else {
          SWIG_Py_DECREF(data->newraw);
          SWIG_Py_DECREF(data->klass);
          free(data);
          return 0;
        }
      } else {
        SWIG_Py_INCREF(obj);
        data->newargs = obj;
      }
    }
    /* the destroy method, aka as the C++ delete method */
    data->destroy = PyObject_GetAttrString(data->klass, "__swig_destroy__");
    if (PyErr_Occurred()) {
      PyErr_Clear();
      data->destroy = 0;
    }
    if (data->destroy) {
      data->delargs = !(PyCFunction_GET_FLAGS(data->destroy) & METH_O);
    } else {
      data->delargs = 0;
    }
    data->implicitconv = 0;
    data->pytype = 0;
    return data;
  }
}

SWIGRUNTIME void 
SwigPyClientData_Del(SwigPyClientData *data)
{
  SWIG_Py_XDECREF(data->klass);
  SWIG_Py_XDECREF(data->newraw);
  SWIG_Py_XDECREF(data->newargs);
  SWIG_Py_XDECREF(data->destroy);
  free(data);
}

/* =============== SwigPyObject =====================*/

typedef struct {
  PyObject_HEAD
  void *ptr;
  swig_type_info *ty;
  int own;
  PyObject *next;
  PyObject *swigdict;
  PyObject *weakreflist;
} SwigPyObject;


#ifdef SWIGPYTHON_BUILTIN

SWIGRUNTIME PyObject *
SwigPyObject_get___dict__(PyObject *v, PyObject *SWIGUNUSEDPARM(args))
{
  SwigPyObject *sobj = (SwigPyObject *)v;

  if (!sobj->swigdict)
    sobj->swigdict = PyDict_New();

  SWIG_Py_XINCREF(sobj->swigdict);
  return sobj->swigdict;
}

#endif

SWIGRUNTIME PyObject *
SwigPyObject_long(SwigPyObject *v)
{
  return PyLong_FromVoidPtr(v->ptr);
}

SWIGRUNTIME PyObject *
SwigPyObject_format(const char* fmt, SwigPyObject *v)
{
  PyObject *res = NULL;
  PyObject *args = PyTuple_New(1);
  if (args) {
    PyObject *val = SwigPyObject_long(v);
    if (val) {
      PyObject *ofmt;
      PyTuple_SET_ITEM(args, 0, val);
      ofmt = SWIG_Python_str_FromChar(fmt);
      if (ofmt) {
#if PY_VERSION_HEX >= 0x03000000
        res = PyUnicode_Format(ofmt,args);
#else
        res = PyString_Format(ofmt,args);
#endif
        SWIG_Py_DECREF(ofmt);
      }
    }
    SWIG_Py_DECREF(args);
  }
  return res;
}

SWIGRUNTIME PyObject *
SwigPyObject_oct(SwigPyObject *v)
{
  return SwigPyObject_format("%o",v);
}

SWIGRUNTIME PyObject *
SwigPyObject_hex(SwigPyObject *v)
{
  return SwigPyObject_format("%x",v);
}

SWIGRUNTIME PyObject *
SwigPyObject_repr(SwigPyObject *v)
{
  const char *name = SWIG_TypePrettyName(v->ty);
  PyObject *repr = SWIG_Python_str_FromFormat("<Swig Object of type '%s' at %p>", (name ? name : "unknown"), (void *)v);
  if (repr && v->next) {
    PyObject *nrep = SwigPyObject_repr((SwigPyObject *)v->next);
    if (nrep) {
# if PY_VERSION_HEX >= 0x03000000
      PyObject *joined = PyUnicode_Concat(repr, nrep);
      SWIG_Py_DECREF(repr);
      SWIG_Py_DECREF(nrep);
      repr = joined;
# else
      PyString_ConcatAndDel(&repr,nrep);
# endif
    } else {
      SWIG_Py_DECREF(repr);
      repr = NULL;
    }
  }
  return repr;
}

/* We need a version taking two PyObject* parameters so it's a valid
 * PyCFunction to use in SwigPyObject_methods[]. */
SWIGRUNTIME PyObject *
SwigPyObject_repr2(PyObject *v, PyObject *SWIGUNUSEDPARM(args))
{
  return SwigPyObject_repr((SwigPyObject*)v);
}

SWIGRUNTIME int
SwigPyObject_compare(PyObject *v, PyObject *w)
{
  /* tp_compare is only called when both objects have the same type, so
   * the casts are guaranteed to be ok. */
  void *i = ((SwigPyObject *)v)->ptr;
  void *j = ((SwigPyObject *)w)->ptr;
  return (i < j) ? -1 : ((i > j) ? 1 : 0);
}

SWIGRUNTIMEINLINE int SwigPyObject_Check(PyObject *);

/* Added for Python 3.x, would it also be useful for Python 2.x? */
SWIGRUNTIME PyObject*
SwigPyObject_richcompare(PyObject *v, PyObject *w, int op)
{
  PyObject* res = NULL;
  if (!PyErr_Occurred()) {
    /* Per https://docs.python.org/3/c-api/typeobj.html#c.PyTypeObject.tp_richcompare
     * the first argument is guaranteed to be an instance of SwigPyObject, but the
     * second is not, so we typecheck that one. */
    if ((op != Py_EQ && op != Py_NE) || !SwigPyObject_Check(w)) {
      SWIG_Py_INCREF(Py_NotImplemented);
      return Py_NotImplemented;
    }
    res = PyBool_FromLong( (SwigPyObject_compare(v, w)==0) == (op == Py_EQ) ? 1 : 0);
  }
  return res;
}


SWIGRUNTIME PyTypeObject* SwigPyObject_TypeOnce(void);

#ifdef SWIGPYTHON_BUILTIN
static swig_type_info *SwigPyObject_stype = 0;
SWIGRUNTIME PyTypeObject*
SwigPyObject_Type(void) {
    SwigPyClientData *cd;
    assert(SwigPyObject_stype);
    cd = (SwigPyClientData*) SwigPyObject_stype->clientdata;
    assert(cd);
    assert(cd->pytype);
    return cd->pytype;
}
#else
SWIGRUNTIME PyTypeObject*
SwigPyObject_Type(void) {
  static PyTypeObject *SWIG_STATIC_POINTER(type) = SwigPyObject_TypeOnce();
  return type;
}
#endif

SWIGRUNTIMEINLINE int
SwigPyObject_Check(PyObject *op) {
  PyTypeObject *target_tp = SwigPyObject_Type();
  PyTypeObject *op_type = Py_TYPE(op);
#ifdef SWIGPYTHON_BUILTIN
  /* Only builtin types have SwigPyObject as a base type */
  return PyType_IsSubtype(op_type, target_tp);
#else
  /* Check for an exact match to SwigPyObject */
  if (op_type == target_tp) {
    return 1;
  } else {
    /* Fallback for multiple modules */
#if PY_VERSION_HEX >= 0x03000000
    int cmp;
    PyObject *tpname = SWIG_PyType_GetFullyQualifiedName(op_type);
    if (!tpname)
      return 0;
    cmp = PyUnicode_CompareWithASCIIString(tpname, SWIG_RUNTIME_MODULE ".SwigPyObject");
    SWIG_Py_DECREF(tpname);
    return cmp == 0;
#else
    return strcmp(op_type->tp_name, SWIG_RUNTIME_MODULE ".SwigPyObject") == 0;
#endif
  }
#endif
}

SWIGRUNTIME PyObject *
SwigPyObject_New(void *ptr, swig_type_info *ty, int own);

static PyObject* Swig_Capsule_global = NULL;

SWIGRUNTIME void
SwigPyObject_dealloc(PyObject *v)
{
  SwigPyObject *sobj = (SwigPyObject *) v;
  PyObject *next = sobj->next;
  if (sobj->own == SWIG_POINTER_OWN) {
    swig_type_info *ty = sobj->ty;
    SwigPyClientData *data = ty ? (SwigPyClientData *) ty->clientdata : 0;
    PyObject *destroy = data ? data->destroy : 0;
    if (destroy) {
      /* destroy is always a VARARGS method */
      PyObject *res;

      /* PyObject_CallFunction() has the potential to silently drop
         the active exception.  In cases of unnamed temporary
         variable or where we just finished iterating over a generator
         StopIteration will be active right now, and this needs to
         remain true upon return from SwigPyObject_dealloc.  So save
         and restore. */
      
      PyObject *type = NULL, *value = NULL, *traceback = NULL;
      PyErr_Fetch(&type, &value, &traceback);

      if (data->delargs) {
        /* we need to create a temporary object to carry the destroy operation */
        PyObject *tmp = SwigPyObject_New(sobj->ptr, ty, 0);
        if (tmp) {
          res = SWIG_Python_CallFunctor(destroy, tmp);
        } else {
          res = 0;
        }
        SWIG_Py_XDECREF(tmp);
      } else {
        PyCFunction meth = PyCFunction_GET_FUNCTION(destroy);
        PyObject *mself = PyCFunction_GET_SELF(destroy);
        res = ((*meth)(mself, v));
      }
      if (!res)
        PyErr_WriteUnraisable(destroy);

      PyErr_Restore(type, value, traceback);

      SWIG_Py_XDECREF(res);
    } 
#if !defined(SWIG_PYTHON_SILENT_MEMLEAK)
    else {
      const char *name = SWIG_TypePrettyName(ty);
      printf("swig/python detected a memory leak of type '%s', no destructor found.\n", (name ? name : "unknown"));
    }
#endif
    SWIG_Py_XDECREF(Swig_Capsule_global);
  }
  SWIG_Py_XDECREF(next);
  SWIG_Py_XDECREF(sobj->swigdict);
  PyObject_Free(v);
}

SWIGRUNTIME PyObject* 
SwigPyObject_append(PyObject* v, PyObject* next)
{
  SwigPyObject *sobj = (SwigPyObject *) v;
  if (!SwigPyObject_Check(next)) {
    PyErr_SetString(PyExc_TypeError, "Attempt to append a non SwigPyObject");
    return NULL;
  }
  ((SwigPyObject *)next)->next = sobj->next;
  sobj->next = next;
  SWIG_Py_INCREF(next);
  return SWIG_Py_Void();
}

SWIGRUNTIME PyObject* 
SwigPyObject_next(PyObject* v, PyObject *SWIGUNUSEDPARM(args))
{
  SwigPyObject *sobj = (SwigPyObject *) v;
  if (sobj->next) {    
    SWIG_Py_INCREF(sobj->next);
    return sobj->next;
  } else {
    return SWIG_Py_Void();
  }
}

SWIGINTERN PyObject*
SwigPyObject_disown(PyObject* v, PyObject *SWIGUNUSEDPARM(args))
{
  SwigPyObject *sobj = (SwigPyObject *)v;
  sobj->own = 0;
  return SWIG_Py_Void();
}

SWIGINTERN PyObject*
SwigPyObject_acquire(PyObject* v, PyObject *SWIGUNUSEDPARM(args))
{
  SwigPyObject *sobj = (SwigPyObject *)v;
  sobj->own = SWIG_POINTER_OWN;
  return SWIG_Py_Void();
}

SWIGINTERN PyObject*
SwigPyObject_own(PyObject *v, PyObject *args)
{
  PyObject *val = 0;
  if (!PyArg_UnpackTuple(args, "own", 0, 1, &val)) {
    return NULL;
  } else {
    SwigPyObject *sobj = (SwigPyObject *)v;
    PyObject *obj = PyBool_FromLong(sobj->own);
    if (val) {
      if (PyObject_IsTrue(val)) {
        SWIG_Py_DECREF(SwigPyObject_acquire(v,args));
      } else {
        SWIG_Py_DECREF(SwigPyObject_disown(v,args));
      }
    } 
    return obj;
  }
}

static PyMethodDef
SwigPyObject_methods[] = {
  {"disown",  SwigPyObject_disown,  METH_NOARGS,  "releases ownership of the pointer"},
  {"acquire", SwigPyObject_acquire, METH_NOARGS,  "acquires ownership of the pointer"},
  {"own",     SwigPyObject_own,     METH_VARARGS, "returns/sets ownership of the pointer"},
  {"append",  SwigPyObject_append,  METH_O,       "appends another 'this' object"},
  {"next",    SwigPyObject_next,    METH_NOARGS,  "returns the next 'this' object"},
  {"__repr__",SwigPyObject_repr2,   METH_NOARGS,  "returns object representation"},
  {0, 0, 0, 0}  
};

SWIGRUNTIME PyTypeObject*
SwigPyObject_TypeOnce(void) {
  static char SwigPyObject_doc[] = "Swig object holding a C/C++ pointer";
#ifndef SWIG_HEAPTYPES
  static PyNumberMethods SwigPyObject_as_number = {
    (binaryfunc)0, /*nb_add*/
    (binaryfunc)0, /*nb_subtract*/
    (binaryfunc)0, /*nb_multiply*/
    /* nb_divide removed in Python 3 */
#if PY_VERSION_HEX < 0x03000000
    (binaryfunc)0, /*nb_divide*/
#endif
    (binaryfunc)0, /*nb_remainder*/
    (binaryfunc)0, /*nb_divmod*/
    (ternaryfunc)0,/*nb_power*/
    (unaryfunc)0,  /*nb_negative*/
    (unaryfunc)0,  /*nb_positive*/
    (unaryfunc)0,  /*nb_absolute*/
    (inquiry)0,    /*nb_nonzero*/
    0,		   /*nb_invert*/
    0,		   /*nb_lshift*/
    0,		   /*nb_rshift*/
    0,		   /*nb_and*/
    0,		   /*nb_xor*/
    0,		   /*nb_or*/
#if PY_VERSION_HEX < 0x03000000
    0,   /*nb_coerce*/
#endif
    (unaryfunc)SwigPyObject_long, /*nb_int*/
#if PY_VERSION_HEX < 0x03000000
    (unaryfunc)SwigPyObject_long, /*nb_long*/
#else
    0, /*nb_reserved*/
#endif
    (unaryfunc)0,                 /*nb_float*/
#if PY_VERSION_HEX < 0x03000000
    (unaryfunc)SwigPyObject_oct,  /*nb_oct*/
    (unaryfunc)SwigPyObject_hex,  /*nb_hex*/
#endif
#if PY_VERSION_HEX >= 0x03050000 /* 3.5 */
    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0 /* nb_inplace_add -> nb_inplace_matrix_multiply */
#elif PY_VERSION_HEX >= 0x03000000 /* 3.0 */
    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0 /* nb_inplace_add -> nb_index, nb_inplace_divide removed */
#else
    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0 /* nb_inplace_add -> nb_index */
#endif
  };

  static PyTypeObject swigpyobject_type;
  static int type_init = 0;
  if (!type_init) {
    const PyTypeObject tmp = {
#if PY_VERSION_HEX >= 0x03000000
      PyVarObject_HEAD_INIT(NULL, 0)
#else
      PyObject_HEAD_INIT(NULL)
      0,                                    /* ob_size */
#endif
      SWIG_RUNTIME_MODULE ".SwigPyObject",  /* tp_name */
      sizeof(SwigPyObject),                 /* tp_basicsize */
      0,                                    /* tp_itemsize */
      (destructor)SwigPyObject_dealloc,     /* tp_dealloc */
#if PY_VERSION_HEX < 0x030800b4
      (printfunc)0,                         /* tp_print */
#else
      (Py_ssize_t)0,                        /* tp_vectorcall_offset */
#endif
      (getattrfunc)0,                       /* tp_getattr */
      (setattrfunc)0,                       /* tp_setattr */
#if PY_VERSION_HEX >= 0x03000000
      0, /* tp_reserved in 3.0.1, tp_compare in 3.0.0 but not used */
#else
      (cmpfunc)SwigPyObject_compare,        /* tp_compare */
#endif
      (reprfunc)SwigPyObject_repr,          /* tp_repr */
      &SwigPyObject_as_number,              /* tp_as_number */
      0,                                    /* tp_as_sequence */
      0,                                    /* tp_as_mapping */
      (hashfunc)0,                          /* tp_hash */
      (ternaryfunc)0,                       /* tp_call */
      0,                                    /* tp_str */
      PyObject_GenericGetAttr,              /* tp_getattro */
      0,                                    /* tp_setattro */
      0,                                    /* tp_as_buffer */
      Py_TPFLAGS_DEFAULT,                   /* tp_flags */
      SwigPyObject_doc,                     /* tp_doc */
      0,                                    /* tp_traverse */
      0,                                    /* tp_clear */
      (richcmpfunc)SwigPyObject_richcompare,/* tp_richcompare */
      offsetof(SwigPyObject, weakreflist),  /* tp_weaklistoffset */
      0,                                    /* tp_iter */
      0,                                    /* tp_iternext */
      SwigPyObject_methods,                 /* tp_methods */
      0,                                    /* tp_members */
      0,                                    /* tp_getset */
      0,                                    /* tp_base */
      0,                                    /* tp_dict */
      0,                                    /* tp_descr_get */
      0,                                    /* tp_descr_set */
      0,                                    /* tp_dictoffset */
      0,                                    /* tp_init */
      0,                                    /* tp_alloc */
      0,                                    /* tp_new */
      0,                                    /* tp_free */
      0,                                    /* tp_is_gc */
      0,                                    /* tp_bases */
      0,                                    /* tp_mro */
      0,                                    /* tp_cache */
      0,                                    /* tp_subclasses */
      0,                                    /* tp_weaklist */
      0,                                    /* tp_del */
      0,                                    /* tp_version_tag */
#if PY_VERSION_HEX >= 0x03040000
      0,                                    /* tp_finalize */
#endif
#if PY_VERSION_HEX >= 0x03080000
      0,                                    /* tp_vectorcall */
#endif
#if (PY_VERSION_HEX >= 0x03080000) && (PY_VERSION_HEX < 0x03090000)
      0,                                    /* tp_print */
#endif
#if PY_VERSION_HEX >= 0x030c0000
      0,                                    /* tp_watched */
#endif
#if PY_VERSION_HEX >= 0x030d00a4
      0,                                    /* tp_versions_used */
#endif
#ifdef COUNT_ALLOCS
      0,                                    /* tp_allocs */
      0,                                    /* tp_frees */
      0,                                    /* tp_maxalloc */
      0,                                    /* tp_prev */
      0                                     /* tp_next */
#endif
    };
    PyObject *runtime_data_module = SWIG_runtime_data_module();
    swigpyobject_type = tmp;
    type_init = 1;
    if (PyType_Ready(&swigpyobject_type) != 0)
      return NULL;
    if (PyModule_AddObject(runtime_data_module, "SwigPyObject", (PyObject *)&swigpyobject_type) == 0)
      SWIG_Py_INCREF((PyObject *)&swigpyobject_type);
  }
  return &swigpyobject_type;
#else
  static PyMemberDef SwigPyObject_members[] = {
      { (char *)"__dictoffset__", Py_T_PYSSIZET, offsetof(SwigPyObject, swigdict), Py_READONLY, NULL },
      { (char *)"__weaklistoffset__", Py_T_PYSSIZET, offsetof(SwigPyObject, weakreflist), Py_READONLY, NULL },
      { NULL, 0, 0, 0, NULL }
  };
  PyType_Slot slots[] = {
    { Py_tp_dealloc, (void *)SwigPyObject_dealloc },
    { Py_tp_repr, (void *)SwigPyObject_repr },
    { Py_tp_getattro, (void *)PyObject_GenericGetAttr },
    { Py_tp_doc, (void *)SwigPyObject_doc },
    { Py_tp_richcompare, (void *)SwigPyObject_richcompare },
    { Py_tp_methods, (void *)SwigPyObject_methods },
    { Py_nb_int, (void *)SwigPyObject_long },
    { Py_tp_members, (void *)SwigPyObject_members },
    { 0, NULL }
  };
  PyType_Spec spec = {
    SWIG_RUNTIME_MODULE ".SwigPyObject",
    sizeof(SwigPyObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE,
    slots
  };
  PyObject *pytype = PyType_FromSpec(&spec);
  PyObject *runtime_data_module = SWIG_runtime_data_module();
#if !defined(Py_LIMITED_API)
/* While this __dictoffset__ is only used with the builtin wrappers, SwigPyObject ought to be
   identical when created for use by proxy class wrappers in case it is shared across multiple modules. */
#if PY_VERSION_HEX < 0x03090000
    /* Workaround as __dictoffset__ and __weaklistoffset__ above are only supported from python-3.9 */
  if (pytype) {
    ((PyTypeObject *)pytype)->tp_dictoffset = offsetof(SwigPyObject, swigdict);
    ((PyTypeObject *)pytype)->tp_weaklistoffset = offsetof(SwigPyObject, weakreflist);
  }
#endif
#endif
  if (pytype && PyModule_AddObject(runtime_data_module, "SwigPyObject", pytype) == 0)
    SWIG_Py_INCREF(pytype);
  return (PyTypeObject *)pytype;
#endif
}

SWIGRUNTIME PyObject *
SwigPyObject_New(void *ptr, swig_type_info *ty, int own)
{
  SwigPyObject *sobj = PyObject_New(SwigPyObject, SwigPyObject_Type());
  if (sobj) {
    sobj->ptr  = ptr;
    sobj->ty   = ty;
    sobj->own  = own;
    sobj->next = 0;
    sobj->swigdict = 0;
    sobj->weakreflist = 0;
    if (own == SWIG_POINTER_OWN) {
      /* Obtain a reference to the Python capsule wrapping the module information, so that the
       * module information is correctly destroyed after all SWIG python objects have been freed
       * by the GC (and corresponding destructors invoked) */
      SWIG_Py_XINCREF(Swig_Capsule_global);
    }
  }
  return (PyObject *)sobj;
}

/* -----------------------------------------------------------------------------
 * Implements a simple Swig Packed type, and use it instead of string
 * ----------------------------------------------------------------------------- */

typedef struct {
  PyObject_HEAD
  void *pack;
  swig_type_info *ty;
  size_t size;
} SwigPyPacked;

SWIGRUNTIME PyObject *
SwigPyPacked_repr(SwigPyPacked *v)
{
  char result[SWIG_BUFFER_SIZE];
  if (SWIG_PackDataName(result, v->pack, v->size, 0, sizeof(result))) {
    return SWIG_Python_str_FromFormat("<Swig Packed at %s%s>", result, v->ty->name);
  } else {
    return SWIG_Python_str_FromFormat("<Swig Packed %s>", v->ty->name);
  }  
}

SWIGRUNTIME PyObject *
SwigPyPacked_str(SwigPyPacked *v)
{
  char result[SWIG_BUFFER_SIZE];
  if (SWIG_PackDataName(result, v->pack, v->size, 0, sizeof(result))){
    return SWIG_Python_str_FromFormat("%s%s", result, v->ty->name);
  } else {
    return SWIG_Python_str_FromChar(v->ty->name);
  }  
}

SWIGRUNTIME int
SwigPyPacked_compare(SwigPyPacked *v, SwigPyPacked *w)
{
  size_t i = v->size;
  size_t j = w->size;
  int s = (i < j) ? -1 : ((i > j) ? 1 : 0);
  return s ? s : strncmp((const char *)v->pack, (const char *)w->pack, 2*v->size);
}

SWIGRUNTIME PyTypeObject* SwigPyPacked_TypeOnce(void);

SWIGRUNTIME PyTypeObject*
SwigPyPacked_Type(void) {
  static PyTypeObject *SWIG_STATIC_POINTER(type) = SwigPyPacked_TypeOnce();
  return type;
}

SWIGRUNTIMEINLINE int
SwigPyPacked_Check(PyObject *op) {
  PyTypeObject *target_tp = SwigPyPacked_Type();
  PyTypeObject *op_type = Py_TYPE(op);
  /* Check for an exact match to SwigPyPacked */
  if (op_type == target_tp) {
    return 1;
  } else {
    /* Fallback for multiple modules */
#if PY_VERSION_HEX >= 0x03000000
    int cmp;
    PyObject *tpname = SWIG_PyType_GetFullyQualifiedName(op_type);
    if (!tpname)
      return 0;
    cmp = PyUnicode_CompareWithASCIIString(tpname, SWIG_RUNTIME_MODULE ".SwigPyPacked");
    SWIG_Py_DECREF(tpname);
    return cmp == 0;
#else
    return strcmp(op_type->tp_name, SWIG_RUNTIME_MODULE ".SwigPyPacked") == 0;
#endif
  }
}

SWIGRUNTIME void
SwigPyPacked_dealloc(PyObject *v)
{
  if (SwigPyPacked_Check(v)) {
    SwigPyPacked *sobj = (SwigPyPacked *) v;
    free(sobj->pack);
  }
  PyObject_Free(v);
}

SWIGRUNTIME PyTypeObject*
SwigPyPacked_TypeOnce(void) {
  static char SwigPyPacked_doc[] = "Swig object holding a C/C++ function pointer";
#ifndef SWIG_HEAPTYPES
  static PyTypeObject swigpypacked_type;
  static int type_init = 0;
  if (!type_init) {
    const PyTypeObject tmp = {
#if PY_VERSION_HEX >= 0x03000000
      PyVarObject_HEAD_INIT(NULL, 0)
#else
      PyObject_HEAD_INIT(NULL)
      0,                                    /* ob_size */
#endif
      SWIG_RUNTIME_MODULE ".SwigPyPacked",  /* tp_name */
      sizeof(SwigPyPacked),                 /* tp_basicsize */
      0,                                    /* tp_itemsize */
      (destructor)SwigPyPacked_dealloc,     /* tp_dealloc */
#if PY_VERSION_HEX < 0x030800b4
      (printfunc)0,                         /* tp_print */
#else
      (Py_ssize_t)0,                        /* tp_vectorcall_offset */
#endif
      (getattrfunc)0,                       /* tp_getattr */
      (setattrfunc)0,                       /* tp_setattr */
#if PY_VERSION_HEX >= 0x03000000
      0, /* tp_reserved in 3.0.1 */
#else
      (cmpfunc)SwigPyPacked_compare,        /* tp_compare */
#endif
      (reprfunc)SwigPyPacked_repr,          /* tp_repr */
      0,                                    /* tp_as_number */
      0,                                    /* tp_as_sequence */
      0,                                    /* tp_as_mapping */
      (hashfunc)0,                          /* tp_hash */
      (ternaryfunc)0,                       /* tp_call */
      (reprfunc)SwigPyPacked_str,           /* tp_str */
      PyObject_GenericGetAttr,              /* tp_getattro */
      0,                                    /* tp_setattro */
      0,                                    /* tp_as_buffer */
      Py_TPFLAGS_DEFAULT,                   /* tp_flags */
      SwigPyPacked_doc,                     /* tp_doc */
      0,                                    /* tp_traverse */
      0,                                    /* tp_clear */
      0,                                    /* tp_richcompare */
      0,                                    /* tp_weaklistoffset */
      0,                                    /* tp_iter */
      0,                                    /* tp_iternext */
      0,                                    /* tp_methods */
      0,                                    /* tp_members */
      0,                                    /* tp_getset */
      0,                                    /* tp_base */
      0,                                    /* tp_dict */
      0,                                    /* tp_descr_get */
      0,                                    /* tp_descr_set */
      0,                                    /* tp_dictoffset */
      0,                                    /* tp_init */
      0,                                    /* tp_alloc */
      0,                                    /* tp_new */
      0,                                    /* tp_free */
      0,                                    /* tp_is_gc */
      0,                                    /* tp_bases */
      0,                                    /* tp_mro */
      0,                                    /* tp_cache */
      0,                                    /* tp_subclasses */
      0,                                    /* tp_weaklist */
      0,                                    /* tp_del */
      0,                                    /* tp_version_tag */
#if PY_VERSION_HEX >= 0x03040000
      0,                                    /* tp_finalize */
#endif
#if PY_VERSION_HEX >= 0x03080000
      0,                                    /* tp_vectorcall */
#endif
#if (PY_VERSION_HEX >= 0x03080000) && (PY_VERSION_HEX < 0x03090000)
      0,                                    /* tp_print */
#endif
#if PY_VERSION_HEX >= 0x030c0000
      0,                                    /* tp_watched */
#endif
#if PY_VERSION_HEX >= 0x030d00a4
      0,                                    /* tp_versions_used */
#endif
#ifdef COUNT_ALLOCS
      0,                                    /* tp_allocs */
      0,                                    /* tp_frees */
      0,                                    /* tp_maxalloc */
      0,                                    /* tp_prev */
      0                                     /* tp_next */
#endif
    };
    PyObject *runtime_data_module = SWIG_runtime_data_module();
    swigpypacked_type = tmp;
    type_init = 1;
    if (PyType_Ready(&swigpypacked_type) != 0)
      return NULL;
    if (PyModule_AddObject(runtime_data_module, "SwigPyPacked", (PyObject *)&swigpypacked_type) == 0)
      SWIG_Py_INCREF((PyObject *)&swigpypacked_type);
  }
  return &swigpypacked_type;
#else
  PyType_Slot slots[] = {
    { Py_tp_dealloc, (void *)SwigPyPacked_dealloc },
    { Py_tp_repr, (void *)SwigPyPacked_repr },
    { Py_tp_str, (void *)SwigPyPacked_str },
    { Py_tp_getattro, (void *)PyObject_GenericGetAttr },
    { Py_tp_doc, (void *)SwigPyPacked_doc },
    { 0, NULL }
  };
  PyType_Spec spec = {
    SWIG_RUNTIME_MODULE ".SwigPyPacked",
    sizeof(SwigPyPacked),
    0,
    Py_TPFLAGS_DEFAULT,
    slots
  };
  PyObject *pytype = PyType_FromSpec(&spec);
  PyObject *runtime_data_module = SWIG_runtime_data_module();
  if (pytype && PyModule_AddObject(runtime_data_module, "SwigPyPacked", pytype) == 0)
    SWIG_Py_INCREF(pytype);
  return (PyTypeObject *)pytype;
#endif
}

SWIGRUNTIME PyObject *
SwigPyPacked_New(void *ptr, size_t size, swig_type_info *ty)
{
  SwigPyPacked *sobj = PyObject_New(SwigPyPacked, SwigPyPacked_Type());
  if (sobj) {
    void *pack = malloc(size);
    if (pack) {
      memcpy(pack, ptr, size);
      sobj->pack = pack;
      sobj->ty   = ty;
      sobj->size = size;
    } else {
      PyObject_Free((PyObject *)sobj);
      sobj = 0;
    }
  }
  return (PyObject *) sobj;
}

SWIGRUNTIME swig_type_info *
SwigPyPacked_UnpackData(PyObject *obj, void *ptr, size_t size)
{
  if (SwigPyPacked_Check(obj)) {
    SwigPyPacked *sobj = (SwigPyPacked *)obj;
    if (sobj->size != size) return 0;
    memcpy(ptr, sobj->pack, size);
    return sobj->ty;
  } else {
    return 0;
  }
}

/* -----------------------------------------------------------------------------
 * pointers/data manipulation
 * ----------------------------------------------------------------------------- */

static PyObject *Swig_This_global = NULL;

SWIGRUNTIME PyObject *
SWIG_This(void)
{
  if (Swig_This_global == NULL)
    Swig_This_global = SWIG_Python_str_FromChar("this");
  return Swig_This_global;
}

/* #define SWIG_PYTHON_SLOW_GETSET_THIS */

/* TODO: I don't know how to implement the fast getset in Python 3 right now */
#if PY_VERSION_HEX >= 0x03000000
#define SWIG_PYTHON_SLOW_GETSET_THIS 
#endif

/* Returns a borrowed reference to the 'this' object */
SWIGRUNTIME SwigPyObject *
SWIG_Python_GetSwigThis(PyObject *pyobj) 
{
  PyObject *obj;

  if (SwigPyObject_Check(pyobj))
    return (SwigPyObject *) pyobj;

#ifdef SWIGPYTHON_BUILTIN
  (void)obj;
  if (PyWeakref_CheckProxy(pyobj)) {
#if PY_VERSION_HEX >= 0x030d0000
    if (PyWeakref_GetRef(pyobj, &pyobj) > 0)
      Py_DECREF(pyobj);
    else
      pyobj = NULL;
#else
    pyobj = PyWeakref_GetObject(pyobj);
#endif
    if (pyobj && SwigPyObject_Check(pyobj))
      return (SwigPyObject*) pyobj;
  }
  return NULL;
#else

  obj = 0;

#if !defined(SWIG_PYTHON_SLOW_GETSET_THIS)
  if (PyInstance_Check(pyobj)) {
    obj = _PyInstance_Lookup(pyobj, SWIG_This());      
  } else {
    PyObject **dictptr = _PyObject_GetDictPtr(pyobj);
    if (dictptr != NULL) {
      PyObject *dict = *dictptr;
      obj = dict ? PyDict_GetItem(dict, SWIG_This()) : 0;
    } else {
      if (PyWeakref_CheckProxy(pyobj)) {
        PyObject *wobj = PyWeakref_GET_OBJECT(pyobj);
	return wobj ? SWIG_Python_GetSwigThis(wobj) : 0;
      }
      obj = PyObject_GetAttr(pyobj, SWIG_This());
      if (obj) {
	SWIG_Py_DECREF(obj);
      } else {
	if (PyErr_Occurred()) PyErr_Clear();
	return 0;
      }
    }
  }
#else
  obj = PyObject_GetAttr(pyobj, SWIG_This());
  if (obj) {
    SWIG_Py_DECREF(obj);
  } else {
    if (PyErr_Occurred()) PyErr_Clear();
    return 0;
  }
#endif
  if (obj && !SwigPyObject_Check(obj)) {
    /* a PyObject is called 'this', try to get the 'real this'
       SwigPyObject from it */ 
    return SWIG_Python_GetSwigThis(obj);
  }
  return (SwigPyObject *)obj;
#endif
}

/* Acquire a pointer value */

SWIGRUNTIME int
SWIG_Python_AcquirePtr(PyObject *obj, int own) {
  if (own == SWIG_POINTER_OWN) {
    SwigPyObject *sobj = SWIG_Python_GetSwigThis(obj);
    if (sobj) {
      int oldown = sobj->own;
      sobj->own = own;
      return oldown;
    }
  }
  return 0;
}

/* Convert a pointer value */

SWIGRUNTIME int
SWIG_Python_ConvertPtrAndOwn(PyObject *obj, void **ptr, swig_type_info *ty, int flags, int *own) {
  int res;
  SwigPyObject *sobj;
  int implicit_conv = (flags & SWIG_POINTER_IMPLICIT_CONV) != 0;

  if (!obj)
    return SWIG_ERROR;
  if (obj == Py_None && !implicit_conv) {
    if (ptr)
      *ptr = 0;
    return (flags & SWIG_POINTER_NO_NULL) ? SWIG_NullReferenceError : SWIG_OK;
  }

  res = SWIG_ERROR;

  sobj = SWIG_Python_GetSwigThis(obj);
  if (own)
    *own = 0;
  while (sobj) {
    void *vptr = sobj->ptr;
    if (ty) {
      swig_type_info *to = sobj->ty;
      if (to == ty) {
        /* no type cast needed */
        if (ptr) *ptr = vptr;
        break;
      } else {
        swig_cast_info *tc = SWIG_TypeCheck(to->name,ty);
        if (!tc) {
          sobj = (SwigPyObject *)sobj->next;
        } else {
          if (ptr) {
            int newmemory = 0;
            *ptr = SWIG_TypeCast(tc,vptr,&newmemory);
            if (newmemory == SWIG_CAST_NEW_MEMORY) {
              assert(own); /* badly formed typemap which will lead to a memory leak - it must set and use own to delete *ptr */
              if (own)
                *own = *own | SWIG_CAST_NEW_MEMORY;
            }
          }
          break;
        }
      }
    } else {
      if (ptr) *ptr = vptr;
      break;
    }
  }
  if (sobj) {
    if (((flags & SWIG_POINTER_RELEASE) == SWIG_POINTER_RELEASE) && !sobj->own) {
      res = SWIG_ERROR_RELEASE_NOT_OWNED;
    } else {
      if (own)
        *own = *own | sobj->own;
      if (flags & SWIG_POINTER_DISOWN) {
        sobj->own = 0;
      }
      if (flags & SWIG_POINTER_CLEAR) {
        sobj->ptr = 0;
      }
      res = SWIG_OK;
    }
  } else {
    if (implicit_conv) {
      SwigPyClientData *data = ty ? (SwigPyClientData *) ty->clientdata : 0;
      if (data && !data->implicitconv) {
        PyObject *klass = data->klass;
        if (klass) {
          PyObject *impconv;
          data->implicitconv = 1; /* avoid recursion and call 'explicit' constructors*/
          impconv = SWIG_Python_CallFunctor(klass, obj);
          data->implicitconv = 0;
          if (PyErr_Occurred()) {
            PyErr_Clear();
            impconv = 0;
          }
          if (impconv) {
            SwigPyObject *iobj = SWIG_Python_GetSwigThis(impconv);
            if (iobj) {
              void *vptr;
              res = SWIG_Python_ConvertPtrAndOwn((PyObject*)iobj, &vptr, ty, 0, 0);
              if (SWIG_IsOK(res)) {
                if (ptr) {
                  *ptr = vptr;
                  /* transfer the ownership to 'ptr' */
                  iobj->own = 0;
                  res = SWIG_AddCast(res);
                  res = SWIG_AddNewMask(res);
                } else {
                  res = SWIG_AddCast(res);		    
                }
              }
            }
            SWIG_Py_DECREF(impconv);
          }
        }
      }
      if (!SWIG_IsOK(res) && obj == Py_None) {
        if (ptr)
          *ptr = 0;
        if (PyErr_Occurred())
          PyErr_Clear();
        res = SWIG_OK;
      }
    }
  }
  return res;
}

/* Convert a function ptr value */

SWIGRUNTIME int
SWIG_Python_ConvertFunctionPtr(PyObject *obj, void **ptr, swig_type_info *ty) {
  if (!PyCFunction_Check(obj)) {
    return SWIG_ConvertPtr(obj, ptr, ty, 0);
  } else {
    void *vptr = 0;
    swig_cast_info *tc;

    /* here we get the method pointer for callbacks */
#ifndef Py_LIMITED_API
    const char *doc = (((PyCFunctionObject *)obj) -> m_ml -> ml_doc);
#else
    PyObject* pystr_doc = PyObject_GetAttrString(obj, "__doc__");
    PyObject *bytes = NULL;
    const char *doc = pystr_doc ? SWIG_PyUnicode_AsUTF8AndSize(pystr_doc, NULL, &bytes) : 0;
#endif
    const char *desc = doc ? strstr(doc, "swig_ptr: ") : 0;
    if (desc)
      desc = ty ? SWIG_UnpackVoidPtr(desc + 10, &vptr, ty->name) : 0;
#ifdef Py_LIMITED_API
    SWIG_Py_XDECREF(bytes);
    SWIG_Py_XDECREF(pystr_doc);
#endif
    if (!desc)
      return SWIG_ERROR;
    tc = SWIG_TypeCheck(desc,ty);
    if (tc) {
      int newmemory = 0;
      *ptr = SWIG_TypeCast(tc,vptr,&newmemory);
      assert(!newmemory); /* newmemory handling not yet implemented */
    } else {
      return SWIG_ERROR;
    }
    return SWIG_OK;
  }
}

/* Convert a packed pointer value */

SWIGRUNTIME int
SWIG_Python_ConvertPacked(PyObject *obj, void *ptr, size_t sz, swig_type_info *ty) {
  swig_type_info *to = SwigPyPacked_UnpackData(obj, ptr, sz);
  if (!to) return SWIG_ERROR;
  if (ty) {
    if (to != ty) {
      /* check type cast? */
      swig_cast_info *tc = SWIG_TypeCheck(to->name,ty);
      if (!tc) return SWIG_ERROR;
    }
  }
  return SWIG_OK;
}  

/* -----------------------------------------------------------------------------
 * Create a new pointer object
 * ----------------------------------------------------------------------------- */

/*
  Create a new instance object, without calling __init__, and set the
  'this' attribute.
*/

SWIGRUNTIME PyObject* 
SWIG_Python_NewShadowInstance(SwigPyClientData *data, PyObject *swig_this)
{
  PyObject *inst = 0;
  PyObject *newraw = data->newraw;
  if (newraw) {
    inst = PyObject_Call(newraw, data->newargs, NULL);
    if (inst) {
#if !defined(SWIG_PYTHON_SLOW_GETSET_THIS)
      PyObject **dictptr = _PyObject_GetDictPtr(inst);
      if (dictptr != NULL) {
        PyObject *dict = *dictptr;
        if (dict == NULL) {
          dict = PyDict_New();
          *dictptr = dict;
        }
        if (dict) {
          PyDict_SetItem(dict, SWIG_This(), swig_this);
        } else{
          SWIG_Py_DECREF(inst);
          inst = 0;
        }
      }
#else
      if (PyObject_SetAttr(inst, SWIG_This(), swig_this) == -1) {
        SWIG_Py_DECREF(inst);
        inst = 0;
      }
#endif
    }
  } else {
#if PY_VERSION_HEX >= 0x03000000
    PyObject *empty_args = PyTuple_New(0);
    if (empty_args) {
      PyObject *empty_kwargs = PyDict_New();
      if (empty_kwargs) {
#ifndef Py_LIMITED_API
        newfunc newfn = ((PyTypeObject *)data->newargs)->tp_new;
#else
        newfunc newfn = (newfunc)PyType_GetSlot((PyTypeObject *)data->newargs, Py_tp_new);
#endif
        inst = newfn((PyTypeObject *)data->newargs, empty_args, empty_kwargs);
        SWIG_Py_DECREF(empty_kwargs);
        if (inst) {
          if (PyObject_SetAttr(inst, SWIG_This(), swig_this) == -1) {
            SWIG_Py_DECREF(inst);
            inst = 0;
          } else {
            PyType_Modified(Py_TYPE(inst));
          }
        }
      }
      SWIG_Py_DECREF(empty_args);
    }
#else
    PyObject *dict = PyDict_New();
    if (dict) {
      PyDict_SetItem(dict, SWIG_This(), swig_this);
      inst = PyInstance_NewRaw(data->newargs, dict);
      SWIG_Py_DECREF(dict);
    }
#endif
  }
  return inst;
}

SWIGRUNTIME int
SWIG_Python_SetSwigThis(PyObject *inst, PyObject *swig_this)
{
#if !defined(SWIG_PYTHON_SLOW_GETSET_THIS)
  PyObject **dictptr = _PyObject_GetDictPtr(inst);
  if (dictptr != NULL) {
    PyObject *dict = *dictptr;
    if (dict == NULL) {
      dict = PyDict_New();
      *dictptr = dict;
    }
    if (dict) {
      return PyDict_SetItem(dict, SWIG_This(), swig_this);
    } else{
      return -1;
    }
  }
#endif
  return PyObject_SetAttr(inst, SWIG_This(), swig_this);
} 


SWIGINTERN PyObject *
SWIG_Python_InitShadowInstance(PyObject *args) {
  PyObject *obj[2];
  if (!SWIG_Python_UnpackTuple(args, "swiginit", 2, 2, obj)) {
    return NULL;
  } else {
    SwigPyObject *sthis = SWIG_Python_GetSwigThis(obj[0]);
    if (sthis) {
      SWIG_Py_DECREF(SwigPyObject_append((PyObject*) sthis, obj[1]));
    } else {
      if (SWIG_Python_SetSwigThis(obj[0], obj[1]) != 0)
        return NULL;
    }
    return SWIG_Py_Void();
  }
}

/* Create a new pointer object */

SWIGRUNTIME PyObject *
SWIG_Python_NewPointerObj(PyObject *self, void *ptr, swig_type_info *type, int flags) {
  SwigPyClientData *clientdata;
  PyObject * robj;
  int own;

  if (!ptr)
    return SWIG_Py_Void();

  clientdata = type ? (SwigPyClientData *)(type->clientdata) : 0;
  own = (flags & SWIG_POINTER_OWN) ? SWIG_POINTER_OWN : 0;
  if (clientdata && clientdata->pytype) {
    SwigPyObject *newobj;
    if (flags & SWIG_BUILTIN_TP_INIT) {
      newobj = (SwigPyObject*) self;
      if (newobj->ptr) {
#ifndef Py_LIMITED_API
        allocfunc alloc = clientdata->pytype->tp_alloc;
#else
        allocfunc alloc = (allocfunc)PyType_GetSlot(clientdata->pytype, Py_tp_alloc);
#endif
        PyObject *next_self = alloc(clientdata->pytype, 0);
        while (newobj->next)
	  newobj = (SwigPyObject *) newobj->next;
        newobj->next = next_self;
        newobj = (SwigPyObject *)next_self;
        newobj->swigdict = 0;
        newobj->weakreflist = 0;
      }
    } else {
      newobj = PyObject_New(SwigPyObject, clientdata->pytype);
      if (newobj) {
        newobj->swigdict = 0;
        newobj->weakreflist = 0;
      }
    }
    if (newobj) {
      newobj->ptr = ptr;
      newobj->ty = type;
      newobj->own = own;
      newobj->next = 0;
      return (PyObject*) newobj;
    }
    return SWIG_Py_Void();
  }

  assert(!(flags & SWIG_BUILTIN_TP_INIT));

  robj = SwigPyObject_New(ptr, type, own);
  if (robj && clientdata && !(flags & SWIG_POINTER_NOSHADOW)) {
    PyObject *inst = SWIG_Python_NewShadowInstance(clientdata, robj);
    SWIG_Py_DECREF(robj);
    robj = inst;
  }
  return robj;
}

/* Create a new packed object */

SWIGRUNTIMEINLINE PyObject *
SWIG_Python_NewPackedObj(void *ptr, size_t sz, swig_type_info *type) {
  return ptr ? SwigPyPacked_New((void *) ptr, sz, type) : SWIG_Py_Void();
}

/* -----------------------------------------------------------------------------*
 *  Get type list 
 * -----------------------------------------------------------------------------*/

#ifdef SWIG_LINK_RUNTIME
void *SWIG_ReturnGlobalTypeList(void *);
#endif

static PyObject *Swig_TypeCache_global = NULL;

/* The python cached type query */
SWIGRUNTIME PyObject *
SWIG_Python_TypeCache(void) {
  if (Swig_TypeCache_global == NULL) {
    Swig_TypeCache_global = PyDict_New();
  }
  return Swig_TypeCache_global;
}

SWIGRUNTIME swig_module_info *
SWIG_Python_GetModule(void *SWIGUNUSEDPARM(clientdata)) {
#ifdef SWIG_LINK_RUNTIME
  static void *type_pointer = (void *)0;
  /* first check if module already created */
  if (!type_pointer) {
    type_pointer = SWIG_ReturnGlobalTypeList((void *)0);
  }
#else
  void *type_pointer = PyCapsule_Import(SWIGPY_CAPSULE_NAME, 0);
  if (PyErr_Occurred()) {
    PyErr_Clear();
    type_pointer = (void *)0;
  }
#endif
  return (swig_module_info *) type_pointer;
}


#if defined(SWIG_REFCNT_DEBUG)
#define SWIG_PYOBJ_REFCNT(OBJ) fprintf(stdout, "" #OBJ " count %ld\n", (OBJ ? Py_REFCNT(OBJ) : 0))
#else
#define SWIG_PYOBJ_REFCNT(OBJ)
#endif

static int interpreter_counter = 0; /* how many (sub-)interpreters are using swig_module's types */

SWIGRUNTIME void
SWIG_Python_DestroyModule(PyObject *obj)
{
  swig_module_info *swig_module = (swig_module_info *) PyCapsule_GetPointer(obj, SWIGPY_CAPSULE_NAME);
  swig_type_info **types = swig_module->types;
  size_t i;
  if (--interpreter_counter != 0) /* another sub-interpreter may still be using the swig_module's types */
    return;
  for (i = 0; i < swig_module->size; ++i) {
    swig_type_info *ty = types[i];
    if (ty->owndata) {
      SwigPyClientData *data = (SwigPyClientData *) ty->clientdata;
      ty->clientdata = 0;
      if (data) SwigPyClientData_Del(data);
    }
  }
  SWIG_PYOBJ_REFCNT(Swig_This_global);
  SWIG_Py_XDECREF(Swig_This_global);
  Swig_This_global = NULL;

  SWIG_PYOBJ_REFCNT(Swig_Globals_global);
  SWIG_Py_XDECREF(Swig_Globals_global);
  Swig_Globals_global = NULL;

  SWIG_PYOBJ_REFCNT(Swig_TypeCache_global);
  SWIG_Py_XDECREF(Swig_TypeCache_global);
  Swig_TypeCache_global = NULL;

  SWIG_PYOBJ_REFCNT(Swig_Capsule_global);
  Swig_Capsule_global = NULL;

  SWIG_PYOBJ_REFCNT(Swig_runtime_data_module_global);
  SWIG_Py_XDECREF(Swig_runtime_data_module_global);
  Swig_runtime_data_module_global = NULL;
}

SWIGRUNTIME void
SWIG_Python_SetModule(swig_module_info *swig_module) {
  PyObject *runtime_data_module = SWIG_runtime_data_module();
  PyObject *pointer = PyCapsule_New((void *) swig_module, SWIGPY_CAPSULE_NAME, SWIG_Python_DestroyModule);
  if (pointer && runtime_data_module) {
    if (PyModule_AddObject(runtime_data_module, SWIGPY_CAPSULE_ATTR_NAME, pointer) == 0) {
      ++interpreter_counter;
      Swig_Capsule_global = pointer;
    } else {
      SWIG_Py_DECREF(pointer);
    }
  } else {
    SWIG_Py_XDECREF(pointer);
  }
}

SWIGRUNTIME swig_type_info *
SWIG_Python_TypeQuery(const char *type)
{
  swig_type_info *descriptor;
  PyObject *cache = SWIG_Python_TypeCache();
  PyObject *obj;
  SWIG_PyDict_GetItemStringRef(cache, type, &obj);
  if (obj) {
    descriptor = (swig_type_info *) PyCapsule_GetPointer(obj, NULL);
  } else {
    swig_module_info *swig_module = SWIG_GetModule(0);
    descriptor = SWIG_TypeQueryModule(swig_module, swig_module, type);
    if (descriptor) {
      obj = PyCapsule_New((void*) descriptor, NULL, NULL);
      if (obj) PyDict_SetItemString(cache, type, obj);
    }
  }
  SWIG_Py_XDECREF(obj);
  return descriptor;
}

/* 
   For backward compatibility only
*/
#define SWIG_POINTER_EXCEPTION  0
#define SWIG_arg_fail(arg)      SWIG_Python_ArgFail(arg)
#define SWIG_MustGetPtr(p, type, argnum, flags)  SWIG_Python_MustGetPtr(p, type, argnum, flags)

SWIGRUNTIME int
SWIG_Python_AddErrMesg(const char* mesg, int infront)
{  
  if (PyErr_Occurred()) {
    PyObject *type = 0;
    PyObject *value = 0;
    PyObject *traceback = 0;
    PyErr_Fetch(&type, &value, &traceback);
    if (value) {
      PyObject *old_str = PyObject_Str(value);
      PyObject *bytes = NULL;
      const char *tmp = SWIG_PyUnicode_AsUTF8AndSize(old_str, NULL, &bytes);
      const char *errmesg = tmp ? tmp : "Invalid error message";
      SWIG_Py_XINCREF(type);
      PyErr_Clear();
      if (infront) {
	PyErr_Format(type, "%s %s", mesg, errmesg);
      } else {
	PyErr_Format(type, "%s %s", errmesg, mesg);
      }
      SWIG_Py_XDECREF(bytes);
      SWIG_Py_DECREF(old_str);
    }
    return 1;
  } else {
    return 0;
  }
}
  
SWIGRUNTIME int
SWIG_Python_ArgFail(int argnum)
{
  if (PyErr_Occurred()) {
    /* add information about failing argument */
    char mesg[256];
    PyOS_snprintf(mesg, sizeof(mesg), "argument number %d:", argnum);
    return SWIG_Python_AddErrMesg(mesg, 1);
  } else {
    return 0;
  }
}

SWIGRUNTIMEINLINE const char *
SwigPyObject_GetDesc(PyObject *self)
{
  SwigPyObject *v = (SwigPyObject *)self;
  swig_type_info *ty = v ? v->ty : 0;
  return ty ? ty->str : "";
}

/* Convert a pointer value, signal an exception on a type mismatch */
SWIGRUNTIME void *
SWIG_Python_MustGetPtr(PyObject *obj, swig_type_info *ty, int SWIGUNUSEDPARM(argnum), int flags) {
  void *result;
  if (SWIG_Python_ConvertPtr(obj, &result, ty, flags) == -1) {
    PyErr_Clear();
  }
  return result;
}

#ifdef SWIGPYTHON_BUILTIN
SWIGRUNTIME int
SWIG_Python_NonDynamicSetAttr(PyObject *obj, PyObject *name, PyObject *value) {
  PyTypeObject *tp = Py_TYPE(obj);
  PyObject *descr;
  PyObject *encoded_name;
  descrsetfunc f;
  int res = -1;

# ifdef Py_USING_UNICODE
  if (PyString_Check(name)) {
    name = PyUnicode_Decode(PyString_AsString(name), PyString_Size(name), NULL, NULL);
    if (!name)
      return -1;
  } else if (!PyUnicode_Check(name))
# else
  if (!PyString_Check(name))
# endif
  {
#if PY_VERSION_HEX >= 0x03000000
    PyObject *tpname = SWIG_PyType_GetFullyQualifiedName(Py_TYPE(name));
    PyErr_Format(PyExc_TypeError, "attribute name must be string, not '%S'", tpname);
    SWIG_Py_DECREF(tpname);
#else
    PyErr_Format(PyExc_TypeError, "attribute name must be string, not '%s'", Py_TYPE(name)->tp_name);
#endif
    return -1;
  } else {
    SWIG_Py_INCREF(name);
  }

  if (!tp->tp_dict) {
    if (PyType_Ready(tp) != 0)
      goto done;
  }

  descr = _PyType_Lookup(tp, name);
  f = NULL;
  if (descr != NULL)
    f = Py_TYPE(descr)->tp_descr_set;
  if (!f) {
    if (PyString_Check(name)) {
      encoded_name = name;
      SWIG_Py_INCREF(name);
    } else {
      encoded_name = PyUnicode_AsUTF8String(name);
      if (!encoded_name)
        goto done;
    }
#if PY_VERSION_HEX >= 0x03000000
    {
      PyObject *tpname = SWIG_PyType_GetFullyQualifiedName(tp);
      PyErr_Format(PyExc_AttributeError, "'%S' object has no attribute '%s'", tpname, PyString_AsString(encoded_name));
      SWIG_Py_DECREF(tpname);
    }
#else
    PyErr_Format(PyExc_AttributeError, "'%s' object has no attribute '%s'", tp->tp_name, PyString_AsString(encoded_name));
#endif
    SWIG_Py_DECREF(encoded_name);
  } else {
    res = f(descr, obj, value);
  }
  
  done:
  SWIG_Py_DECREF(name);
  return res;
}
#endif


#ifdef __cplusplus
}
#endif



#define SWIG_exception_fail(code, msg) do { SWIG_Error(code, msg); SWIG_fail; } while(0) 

#define SWIG_contract_assert(expr, msg) do { if (!(expr)) { SWIG_Error(SWIG_RuntimeError, msg); SWIG_fail; } } while (0) 



  #define SWIG_exception(code, msg) do { SWIG_Error(code, msg); SWIG_fail;; } while(0) 


/* -------- TYPES TABLE (BEGIN) -------- */

#define SWIGTYPE_p_FILE swig_types[0]
#define SWIGTYPE_p_WS_LASTERR_Code swig_types[1]
#define SWIGTYPE_p_WsEnumerateInfo swig_types[2]
#define SWIGTYPE_p_WsmanKnownStatusCode swig_types[3]
#define SWIGTYPE_p_WsmanMessage swig_types[4]
#define SWIGTYPE_p__WS_CONTEXT swig_types[5]
#define SWIGTYPE_p__WsManClient swig_types[6]
#define SWIGTYPE_p__WsManFault swig_types[7]
#define SWIGTYPE_p__WsManTransport swig_types[8]
#define SWIGTYPE_p__WsXmlDoc swig_types[9]
#define SWIGTYPE_p__WsmanStatus swig_types[10]
#define SWIGTYPE_p___Soap swig_types[11]
#define SWIGTYPE_p___SoapOp swig_types[12]
#define SWIGTYPE_p___WsEnumerateInfo swig_types[13]
#define SWIGTYPE_p___WsXmlAttr swig_types[14]
#define SWIGTYPE_p___WsXmlNode swig_types[15]
#define SWIGTYPE_p___WsXmlNs swig_types[16]
#define SWIGTYPE_p___WsmanFaultCodeTable swig_types[17]
#define SWIGTYPE_p___WsmanFaultCodeType swig_types[18]
#define SWIGTYPE_p___WsmanFaultDetailTable swig_types[19]
#define SWIGTYPE_p___WsmanFaultDetailType swig_types[20]
#define SWIGTYPE_p_char swig_types[21]
#define SWIGTYPE_p_client_opt_t swig_types[22]
#define SWIGTYPE_p_epr_t swig_types[23]
#define SWIGTYPE_p_filter_t swig_types[24]
#define SWIGTYPE_p_p_char swig_types[25]
#define SWIGTYPE_p_void swig_types[26]
#define SWIGTYPE_p_wsman_auth_request_func_t swig_types[27]
#define SWIGTYPE_p_wsman_auth_type_t swig_types[28]
static swig_type_info *swig_types[30];
static swig_module_info swig_module = {swig_types, 29, 0, 0, 0, 0};
#define SWIG_TypeQuery(name) SWIG_TypeQueryModule(&swig_module, &swig_module, name)
#define SWIG_MangledTypeQuery(name) SWIG_MangledTypeQueryModule(&swig_module, &swig_module, name)

/* -------- TYPES TABLE (END) -------- */

#ifdef SWIG_TypeQuery
# undef SWIG_TypeQuery
#endif
#define SWIG_TypeQuery SWIG_Python_TypeQuery

/*-----------------------------------------------
              @(target):= _pywsman.so
  ------------------------------------------------*/
#if PY_VERSION_HEX >= 0x03000000
#  define SWIG_init    PyInit__pywsman

#else
#  define SWIG_init    init_pywsman

#endif

#define SWIG_as_voidptr(a) (void *)((const void *)(a)) 
#define SWIG_as_voidptrptr(a) ((void)SWIG_as_voidptr(*a),(void**)(a)) 


/*
 * type definitions to keep the C code generic
 */
 
#if defined(SWIGPYTHON)
#define Target_Null_p(x) (x == Py_None)
#define Target_INCREF(x) Py_INCREF(x)
#define Target_DECREF(x) Py_DECREF(x)
#define Target_True Py_True
#define Target_False Py_False
#define Target_Null Py_None
#define Target_Type PyObject*
#define Target_Bool(x) PyBool_FromLong(x)
#define Target_Char16(x) PyInt_FromLong(x)
#define Target_Int(x) PyInt_FromLong(x)
#define Target_String(x) PyString_FromString(x)
#define Target_Real(x) Py_None
#define Target_Array() PyList_New(0)
#define Target_SizedArray(len) PyList_New(len)
#define Target_ListSet(x,n,y) PyList_SetItem(x,n,y)
#define Target_Append(x,y) PyList_Append(x,y)
#include <Python.h>
#define TARGET_THREAD_BEGIN_BLOCK SWIG_PYTHON_THREAD_BEGIN_BLOCK
#define TARGET_THREAD_END_BLOCK SWIG_PYTHON_THREAD_END_BLOCK
#define TARGET_THREAD_BEGIN_ALLOW SWIG_PYTHON_THREAD_BEGIN_ALLOW
#define TARGET_THREAD_END_ALLOW SWIG_PYTHON_THREAD_END_ALLOW
#endif

#if defined(SWIGRUBY)
#define Target_Null_p(x) NIL_P(x)
#define Target_INCREF(x) 
#define Target_DECREF(x) 
#define Target_True Qtrue
#define Target_False Qfalse
#define Target_Null Qnil
#define Target_Type VALUE
#define Target_Bool(x) ((x)?Qtrue:Qfalse)
#define Target_Char16(x) INT2FIX(x)
#define Target_Int(x) INT2FIX(x)
#define Target_String(x) rb_str_new2(x)
#define Target_Real(x) rb_float_new(x)
#define Target_Array() rb_ary_new()
#define Target_SizedArray(len) rb_ary_new2(len)
#define Target_ListSet(x,n,y) rb_ary_store(x,n,y)
#define Target_Append(x,y) rb_ary_push(x,y)
#define TARGET_THREAD_BEGIN_BLOCK do {} while(0)
#define TARGET_THREAD_END_BLOCK do {} while(0)
#define TARGET_THREAD_BEGIN_ALLOW do {} while(0)
#define TARGET_THREAD_END_ALLOW do {} while(0)
#include <ruby.h>
#if HAVE_RUBY_IO_H
#include <ruby/io.h> /* Ruby 1.9 style */
#else
#include <rubyio.h>
#endif
#if HAVE_RUBY_VERSION_H
#include <ruby/version.h>
#endif
#endif

#if defined(SWIGPERL)
#define TARGET_THREAD_BEGIN_BLOCK do {} while(0)
#define TARGET_THREAD_END_BLOCK do {} while(0)
#define TARGET_THREAD_BEGIN_ALLOW do {} while(0)
#define TARGET_THREAD_END_ALLOW do {} while(0)

SWIGINTERNINLINE SV *SWIG_From_long  SWIG_PERL_DECL_ARGS_1(long value);
SWIGINTERNINLINE SV *SWIG_FromCharPtr(const char *cptr);
SWIGINTERNINLINE SV *SWIG_From_double  SWIG_PERL_DECL_ARGS_1(double value);

#define Target_Null_p(x) (x == NULL)
#define Target_INCREF(x) 
#define Target_DECREF(x) 
#define Target_True (&PL_sv_yes)
#define Target_False (&PL_sv_no)
#define Target_Null NULL
#define Target_Type SV *
#define Target_Bool(x) (x)?Target_True:Target_False
#define Target_Char16(x) SWIG_From_long(x)
#define Target_Int(x) SWIG_From_long(x)
#define Target_String(x) SWIG_FromCharPtr(x)
#define Target_Real(x) SWIG_From_double(x)
#define Target_Array() (SV *)newAV()
#define Target_SizedArray(len) (SV *)newAV()
#define Target_ListSet(x,n,y) av_store((AV *)(x),n,y)
#define Target_Append(x,y) av_push(((AV *)(x)), y)
#include <perl.h>
#include <EXTERN.h>
#endif



SWIGINTERN swig_type_info*
SWIG_pchar_descriptor(void)
{
  static swig_type_info* info = 0;
  if (!info) {
    info = SWIG_TypeQuery("_p_char");
  }
  return info;
}


/* Return string from Python obj. NOTE: obj must remain in scope in order
   to use the returned cptr (but only when alloc is set to SWIG_OLDOBJ) */
SWIGINTERN int
SWIG_AsCharPtrAndSize(PyObject *obj, char **cptr, size_t *psize, int *alloc)
{
#if PY_VERSION_HEX >= 0x03000000
#if defined(SWIG_PYTHON_STRICT_BYTE_CHAR)
  if (PyBytes_Check(obj))
#else
  if (PyUnicode_Check(obj))
#endif
#else  
  if (PyString_Check(obj))
#endif
  {
    char *cstr; Py_ssize_t len;
    PyObject *bytes = NULL;
    int ret = SWIG_OK;
    if (alloc)
      *alloc = SWIG_OLDOBJ;
#if PY_VERSION_HEX >= 0x03000000 && defined(SWIG_PYTHON_STRICT_BYTE_CHAR)
    if (PyBytes_AsStringAndSize(obj, &cstr, &len) == -1)
      return SWIG_TypeError;
#else
    cstr = (char *)SWIG_PyUnicode_AsUTF8AndSize(obj, &len, &bytes);
    if (!cstr)
      return SWIG_TypeError;
    /* The returned string is only duplicated if the char * returned is not owned and memory managed by obj */
    if (bytes && cptr) {
      if (alloc) {
        cstr = (char *)memcpy(malloc((len + 1)*sizeof(char)), cstr, sizeof(char)*(len + 1));
        *alloc = SWIG_NEWOBJ;
      } else {
        /* alloc must be set in order to clean up allocated memory */
        return SWIG_RuntimeError;
      }
    }
#endif
    if (cptr) *cptr = cstr;
    if (psize) *psize = len + 1;
    SWIG_Py_XDECREF(bytes);
    return ret;
  } else {
#if defined(SWIG_PYTHON_2_UNICODE)
#if defined(SWIG_PYTHON_STRICT_BYTE_CHAR)
#error "Cannot use both SWIG_PYTHON_2_UNICODE and SWIG_PYTHON_STRICT_BYTE_CHAR at once"
#endif
#if PY_VERSION_HEX < 0x03000000
    if (PyUnicode_Check(obj)) {
      char *cstr; Py_ssize_t len;
      if (!alloc && cptr) {
        return SWIG_RuntimeError;
      }
      obj = PyUnicode_AsUTF8String(obj);
      if (!obj)
        return SWIG_TypeError;
      if (PyString_AsStringAndSize(obj, &cstr, &len) != -1) {
        if (cptr) {
          if (alloc) *alloc = SWIG_NEWOBJ;
          *cptr = (char *)memcpy(malloc((len + 1)*sizeof(char)), cstr, sizeof(char)*(len + 1));
        }
        if (psize) *psize = len + 1;

        SWIG_Py_XDECREF(obj);
        return SWIG_OK;
      } else {
        SWIG_Py_XDECREF(obj);
      }
    }
#endif
#endif

    swig_type_info* pchar_descriptor = SWIG_pchar_descriptor();
    if (pchar_descriptor) {
      void* vptr = 0;
      if (SWIG_ConvertPtr(obj, &vptr, pchar_descriptor, 0) == SWIG_OK) {
	if (cptr) *cptr = (char *) vptr;
	if (psize) *psize = vptr ? (strlen((char *)vptr) + 1) : 0;
	if (alloc) *alloc = SWIG_OLDOBJ;
	return SWIG_OK;
      }
    }
  }
  return SWIG_TypeError;
}





#if defined(SWIGPERL)
/* filter_t is defined in Perls CORE/perl.h */
#define filter_t filter_type

/* undef Perl's die and warn macros as libu is going to reuse this names */
#undef die
#undef warn
#endif /* SWIGPERL */

#include <u/libu.h>
#include <wsman-types.h>
#include <wsman-client.h>
#include <wsman-client-transport.h>
#include <wsman-api.h>
#include <wsman-xml-binding.h>
#include <wsman-xml.h>
#include <wsman-epr.h>
#include <wsman-filter.h>
#include <wsman-soap.h>
#include <wsman-soap-envelope.h>
#include <openwsman.h>

#if defined(SWIGRUBY)
#include <ruby/helpers.h>

SWIGEXPORT
/* Init_ for the %module, defined by Swig
 * :nodoc:
 */
void Init_Openwsman(void);

SWIGEXPORT
/* Init_ for the .so lib, called by Ruby
 * :nodoc:
 */
void Init__openwsman(void) {
  Init_Openwsman();
}
#endif
#if defined(SWIGPYTHON)
#include <python/helpers.h>
#endif
#if defined(SWIGJAVA)
#include <java/helpers.h>
#endif
#if defined(SWIGPERL)
#include <perl/helpers.h>
#endif

/* Provide WsManTransport definition so it can be used as
 * dedicated datatype in bindings.
 * :nodoc:ly, its aliased to WsManClient
 *
 */
struct _WsManTransport { };
typedef struct _WsManTransport WsManTransport;

static void set_debug(int dbg);

/*
 * Set openwsman debug level.
 * call-seq:
 *   Openwsman::debug = -1 # full debug
 *
 */
static void set_debug(int dbg) {
  static int init = 0;

  if (!init && dbg != 0) {
    init = 1;
    debug_add_handler( debug_message_handler, DEBUG_LEVEL_ALWAYS, NULL );
  }
  wsman_debug_set_level( dbg );
	
}

/* module-level methods */

static int get_debug(void);

/*
 * Return openwsman debug level.
 * call-seq:
 *   Openwsman::debug -> Integer
 *
 */
static int get_debug(void) {
  return (int)wsman_debug_get_level();
}

static WsXmlDocH create_soap_envelope(void);

/*
 * Create empty SOAP envelope
 * call-seq:
 *   Openwsman::create_soap_envelope -> XmlDoc
 *
 */
static WsXmlDocH create_soap_envelope() {
  return ws_xml_create_soap_envelope();
}

static WsXmlDocH create_doc_from_file(const char *filename, const char *encoding);

/*
 * Read XmlDoc from file
 * call-seq:
 *   Openwsman::create_doc_from_file("/path/to/file", "utf-8") -> XmlDoc
 *
 */
static WsXmlDocH create_doc_from_file(const char *filename, const char *encoding) {
  return xml_parser_file_to_doc( filename, encoding, 0);                 
}

static WsXmlDocH create_doc_from_string(const char *buf, const char *encoding);

/*
 * Read XmlDoc from string
 * call-seq:
 *   Openwsman::create_doc_from_string("<xml ...>", "utf-8") -> XmlDoc
 *
 */
static WsXmlDocH create_doc_from_string(const char *buf, const char *encoding) {
  return xml_parser_memory_to_doc( buf, strlen(buf), encoding, 0);
}

static char *uri_classname(const char *uri);
/*
 * get classname from resource URI
 * call-seq:
 *   Openwsman::uri_classname("http://sblim.sf.net/wbem/wscim/1/cim-schema/2/Linux_OperatingSystem") -> "Linux_OperatingSystem"
 *
 */
static char *uri_classname(const char *uri) {
  const char *lastslash = strrchr(uri,'/');
  if (lastslash) {
    return strdup(lastslash+1);
  }
  return NULL;
}

static const char *uri_prefix(const char *classname);
/*
 * Map classname (class schema) to resource uri prefix
 * call-seq:
 *   Openwsman::uri_prefix("Linux") -> "http://sblim.sf.net/wbem/wscim/1/cim-schema/2"
 *   Openwsman::uri_prefix("Win32") -> "http://schemas.microsoft.com/wbem/wsman/1/wmi"
 *
 */
static const char *uri_prefix(const char *classname) {
  static struct map {
    int len;
    const char *schema;
    const char *prefix;
  } mapping[] = {
    /* dmtf CIM */
    { 3, "CIM", "http://schemas.dmtf.org/wbem/wscim/1/cim-schema/2" },
    /* dmtf reserved */
    { 3, "PRS", "http://schemas.dmtf.org/wbem/wscim/1/cim-schema/2" },
    /* Microsoft WMI */
    { 5, "Win32", "http://schemas.microsoft.com/wbem/wsman/1/wmi" },
    /* openwbem.org */
    { 8, "OpenWBEM", "http://schema.openwbem.org/wbem/wscim/1/cim-schema/2" },
    /* sblim */
    { 5, "Linux", "http://sblim.sf.net/wbem/wscim/1/cim-schema/2" },
    /* omc-project */
    { 3, "OMC", "http://schema.omc-project.org/wbem/wscim/1/cim-schema/2" },
    /* pegasus.org */
    { 2, "PG", "http://schema.openpegasus.org/wbem/wscim/1/cim-schema/2" },
    /* Intel AMT */
    { 3, "AMT", "http://intel.com/wbem/wscim/1/amt-schema/1" },
    /* Intel */
    { 3, "IPS", "http://intel.com/wbem/wscim/1/ips-schema/1" },
    /* Sun */
    { 3, "Sun","http://schemas.sun.com/wbem/wscim/1/cim-schema/2" },
    /* Microsoft HyperV */
    { 4, "Msvm", "http://schemas.microsoft.com/wbem/wsman/1/wmi" },
    /* Dell DRAC */
    { 4, "DCIM", "http://schemas.dell.com/wbem/wscim/1/cim-schema/2" },
    /* Unisys */
    { 4, "SPAR", "http://schema.unisys.com/wbem/wscim/1/cim-schema/2" },
    /* Fujitsu */
    { 3, "SVS", "http://schemas.ts.fujitsu.com/wbem/wscim/1/cim-schema/2" },
    { 0, NULL, NULL }
  };
  const char *schema_end;
  struct map *map;
  int len;
  if (classname == NULL)
    return NULL;
  if (strcmp(classname, "*") == 0) {
    return "http://schemas.dmtf.org/wbem/wscim/1";
  }
  if ((strcmp(classname, "meta_class") == 0)
      ||(strncmp(classname, "__", 2) == 0)) {
    return "http://schemas.microsoft.com/wbem/wsman/1/wmi";
  }
  schema_end = strchr(classname, '_');
  if (schema_end == NULL)
    return NULL; /* Bad class name */
  len = schema_end - classname;
  map = mapping;
  while (map->len > 0) {
    if ((len == map->len)
        && (strncasecmp(classname, map->schema, map->len) == 0)) {
      return map->prefix;
    }
    ++map;
  }
  return NULL;
}

#if defined(SWIGRUBY)
static epr_t *my_epr_deserialize(WsXmlNodeH node);
/*:nodoc:*/
static epr_t *my_epr_deserialize(WsXmlNodeH node) {
  if (strcmp(WSA_EPR, ws_xml_get_node_local_name(node)) == 0) {
    /* Use node as-is if its already a WSA_EPR */
    return epr_deserialize(node, NULL, NULL, 1);
  }
  /* else search the WSA_EPR node */
  return epr_deserialize(node, XML_NS_ADDRESSING, WSA_EPR, 1);
}

/*:nodoc:*/
static VALUE kv_list_to_hash(list_t *list)
{
  VALUE v = Qnil;
  if (!list_isempty(list)) {
  v = rb_hash_new();
  lnode_t *node = list_first(list);
  while (node) {
    key_value_t *kv = (key_value_t *)node->list_data;
    if (kv->type == 0) {
      rb_hash_aset( v, makestring(kv->key), makestring(kv->v.text));
    }
    else {
      VALUE epr = SWIG_NewPointerObj((void*)kv->v.epr, SWIGTYPE_p_epr_t, 0);
      rb_hash_aset( v, makestring(kv->key), epr);
    }
    node = list_next(list, node);
    }
  }
  return v;
}
#endif

static char *epr_prefix(const char *uri);
/* Get prefix from a EPR uri
 * :nodoc:
 */
static char *epr_prefix(const char *uri) {
  char *classname = uri_classname(uri);
  const char *prefix = uri_prefix(classname);
  if (prefix) {
    const char *lastslash;
    if (strncmp(uri, prefix, strlen(prefix)) == 0) {
      return strdup(prefix);
    }
    lastslash = strrchr(uri, '/');
    if (lastslash) {
      return strndup(uri, lastslash-uri);
    }
  }
  return strdup(uri);
}



SWIGINTERNINLINE PyObject*
  SWIG_From_int  (int value)
{
  return PyInt_FromLong((long) value);
}


SWIGINTERNINLINE PyObject *
SWIG_FromCharPtrAndSize(const char* carray, size_t size)
{
  if (carray) {
    if (size > (size_t)PY_SSIZE_T_MAX) {
      swig_type_info* pchar_descriptor = SWIG_pchar_descriptor();
      return pchar_descriptor ? 
	SWIG_InternalNewPointerObj((char *)(carray), pchar_descriptor, 0) : SWIG_Py_Void();
    } else {
#if PY_VERSION_HEX >= 0x03000000
#if defined(SWIG_PYTHON_STRICT_BYTE_CHAR)
      return PyBytes_FromStringAndSize(carray, (Py_ssize_t)(size));
#else
      return PyUnicode_DecodeUTF8(carray, (Py_ssize_t)(size), "surrogateescape");
#endif
#else
      return PyString_FromStringAndSize(carray, (Py_ssize_t)(size));
#endif
    }
  } else {
    return SWIG_Py_Void();
  }
}


SWIGINTERNINLINE PyObject * 
SWIG_FromCharPtr(const char *cptr)
{ 
  return SWIG_FromCharPtrAndSize(cptr, (cptr ? strlen(cptr) : 0));
}

SWIGINTERN struct _WsXmlDoc *new__WsXmlDoc(char const *name,char const *ns){
    return ws_xml_create_doc(ns, name);
  }
SWIGINTERN void delete__WsXmlDoc(struct _WsXmlDoc *self){
    ws_xml_destroy_doc( self );
  }
SWIGINTERN char *_WsXmlDoc_string(struct _WsXmlDoc *self){
    int size;
    char *buf;
    /* force utf-8 encoding since e.g. winrm sends utf-16 */
    ws_xml_dump_memory_node_tree_enc( ws_xml_get_doc_root(self), &buf, &size, "UTF-8" );
    return buf;
  }
SWIGINTERN char *_WsXmlDoc_encode(struct _WsXmlDoc *self,char const *encoding){
    int size;
    char *buf;
    ws_xml_dump_memory_enc( self, &buf, &size, encoding );
    return buf;
  }
SWIGINTERN void _WsXmlDoc_dump_file(struct _WsXmlDoc *self,FILE *fp){
    ws_xml_dump_doc( fp, self );
  }
SWIGINTERN WsXmlNodeH _WsXmlDoc_root(struct _WsXmlDoc *self){
    return ws_xml_get_doc_root( self );
  }
SWIGINTERN WsXmlNodeH _WsXmlDoc_envelope(struct _WsXmlDoc *self){
    return ws_xml_get_soap_envelope( self );
  }
SWIGINTERN WsXmlNodeH _WsXmlDoc_header(struct _WsXmlDoc *self){
    return ws_xml_get_soap_header( self );
  }
SWIGINTERN WsXmlNodeH _WsXmlDoc_body(struct _WsXmlDoc *self){
    return ws_xml_get_soap_body( self );
  }
SWIGINTERN WsXmlNodeH _WsXmlDoc_element(struct _WsXmlDoc *self,char const *name){
    return ws_xml_get_soap_element( self, name );
  }
SWIGINTERN char const *_WsXmlDoc_context(struct _WsXmlDoc *self){
    char *c = wsmc_get_enum_context( self );
    if (c) {
      if (*c)
        return c;
      u_free(c);
    }
    return NULL;
  }
SWIGINTERN WsXmlDocH _WsXmlDoc_generate_fault(struct _WsXmlDoc *self,WsmanStatus *s){
    return wsman_generate_fault( self, s->fault_code, s->fault_detail_code, s->fault_msg);
  }
SWIGINTERN int _WsXmlDoc_is_fault(struct _WsXmlDoc *self){
    return wsmc_check_for_fault( self );
  }
SWIGINTERN WsManFault *_WsXmlDoc_fault(struct _WsXmlDoc *self){
    WsManFault *f = NULL;
    if (wsmc_check_for_fault(self)) {
      f = (WsManFault *)calloc(1, sizeof(WsManFault));
      wsmc_get_fault_data(self, f);
    }
    return f;
  }
SWIGINTERN WsXmlDocH _WsXmlDoc_create_response_envelope(struct _WsXmlDoc *self,char const *action){
    return wsman_create_response_envelope(self, action);
  }
SWIGINTERN int _WsXmlDoc_is_end_of_sequence(struct _WsXmlDoc *self){
    return NULL != ws_xml_find_in_tree( ws_xml_get_soap_body( self ), XML_NS_ENUMERATION, WSENUM_END_OF_SEQUENCE, 1 );
  }
SWIGINTERN void delete___WsXmlNode(struct __WsXmlNode *self){
    ws_xml_unlink_node(self);
  }
SWIGINTERN char *__WsXmlNode_string(struct __WsXmlNode *self){
    int size;
    char *buf;
    ws_xml_dump_memory_node_tree( self, &buf, &size );
    return buf;
  }
SWIGINTERN void __WsXmlNode_dump_file(struct __WsXmlNode *self,FILE *fp){
    ws_xml_dump_node_tree( fp, self );
  }
SWIGINTERN int __WsXmlNode_equal(struct __WsXmlNode *self,WsXmlNodeH n){ return self == n; }
SWIGINTERN char *__WsXmlNode_text(struct __WsXmlNode *self){
    return ws_xml_get_node_text( self );
  }
SWIGINTERN void __WsXmlNode_set_text(struct __WsXmlNode *self,char const *text){
    ws_xml_set_node_text( self, text );
  }
SWIGINTERN WsXmlDocH __WsXmlNode_doc(struct __WsXmlNode *self){
    return ws_xml_get_node_doc( self );
  }
SWIGINTERN WsXmlNodeH __WsXmlNode_parent(struct __WsXmlNode *self){
    return ws_xml_get_node_parent( self );
  }
SWIGINTERN WsXmlNodeH __WsXmlNode_child(struct __WsXmlNode *self){
    return xml_parser_get_first_child(self);
  }
SWIGINTERN char *__WsXmlNode_name(struct __WsXmlNode *self){
    return ws_xml_get_node_local_name( self );
  }
SWIGINTERN void __WsXmlNode_set_name(struct __WsXmlNode *self,char const *name){
    ws_xml_set_node_name( self, ws_xml_get_node_name_ns( self ), name );
  }
SWIGINTERN char *__WsXmlNode_ns(struct __WsXmlNode *self){
    return ws_xml_get_node_name_ns( self );
  }
SWIGINTERN void __WsXmlNode_set_ns(struct __WsXmlNode *self,char const *ns){
    ws_xml_set_ns( self, ns, ws_xml_get_node_name_ns_prefix(self) );
  }
SWIGINTERN char const *__WsXmlNode_prefix(struct __WsXmlNode *self){
    return ws_xml_get_node_name_ns_prefix(self);
  }
SWIGINTERN void __WsXmlNode_set_lang(struct __WsXmlNode *self,char const *lang){
    ws_xml_set_node_lang(self, lang);
  }

#include <limits.h>
#if !defined(SWIG_NO_LLONG_MAX)
# if !defined(LLONG_MAX) && defined(__GNUC__) && defined (__LONG_LONG_MAX__)
#   define LLONG_MAX __LONG_LONG_MAX__
#   define LLONG_MIN (-LLONG_MAX - 1LL)
#   define ULLONG_MAX (LLONG_MAX * 2ULL + 1ULL)
# endif
#endif


SWIGINTERN int
SWIG_AsVal_double (PyObject *obj, double *val)
{
  int res = SWIG_TypeError;
  if (PyFloat_Check(obj)) {
    if (val) *val = PyFloat_AsDouble(obj);
    return SWIG_OK;
#if PY_VERSION_HEX < 0x03000000
  } else if (PyInt_Check(obj)) {
    if (val) *val = (double) PyInt_AsLong(obj);
    return SWIG_OK;
#endif
  } else if (PyLong_Check(obj)) {
    double v = PyLong_AsDouble(obj);
    if (!PyErr_Occurred()) {
      if (val) *val = v;
      return SWIG_OK;
    } else {
      PyErr_Clear();
    }
  }
#ifdef SWIG_PYTHON_CAST_MODE
  {
    int dispatch = 0;
    double d = PyFloat_AsDouble(obj);
    if (!PyErr_Occurred()) {
      if (val) *val = d;
      return SWIG_AddCast(SWIG_OK);
    } else {
      PyErr_Clear();
    }
    if (!dispatch) {
      long v = PyLong_AsLong(obj);
      if (!PyErr_Occurred()) {
	if (val) *val = v;
	return SWIG_AddCast(SWIG_AddCast(SWIG_OK));
      } else {
	PyErr_Clear();
      }
    }
  }
#endif
  return res;
}


#include <errno.h>


#include <float.h>


#include <math.h>


SWIGINTERNINLINE int
SWIG_CanCastAsInteger(double *d, double min, double max) {
  double x = *d;
  if ((min <= x && x <= max)) {
   double fx, cx, rd;
   errno = 0;
   fx = floor(x);
   cx = ceil(x);
   rd =  ((x - fx) < 0.5) ? fx : cx; /* simple rint */
   if ((errno == EDOM) || (errno == ERANGE)) {
     errno = 0;
   } else {
     double summ, reps, diff;
     if (rd < x) {
       diff = x - rd;
     } else if (rd > x) {
       diff = rd - x;
     } else {
       return 1;
     }
     summ = rd + x;
     reps = diff/summ;
     if (reps < 8*DBL_EPSILON) {
       *d = rd;
       return 1;
     }
   }
  }
  return 0;
}


SWIGINTERN int
SWIG_AsVal_long (PyObject *obj, long* val)
{
#if PY_VERSION_HEX < 0x03000000
  if (PyInt_Check(obj)) {
    if (val) *val = PyInt_AsLong(obj);
    return SWIG_OK;
  } else
#endif
  if (PyLong_Check(obj)) {
    long v = PyLong_AsLong(obj);
    if (!PyErr_Occurred()) {
      if (val) *val = v;
      return SWIG_OK;
    } else {
      PyErr_Clear();
      return SWIG_OverflowError;
    }
  }
#ifdef SWIG_PYTHON_CAST_MODE
  {
    int dispatch = 0;
    long v = PyInt_AsLong(obj);
    if (!PyErr_Occurred()) {
      if (val) *val = v;
      return SWIG_AddCast(SWIG_OK);
    } else {
      PyErr_Clear();
    }
    if (!dispatch) {
      double d;
      int res = SWIG_AddCast(SWIG_AsVal_double (obj,&d));
      // Largest double not larger than LONG_MAX (not portably calculated easily)
      // Note that double(LONG_MAX) is stored in a double rounded up by one (for 64-bit long)
      // 0x7ffffffffffffc00LL == (int64_t)std::nextafter(double(__uint128_t(LONG_MAX)+1), double(0))
      const double long_max = sizeof(long) == 8 ? 0x7ffffffffffffc00LL : LONG_MAX;
      // No equivalent needed for 64-bit double(LONG_MIN) is exactly LONG_MIN
      if (SWIG_IsOK(res) && SWIG_CanCastAsInteger(&d, LONG_MIN, long_max)) {
	if (val) *val = (long)(d);
	return res;
      }
    }
  }
#endif
  return SWIG_TypeError;
}


SWIGINTERN int
SWIG_AsVal_int (PyObject * obj, int *val)
{
  long v;
  int res = SWIG_AsVal_long (obj, &v);
  if (SWIG_IsOK(res)) {
    if ((v < INT_MIN || v > INT_MAX)) {
      return SWIG_OverflowError;
    } else {
      if (val) *val = (int)(v);
    }
  }  
  return res;
}

SWIGINTERN WsXmlNodeH __WsXmlNode_find(struct __WsXmlNode *self,char const *ns,char const *name,int recursive){
    return ws_xml_find_in_tree( self, ns, name, recursive );
  }
SWIGINTERN WsXmlNodeH __WsXmlNode_next(struct __WsXmlNode *self,int all){
    WsXmlNodeH next_node = xml_parser_get_next_child(self);
    if (next_node && !all) {
      const char *ns_uri = ws_xml_get_node_name_ns(self);
      const char *name = ws_xml_get_node_local_name(self);
      if (ws_xml_is_node_qname(next_node, ns_uri, name) == 0) {
        next_node = NULL;
      }
    }
    return next_node;
  }
SWIGINTERN int __WsXmlNode_size(struct __WsXmlNode *self,char const *name,char const *ns){
    return ws_xml_get_child_count_by_qname(self, ns, name);
  }
SWIGINTERN WsXmlNodeH __WsXmlNode_add__SWIG_0(struct __WsXmlNode *self,char const *ns,char const *name,char const *text){
    return ws_xml_add_child( self, ns, name, text );
  }
SWIGINTERN WsXmlNodeH __WsXmlNode_add_before(struct __WsXmlNode *self,char const *ns,char const *name,char const *text){
    return ws_xml_add_prev_sibling( self, ns, name, text );
  }
SWIGINTERN WsXmlNodeH __WsXmlNode_add__SWIG_1(struct __WsXmlNode *self,WsXmlNodeH node){
    ws_xml_duplicate_tree( self, node );
    return self;
  }
SWIGINTERN WsXmlNodeH __WsXmlNode_get__SWIG_0(struct __WsXmlNode *self,int i,char const *name,char const *ns){
    if (i < 0 || i >= ws_xml_get_child_count_by_qname(self,ns,name))
      return NULL;
    return ws_xml_get_child(self, i, ns, name);
  }
SWIGINTERN WsXmlNodeH __WsXmlNode_get__SWIG_1(struct __WsXmlNode *self,char const *name,char const *ns){
    return ws_xml_get_child(self, 0, ns, name);
  }
SWIGINTERN WsXmlAttrH __WsXmlNode_attr(struct __WsXmlNode *self,int index){
    return ws_xml_get_node_attr( self, index );
  }
SWIGINTERN int __WsXmlNode_attr_count(struct __WsXmlNode *self){
    return ws_xml_get_node_attr_count( self );
  }
SWIGINTERN WsXmlAttrH __WsXmlNode_attr_find(struct __WsXmlNode *self,char const *ns,char const *name){
    return ws_xml_find_node_attr( self, ns, name );
  }
SWIGINTERN WsXmlAttrH __WsXmlNode_attr_add(struct __WsXmlNode *self,char const *ns,char const *name,char const *value){
    return ws_xml_add_node_attr( self, ns, name, value );
  }
SWIGINTERN epr_t *__WsXmlNode_epr(struct __WsXmlNode *self,char const *ns,char const *epr_node_name,int embedded){
    return epr_deserialize(self, ns, epr_node_name, embedded);
  }
SWIGINTERN char *__WsXmlAttr_name(struct __WsXmlAttr *self){
    return ws_xml_get_attr_name( self );
  }
SWIGINTERN char *__WsXmlAttr_ns(struct __WsXmlAttr *self){
    return ws_xml_get_attr_ns( self );
  }
SWIGINTERN char *__WsXmlAttr_value(struct __WsXmlAttr *self){
    return ws_xml_get_attr_value( self );
  }
SWIGINTERN void __WsXmlAttr_remove(struct __WsXmlAttr *self){
    ws_xml_remove_node_attr( self );
  }
SWIGINTERN epr_t *new_epr_t__SWIG_0(char const *uri,char const *address){
    return epr_create( uri, NULL, address);
  }
SWIGINTERN epr_t *new_epr_t__SWIG_1(char const *uri){
    return epr_from_string( uri );
  }
SWIGINTERN void delete_epr_t(epr_t *self){
    epr_destroy( self );
  }
SWIGINTERN void epr_t_add_selector(epr_t *self,char const *name,char const *text){
    epr_add_selector_text(self, name, text);
  }
SWIGINTERN int epr_t_serialize(epr_t *self,WsXmlNodeH node,char const *ns,char const *epr_node_name,int embedded){
    return epr_serialize(node, ns, epr_node_name, self, embedded);
  }
SWIGINTERN int epr_t_cmp(epr_t *self,epr_t const *epr2){
    return epr_cmp(self, epr2);
  }
SWIGINTERN char *epr_t_to_xml(epr_t *self,char const *ns,char const *epr_node_name){
    return epr_to_txt(self, ns?ns:"http://schemas.xmlsoap.org/ws/2004/08/addressing", epr_node_name?epr_node_name:"EndpointReference");
  }
SWIGINTERN char *epr_t_string(epr_t *self){
    return epr_to_string(self);
  }
SWIGINTERN int epr_t_selector_count(epr_t *self){
    return epr_selector_count(self);
  }
SWIGINTERN char *epr_t_resource_uri(epr_t *self){
    return epr_get_resource_uri(self);
  }
SWIGINTERN char *epr_t_selector(epr_t *self,char const *name){

    return wsman_epr_selector_by_name(self, name);
  }
SWIGINTERN PyObject *epr_t_selector_names(epr_t *self){




    int i;
    Target_Type ary = Target_SizedArray(self->refparams.selectorset.count);
    key_value_t *p = self->refparams.selectorset.selectors;
    for (i = 0; i < self->refparams.selectorset.count; i++) {
      Target_ListSet(ary, i, SWIG_FromCharPtr(p->key));
      ++p;
    }



    return ary;

  }
SWIGINTERN char *epr_t_classname(epr_t *self){
    return uri_classname(self->refparams.uri);
  }
SWIGINTERN char *epr_t_namespace(epr_t *self){
    char *classname;
    int classnamelen, namespacelen;
    const char *prefix;
    const char *uri;

    /* try to get namespace from selectors (WS-Management style) */
    char *ns = get_cimnamespace_from_selectorset(&(self->refparams.selectorset));
    if (ns) {
      return strdup(ns);
    }
    /* WMI style? - extract namespace from uri */

    uri = self->refparams.uri;
    prefix = epr_prefix(uri);
    if (prefix == NULL) {
      return NULL; /* bad classname in URI */
    }
    classname = uri_classname(uri);
    if (classname == NULL)
      return NULL; /* bad URI */
    classnamelen = strlen(classname);
    free(classname);
    namespacelen = strlen(uri) - classnamelen - strlen(prefix) - 2; /* drop enclosing slashes */
    if (namespacelen <= 0)
      return strdup("");
    /* copy after prefix slash (+ 1) */
    return strndup(uri + strlen(prefix) + 1, namespacelen);
  }
SWIGINTERN char *epr_t_prefix(epr_t *self){
    return epr_prefix(self->refparams.uri);
  }
SWIGINTERN filter_t *new_filter_t(void){
    return filter_initialize();
  }
SWIGINTERN void delete_filter_t(filter_t *self){
    filter_destroy( self );
  }
SWIGINTERN int filter_t_associators(filter_t *self,epr_t *epr,char const *assocClass,char const *resultClass,char const *role,char const *resultRole,char **resultProp,int const propNum){
    return filter_set_assoc(self, epr, 0, assocClass, resultClass, role, resultRole, resultProp, propNum);
  }
SWIGINTERN int filter_t_references(filter_t *self,epr_t *epr,char const *assocClass,char const *resultClass,char const *role,char const *resultRole,char **resultProp,int const propNum){
    return filter_set_assoc(self, epr, 1, assocClass, resultClass, role, resultRole, resultProp, propNum);
  }
SWIGINTERN int filter_t_simple(filter_t *self,char const *dialect,char const *query){
    return filter_set_simple(self, dialect, query );
  }
SWIGINTERN int filter_t_xpath(filter_t *self,char const *query){
    return filter_set_simple(self,          "http://www.w3.org/TR/1999/REC-xpath-19991116", query );
  }
SWIGINTERN int filter_t_cql(filter_t *self,char const *query){
    return filter_set_simple(self,          "http://schemas.dmtf.org/wbem/cql/1/dsp0202.pdf", query );
  }
SWIGINTERN int filter_t_wql(filter_t *self,char const *query){
    return filter_set_simple(self,          "http://schemas.microsoft.com/wbem/wsman/1/WQL", query );
  }
SWIGINTERN void delete___WsEnumerateInfo(struct __WsEnumerateInfo *self){
  }
SWIGINTERN int __WsEnumerateInfo_max_items(struct __WsEnumerateInfo *self){ return self->maxItems; }
SWIGINTERN void __WsEnumerateInfo_set_max_items(struct __WsEnumerateInfo *self,int mi){ self->maxItems = mi; }
SWIGINTERN int __WsEnumerateInfo_flags(struct __WsEnumerateInfo *self){
    return self->flags;
  }
SWIGINTERN char const *__WsEnumerateInfo_epr_to(struct __WsEnumerateInfo *self){
    return self->epr_to;
  }
SWIGINTERN char const *__WsEnumerateInfo_epr_uri(struct __WsEnumerateInfo *self){
    return self->epr_uri;
  }
SWIGINTERN char const *__WsEnumerateInfo_encoding(struct __WsEnumerateInfo *self){
    return self->encoding;
  }
SWIGINTERN filter_t const *__WsEnumerateInfo_filter(struct __WsEnumerateInfo *self){
    return self->filter;
  }
SWIGINTERN int __WsEnumerateInfo_index(struct __WsEnumerateInfo *self){
    return self->index;
  }
SWIGINTERN void __WsEnumerateInfo_set_index(struct __WsEnumerateInfo *self,int i){
    self->index = i;
  }
SWIGINTERN int __WsEnumerateInfo_total_items(struct __WsEnumerateInfo *self){
    return self->totalItems;
  }
SWIGINTERN void __WsEnumerateInfo_set_total_items(struct __WsEnumerateInfo *self,int i){
    self->totalItems = i;
  }
SWIGINTERN WsXmlDocH __WsEnumerateInfo_pull_result(struct __WsEnumerateInfo *self){
    return (WsXmlDocH)self->pullResultPtr;
  }
SWIGINTERN void __WsEnumerateInfo_set_pull_result(struct __WsEnumerateInfo *self,WsXmlDocH result){
    self->pullResultPtr = (void *)result;
  }
SWIGINTERN WsXmlDocH __SoapOp_indoc(struct __SoapOp *self){
    return soap_get_op_doc(self, 1);
  }
SWIGINTERN void __SoapOp_set_indoc(struct __SoapOp *self,WsXmlDocH doc){
    soap_set_op_doc( self, doc, 1 );
  }
SWIGINTERN WsXmlDocH __SoapOp_outdoc(struct __SoapOp *self){
    return soap_get_op_doc(self, 0);
  }
SWIGINTERN void __SoapOp_set_outdoc(struct __SoapOp *self,WsXmlDocH doc){
    soap_set_op_doc( self, doc, 0 );
  }
SWIGINTERN struct __Soap *__SoapOp_soap(struct __SoapOp *self){
    return soap_get_op_soap(self);
  }
SWIGINTERN WsmanMessage *__SoapOp_msg(struct __SoapOp *self){
    return wsman_get_msg_from_op(self);
  }
SWIGINTERN unsigned long __SoapOp_maxsize(struct __SoapOp *self){
    return wsman_get_maxsize_from_op(self);
  }

  #define SWIG_From_long   PyInt_FromLong 


SWIGINTERNINLINE PyObject* 
SWIG_From_unsigned_SS_long  (unsigned long value)
{
  return (value > LONG_MAX) ?
    PyLong_FromUnsignedLong(value) : PyInt_FromLong((long)(value));
}

SWIGINTERN void delete___Soap(struct __Soap *self){
    soap_destroy(self);
  }
SWIGINTERN WsContextH __Soap_create_context(struct __Soap *self){
    return ws_create_context(self);
  }
SWIGINTERN WsContextH __Soap_context(struct __Soap *self){
    return ws_get_soap_context(self);
  }
SWIGINTERN WsContextH __Soap_create_ep_context(struct __Soap *self,WsXmlDocH doc){
    return ws_create_ep_context( self, doc );
  }
SWIGINTERN void delete__WS_CONTEXT(struct _WS_CONTEXT *self){
    ws_destroy_context(self);
  }
SWIGINTERN WsXmlDocH _WS_CONTEXT_indoc(struct _WS_CONTEXT *self){
    return self->indoc;
  }
SWIGINTERN struct __Soap *_WS_CONTEXT_runtime(struct _WS_CONTEXT *self){
    return ws_context_get_runtime(self);
  }

SWIGINTERN int
SWIG_AsVal_unsigned_SS_long (PyObject *obj, unsigned long *val) 
{
#if PY_VERSION_HEX < 0x03000000
  if (PyInt_Check(obj)) {
    long v = PyInt_AsLong(obj);
    if (v >= 0) {
      if (val) *val = v;
      return SWIG_OK;
    } else {
      return SWIG_OverflowError;
    }
  } else
#endif
  if (PyLong_Check(obj)) {
    unsigned long v = PyLong_AsUnsignedLong(obj);
    if (!PyErr_Occurred()) {
      if (val) *val = v;
      return SWIG_OK;
    } else {
      PyErr_Clear();
      return SWIG_OverflowError;
    }
  }
#ifdef SWIG_PYTHON_CAST_MODE
  {
    int dispatch = 0;
    unsigned long v = PyLong_AsUnsignedLong(obj);
    if (!PyErr_Occurred()) {
      if (val) *val = v;
      return SWIG_AddCast(SWIG_OK);
    } else {
      PyErr_Clear();
    }
    if (!dispatch) {
      double d;
      int res = SWIG_AddCast(SWIG_AsVal_double (obj,&d));
      // Largest double not larger than ULONG_MAX (not portably calculated easily)
      // Note that double(ULONG_MAX) is stored in a double rounded up by one (for 64-bit unsigned long)
      // 0xfffffffffffff800ULL == (uint64_t)std::nextafter(double(__uint128_t(ULONG_MAX)+1), double(0))
      const double ulong_max = sizeof(unsigned long) == 8 ? 0xfffffffffffff800ULL : ULONG_MAX;
      if (SWIG_IsOK(res) && SWIG_CanCastAsInteger(&d, 0, ulong_max)) {
	if (val) *val = (unsigned long)(d);
	return res;
      }
    }
  }
#endif
  return SWIG_TypeError;
}

SWIGINTERN void _WS_CONTEXT_set_enumIdleTimeout(struct _WS_CONTEXT *self,unsigned long timeout){
    ws_set_context_enumIdleTimeout(self, timeout);
  }
SWIGINTERN char const *_WS_CONTEXT_classname(struct _WS_CONTEXT *self){
    return wsman_get_class_name(self);
  }
SWIGINTERN char const *_WS_CONTEXT_method(struct _WS_CONTEXT *self){
    return wsman_get_method_name(self);
  }
SWIGINTERN hash_t *_WS_CONTEXT_method_args(struct _WS_CONTEXT *self,char const *resource_uri){
    return wsman_get_method_args(self, resource_uri);
  }
SWIGINTERN int _WS_CONTEXT_max_elements(struct _WS_CONTEXT *self,WsXmlDocH doc){
    return wsman_get_max_elements(self, doc);
  }
SWIGINTERN unsigned long _WS_CONTEXT_max_envelope_size(struct _WS_CONTEXT *self,WsXmlDocH doc){
    return wsman_get_max_envelope_size(self, doc);
  }
SWIGINTERN char const *_WS_CONTEXT_fragment_string(struct _WS_CONTEXT *self,WsXmlDocH doc){
    return wsman_get_fragment_string(self, doc);
  }
SWIGINTERN char const *_WS_CONTEXT_selector(struct _WS_CONTEXT *self,WsXmlDocH doc,char const *name,int index){
    return wsman_get_selector(self, doc, name, index);
  }
SWIGINTERN hash_t *_WS_CONTEXT_selectors_from_epr(struct _WS_CONTEXT *self,WsXmlNodeH epr_node){
    return wsman_get_selectors_from_epr(self, epr_node);
  }
SWIGINTERN hash_t *_WS_CONTEXT_selectors(struct _WS_CONTEXT *self,WsXmlDocH doc){
    return wsman_get_selector_list(self, doc);
  }
SWIGINTERN hash_t *_WS_CONTEXT_selectors_from_filter(struct _WS_CONTEXT *self,WsXmlDocH doc){
    return wsman_get_selector_list_from_filter(self, doc);
  }
SWIGINTERN char const *_WS_CONTEXT_action(struct _WS_CONTEXT *self,WsXmlDocH doc){
    return wsman_get_action(self, doc);
  }
SWIGINTERN char const *_WS_CONTEXT_resource_uri(struct _WS_CONTEXT *self,WsXmlDocH doc){
    return wsman_get_resource_uri(self, doc);
  }
SWIGINTERN char const *_WS_CONTEXT_option_set(struct _WS_CONTEXT *self,WsXmlDocH doc,char const *op){
    return wsman_get_option_set(self, doc, op);
  }
SWIGINTERN int _WS_CONTEXT_parse_enum_request(struct _WS_CONTEXT *self,WsEnumerateInfo *enumInfo){
    WsmanStatus status;
    wsman_status_init(&status);
    return wsman_parse_enum_request( self, enumInfo, &status);
    /* FIXME: return status */
  }
SWIGINTERN struct _WsmanStatus *new__WsmanStatus(int code,int detail,char const *msg){
    WsmanStatus *s = (WsmanStatus *)malloc(sizeof(WsmanStatus));
    wsman_status_init(s);
    if (code)
      s->fault_code = code;
    if (msg)
      s->fault_msg = strdup(msg);
    if (detail < 0
        || detail > OWSMAN_SYSTEM_ERROR) {
      SWIG_exception( SWIG_ValueError, "Bad fault detail" );
    }
    else {
      s->fault_detail_code = detail;
    }

    fail:

    return s;
  }
SWIGINTERN void delete__WsmanStatus(struct _WsmanStatus *self){
    if (self->fault_msg) free(self->fault_msg);
    free(self);
  }
SWIGINTERN char const *_WsmanStatus_to_s(struct _WsmanStatus *self){
    return self->fault_msg;
  }
SWIGINTERN void _WsmanStatus_set_code(struct _WsmanStatus *self,int code){ self->fault_code = code; }
SWIGINTERN int _WsmanStatus_code(struct _WsmanStatus *self){
    return self->fault_code;
  }
SWIGINTERN void _WsmanStatus_set_detail(struct _WsmanStatus *self,int detail){
    if (detail < 0
        || detail > OWSMAN_SYSTEM_ERROR) {
      SWIG_exception( SWIG_ValueError, "Bad fault detail" );
    }
    else {
      self->fault_detail_code = detail;
    }

    fail:
    return;

  }
SWIGINTERN int _WsmanStatus_detail(struct _WsmanStatus *self){
    return self->fault_detail_code;
  }
SWIGINTERN void _WsmanStatus_set_msg(struct _WsmanStatus *self,char const *msg){
    if (self->fault_msg)
      free(self->fault_msg);
    if (msg)
      self->fault_msg = strdup(msg);
    else
      self->fault_msg = NULL;
  }
SWIGINTERN char const *_WsmanStatus_msg(struct _WsmanStatus *self){
    return self->fault_msg;
  }
SWIGINTERN WsXmlDocH _WsmanStatus_generate_fault(struct _WsmanStatus *self,WsXmlDocH doc){
    return wsman_generate_fault( doc, self->fault_code, self->fault_detail_code, self->fault_msg);
  }
SWIGINTERN struct _WsManFault *new__WsManFault(WsXmlDocH doc){
    WsManFault *fault = wsmc_fault_new();
    wsmc_get_fault_data(doc, fault);
    return fault;
  }
SWIGINTERN void delete__WsManFault(struct _WsManFault *self){
    wsmc_fault_destroy(self);
  }
SWIGINTERN char const *_WsManFault_code(struct _WsManFault *self){
    return self->code;
  }
SWIGINTERN char const *_WsManFault_subcode(struct _WsManFault *self){
    return self->subcode;
  }
SWIGINTERN char const *_WsManFault_reason(struct _WsManFault *self){
    return self->reason;
  }
SWIGINTERN char const *_WsManFault_detail(struct _WsManFault *self){
    return self->fault_detail;
  }
SWIGINTERN int _WsManTransport_is_auth_method(struct _WsManTransport *self,int method){
    return wsman_is_auth_method((WsManClient *)self, method);
  }
SWIGINTERN void _WsManTransport_close(struct _WsManTransport *self){
    wsman_transport_close_transport((WsManClient *)self);
  }
SWIGINTERN void _WsManTransport_set_agent(struct _WsManTransport *self,char const *agent){
    wsman_transport_set_agent((WsManClient *)self, agent);
  }
SWIGINTERN char *_WsManTransport_agent(struct _WsManTransport *self){
    return wsman_transport_get_agent ((WsManClient *)self);
  }
SWIGINTERN char *_WsManTransport_get_username(struct _WsManTransport *self){
    return wsman_transport_get_userName((WsManClient *)self);
  }
SWIGINTERN void _WsManTransport_set_username(struct _WsManTransport *self,char *user_name){
    wsman_transport_set_userName((WsManClient *)self, user_name);
  }
SWIGINTERN char *_WsManTransport_get_password(struct _WsManTransport *self){
    return wsman_transport_get_password((WsManClient *)self);
  }
SWIGINTERN void _WsManTransport_set_password(struct _WsManTransport *self,char *password){
    wsman_transport_set_password((WsManClient *)self, password);
  }
SWIGINTERN char *_WsManTransport_get_proxy_username(struct _WsManTransport *self){
    return wsman_transport_get_proxy_username((WsManClient *)self );
  }
SWIGINTERN void _WsManTransport_set_proxy_username(struct _WsManTransport *self,char *proxy_username){
    wsman_transport_set_proxy_username((WsManClient *)self, proxy_username );
  }
SWIGINTERN char *_WsManTransport_get_proxy_password(struct _WsManTransport *self){
    return wsman_transport_get_proxy_password((WsManClient *)self );
  }
SWIGINTERN void _WsManTransport_set_proxy_password(struct _WsManTransport *self,char *proxy_password){
    wsman_transport_set_proxy_password((WsManClient *)self, proxy_password );
  }
SWIGINTERN void _WsManTransport_set_auth_method(struct _WsManTransport *self,char const *am){
    wsman_transport_set_auth_method((WsManClient *)self, am);
  }
SWIGINTERN char *_WsManTransport_auth_method(struct _WsManTransport *self){
    return wsman_transport_get_auth_method ((WsManClient *)self);
  }
SWIGINTERN char const *_WsManTransport_auth_name(int auth){
    return wsmc_transport_get_auth_name(auth);
  }
SWIGINTERN int _WsManTransport_auth_value(struct _WsManTransport *self){
    return wsmc_transport_get_auth_value((WsManClient *)self);
  }
SWIGINTERN char *_WsManTransport_error_string(int err){
    return wsman_transport_get_last_error_string(err);
  }
SWIGINTERN void _WsManTransport_set_timeout(struct _WsManTransport *self,unsigned long timeout){
    wsman_transport_set_timeout((WsManClient *)self, timeout);
  }
SWIGINTERN unsigned long _WsManTransport_timeout(struct _WsManTransport *self){
    return wsman_transport_get_timeout((WsManClient *)self);
  }

SWIGINTERN int
SWIG_AsVal_unsigned_SS_int (PyObject * obj, unsigned int *val)
{
  unsigned long v;
  int res = SWIG_AsVal_unsigned_SS_long (obj, &v);
  if (SWIG_IsOK(res)) {
    if ((v > UINT_MAX)) {
      return SWIG_OverflowError;
    } else {
      if (val) *val = (unsigned int)(v);
    }
  }  
  return res;
}

SWIGINTERN void _WsManTransport_set_verify_peer(struct _WsManTransport *self,unsigned int value){

    wsman_transport_set_verify_peer((WsManClient *)self, value);
  }
SWIGINTERN unsigned int _WsManTransport_verify_peer(struct _WsManTransport *self){
    return wsman_transport_get_verify_peer((WsManClient *)self);
  }

SWIGINTERNINLINE PyObject*
  SWIG_From_unsigned_SS_int  (unsigned int value)
{
  return PyInt_FromSize_t((size_t) value);
}

SWIGINTERN void _WsManTransport_set_verify_host(struct _WsManTransport *self,unsigned int value){

    wsman_transport_set_verify_host((WsManClient *)self, value);
  }
SWIGINTERN unsigned int _WsManTransport_verify_host(struct _WsManTransport *self){
    return wsman_transport_get_verify_host((WsManClient *)self);
  }
SWIGINTERN void _WsManTransport_set_proxy(struct _WsManTransport *self,char const *proxy){
    wsman_transport_set_proxy((WsManClient *)self, proxy);
  }
SWIGINTERN char *_WsManTransport_proxy(struct _WsManTransport *self){
    return wsman_transport_get_proxy((WsManClient *)self);
  }
SWIGINTERN void _WsManTransport_set_proxyauth(struct _WsManTransport *self,char const *pauth){
    wsman_transport_set_proxyauth((WsManClient *)self, pauth);
  }
SWIGINTERN char *_WsManTransport_proxyauth(struct _WsManTransport *self){
    return wsman_transport_get_proxyauth((WsManClient *)self);
  }
SWIGINTERN void _WsManTransport_set_cainfo(struct _WsManTransport *self,char const *cainfo){
    wsman_transport_set_cainfo((WsManClient *)self, cainfo);
  }
SWIGINTERN char *_WsManTransport_cainfo(struct _WsManTransport *self){
    return wsman_transport_get_cainfo((WsManClient *)self);
  }
SWIGINTERN void _WsManTransport_set_certhumbprint(struct _WsManTransport *self,char const *arg){
    wsman_transport_set_certhumbprint((WsManClient *)self, arg);
  }
SWIGINTERN char *_WsManTransport_certhumbprint(struct _WsManTransport *self){
    return wsman_transport_get_certhumbprint((WsManClient *)self);
  }
SWIGINTERN void _WsManTransport_set_capath(struct _WsManTransport *self,char const *capath){
    wsman_transport_set_capath((WsManClient *)self, capath);
  }
SWIGINTERN char *_WsManTransport_capath(struct _WsManTransport *self){
    return wsman_transport_get_capath((WsManClient *)self);
  }
SWIGINTERN void _WsManTransport_set_caoid(struct _WsManTransport *self,char const *oid){
    wsman_transport_set_caoid((WsManClient *)self, oid);
  }
SWIGINTERN char *_WsManTransport_caoid(struct _WsManTransport *self){
    return wsman_transport_get_caoid((WsManClient *)self);
  }
SWIGINTERN void _WsManTransport_set_cert(struct _WsManTransport *self,char const *cert){
    wsman_transport_set_cert((WsManClient *)self, cert);
  }
SWIGINTERN char *_WsManTransport_cert(struct _WsManTransport *self){
    return wsman_transport_get_cert((WsManClient *)self);
  }
SWIGINTERN void _WsManTransport_set_key(struct _WsManTransport *self,char const *key){
    wsman_transport_set_key((WsManClient *)self, key);
  }
SWIGINTERN char *_WsManTransport_key(struct _WsManTransport *self){
    return wsman_transport_get_key((WsManClient *)self);
  }
SWIGINTERN client_opt_t *new_client_opt_t(void){
    client_opt_t *options = wsmc_options_init();
    return options;
  }
SWIGINTERN void delete_client_opt_t(client_opt_t *self){
    wsmc_options_destroy( self );
  }
SWIGINTERN void client_opt_t_set_dump_request(client_opt_t *self){
    wsmc_set_action_option(self, 0x0010 );
  }
SWIGINTERN void client_opt_t_clear_dump_request(client_opt_t *self){
    wsmc_clear_action_option(self, 0x0010 );
  }
SWIGINTERN void client_opt_t_set_flags(client_opt_t *self,unsigned long flags){
    wsmc_set_action_option(self, flags);
  }
SWIGINTERN unsigned long client_opt_t_get_flags(client_opt_t *self){
    return wsmc_get_action_option(self);
  }
SWIGINTERN void client_opt_t_clear_flags(client_opt_t *self,unsigned long flags){
    wsmc_clear_action_option(self, flags);
  }
SWIGINTERN void client_opt_t_reset_flags(client_opt_t *self){
    wsmc_clear_action_option(self, ~0x0000);
  }
SWIGINTERN void client_opt_t_set_max_envelope_size(client_opt_t *self,unsigned long size){
    self->max_envelope_size = size;
  }
SWIGINTERN unsigned long client_opt_t_get_max_envelope_size(client_opt_t *self){
    return self->max_envelope_size;
  }
SWIGINTERN void client_opt_t_set_max_elements(client_opt_t *self,int elements){
    self->max_elements = elements;
  }
SWIGINTERN int client_opt_t_get_max_elements(client_opt_t *self){
    return self->max_elements;
  }
SWIGINTERN void client_opt_t_set_timeout(client_opt_t *self,unsigned long timeout){
    self->timeout = timeout;
  }
SWIGINTERN unsigned long client_opt_t_get_timeout(client_opt_t *self){
    return self->timeout;
  }
SWIGINTERN void client_opt_t_set_fragment(client_opt_t *self,char *fragment){
    wsmc_set_fragment(fragment, self);
  }
SWIGINTERN char const *client_opt_t_get_fragment(client_opt_t *self){
    return self->fragment;
  }
SWIGINTERN void client_opt_t_set_cim_namespace(client_opt_t *self,char *cim_namespace){
    wsmc_set_cim_ns(cim_namespace, self);
  }
SWIGINTERN char const *client_opt_t_get_cim_namespace(client_opt_t *self){
    return self->cim_ns;
  }
SWIGINTERN void client_opt_t_set_reference(client_opt_t *self,char const *reference){
    wsmc_set_reference(reference, self);
  }
SWIGINTERN char const *client_opt_t_get_reference(client_opt_t *self){
    return self->reference;
  }
SWIGINTERN void client_opt_t_add_option(client_opt_t *self,char const *key,char const *value){

    wsmc_add_option(self, key, value);
  }
SWIGINTERN void client_opt_t_add_selector(client_opt_t *self,char const *key,char const *value){
    wsmc_add_selector(self, key, value);
  }
SWIGINTERN void client_opt_t_add_property__SWIG_0(client_opt_t *self,char const *key,char const *value){
    wsmc_add_property(self, key, value);
  }
SWIGINTERN void client_opt_t_add_property_array_item(client_opt_t *self,char const *key,char const *value){
    wsmc_add_property_array_item(self, key, value);
  }
SWIGINTERN void client_opt_t_add_property__SWIG_1(client_opt_t *self,char const *key,epr_t const *epr){
    wsmc_add_property_epr(self, key, epr);
  }
SWIGINTERN void client_opt_t_set_delivery_uri(client_opt_t *self,char const *delivery_uri){
    wsmc_set_delivery_uri(delivery_uri, self);
  }
SWIGINTERN char const *client_opt_t_delivery_uri(client_opt_t *self){
    return self->delivery_uri;
  }

/* Getting isfinite working pre C99 across multiple platforms is non-trivial. Users can provide SWIG_isfinite on older platforms. */
#ifndef SWIG_isfinite
/* isfinite() is a macro for C99 */
# if defined(isfinite)
#  define SWIG_isfinite(X) (isfinite(X))
# elif defined(__cplusplus) && __cplusplus >= 201103L
/* Use a template so that this works whether isfinite() is std::isfinite() or
 * in the global namespace.  The reality seems to vary between compiler
 * versions.
 *
 * Make sure namespace std exists to avoid compiler warnings.
 *
 * extern "C++" is required as this fragment can end up inside an extern "C" { } block
 */
namespace std { }
extern "C++" template<typename T>
inline int SWIG_isfinite_func(T x) {
  using namespace std;
  return isfinite(x);
}
#  define SWIG_isfinite(X) (SWIG_isfinite_func(X))
# elif defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 2))
#  define SWIG_isfinite(X) (__builtin_isfinite(X))
# elif defined(_MSC_VER)
#  define SWIG_isfinite(X) (_finite(X))
# elif defined(__sun) && defined(__SVR4)
#  include <ieeefp.h>
#  define SWIG_isfinite(X) (finite(X))
# endif
#endif


/* Accept infinite as a valid float value unless we are unable to check if a value is finite */
#ifdef SWIG_isfinite
# define SWIG_Float_Overflow_Check(X) ((X < -FLT_MAX || X > FLT_MAX) && SWIG_isfinite(X))
#else
# define SWIG_Float_Overflow_Check(X) ((X < -FLT_MAX || X > FLT_MAX))
#endif


SWIGINTERN int
SWIG_AsVal_float (PyObject * obj, float *val)
{
  double v;
  int res = SWIG_AsVal_double (obj, &v);
  if (SWIG_IsOK(res)) {
    if (SWIG_Float_Overflow_Check(v)) {
      return SWIG_OverflowError;
    } else {
      if (val) *val = (float)(v);
    }
  }  
  return res;
}

SWIGINTERN void client_opt_t_set_sub_expiry(client_opt_t *self,float event_subscription_expire){
	wsmc_set_sub_expiry(event_subscription_expire, self);
  }
SWIGINTERN float client_opt_t_sub_expiry(client_opt_t *self){
    return self->expires;
  }

  #define SWIG_From_double   PyFloat_FromDouble 


SWIGINTERNINLINE PyObject *
SWIG_From_float  (float value)
{    
  return SWIG_From_double  (value);
}

SWIGINTERN void client_opt_t_set_heartbeat_interval(client_opt_t *self,float heartbeat_interval){
	wsmc_set_heartbeat_interval(heartbeat_interval, self);
  }
SWIGINTERN float client_opt_t_heartbeat_interval(client_opt_t *self){
    return self->heartbeat_interval;
  }
SWIGINTERN void client_opt_t_set_delivery_mode(client_opt_t *self,unsigned int delivery_mode){
    if (delivery_mode > 3)
      SWIG_exception( SWIG_ValueError, "Bad delivery mode" );
	
    wsmc_set_delivery_mode(delivery_mode, self);

    fail:
    return;

  }
SWIGINTERN int client_opt_t_delivery_mode(client_opt_t *self){
    return self->delivery_mode;
  }
SWIGINTERN void client_opt_t_set_delivery_security_mode(client_opt_t *self,unsigned int delivery_sec_mode){
    if (delivery_sec_mode > 10)
      SWIG_exception( SWIG_ValueError, "Bad delivery security mode" );
    wsmc_set_delivery_security_mode(delivery_sec_mode, self);

    fail:
    return;

  }
SWIGINTERN int client_opt_t_delivery_sec_mode(client_opt_t *self){
    return self->delivery_sec_mode;
  }
SWIGINTERN void client_opt_t_set_locale(client_opt_t *self,char const *locale){
	wsmc_set_locale(self, locale);
  }
SWIGINTERN char const *client_opt_t_locale(client_opt_t *self){
    return self->locale;
  }
SWIGINTERN struct _WsManClient *new__WsManClient__SWIG_0(char const *uri){
    struct _WsManClient *client = wsmc_create_from_uri( uri );
    if (client == NULL)
      SWIG_exception( SWIG_ValueError, "Can't create Openwsman::Client from given URI" );

    fail:

    return client;
  }
SWIGINTERN struct _WsManClient *new__WsManClient__SWIG_1(char const *hostname,int const port,char const *path,char const *scheme,char const *username,char const *password){
    struct _WsManClient *client = wsmc_create( hostname, port, path, scheme, username, password );
    if (client == NULL)
      SWIG_exception( SWIG_ValueError, "Can't create Openwsman::Client from given values" );

    fail:

    return client;
  }
SWIGINTERN void delete__WsManClient(struct _WsManClient *self){
    wsmc_release( self );
  }
SWIGINTERN void _WsManClient_set_dumpfile(struct _WsManClient *self,FILE *f){
    wsmc_set_dumpfile( self, f );
  }
SWIGINTERN long _WsManClient_response_code(struct _WsManClient *self){
    return wsmc_get_response_code( self );
  }
SWIGINTERN char *_WsManClient_scheme(struct _WsManClient *self){
    return wsmc_get_scheme( self );
  }
SWIGINTERN char *_WsManClient_host(struct _WsManClient *self){
    return wsmc_get_hostname( self );
  }
SWIGINTERN int _WsManClient_port(struct _WsManClient *self){
    return wsmc_get_port( self );
  }
SWIGINTERN char *_WsManClient_path(struct _WsManClient *self){
    return wsmc_get_path( self );
  }
SWIGINTERN char *_WsManClient_user(struct _WsManClient *self){
    return wsmc_get_user( self );
  }
SWIGINTERN char *_WsManClient_password(struct _WsManClient *self){
    return wsmc_get_password( self );
  }
SWIGINTERN WsManTransport *_WsManClient_transport(struct _WsManClient *self){
    wsmc_transport_init(self, NULL);
    wsmc_transport_set_auth_request_func( self, auth_request_callback );

    return (WsManTransport *)self;
  }
SWIGINTERN int _WsManClient_send_request(struct _WsManClient *self,WsXmlDocH request){
    return wsman_send_request(self, request);
  }
SWIGINTERN WsXmlDocH _WsManClient_build_envelope_from_response(struct _WsManClient *self){
    return wsmc_build_envelope_from_response(self);
  }
SWIGINTERN char *_WsManClient_encoding(struct _WsManClient *self){
    return wsmc_get_encoding(self);
  }
SWIGINTERN void _WsManClient_set_encoding(struct _WsManClient *self,char const *encoding){
    wsmc_set_encoding(self, encoding);
  }
SWIGINTERN WsXmlDocH _WsManClient_identify(struct _WsManClient *self,client_opt_t *options){










    return wsmc_action_identify( self, options );

  }
SWIGINTERN WsXmlDocH _WsManClient_get_from_epr(struct _WsManClient *self,client_opt_t *options,epr_t *epr){











    return wsmc_action_get_from_epr( self, epr, options);

  }
SWIGINTERN WsXmlDocH _WsManClient_delete_from_epr(struct _WsManClient *self,client_opt_t *options,epr_t *epr){











    return wsmc_action_delete_from_epr( self, epr, options);

  }
SWIGINTERN WsXmlDocH _WsManClient_enumerate(struct _WsManClient *self,client_opt_t *options,filter_t *filter,char *resource_uri){












    return wsmc_action_enumerate( self, resource_uri, options, filter);

  }
SWIGINTERN WsXmlDocH _WsManClient_pull(struct _WsManClient *self,client_opt_t *options,filter_t *filter,char const *resource_uri,char const *context){













    return wsmc_action_pull( self, resource_uri, options, filter, context);

  }

#if defined(LLONG_MAX) && !defined(SWIG_LONG_LONG_AVAILABLE)
#  define SWIG_LONG_LONG_AVAILABLE
#endif


#ifdef SWIG_LONG_LONG_AVAILABLE
SWIGINTERN int
SWIG_AsVal_unsigned_SS_long_SS_long (PyObject *obj, unsigned long long *val)
{
  int res = SWIG_TypeError;
  if (PyLong_Check(obj)) {
    unsigned long long v = PyLong_AsUnsignedLongLong(obj);
    if (!PyErr_Occurred()) {
      if (val) *val = v;
      return SWIG_OK;
    } else {
      PyErr_Clear();
      res = SWIG_OverflowError;
    }
  } else {
    unsigned long v;
    res = SWIG_AsVal_unsigned_SS_long (obj,&v);
    if (SWIG_IsOK(res)) {
      if (val) *val = v;
      return res;
    }
  }
#ifdef SWIG_PYTHON_CAST_MODE
  {
    const double mant_max = 1LL << DBL_MANT_DIG;
    double d;
    res = SWIG_AsVal_double (obj,&d);
    if (SWIG_IsOK(res) && !SWIG_CanCastAsInteger(&d, 0, mant_max))
      return SWIG_OverflowError;
    if (SWIG_IsOK(res) && SWIG_CanCastAsInteger(&d, 0, mant_max)) {
      if (val) *val = (unsigned long long)(d);
      return SWIG_AddCast(res);
    }
    res = SWIG_TypeError;
  }
#endif
  return res;
}
#endif


SWIGINTERNINLINE int
SWIG_AsVal_size_t (PyObject * obj, size_t *val)
{
  int res = SWIG_TypeError;
#ifdef SWIG_LONG_LONG_AVAILABLE
  if (sizeof(size_t) <= sizeof(unsigned long)) {
#endif
    unsigned long v;
    res = SWIG_AsVal_unsigned_SS_long (obj, val ? &v : 0);
    if (SWIG_IsOK(res) && val) *val = (size_t)(v);
#ifdef SWIG_LONG_LONG_AVAILABLE
  } else if (sizeof(size_t) <= sizeof(unsigned long long)) {
    unsigned long long v;
    res = SWIG_AsVal_unsigned_SS_long_SS_long (obj, val ? &v : 0);
    if (SWIG_IsOK(res) && val) *val = (size_t)(v);
  }
#endif
  return res;
}

SWIGINTERN WsXmlDocH _WsManClient_create(struct _WsManClient *self,client_opt_t *options,char const *resource_uri,char const *data,size_t size,char const *encoding){














    return wsmc_action_create_fromtext( self, resource_uri, options, data, size, encoding);

  }
SWIGINTERN WsXmlDocH _WsManClient_put(struct _WsManClient *self,client_opt_t *options,char const *resource_uri,char const *data,size_t size,char const *encoding){














    return wsmc_action_put_fromtext( self, resource_uri, options, data, size, encoding);

  }
SWIGINTERN WsXmlDocH _WsManClient_release(struct _WsManClient *self,client_opt_t *options,char const *resource_uri,char const *context){












    return wsmc_action_release( self, resource_uri, options, context);

  }
SWIGINTERN WsXmlDocH _WsManClient_get(struct _WsManClient *self,client_opt_t *options,char const *resource_uri){











    return wsmc_action_get( self, resource_uri, options);

  }
SWIGINTERN WsXmlDocH _WsManClient_delete(struct _WsManClient *self,client_opt_t *options,char const *resource_uri){











    return wsmc_action_delete( self, resource_uri, options);

  }
SWIGINTERN WsXmlDocH _WsManClient_invoke(struct _WsManClient *self,client_opt_t *options,char const *resource_uri,char const *method,WsXmlDocH data){













    return wsmc_action_invoke( self, resource_uri, options, method, data);

  }
SWIGINTERN WsXmlDocH _WsManClient_subscribe(struct _WsManClient *self,client_opt_t *options,filter_t *filter,char const *resource_uri){












    return wsmc_action_subscribe(self,  resource_uri, options, filter);

  }
SWIGINTERN WsXmlDocH _WsManClient_unsubscribe(struct _WsManClient *self,client_opt_t *options,filter_t *filter,char const *resource_uri,char const *identifier){













    return wsmc_action_unsubscribe(self, resource_uri, options, identifier);

  }
SWIGINTERN WsXmlDocH _WsManClient_renew(struct _WsManClient *self,client_opt_t *options,char *resource_uri,char *identifier){












    return wsmc_action_renew(self, resource_uri, options, identifier);

  }
SWIGINTERN char *_WsManClient_fault_string(struct _WsManClient *self){
    return wsmc_get_fault_string(self);
  }
SWIGINTERN int _WsManClient_last_error(struct _WsManClient *self){
     return wsmc_get_last_error(self);
   }
#ifdef __cplusplus
extern "C" {
#endif
SWIGINTERN PyObject *_wrap_fopen(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  char *arg1 = 0 ;
  char *arg2 = 0 ;
  int res1 ;
  char *buf1 = 0 ;
  int alloc1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  PyObject *swig_obj[2] ;
  FILE *result = 0 ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "fopen", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_AsCharPtrAndSize(swig_obj[0], &buf1, NULL, &alloc1);
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "fopen" "', argument " "1"" of type '" "char *""'");
  }
  arg1 = (char *)(buf1);
  res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "fopen" "', argument " "2"" of type '" "char *""'");
  }
  arg2 = (char *)(buf2);
  result = (FILE *)fopen(arg1,arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_FILE, 0 |  0 );
  if (alloc1 == SWIG_NEWOBJ) free((char*)buf1);
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return resultobj;
fail:
  if (alloc1 == SWIG_NEWOBJ) free((char*)buf1);
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return NULL;
}


SWIGINTERN PyObject *_wrap_fclose(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  FILE *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_FILE, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "fclose" "', argument " "1"" of type '" "FILE *""'"); 
  }
  arg1 = (FILE *)(argp1);
  fclose(arg1);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *XmlNs_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj = NULL;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p___WsXmlNs, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_XmlDoc(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  char *arg1 = 0 ;
  char *arg2 = (char *)NULL ;
  int res1 ;
  char *buf1 = 0 ;
  int alloc1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  PyObject *swig_obj[2] ;
  struct _WsXmlDoc *result = 0 ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "new_XmlDoc", 1, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_AsCharPtrAndSize(swig_obj[0], &buf1, NULL, &alloc1);
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_XmlDoc" "', argument " "1"" of type '" "char const *""'");
  }
  arg1 = (char *)(buf1);
  if (swig_obj[1]) {
    res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "new_XmlDoc" "', argument " "2"" of type '" "char const *""'");
    }
    arg2 = (char *)(buf2);
  }
  result = (struct _WsXmlDoc *)new__WsXmlDoc((char const *)arg1,(char const *)arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p__WsXmlDoc, SWIG_POINTER_NEW |  0 );
  if (alloc1 == SWIG_NEWOBJ) free((char*)buf1);
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return resultobj;
fail:
  if (alloc1 == SWIG_NEWOBJ) free((char*)buf1);
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_XmlDoc(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsXmlDoc *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsXmlDoc, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_XmlDoc" "', argument " "1"" of type '" "struct _WsXmlDoc *""'"); 
  }
  arg1 = (struct _WsXmlDoc *)(argp1);
  delete__WsXmlDoc(arg1);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_XmlDoc___str__(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsXmlDoc *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsXmlDoc, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "XmlDoc___str__" "', argument " "1"" of type '" "struct _WsXmlDoc *""'"); 
  }
  arg1 = (struct _WsXmlDoc *)(argp1);
  result = (char *)_WsXmlDoc_string(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  free(result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_XmlDoc_encode(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsXmlDoc *arg1 = 0 ;
  char *arg2 = (char *)"utf-8" ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  PyObject *swig_obj[2] ;
  char *result = 0 ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "XmlDoc_encode", 1, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsXmlDoc, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "XmlDoc_encode" "', argument " "1"" of type '" "struct _WsXmlDoc *""'"); 
  }
  arg1 = (struct _WsXmlDoc *)(argp1);
  if (swig_obj[1]) {
    res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "XmlDoc_encode" "', argument " "2"" of type '" "char const *""'");
    }
    arg2 = (char *)(buf2);
  }
  result = (char *)_WsXmlDoc_encode(arg1,(char const *)arg2);
  resultobj = SWIG_FromCharPtr((const char *)result);
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  free(result);
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return NULL;
}


SWIGINTERN PyObject *_wrap_XmlDoc_dump_file(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsXmlDoc *arg1 = 0 ;
  FILE *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "XmlDoc_dump_file", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsXmlDoc, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "XmlDoc_dump_file" "', argument " "1"" of type '" "struct _WsXmlDoc *""'"); 
  }
  arg1 = (struct _WsXmlDoc *)(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_FILE, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "XmlDoc_dump_file" "', argument " "2"" of type '" "FILE *""'"); 
  }
  arg2 = (FILE *)(argp2);
  _WsXmlDoc_dump_file(arg1,arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_XmlDoc_root(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsXmlDoc *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  WsXmlNodeH result;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsXmlDoc, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "XmlDoc_root" "', argument " "1"" of type '" "struct _WsXmlDoc *""'"); 
  }
  arg1 = (struct _WsXmlDoc *)(argp1);
  result = (WsXmlNodeH)_WsXmlDoc_root(arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p___WsXmlNode, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_XmlDoc_envelope(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsXmlDoc *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  WsXmlNodeH result;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsXmlDoc, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "XmlDoc_envelope" "', argument " "1"" of type '" "struct _WsXmlDoc *""'"); 
  }
  arg1 = (struct _WsXmlDoc *)(argp1);
  result = (WsXmlNodeH)_WsXmlDoc_envelope(arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p___WsXmlNode, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_XmlDoc_header(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsXmlDoc *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  WsXmlNodeH result;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsXmlDoc, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "XmlDoc_header" "', argument " "1"" of type '" "struct _WsXmlDoc *""'"); 
  }
  arg1 = (struct _WsXmlDoc *)(argp1);
  result = (WsXmlNodeH)_WsXmlDoc_header(arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p___WsXmlNode, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_XmlDoc_body(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsXmlDoc *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  WsXmlNodeH result;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsXmlDoc, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "XmlDoc_body" "', argument " "1"" of type '" "struct _WsXmlDoc *""'"); 
  }
  arg1 = (struct _WsXmlDoc *)(argp1);
  result = (WsXmlNodeH)_WsXmlDoc_body(arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p___WsXmlNode, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_XmlDoc_element(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsXmlDoc *arg1 = 0 ;
  char *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  PyObject *swig_obj[2] ;
  WsXmlNodeH result;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "XmlDoc_element", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsXmlDoc, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "XmlDoc_element" "', argument " "1"" of type '" "struct _WsXmlDoc *""'"); 
  }
  arg1 = (struct _WsXmlDoc *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "XmlDoc_element" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = (char *)(buf2);
  result = (WsXmlNodeH)_WsXmlDoc_element(arg1,(char const *)arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p___WsXmlNode, 0 |  0 );
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return NULL;
}


SWIGINTERN PyObject *_wrap_XmlDoc_context(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsXmlDoc *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsXmlDoc, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "XmlDoc_context" "', argument " "1"" of type '" "struct _WsXmlDoc *""'"); 
  }
  arg1 = (struct _WsXmlDoc *)(argp1);
  result = (char *)_WsXmlDoc_context(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  free(result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_XmlDoc_generate_fault(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsXmlDoc *arg1 = 0 ;
  WsmanStatus *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  WsXmlDocH result;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "XmlDoc_generate_fault", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsXmlDoc, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "XmlDoc_generate_fault" "', argument " "1"" of type '" "struct _WsXmlDoc *""'"); 
  }
  arg1 = (struct _WsXmlDoc *)(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p__WsmanStatus, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "XmlDoc_generate_fault" "', argument " "2"" of type '" "WsmanStatus *""'"); 
  }
  arg2 = (WsmanStatus *)(argp2);
  result = (WsXmlDocH)_WsXmlDoc_generate_fault(arg1,arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p__WsXmlDoc, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_XmlDoc_is_fault(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsXmlDoc *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsXmlDoc, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "XmlDoc_is_fault" "', argument " "1"" of type '" "struct _WsXmlDoc *""'"); 
  }
  arg1 = (struct _WsXmlDoc *)(argp1);
  result = (int)_WsXmlDoc_is_fault(arg1);
  resultobj = SWIG_From_int((int)(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_XmlDoc_fault(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsXmlDoc *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  WsManFault *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsXmlDoc, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "XmlDoc_fault" "', argument " "1"" of type '" "struct _WsXmlDoc *""'"); 
  }
  arg1 = (struct _WsXmlDoc *)(argp1);
  result = (WsManFault *)_WsXmlDoc_fault(arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p__WsManFault, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_XmlDoc_create_response_envelope(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsXmlDoc *arg1 = 0 ;
  char *arg2 = (char *)NULL ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  PyObject *swig_obj[2] ;
  WsXmlDocH result;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "XmlDoc_create_response_envelope", 1, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsXmlDoc, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "XmlDoc_create_response_envelope" "', argument " "1"" of type '" "struct _WsXmlDoc *""'"); 
  }
  arg1 = (struct _WsXmlDoc *)(argp1);
  if (swig_obj[1]) {
    res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "XmlDoc_create_response_envelope" "', argument " "2"" of type '" "char const *""'");
    }
    arg2 = (char *)(buf2);
  }
  result = (WsXmlDocH)_WsXmlDoc_create_response_envelope(arg1,(char const *)arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p__WsXmlDoc, 0 |  0 );
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return NULL;
}


SWIGINTERN PyObject *_wrap_XmlDoc_is_end_of_sequence(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsXmlDoc *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsXmlDoc, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "XmlDoc_is_end_of_sequence" "', argument " "1"" of type '" "struct _WsXmlDoc *""'"); 
  }
  arg1 = (struct _WsXmlDoc *)(argp1);
  result = (int)_WsXmlDoc_is_end_of_sequence(arg1);
  resultobj = SWIG_From_int((int)(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *XmlDoc_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj = NULL;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p__WsXmlDoc, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *XmlDoc_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_delete_XmlNode(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct __WsXmlNode *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p___WsXmlNode, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_XmlNode" "', argument " "1"" of type '" "struct __WsXmlNode *""'"); 
  }
  arg1 = (struct __WsXmlNode *)(argp1);
  delete___WsXmlNode(arg1);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_XmlNode_string(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct __WsXmlNode *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p___WsXmlNode, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "XmlNode_string" "', argument " "1"" of type '" "struct __WsXmlNode *""'"); 
  }
  arg1 = (struct __WsXmlNode *)(argp1);
  result = (char *)__WsXmlNode_string(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  free(result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_XmlNode_dump_file(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct __WsXmlNode *arg1 = 0 ;
  FILE *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "XmlNode_dump_file", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p___WsXmlNode, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "XmlNode_dump_file" "', argument " "1"" of type '" "struct __WsXmlNode *""'"); 
  }
  arg1 = (struct __WsXmlNode *)(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_FILE, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "XmlNode_dump_file" "', argument " "2"" of type '" "FILE *""'"); 
  }
  arg2 = (FILE *)(argp2);
  __WsXmlNode_dump_file(arg1,arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_XmlNode_equal(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct __WsXmlNode *arg1 = 0 ;
  WsXmlNodeH arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  int result;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "XmlNode_equal", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p___WsXmlNode, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "XmlNode_equal" "', argument " "1"" of type '" "struct __WsXmlNode *""'"); 
  }
  arg1 = (struct __WsXmlNode *)(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p___WsXmlNode, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "XmlNode_equal" "', argument " "2"" of type '" "WsXmlNodeH""'"); 
  }
  arg2 = (WsXmlNodeH)(argp2);
  result = (int)__WsXmlNode_equal(arg1,arg2);
  resultobj = SWIG_From_int((int)(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_XmlNode___str__(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct __WsXmlNode *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p___WsXmlNode, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "XmlNode___str__" "', argument " "1"" of type '" "struct __WsXmlNode *""'"); 
  }
  arg1 = (struct __WsXmlNode *)(argp1);
  result = (char *)__WsXmlNode_text(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_XmlNode_set_text(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct __WsXmlNode *arg1 = 0 ;
  char *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "XmlNode_set_text", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p___WsXmlNode, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "XmlNode_set_text" "', argument " "1"" of type '" "struct __WsXmlNode *""'"); 
  }
  arg1 = (struct __WsXmlNode *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "XmlNode_set_text" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = (char *)(buf2);
  __WsXmlNode_set_text(arg1,(char const *)arg2);
  resultobj = SWIG_Py_Void();
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return NULL;
}


SWIGINTERN PyObject *_wrap_XmlNode_doc(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct __WsXmlNode *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  WsXmlDocH result;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p___WsXmlNode, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "XmlNode_doc" "', argument " "1"" of type '" "struct __WsXmlNode *""'"); 
  }
  arg1 = (struct __WsXmlNode *)(argp1);
  result = (WsXmlDocH)__WsXmlNode_doc(arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p__WsXmlDoc, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_XmlNode_parent(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct __WsXmlNode *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  WsXmlNodeH result;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p___WsXmlNode, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "XmlNode_parent" "', argument " "1"" of type '" "struct __WsXmlNode *""'"); 
  }
  arg1 = (struct __WsXmlNode *)(argp1);
  result = (WsXmlNodeH)__WsXmlNode_parent(arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p___WsXmlNode, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_XmlNode_child(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct __WsXmlNode *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  WsXmlNodeH result;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p___WsXmlNode, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "XmlNode_child" "', argument " "1"" of type '" "struct __WsXmlNode *""'"); 
  }
  arg1 = (struct __WsXmlNode *)(argp1);
  result = (WsXmlNodeH)__WsXmlNode_child(arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p___WsXmlNode, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_XmlNode_name(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct __WsXmlNode *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p___WsXmlNode, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "XmlNode_name" "', argument " "1"" of type '" "struct __WsXmlNode *""'"); 
  }
  arg1 = (struct __WsXmlNode *)(argp1);
  result = (char *)__WsXmlNode_name(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_XmlNode_set_name(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct __WsXmlNode *arg1 = 0 ;
  char *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "XmlNode_set_name", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p___WsXmlNode, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "XmlNode_set_name" "', argument " "1"" of type '" "struct __WsXmlNode *""'"); 
  }
  arg1 = (struct __WsXmlNode *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "XmlNode_set_name" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = (char *)(buf2);
  __WsXmlNode_set_name(arg1,(char const *)arg2);
  resultobj = SWIG_Py_Void();
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return NULL;
}


SWIGINTERN PyObject *_wrap_XmlNode_ns(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct __WsXmlNode *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p___WsXmlNode, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "XmlNode_ns" "', argument " "1"" of type '" "struct __WsXmlNode *""'"); 
  }
  arg1 = (struct __WsXmlNode *)(argp1);
  result = (char *)__WsXmlNode_ns(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_XmlNode_set_ns(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct __WsXmlNode *arg1 = 0 ;
  char *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "XmlNode_set_ns", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p___WsXmlNode, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "XmlNode_set_ns" "', argument " "1"" of type '" "struct __WsXmlNode *""'"); 
  }
  arg1 = (struct __WsXmlNode *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "XmlNode_set_ns" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = (char *)(buf2);
  __WsXmlNode_set_ns(arg1,(char const *)arg2);
  resultobj = SWIG_Py_Void();
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return NULL;
}


SWIGINTERN PyObject *_wrap_XmlNode_prefix(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct __WsXmlNode *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p___WsXmlNode, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "XmlNode_prefix" "', argument " "1"" of type '" "struct __WsXmlNode *""'"); 
  }
  arg1 = (struct __WsXmlNode *)(argp1);
  result = (char *)__WsXmlNode_prefix(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_XmlNode_set_lang(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct __WsXmlNode *arg1 = 0 ;
  char *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "XmlNode_set_lang", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p___WsXmlNode, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "XmlNode_set_lang" "', argument " "1"" of type '" "struct __WsXmlNode *""'"); 
  }
  arg1 = (struct __WsXmlNode *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "XmlNode_set_lang" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = (char *)(buf2);
  __WsXmlNode_set_lang(arg1,(char const *)arg2);
  resultobj = SWIG_Py_Void();
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return NULL;
}


SWIGINTERN PyObject *_wrap_XmlNode_find(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct __WsXmlNode *arg1 = 0 ;
  char *arg2 = 0 ;
  char *arg3 = 0 ;
  int arg4 = 1 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  int res3 ;
  char *buf3 = 0 ;
  int alloc3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  PyObject *swig_obj[4] ;
  WsXmlNodeH result;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "XmlNode_find", 3, 4, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p___WsXmlNode, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "XmlNode_find" "', argument " "1"" of type '" "struct __WsXmlNode *""'"); 
  }
  arg1 = (struct __WsXmlNode *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "XmlNode_find" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = (char *)(buf2);
  res3 = SWIG_AsCharPtrAndSize(swig_obj[2], &buf3, NULL, &alloc3);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "XmlNode_find" "', argument " "3"" of type '" "char const *""'");
  }
  arg3 = (char *)(buf3);
  if (swig_obj[3]) {
    ecode4 = SWIG_AsVal_int(swig_obj[3], &val4);
    if (!SWIG_IsOK(ecode4)) {
      SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "XmlNode_find" "', argument " "4"" of type '" "int""'");
    } 
    arg4 = (int)(val4);
  }
  result = (WsXmlNodeH)__WsXmlNode_find(arg1,(char const *)arg2,(char const *)arg3,arg4);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p___WsXmlNode, 0 |  0 );
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  if (alloc3 == SWIG_NEWOBJ) free((char*)buf3);
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  if (alloc3 == SWIG_NEWOBJ) free((char*)buf3);
  return NULL;
}


SWIGINTERN PyObject *_wrap_XmlNode_next(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct __WsXmlNode *arg1 = 0 ;
  int arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  WsXmlNodeH result;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "XmlNode_next", 1, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p___WsXmlNode, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "XmlNode_next" "', argument " "1"" of type '" "struct __WsXmlNode *""'"); 
  }
  arg1 = (struct __WsXmlNode *)(argp1);
  if (swig_obj[1]) {
    ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
    if (!SWIG_IsOK(ecode2)) {
      SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "XmlNode_next" "', argument " "2"" of type '" "int""'");
    } 
    arg2 = (int)(val2);
  }
  result = (WsXmlNodeH)__WsXmlNode_next(arg1,arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p___WsXmlNode, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_XmlNode_size(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct __WsXmlNode *arg1 = 0 ;
  char *arg2 = (char *)NULL ;
  char *arg3 = (char *)NULL ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  int res3 ;
  char *buf3 = 0 ;
  int alloc3 = 0 ;
  PyObject *swig_obj[3] ;
  int result;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "XmlNode_size", 1, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p___WsXmlNode, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "XmlNode_size" "', argument " "1"" of type '" "struct __WsXmlNode *""'"); 
  }
  arg1 = (struct __WsXmlNode *)(argp1);
  if (swig_obj[1]) {
    res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "XmlNode_size" "', argument " "2"" of type '" "char const *""'");
    }
    arg2 = (char *)(buf2);
  }
  if (swig_obj[2]) {
    res3 = SWIG_AsCharPtrAndSize(swig_obj[2], &buf3, NULL, &alloc3);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "XmlNode_size" "', argument " "3"" of type '" "char const *""'");
    }
    arg3 = (char *)(buf3);
  }
  result = (int)__WsXmlNode_size(arg1,(char const *)arg2,(char const *)arg3);
  resultobj = SWIG_From_int((int)(result));
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  if (alloc3 == SWIG_NEWOBJ) free((char*)buf3);
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  if (alloc3 == SWIG_NEWOBJ) free((char*)buf3);
  return NULL;
}


SWIGINTERN PyObject *_wrap_XmlNode_add__SWIG_0(PyObject *self, Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  struct __WsXmlNode *arg1 = 0 ;
  char *arg2 = 0 ;
  char *arg3 = 0 ;
  char *arg4 = (char *)NULL ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  int res3 ;
  char *buf3 = 0 ;
  int alloc3 = 0 ;
  int res4 ;
  char *buf4 = 0 ;
  int alloc4 = 0 ;
  WsXmlNodeH result;
  
  (void)self;
  if ((nobjs < 3) || (nobjs > 4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p___WsXmlNode, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "XmlNode_add" "', argument " "1"" of type '" "struct __WsXmlNode *""'"); 
  }
  arg1 = (struct __WsXmlNode *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "XmlNode_add" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = (char *)(buf2);
  res3 = SWIG_AsCharPtrAndSize(swig_obj[2], &buf3, NULL, &alloc3);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "XmlNode_add" "', argument " "3"" of type '" "char const *""'");
  }
  arg3 = (char *)(buf3);
  if (swig_obj[3]) {
    res4 = SWIG_AsCharPtrAndSize(swig_obj[3], &buf4, NULL, &alloc4);
    if (!SWIG_IsOK(res4)) {
      SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "XmlNode_add" "', argument " "4"" of type '" "char const *""'");
    }
    arg4 = (char *)(buf4);
  }
  result = (WsXmlNodeH)__WsXmlNode_add__SWIG_0(arg1,(char const *)arg2,(char const *)arg3,(char const *)arg4);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p___WsXmlNode, 0 |  0 );
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  if (alloc3 == SWIG_NEWOBJ) free((char*)buf3);
  if (alloc4 == SWIG_NEWOBJ) free((char*)buf4);
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  if (alloc3 == SWIG_NEWOBJ) free((char*)buf3);
  if (alloc4 == SWIG_NEWOBJ) free((char*)buf4);
  return NULL;
}


SWIGINTERN PyObject *_wrap_XmlNode_add_before(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct __WsXmlNode *arg1 = 0 ;
  char *arg2 = 0 ;
  char *arg3 = 0 ;
  char *arg4 = (char *)NULL ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  int res3 ;
  char *buf3 = 0 ;
  int alloc3 = 0 ;
  int res4 ;
  char *buf4 = 0 ;
  int alloc4 = 0 ;
  PyObject *swig_obj[4] ;
  WsXmlNodeH result;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "XmlNode_add_before", 3, 4, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p___WsXmlNode, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "XmlNode_add_before" "', argument " "1"" of type '" "struct __WsXmlNode *""'"); 
  }
  arg1 = (struct __WsXmlNode *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "XmlNode_add_before" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = (char *)(buf2);
  res3 = SWIG_AsCharPtrAndSize(swig_obj[2], &buf3, NULL, &alloc3);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "XmlNode_add_before" "', argument " "3"" of type '" "char const *""'");
  }
  arg3 = (char *)(buf3);
  if (swig_obj[3]) {
    res4 = SWIG_AsCharPtrAndSize(swig_obj[3], &buf4, NULL, &alloc4);
    if (!SWIG_IsOK(res4)) {
      SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "XmlNode_add_before" "', argument " "4"" of type '" "char const *""'");
    }
    arg4 = (char *)(buf4);
  }
  result = (WsXmlNodeH)__WsXmlNode_add_before(arg1,(char const *)arg2,(char const *)arg3,(char const *)arg4);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p___WsXmlNode, 0 |  0 );
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  if (alloc3 == SWIG_NEWOBJ) free((char*)buf3);
  if (alloc4 == SWIG_NEWOBJ) free((char*)buf4);
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  if (alloc3 == SWIG_NEWOBJ) free((char*)buf3);
  if (alloc4 == SWIG_NEWOBJ) free((char*)buf4);
  return NULL;
}


SWIGINTERN PyObject *_wrap_XmlNode_add__SWIG_1(PyObject *self, Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  struct __WsXmlNode *arg1 = 0 ;
  WsXmlNodeH arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  WsXmlNodeH result;
  
  (void)self;
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p___WsXmlNode, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "XmlNode_add" "', argument " "1"" of type '" "struct __WsXmlNode *""'"); 
  }
  arg1 = (struct __WsXmlNode *)(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p___WsXmlNode, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "XmlNode_add" "', argument " "2"" of type '" "WsXmlNodeH""'"); 
  }
  arg2 = (WsXmlNodeH)(argp2);
  result = (WsXmlNodeH)__WsXmlNode_add__SWIG_1(arg1,arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p___WsXmlNode, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_XmlNode_add(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "XmlNode_add", 0, 4, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v = 0;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p___WsXmlNode, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p___WsXmlNode, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_XmlNode_add__SWIG_1(self, argc, argv);
      }
    }
  }
  if ((argc >= 3) && (argc <= 4)) {
    int _v = 0;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p___WsXmlNode, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_AsCharPtrAndSize(argv[1], 0, NULL, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        int res = SWIG_AsCharPtrAndSize(argv[2], 0, NULL, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          if (argc <= 3) {
            return _wrap_XmlNode_add__SWIG_0(self, argc, argv);
          }
          int res = SWIG_AsCharPtrAndSize(argv[3], 0, NULL, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_XmlNode_add__SWIG_0(self, argc, argv);
          }
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'XmlNode_add'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    __WsXmlNode::add(char const *,char const *,char const *)\n"
    "    __WsXmlNode::add(WsXmlNodeH)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_XmlNode_get__SWIG_0(PyObject *self, Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  struct __WsXmlNode *arg1 = 0 ;
  int arg2 ;
  char *arg3 = (char *)NULL ;
  char *arg4 = (char *)NULL ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  int res3 ;
  char *buf3 = 0 ;
  int alloc3 = 0 ;
  int res4 ;
  char *buf4 = 0 ;
  int alloc4 = 0 ;
  WsXmlNodeH result;
  
  (void)self;
  if ((nobjs < 2) || (nobjs > 4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p___WsXmlNode, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "XmlNode_get" "', argument " "1"" of type '" "struct __WsXmlNode *""'"); 
  }
  arg1 = (struct __WsXmlNode *)(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "XmlNode_get" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = (int)(val2);
  if (swig_obj[2]) {
    res3 = SWIG_AsCharPtrAndSize(swig_obj[2], &buf3, NULL, &alloc3);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "XmlNode_get" "', argument " "3"" of type '" "char const *""'");
    }
    arg3 = (char *)(buf3);
  }
  if (swig_obj[3]) {
    res4 = SWIG_AsCharPtrAndSize(swig_obj[3], &buf4, NULL, &alloc4);
    if (!SWIG_IsOK(res4)) {
      SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "XmlNode_get" "', argument " "4"" of type '" "char const *""'");
    }
    arg4 = (char *)(buf4);
  }
  result = (WsXmlNodeH)__WsXmlNode_get__SWIG_0(arg1,arg2,(char const *)arg3,(char const *)arg4);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p___WsXmlNode, 0 |  0 );
  if (alloc3 == SWIG_NEWOBJ) free((char*)buf3);
  if (alloc4 == SWIG_NEWOBJ) free((char*)buf4);
  return resultobj;
fail:
  if (alloc3 == SWIG_NEWOBJ) free((char*)buf3);
  if (alloc4 == SWIG_NEWOBJ) free((char*)buf4);
  return NULL;
}


SWIGINTERN PyObject *_wrap_XmlNode_get__SWIG_1(PyObject *self, Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  struct __WsXmlNode *arg1 = 0 ;
  char *arg2 = 0 ;
  char *arg3 = (char *)NULL ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  int res3 ;
  char *buf3 = 0 ;
  int alloc3 = 0 ;
  WsXmlNodeH result;
  
  (void)self;
  if ((nobjs < 2) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p___WsXmlNode, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "XmlNode_get" "', argument " "1"" of type '" "struct __WsXmlNode *""'"); 
  }
  arg1 = (struct __WsXmlNode *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "XmlNode_get" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = (char *)(buf2);
  if (swig_obj[2]) {
    res3 = SWIG_AsCharPtrAndSize(swig_obj[2], &buf3, NULL, &alloc3);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "XmlNode_get" "', argument " "3"" of type '" "char const *""'");
    }
    arg3 = (char *)(buf3);
  }
  result = (WsXmlNodeH)__WsXmlNode_get__SWIG_1(arg1,(char const *)arg2,(char const *)arg3);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p___WsXmlNode, 0 |  0 );
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  if (alloc3 == SWIG_NEWOBJ) free((char*)buf3);
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  if (alloc3 == SWIG_NEWOBJ) free((char*)buf3);
  return NULL;
}


SWIGINTERN PyObject *_wrap_XmlNode_get(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "XmlNode_get", 0, 4, argv))) SWIG_fail;
  --argc;
  if ((argc >= 2) && (argc <= 4)) {
    int _v = 0;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p___WsXmlNode, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        if (argc <= 2) {
          return _wrap_XmlNode_get__SWIG_0(self, argc, argv);
        }
        int res = SWIG_AsCharPtrAndSize(argv[2], 0, NULL, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          if (argc <= 3) {
            return _wrap_XmlNode_get__SWIG_0(self, argc, argv);
          }
          int res = SWIG_AsCharPtrAndSize(argv[3], 0, NULL, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_XmlNode_get__SWIG_0(self, argc, argv);
          }
        }
      }
    }
  }
  if ((argc >= 2) && (argc <= 3)) {
    int _v = 0;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p___WsXmlNode, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_AsCharPtrAndSize(argv[1], 0, NULL, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        if (argc <= 2) {
          return _wrap_XmlNode_get__SWIG_1(self, argc, argv);
        }
        int res = SWIG_AsCharPtrAndSize(argv[2], 0, NULL, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_XmlNode_get__SWIG_1(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'XmlNode_get'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    __WsXmlNode::get(int,char const *,char const *)\n"
    "    __WsXmlNode::get(char const *,char const *)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_XmlNode_attr(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct __WsXmlNode *arg1 = 0 ;
  int arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  WsXmlAttrH result;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "XmlNode_attr", 1, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p___WsXmlNode, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "XmlNode_attr" "', argument " "1"" of type '" "struct __WsXmlNode *""'"); 
  }
  arg1 = (struct __WsXmlNode *)(argp1);
  if (swig_obj[1]) {
    ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
    if (!SWIG_IsOK(ecode2)) {
      SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "XmlNode_attr" "', argument " "2"" of type '" "int""'");
    } 
    arg2 = (int)(val2);
  }
  result = (WsXmlAttrH)__WsXmlNode_attr(arg1,arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p___WsXmlAttr, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_XmlNode_attr_count(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct __WsXmlNode *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p___WsXmlNode, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "XmlNode_attr_count" "', argument " "1"" of type '" "struct __WsXmlNode *""'"); 
  }
  arg1 = (struct __WsXmlNode *)(argp1);
  result = (int)__WsXmlNode_attr_count(arg1);
  resultobj = SWIG_From_int((int)(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_XmlNode_attr_find(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct __WsXmlNode *arg1 = 0 ;
  char *arg2 = 0 ;
  char *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  int res3 ;
  char *buf3 = 0 ;
  int alloc3 = 0 ;
  PyObject *swig_obj[3] ;
  WsXmlAttrH result;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "XmlNode_attr_find", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p___WsXmlNode, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "XmlNode_attr_find" "', argument " "1"" of type '" "struct __WsXmlNode *""'"); 
  }
  arg1 = (struct __WsXmlNode *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "XmlNode_attr_find" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = (char *)(buf2);
  res3 = SWIG_AsCharPtrAndSize(swig_obj[2], &buf3, NULL, &alloc3);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "XmlNode_attr_find" "', argument " "3"" of type '" "char const *""'");
  }
  arg3 = (char *)(buf3);
  result = (WsXmlAttrH)__WsXmlNode_attr_find(arg1,(char const *)arg2,(char const *)arg3);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p___WsXmlAttr, 0 |  0 );
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  if (alloc3 == SWIG_NEWOBJ) free((char*)buf3);
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  if (alloc3 == SWIG_NEWOBJ) free((char*)buf3);
  return NULL;
}


SWIGINTERN PyObject *_wrap_XmlNode_attr_add(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct __WsXmlNode *arg1 = 0 ;
  char *arg2 = 0 ;
  char *arg3 = 0 ;
  char *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  int res3 ;
  char *buf3 = 0 ;
  int alloc3 = 0 ;
  int res4 ;
  char *buf4 = 0 ;
  int alloc4 = 0 ;
  PyObject *swig_obj[4] ;
  WsXmlAttrH result;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "XmlNode_attr_add", 4, 4, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p___WsXmlNode, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "XmlNode_attr_add" "', argument " "1"" of type '" "struct __WsXmlNode *""'"); 
  }
  arg1 = (struct __WsXmlNode *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "XmlNode_attr_add" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = (char *)(buf2);
  res3 = SWIG_AsCharPtrAndSize(swig_obj[2], &buf3, NULL, &alloc3);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "XmlNode_attr_add" "', argument " "3"" of type '" "char const *""'");
  }
  arg3 = (char *)(buf3);
  res4 = SWIG_AsCharPtrAndSize(swig_obj[3], &buf4, NULL, &alloc4);
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "XmlNode_attr_add" "', argument " "4"" of type '" "char const *""'");
  }
  arg4 = (char *)(buf4);
  result = (WsXmlAttrH)__WsXmlNode_attr_add(arg1,(char const *)arg2,(char const *)arg3,(char const *)arg4);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p___WsXmlAttr, 0 |  0 );
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  if (alloc3 == SWIG_NEWOBJ) free((char*)buf3);
  if (alloc4 == SWIG_NEWOBJ) free((char*)buf4);
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  if (alloc3 == SWIG_NEWOBJ) free((char*)buf3);
  if (alloc4 == SWIG_NEWOBJ) free((char*)buf4);
  return NULL;
}


SWIGINTERN PyObject *_wrap_XmlNode_epr(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct __WsXmlNode *arg1 = 0 ;
  char *arg2 = 0 ;
  char *arg3 = 0 ;
  int arg4 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  int res3 ;
  char *buf3 = 0 ;
  int alloc3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  PyObject *swig_obj[4] ;
  epr_t *result = 0 ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "XmlNode_epr", 4, 4, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p___WsXmlNode, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "XmlNode_epr" "', argument " "1"" of type '" "struct __WsXmlNode *""'"); 
  }
  arg1 = (struct __WsXmlNode *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "XmlNode_epr" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = (char *)(buf2);
  res3 = SWIG_AsCharPtrAndSize(swig_obj[2], &buf3, NULL, &alloc3);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "XmlNode_epr" "', argument " "3"" of type '" "char const *""'");
  }
  arg3 = (char *)(buf3);
  ecode4 = SWIG_AsVal_int(swig_obj[3], &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "XmlNode_epr" "', argument " "4"" of type '" "int""'");
  } 
  arg4 = (int)(val4);
  result = (epr_t *)__WsXmlNode_epr(arg1,(char const *)arg2,(char const *)arg3,arg4);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_epr_t, 0 |  0 );
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  if (alloc3 == SWIG_NEWOBJ) free((char*)buf3);
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  if (alloc3 == SWIG_NEWOBJ) free((char*)buf3);
  return NULL;
}


SWIGINTERN PyObject *XmlNode_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj = NULL;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p___WsXmlNode, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_XmlAttr_name(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct __WsXmlAttr *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p___WsXmlAttr, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "XmlAttr_name" "', argument " "1"" of type '" "struct __WsXmlAttr *""'"); 
  }
  arg1 = (struct __WsXmlAttr *)(argp1);
  result = (char *)__WsXmlAttr_name(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_XmlAttr_ns(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct __WsXmlAttr *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p___WsXmlAttr, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "XmlAttr_ns" "', argument " "1"" of type '" "struct __WsXmlAttr *""'"); 
  }
  arg1 = (struct __WsXmlAttr *)(argp1);
  result = (char *)__WsXmlAttr_ns(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_XmlAttr_value(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct __WsXmlAttr *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p___WsXmlAttr, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "XmlAttr_value" "', argument " "1"" of type '" "struct __WsXmlAttr *""'"); 
  }
  arg1 = (struct __WsXmlAttr *)(argp1);
  result = (char *)__WsXmlAttr_value(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_XmlAttr_remove(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct __WsXmlAttr *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p___WsXmlAttr, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "XmlAttr_remove" "', argument " "1"" of type '" "struct __WsXmlAttr *""'"); 
  }
  arg1 = (struct __WsXmlAttr *)(argp1);
  __WsXmlAttr_remove(arg1);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *XmlAttr_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj = NULL;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p___WsXmlAttr, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_EndPointReference__SWIG_0(PyObject *self, Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  char *arg1 = 0 ;
  char *arg2 = 0 ;
  int res1 ;
  char *buf1 = 0 ;
  int alloc1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  epr_t *result = 0 ;
  
  (void)self;
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_AsCharPtrAndSize(swig_obj[0], &buf1, NULL, &alloc1);
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_EndPointReference" "', argument " "1"" of type '" "char const *""'");
  }
  arg1 = (char *)(buf1);
  res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "new_EndPointReference" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = (char *)(buf2);
  result = (epr_t *)new_epr_t__SWIG_0((char const *)arg1,(char const *)arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_epr_t, SWIG_POINTER_NEW |  0 );
  if (alloc1 == SWIG_NEWOBJ) free((char*)buf1);
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return resultobj;
fail:
  if (alloc1 == SWIG_NEWOBJ) free((char*)buf1);
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_EndPointReference__SWIG_1(PyObject *self, Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  char *arg1 = 0 ;
  int res1 ;
  char *buf1 = 0 ;
  int alloc1 = 0 ;
  epr_t *result = 0 ;
  
  (void)self;
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  res1 = SWIG_AsCharPtrAndSize(swig_obj[0], &buf1, NULL, &alloc1);
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_EndPointReference" "', argument " "1"" of type '" "char const *""'");
  }
  arg1 = (char *)(buf1);
  result = (epr_t *)new_epr_t__SWIG_1((char const *)arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_epr_t, SWIG_POINTER_NEW |  0 );
  if (alloc1 == SWIG_NEWOBJ) free((char*)buf1);
  return resultobj;
fail:
  if (alloc1 == SWIG_NEWOBJ) free((char*)buf1);
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_EndPointReference(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "new_EndPointReference", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 1) {
    int _v = 0;
    int res = SWIG_AsCharPtrAndSize(argv[0], 0, NULL, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_new_EndPointReference__SWIG_1(self, argc, argv);
    }
  }
  if (argc == 2) {
    int _v = 0;
    int res = SWIG_AsCharPtrAndSize(argv[0], 0, NULL, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_AsCharPtrAndSize(argv[1], 0, NULL, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_new_EndPointReference__SWIG_0(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'new_EndPointReference'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    epr_t::epr_t(char const *,char const *)\n"
    "    epr_t::epr_t(char const *)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_delete_EndPointReference(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  epr_t *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_epr_t, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_EndPointReference" "', argument " "1"" of type '" "epr_t *""'"); 
  }
  arg1 = (epr_t *)(argp1);
  delete_epr_t(arg1);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_EndPointReference_add_selector(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  epr_t *arg1 = 0 ;
  char *arg2 = 0 ;
  char *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  int res3 ;
  char *buf3 = 0 ;
  int alloc3 = 0 ;
  PyObject *swig_obj[3] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "EndPointReference_add_selector", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_epr_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "EndPointReference_add_selector" "', argument " "1"" of type '" "epr_t *""'"); 
  }
  arg1 = (epr_t *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "EndPointReference_add_selector" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = (char *)(buf2);
  res3 = SWIG_AsCharPtrAndSize(swig_obj[2], &buf3, NULL, &alloc3);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "EndPointReference_add_selector" "', argument " "3"" of type '" "char const *""'");
  }
  arg3 = (char *)(buf3);
  epr_t_add_selector(arg1,(char const *)arg2,(char const *)arg3);
  resultobj = SWIG_Py_Void();
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  if (alloc3 == SWIG_NEWOBJ) free((char*)buf3);
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  if (alloc3 == SWIG_NEWOBJ) free((char*)buf3);
  return NULL;
}


SWIGINTERN PyObject *_wrap_EndPointReference_serialize(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  epr_t *arg1 = 0 ;
  WsXmlNodeH arg2 = 0 ;
  char *arg3 = 0 ;
  char *arg4 = 0 ;
  int arg5 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  int res3 ;
  char *buf3 = 0 ;
  int alloc3 = 0 ;
  int res4 ;
  char *buf4 = 0 ;
  int alloc4 = 0 ;
  int val5 ;
  int ecode5 = 0 ;
  PyObject *swig_obj[5] ;
  int result;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "EndPointReference_serialize", 5, 5, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_epr_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "EndPointReference_serialize" "', argument " "1"" of type '" "epr_t *""'"); 
  }
  arg1 = (epr_t *)(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p___WsXmlNode, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "EndPointReference_serialize" "', argument " "2"" of type '" "WsXmlNodeH""'"); 
  }
  arg2 = (WsXmlNodeH)(argp2);
  res3 = SWIG_AsCharPtrAndSize(swig_obj[2], &buf3, NULL, &alloc3);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "EndPointReference_serialize" "', argument " "3"" of type '" "char const *""'");
  }
  arg3 = (char *)(buf3);
  res4 = SWIG_AsCharPtrAndSize(swig_obj[3], &buf4, NULL, &alloc4);
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "EndPointReference_serialize" "', argument " "4"" of type '" "char const *""'");
  }
  arg4 = (char *)(buf4);
  ecode5 = SWIG_AsVal_int(swig_obj[4], &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "EndPointReference_serialize" "', argument " "5"" of type '" "int""'");
  } 
  arg5 = (int)(val5);
  result = (int)epr_t_serialize(arg1,arg2,(char const *)arg3,(char const *)arg4,arg5);
  resultobj = SWIG_From_int((int)(result));
  if (alloc3 == SWIG_NEWOBJ) free((char*)buf3);
  if (alloc4 == SWIG_NEWOBJ) free((char*)buf4);
  return resultobj;
fail:
  if (alloc3 == SWIG_NEWOBJ) free((char*)buf3);
  if (alloc4 == SWIG_NEWOBJ) free((char*)buf4);
  return NULL;
}


SWIGINTERN PyObject *_wrap_EndPointReference_cmp(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  epr_t *arg1 = 0 ;
  epr_t *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  int result;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "EndPointReference_cmp", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_epr_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "EndPointReference_cmp" "', argument " "1"" of type '" "epr_t *""'"); 
  }
  arg1 = (epr_t *)(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_epr_t, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "EndPointReference_cmp" "', argument " "2"" of type '" "epr_t const *""'"); 
  }
  arg2 = (epr_t *)(argp2);
  result = (int)epr_t_cmp(arg1,(epr_t const *)arg2);
  resultobj = SWIG_From_int((int)(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_EndPointReference_to_xml(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  epr_t *arg1 = 0 ;
  char *arg2 = (char *)NULL ;
  char *arg3 = (char *)NULL ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  int res3 ;
  char *buf3 = 0 ;
  int alloc3 = 0 ;
  PyObject *swig_obj[3] ;
  char *result = 0 ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "EndPointReference_to_xml", 1, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_epr_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "EndPointReference_to_xml" "', argument " "1"" of type '" "epr_t *""'"); 
  }
  arg1 = (epr_t *)(argp1);
  if (swig_obj[1]) {
    res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "EndPointReference_to_xml" "', argument " "2"" of type '" "char const *""'");
    }
    arg2 = (char *)(buf2);
  }
  if (swig_obj[2]) {
    res3 = SWIG_AsCharPtrAndSize(swig_obj[2], &buf3, NULL, &alloc3);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "EndPointReference_to_xml" "', argument " "3"" of type '" "char const *""'");
    }
    arg3 = (char *)(buf3);
  }
  result = (char *)epr_t_to_xml(arg1,(char const *)arg2,(char const *)arg3);
  resultobj = SWIG_FromCharPtr((const char *)result);
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  if (alloc3 == SWIG_NEWOBJ) free((char*)buf3);
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  if (alloc3 == SWIG_NEWOBJ) free((char*)buf3);
  return NULL;
}


SWIGINTERN PyObject *_wrap_EndPointReference_string(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  epr_t *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_epr_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "EndPointReference_string" "', argument " "1"" of type '" "epr_t *""'"); 
  }
  arg1 = (epr_t *)(argp1);
  result = (char *)epr_t_string(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  free(result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_EndPointReference_selector_count(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  epr_t *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_epr_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "EndPointReference_selector_count" "', argument " "1"" of type '" "epr_t *""'"); 
  }
  arg1 = (epr_t *)(argp1);
  result = (int)epr_t_selector_count(arg1);
  resultobj = SWIG_From_int((int)(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_EndPointReference_resource_uri(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  epr_t *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_epr_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "EndPointReference_resource_uri" "', argument " "1"" of type '" "epr_t *""'"); 
  }
  arg1 = (epr_t *)(argp1);
  result = (char *)epr_t_resource_uri(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_EndPointReference_selector(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  epr_t *arg1 = 0 ;
  char *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  PyObject *swig_obj[2] ;
  char *result = 0 ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "EndPointReference_selector", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_epr_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "EndPointReference_selector" "', argument " "1"" of type '" "epr_t *""'"); 
  }
  arg1 = (epr_t *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "EndPointReference_selector" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = (char *)(buf2);
  result = (char *)epr_t_selector(arg1,(char const *)arg2);
  resultobj = SWIG_FromCharPtr((const char *)result);
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return NULL;
}


SWIGINTERN PyObject *_wrap_EndPointReference_selector_names(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  epr_t *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  PyObject *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_epr_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "EndPointReference_selector_names" "', argument " "1"" of type '" "epr_t *""'"); 
  }
  arg1 = (epr_t *)(argp1);
  result = (PyObject *)epr_t_selector_names(arg1);
  resultobj = result;
  if (!resultobj) SWIG_fail;
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_EndPointReference_classname(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  epr_t *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_epr_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "EndPointReference_classname" "', argument " "1"" of type '" "epr_t *""'"); 
  }
  arg1 = (epr_t *)(argp1);
  result = (char *)epr_t_classname(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  free(result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_EndPointReference_namespace(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  epr_t *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_epr_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "EndPointReference_namespace" "', argument " "1"" of type '" "epr_t *""'"); 
  }
  arg1 = (epr_t *)(argp1);
  result = (char *)epr_t_namespace(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  free(result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_EndPointReference_prefix(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  epr_t *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_epr_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "EndPointReference_prefix" "', argument " "1"" of type '" "epr_t *""'"); 
  }
  arg1 = (epr_t *)(argp1);
  result = (char *)epr_t_prefix(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  free(result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *EndPointReference_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj = NULL;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_epr_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *EndPointReference_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_Filter_resultClass_set(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  filter_t *arg1 = 0 ;
  char *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "Filter_resultClass_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_filter_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Filter_resultClass_set" "', argument " "1"" of type '" "filter_t *""'"); 
  }
  arg1 = (filter_t *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Filter_resultClass_set" "', argument " "2"" of type '" "char *""'");
  }
  arg2 = (char *)(buf2);
  free((char*)arg1->resultClass);
  if (arg2) {
    size_t size = strlen((const char *)(arg2)) + 1;
    arg1->resultClass = (char *)(char *)memcpy(malloc((size)*sizeof(char)), (const char *)(arg2), sizeof(char)*(size));
  } else {
    arg1->resultClass = 0;
  }
  resultobj = SWIG_Py_Void();
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return NULL;
}


SWIGINTERN PyObject *_wrap_Filter_resultClass_get(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  filter_t *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_filter_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Filter_resultClass_get" "', argument " "1"" of type '" "filter_t *""'"); 
  }
  arg1 = (filter_t *)(argp1);
  result = (char *) ((arg1)->resultClass);
  resultobj = SWIG_FromCharPtr((const char *)result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Filter_assocClass_set(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  filter_t *arg1 = 0 ;
  char *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "Filter_assocClass_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_filter_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Filter_assocClass_set" "', argument " "1"" of type '" "filter_t *""'"); 
  }
  arg1 = (filter_t *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Filter_assocClass_set" "', argument " "2"" of type '" "char *""'");
  }
  arg2 = (char *)(buf2);
  free((char*)arg1->assocClass);
  if (arg2) {
    size_t size = strlen((const char *)(arg2)) + 1;
    arg1->assocClass = (char *)(char *)memcpy(malloc((size)*sizeof(char)), (const char *)(arg2), sizeof(char)*(size));
  } else {
    arg1->assocClass = 0;
  }
  resultobj = SWIG_Py_Void();
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return NULL;
}


SWIGINTERN PyObject *_wrap_Filter_assocClass_get(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  filter_t *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_filter_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Filter_assocClass_get" "', argument " "1"" of type '" "filter_t *""'"); 
  }
  arg1 = (filter_t *)(argp1);
  result = (char *) ((arg1)->assocClass);
  resultobj = SWIG_FromCharPtr((const char *)result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_Filter(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  filter_t *result = 0 ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "new_Filter", 0, 0, 0)) SWIG_fail;
  result = (filter_t *)new_filter_t();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_filter_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_Filter(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  filter_t *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_filter_t, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Filter" "', argument " "1"" of type '" "filter_t *""'"); 
  }
  arg1 = (filter_t *)(argp1);
  delete_filter_t(arg1);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Filter_associators(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  filter_t *arg1 = 0 ;
  epr_t *arg2 = 0 ;
  char *arg3 = 0 ;
  char *arg4 = 0 ;
  char *arg5 = 0 ;
  char *arg6 = 0 ;
  char **arg7 = 0 ;
  int arg8 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  int res3 ;
  char *buf3 = 0 ;
  int alloc3 = 0 ;
  int res4 ;
  char *buf4 = 0 ;
  int alloc4 = 0 ;
  int res5 ;
  char *buf5 = 0 ;
  int alloc5 = 0 ;
  int res6 ;
  char *buf6 = 0 ;
  int alloc6 = 0 ;
  void *argp7 = 0 ;
  int res7 = 0 ;
  int val8 ;
  int ecode8 = 0 ;
  PyObject *swig_obj[8] ;
  int result;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "Filter_associators", 8, 8, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_filter_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Filter_associators" "', argument " "1"" of type '" "filter_t *""'"); 
  }
  arg1 = (filter_t *)(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_epr_t, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Filter_associators" "', argument " "2"" of type '" "epr_t *""'"); 
  }
  arg2 = (epr_t *)(argp2);
  res3 = SWIG_AsCharPtrAndSize(swig_obj[2], &buf3, NULL, &alloc3);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Filter_associators" "', argument " "3"" of type '" "char const *""'");
  }
  arg3 = (char *)(buf3);
  res4 = SWIG_AsCharPtrAndSize(swig_obj[3], &buf4, NULL, &alloc4);
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Filter_associators" "', argument " "4"" of type '" "char const *""'");
  }
  arg4 = (char *)(buf4);
  res5 = SWIG_AsCharPtrAndSize(swig_obj[4], &buf5, NULL, &alloc5);
  if (!SWIG_IsOK(res5)) {
    SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "Filter_associators" "', argument " "5"" of type '" "char const *""'");
  }
  arg5 = (char *)(buf5);
  res6 = SWIG_AsCharPtrAndSize(swig_obj[5], &buf6, NULL, &alloc6);
  if (!SWIG_IsOK(res6)) {
    SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "Filter_associators" "', argument " "6"" of type '" "char const *""'");
  }
  arg6 = (char *)(buf6);
  res7 = SWIG_ConvertPtr(swig_obj[6], &argp7,SWIGTYPE_p_p_char, 0 |  0 );
  if (!SWIG_IsOK(res7)) {
    SWIG_exception_fail(SWIG_ArgError(res7), "in method '" "Filter_associators" "', argument " "7"" of type '" "char **""'"); 
  }
  arg7 = (char **)(argp7);
  ecode8 = SWIG_AsVal_int(swig_obj[7], &val8);
  if (!SWIG_IsOK(ecode8)) {
    SWIG_exception_fail(SWIG_ArgError(ecode8), "in method '" "Filter_associators" "', argument " "8"" of type '" "int""'");
  } 
  arg8 = (int)(val8);
  result = (int)filter_t_associators(arg1,arg2,(char const *)arg3,(char const *)arg4,(char const *)arg5,(char const *)arg6,arg7,arg8);
  resultobj = SWIG_From_int((int)(result));
  if (alloc3 == SWIG_NEWOBJ) free((char*)buf3);
  if (alloc4 == SWIG_NEWOBJ) free((char*)buf4);
  if (alloc5 == SWIG_NEWOBJ) free((char*)buf5);
  if (alloc6 == SWIG_NEWOBJ) free((char*)buf6);
  return resultobj;
fail:
  if (alloc3 == SWIG_NEWOBJ) free((char*)buf3);
  if (alloc4 == SWIG_NEWOBJ) free((char*)buf4);
  if (alloc5 == SWIG_NEWOBJ) free((char*)buf5);
  if (alloc6 == SWIG_NEWOBJ) free((char*)buf6);
  return NULL;
}


SWIGINTERN PyObject *_wrap_Filter_references(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  filter_t *arg1 = 0 ;
  epr_t *arg2 = 0 ;
  char *arg3 = 0 ;
  char *arg4 = 0 ;
  char *arg5 = 0 ;
  char *arg6 = 0 ;
  char **arg7 = 0 ;
  int arg8 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  int res3 ;
  char *buf3 = 0 ;
  int alloc3 = 0 ;
  int res4 ;
  char *buf4 = 0 ;
  int alloc4 = 0 ;
  int res5 ;
  char *buf5 = 0 ;
  int alloc5 = 0 ;
  int res6 ;
  char *buf6 = 0 ;
  int alloc6 = 0 ;
  void *argp7 = 0 ;
  int res7 = 0 ;
  int val8 ;
  int ecode8 = 0 ;
  PyObject *swig_obj[8] ;
  int result;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "Filter_references", 8, 8, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_filter_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Filter_references" "', argument " "1"" of type '" "filter_t *""'"); 
  }
  arg1 = (filter_t *)(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_epr_t, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Filter_references" "', argument " "2"" of type '" "epr_t *""'"); 
  }
  arg2 = (epr_t *)(argp2);
  res3 = SWIG_AsCharPtrAndSize(swig_obj[2], &buf3, NULL, &alloc3);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Filter_references" "', argument " "3"" of type '" "char const *""'");
  }
  arg3 = (char *)(buf3);
  res4 = SWIG_AsCharPtrAndSize(swig_obj[3], &buf4, NULL, &alloc4);
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Filter_references" "', argument " "4"" of type '" "char const *""'");
  }
  arg4 = (char *)(buf4);
  res5 = SWIG_AsCharPtrAndSize(swig_obj[4], &buf5, NULL, &alloc5);
  if (!SWIG_IsOK(res5)) {
    SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "Filter_references" "', argument " "5"" of type '" "char const *""'");
  }
  arg5 = (char *)(buf5);
  res6 = SWIG_AsCharPtrAndSize(swig_obj[5], &buf6, NULL, &alloc6);
  if (!SWIG_IsOK(res6)) {
    SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "Filter_references" "', argument " "6"" of type '" "char const *""'");
  }
  arg6 = (char *)(buf6);
  res7 = SWIG_ConvertPtr(swig_obj[6], &argp7,SWIGTYPE_p_p_char, 0 |  0 );
  if (!SWIG_IsOK(res7)) {
    SWIG_exception_fail(SWIG_ArgError(res7), "in method '" "Filter_references" "', argument " "7"" of type '" "char **""'"); 
  }
  arg7 = (char **)(argp7);
  ecode8 = SWIG_AsVal_int(swig_obj[7], &val8);
  if (!SWIG_IsOK(ecode8)) {
    SWIG_exception_fail(SWIG_ArgError(ecode8), "in method '" "Filter_references" "', argument " "8"" of type '" "int""'");
  } 
  arg8 = (int)(val8);
  result = (int)filter_t_references(arg1,arg2,(char const *)arg3,(char const *)arg4,(char const *)arg5,(char const *)arg6,arg7,arg8);
  resultobj = SWIG_From_int((int)(result));
  if (alloc3 == SWIG_NEWOBJ) free((char*)buf3);
  if (alloc4 == SWIG_NEWOBJ) free((char*)buf4);
  if (alloc5 == SWIG_NEWOBJ) free((char*)buf5);
  if (alloc6 == SWIG_NEWOBJ) free((char*)buf6);
  return resultobj;
fail:
  if (alloc3 == SWIG_NEWOBJ) free((char*)buf3);
  if (alloc4 == SWIG_NEWOBJ) free((char*)buf4);
  if (alloc5 == SWIG_NEWOBJ) free((char*)buf5);
  if (alloc6 == SWIG_NEWOBJ) free((char*)buf6);
  return NULL;
}


SWIGINTERN PyObject *_wrap_Filter_simple(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  filter_t *arg1 = 0 ;
  char *arg2 = 0 ;
  char *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  int res3 ;
  char *buf3 = 0 ;
  int alloc3 = 0 ;
  PyObject *swig_obj[3] ;
  int result;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "Filter_simple", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_filter_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Filter_simple" "', argument " "1"" of type '" "filter_t *""'"); 
  }
  arg1 = (filter_t *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Filter_simple" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = (char *)(buf2);
  res3 = SWIG_AsCharPtrAndSize(swig_obj[2], &buf3, NULL, &alloc3);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Filter_simple" "', argument " "3"" of type '" "char const *""'");
  }
  arg3 = (char *)(buf3);
  result = (int)filter_t_simple(arg1,(char const *)arg2,(char const *)arg3);
  resultobj = SWIG_From_int((int)(result));
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  if (alloc3 == SWIG_NEWOBJ) free((char*)buf3);
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  if (alloc3 == SWIG_NEWOBJ) free((char*)buf3);
  return NULL;
}


SWIGINTERN PyObject *_wrap_Filter_xpath(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  filter_t *arg1 = 0 ;
  char *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  PyObject *swig_obj[2] ;
  int result;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "Filter_xpath", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_filter_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Filter_xpath" "', argument " "1"" of type '" "filter_t *""'"); 
  }
  arg1 = (filter_t *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Filter_xpath" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = (char *)(buf2);
  result = (int)filter_t_xpath(arg1,(char const *)arg2);
  resultobj = SWIG_From_int((int)(result));
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return NULL;
}


SWIGINTERN PyObject *_wrap_Filter_cql(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  filter_t *arg1 = 0 ;
  char *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  PyObject *swig_obj[2] ;
  int result;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "Filter_cql", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_filter_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Filter_cql" "', argument " "1"" of type '" "filter_t *""'"); 
  }
  arg1 = (filter_t *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Filter_cql" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = (char *)(buf2);
  result = (int)filter_t_cql(arg1,(char const *)arg2);
  resultobj = SWIG_From_int((int)(result));
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return NULL;
}


SWIGINTERN PyObject *_wrap_Filter_wql(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  filter_t *arg1 = 0 ;
  char *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  PyObject *swig_obj[2] ;
  int result;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "Filter_wql", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_filter_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Filter_wql" "', argument " "1"" of type '" "filter_t *""'"); 
  }
  arg1 = (filter_t *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Filter_wql" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = (char *)(buf2);
  result = (int)filter_t_wql(arg1,(char const *)arg2);
  resultobj = SWIG_From_int((int)(result));
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return NULL;
}


SWIGINTERN PyObject *Filter_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj = NULL;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_filter_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *Filter_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_delete_EnumerateInfo(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct __WsEnumerateInfo *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p___WsEnumerateInfo, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_EnumerateInfo" "', argument " "1"" of type '" "struct __WsEnumerateInfo *""'"); 
  }
  arg1 = (struct __WsEnumerateInfo *)(argp1);
  delete___WsEnumerateInfo(arg1);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_EnumerateInfo_max_items(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct __WsEnumerateInfo *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p___WsEnumerateInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "EnumerateInfo_max_items" "', argument " "1"" of type '" "struct __WsEnumerateInfo *""'"); 
  }
  arg1 = (struct __WsEnumerateInfo *)(argp1);
  result = (int)__WsEnumerateInfo_max_items(arg1);
  resultobj = SWIG_From_int((int)(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_EnumerateInfo_set_max_items(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct __WsEnumerateInfo *arg1 = 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "EnumerateInfo_set_max_items", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p___WsEnumerateInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "EnumerateInfo_set_max_items" "', argument " "1"" of type '" "struct __WsEnumerateInfo *""'"); 
  }
  arg1 = (struct __WsEnumerateInfo *)(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "EnumerateInfo_set_max_items" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = (int)(val2);
  __WsEnumerateInfo_set_max_items(arg1,arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_EnumerateInfo_flags(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct __WsEnumerateInfo *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p___WsEnumerateInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "EnumerateInfo_flags" "', argument " "1"" of type '" "struct __WsEnumerateInfo *""'"); 
  }
  arg1 = (struct __WsEnumerateInfo *)(argp1);
  result = (int)__WsEnumerateInfo_flags(arg1);
  resultobj = SWIG_From_int((int)(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_EnumerateInfo_epr_to(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct __WsEnumerateInfo *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p___WsEnumerateInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "EnumerateInfo_epr_to" "', argument " "1"" of type '" "struct __WsEnumerateInfo *""'"); 
  }
  arg1 = (struct __WsEnumerateInfo *)(argp1);
  result = (char *)__WsEnumerateInfo_epr_to(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_EnumerateInfo_epr_uri(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct __WsEnumerateInfo *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p___WsEnumerateInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "EnumerateInfo_epr_uri" "', argument " "1"" of type '" "struct __WsEnumerateInfo *""'"); 
  }
  arg1 = (struct __WsEnumerateInfo *)(argp1);
  result = (char *)__WsEnumerateInfo_epr_uri(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_EnumerateInfo_encoding(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct __WsEnumerateInfo *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p___WsEnumerateInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "EnumerateInfo_encoding" "', argument " "1"" of type '" "struct __WsEnumerateInfo *""'"); 
  }
  arg1 = (struct __WsEnumerateInfo *)(argp1);
  result = (char *)__WsEnumerateInfo_encoding(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_EnumerateInfo_filter(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct __WsEnumerateInfo *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  filter_t *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p___WsEnumerateInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "EnumerateInfo_filter" "', argument " "1"" of type '" "struct __WsEnumerateInfo *""'"); 
  }
  arg1 = (struct __WsEnumerateInfo *)(argp1);
  result = (filter_t *)__WsEnumerateInfo_filter(arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_filter_t, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_EnumerateInfo_index(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct __WsEnumerateInfo *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p___WsEnumerateInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "EnumerateInfo_index" "', argument " "1"" of type '" "struct __WsEnumerateInfo *""'"); 
  }
  arg1 = (struct __WsEnumerateInfo *)(argp1);
  result = (int)__WsEnumerateInfo_index(arg1);
  resultobj = SWIG_From_int((int)(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_EnumerateInfo_set_index(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct __WsEnumerateInfo *arg1 = 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "EnumerateInfo_set_index", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p___WsEnumerateInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "EnumerateInfo_set_index" "', argument " "1"" of type '" "struct __WsEnumerateInfo *""'"); 
  }
  arg1 = (struct __WsEnumerateInfo *)(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "EnumerateInfo_set_index" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = (int)(val2);
  __WsEnumerateInfo_set_index(arg1,arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_EnumerateInfo_total_items(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct __WsEnumerateInfo *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p___WsEnumerateInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "EnumerateInfo_total_items" "', argument " "1"" of type '" "struct __WsEnumerateInfo *""'"); 
  }
  arg1 = (struct __WsEnumerateInfo *)(argp1);
  result = (int)__WsEnumerateInfo_total_items(arg1);
  resultobj = SWIG_From_int((int)(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_EnumerateInfo_set_total_items(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct __WsEnumerateInfo *arg1 = 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "EnumerateInfo_set_total_items", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p___WsEnumerateInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "EnumerateInfo_set_total_items" "', argument " "1"" of type '" "struct __WsEnumerateInfo *""'"); 
  }
  arg1 = (struct __WsEnumerateInfo *)(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "EnumerateInfo_set_total_items" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = (int)(val2);
  __WsEnumerateInfo_set_total_items(arg1,arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_EnumerateInfo_pull_result(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct __WsEnumerateInfo *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  WsXmlDocH result;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p___WsEnumerateInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "EnumerateInfo_pull_result" "', argument " "1"" of type '" "struct __WsEnumerateInfo *""'"); 
  }
  arg1 = (struct __WsEnumerateInfo *)(argp1);
  result = (WsXmlDocH)__WsEnumerateInfo_pull_result(arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p__WsXmlDoc, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_EnumerateInfo_set_pull_result(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct __WsEnumerateInfo *arg1 = 0 ;
  WsXmlDocH arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "EnumerateInfo_set_pull_result", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p___WsEnumerateInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "EnumerateInfo_set_pull_result" "', argument " "1"" of type '" "struct __WsEnumerateInfo *""'"); 
  }
  arg1 = (struct __WsEnumerateInfo *)(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p__WsXmlDoc, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "EnumerateInfo_set_pull_result" "', argument " "2"" of type '" "WsXmlDocH""'"); 
  }
  arg2 = (WsXmlDocH)(argp2);
  __WsEnumerateInfo_set_pull_result(arg1,arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *EnumerateInfo_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj = NULL;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p___WsEnumerateInfo, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_SoapOp_indoc(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct __SoapOp *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  WsXmlDocH result;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p___SoapOp, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SoapOp_indoc" "', argument " "1"" of type '" "struct __SoapOp *""'"); 
  }
  arg1 = (struct __SoapOp *)(argp1);
  result = (WsXmlDocH)__SoapOp_indoc(arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p__WsXmlDoc, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SoapOp_set_indoc(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct __SoapOp *arg1 = 0 ;
  WsXmlDocH arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "SoapOp_set_indoc", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p___SoapOp, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SoapOp_set_indoc" "', argument " "1"" of type '" "struct __SoapOp *""'"); 
  }
  arg1 = (struct __SoapOp *)(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p__WsXmlDoc, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SoapOp_set_indoc" "', argument " "2"" of type '" "WsXmlDocH""'"); 
  }
  arg2 = (WsXmlDocH)(argp2);
  __SoapOp_set_indoc(arg1,arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SoapOp_outdoc(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct __SoapOp *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  WsXmlDocH result;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p___SoapOp, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SoapOp_outdoc" "', argument " "1"" of type '" "struct __SoapOp *""'"); 
  }
  arg1 = (struct __SoapOp *)(argp1);
  result = (WsXmlDocH)__SoapOp_outdoc(arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p__WsXmlDoc, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SoapOp_set_outdoc(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct __SoapOp *arg1 = 0 ;
  WsXmlDocH arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "SoapOp_set_outdoc", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p___SoapOp, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SoapOp_set_outdoc" "', argument " "1"" of type '" "struct __SoapOp *""'"); 
  }
  arg1 = (struct __SoapOp *)(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p__WsXmlDoc, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SoapOp_set_outdoc" "', argument " "2"" of type '" "WsXmlDocH""'"); 
  }
  arg2 = (WsXmlDocH)(argp2);
  __SoapOp_set_outdoc(arg1,arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SoapOp_soap(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct __SoapOp *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  struct __Soap *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p___SoapOp, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SoapOp_soap" "', argument " "1"" of type '" "struct __SoapOp *""'"); 
  }
  arg1 = (struct __SoapOp *)(argp1);
  result = (struct __Soap *)__SoapOp_soap(arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p___Soap, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SoapOp_msg(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct __SoapOp *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  WsmanMessage *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p___SoapOp, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SoapOp_msg" "', argument " "1"" of type '" "struct __SoapOp *""'"); 
  }
  arg1 = (struct __SoapOp *)(argp1);
  result = (WsmanMessage *)__SoapOp_msg(arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_WsmanMessage, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SoapOp_maxsize(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct __SoapOp *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned long result;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p___SoapOp, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SoapOp_maxsize" "', argument " "1"" of type '" "struct __SoapOp *""'"); 
  }
  arg1 = (struct __SoapOp *)(argp1);
  result = (unsigned long)__SoapOp_maxsize(arg1);
  resultobj = SWIG_From_unsigned_SS_long((unsigned long)(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *SoapOp_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj = NULL;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p___SoapOp, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_delete_Soap(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct __Soap *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p___Soap, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Soap" "', argument " "1"" of type '" "struct __Soap *""'"); 
  }
  arg1 = (struct __Soap *)(argp1);
  delete___Soap(arg1);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Soap_create_context(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct __Soap *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  WsContextH result;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p___Soap, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Soap_create_context" "', argument " "1"" of type '" "struct __Soap *""'"); 
  }
  arg1 = (struct __Soap *)(argp1);
  result = (WsContextH)__Soap_create_context(arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p__WS_CONTEXT, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Soap_context(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct __Soap *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  WsContextH result;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p___Soap, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Soap_context" "', argument " "1"" of type '" "struct __Soap *""'"); 
  }
  arg1 = (struct __Soap *)(argp1);
  result = (WsContextH)__Soap_context(arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p__WS_CONTEXT, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Soap_create_ep_context(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct __Soap *arg1 = 0 ;
  WsXmlDocH arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  WsContextH result;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "Soap_create_ep_context", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p___Soap, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Soap_create_ep_context" "', argument " "1"" of type '" "struct __Soap *""'"); 
  }
  arg1 = (struct __Soap *)(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p__WsXmlDoc, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Soap_create_ep_context" "', argument " "2"" of type '" "WsXmlDocH""'"); 
  }
  arg2 = (WsXmlDocH)(argp2);
  result = (WsContextH)__Soap_create_ep_context(arg1,arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p__WS_CONTEXT, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *Soap_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj = NULL;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p___Soap, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_delete_Context(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WS_CONTEXT *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WS_CONTEXT, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Context" "', argument " "1"" of type '" "struct _WS_CONTEXT *""'"); 
  }
  arg1 = (struct _WS_CONTEXT *)(argp1);
  delete__WS_CONTEXT(arg1);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Context_indoc(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WS_CONTEXT *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  WsXmlDocH result;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WS_CONTEXT, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Context_indoc" "', argument " "1"" of type '" "struct _WS_CONTEXT *""'"); 
  }
  arg1 = (struct _WS_CONTEXT *)(argp1);
  result = (WsXmlDocH)_WS_CONTEXT_indoc(arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p__WsXmlDoc, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Context_runtime(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WS_CONTEXT *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  struct __Soap *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WS_CONTEXT, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Context_runtime" "', argument " "1"" of type '" "struct _WS_CONTEXT *""'"); 
  }
  arg1 = (struct _WS_CONTEXT *)(argp1);
  result = (struct __Soap *)_WS_CONTEXT_runtime(arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p___Soap, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Context_set_enumIdleTimeout(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WS_CONTEXT *arg1 = 0 ;
  unsigned long arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned long val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "Context_set_enumIdleTimeout", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WS_CONTEXT, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Context_set_enumIdleTimeout" "', argument " "1"" of type '" "struct _WS_CONTEXT *""'"); 
  }
  arg1 = (struct _WS_CONTEXT *)(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_long(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Context_set_enumIdleTimeout" "', argument " "2"" of type '" "unsigned long""'");
  } 
  arg2 = (unsigned long)(val2);
  _WS_CONTEXT_set_enumIdleTimeout(arg1,arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Context_classname(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WS_CONTEXT *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WS_CONTEXT, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Context_classname" "', argument " "1"" of type '" "struct _WS_CONTEXT *""'"); 
  }
  arg1 = (struct _WS_CONTEXT *)(argp1);
  result = (char *)_WS_CONTEXT_classname(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Context_method(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WS_CONTEXT *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WS_CONTEXT, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Context_method" "', argument " "1"" of type '" "struct _WS_CONTEXT *""'"); 
  }
  arg1 = (struct _WS_CONTEXT *)(argp1);
  result = (char *)_WS_CONTEXT_method(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Context_method_args(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WS_CONTEXT *arg1 = 0 ;
  char *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  PyObject *swig_obj[2] ;
  hash_t *result = 0 ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "Context_method_args", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WS_CONTEXT, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Context_method_args" "', argument " "1"" of type '" "struct _WS_CONTEXT *""'"); 
  }
  arg1 = (struct _WS_CONTEXT *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Context_method_args" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = (char *)(buf2);
  result = (hash_t *)_WS_CONTEXT_method_args(arg1,(char const *)arg2);
  {
    resultobj = hash2value(result);
    
  }
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return NULL;
}


SWIGINTERN PyObject *_wrap_Context_max_elements(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WS_CONTEXT *arg1 = 0 ;
  WsXmlDocH arg2 = NULL ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  int result;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "Context_max_elements", 1, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WS_CONTEXT, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Context_max_elements" "', argument " "1"" of type '" "struct _WS_CONTEXT *""'"); 
  }
  arg1 = (struct _WS_CONTEXT *)(argp1);
  if (swig_obj[1]) {
    res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p__WsXmlDoc, 0 |  0 );
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Context_max_elements" "', argument " "2"" of type '" "WsXmlDocH""'"); 
    }
    arg2 = (WsXmlDocH)(argp2);
  }
  result = (int)_WS_CONTEXT_max_elements(arg1,arg2);
  resultobj = SWIG_From_int((int)(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Context_max_envelope_size(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WS_CONTEXT *arg1 = 0 ;
  WsXmlDocH arg2 = NULL ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  unsigned long result;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "Context_max_envelope_size", 1, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WS_CONTEXT, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Context_max_envelope_size" "', argument " "1"" of type '" "struct _WS_CONTEXT *""'"); 
  }
  arg1 = (struct _WS_CONTEXT *)(argp1);
  if (swig_obj[1]) {
    res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p__WsXmlDoc, 0 |  0 );
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Context_max_envelope_size" "', argument " "2"" of type '" "WsXmlDocH""'"); 
    }
    arg2 = (WsXmlDocH)(argp2);
  }
  result = (unsigned long)_WS_CONTEXT_max_envelope_size(arg1,arg2);
  resultobj = SWIG_From_unsigned_SS_long((unsigned long)(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Context_fragment_string(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WS_CONTEXT *arg1 = 0 ;
  WsXmlDocH arg2 = NULL ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  char *result = 0 ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "Context_fragment_string", 1, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WS_CONTEXT, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Context_fragment_string" "', argument " "1"" of type '" "struct _WS_CONTEXT *""'"); 
  }
  arg1 = (struct _WS_CONTEXT *)(argp1);
  if (swig_obj[1]) {
    res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p__WsXmlDoc, 0 |  0 );
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Context_fragment_string" "', argument " "2"" of type '" "WsXmlDocH""'"); 
    }
    arg2 = (WsXmlDocH)(argp2);
  }
  result = (char *)_WS_CONTEXT_fragment_string(arg1,arg2);
  resultobj = SWIG_FromCharPtr((const char *)result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Context_selector(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WS_CONTEXT *arg1 = 0 ;
  WsXmlDocH arg2 = 0 ;
  char *arg3 = 0 ;
  int arg4 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  int res3 ;
  char *buf3 = 0 ;
  int alloc3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  PyObject *swig_obj[4] ;
  char *result = 0 ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "Context_selector", 4, 4, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WS_CONTEXT, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Context_selector" "', argument " "1"" of type '" "struct _WS_CONTEXT *""'"); 
  }
  arg1 = (struct _WS_CONTEXT *)(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p__WsXmlDoc, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Context_selector" "', argument " "2"" of type '" "WsXmlDocH""'"); 
  }
  arg2 = (WsXmlDocH)(argp2);
  res3 = SWIG_AsCharPtrAndSize(swig_obj[2], &buf3, NULL, &alloc3);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Context_selector" "', argument " "3"" of type '" "char const *""'");
  }
  arg3 = (char *)(buf3);
  ecode4 = SWIG_AsVal_int(swig_obj[3], &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Context_selector" "', argument " "4"" of type '" "int""'");
  } 
  arg4 = (int)(val4);
  result = (char *)_WS_CONTEXT_selector(arg1,arg2,(char const *)arg3,arg4);
  resultobj = SWIG_FromCharPtr((const char *)result);
  if (alloc3 == SWIG_NEWOBJ) free((char*)buf3);
  return resultobj;
fail:
  if (alloc3 == SWIG_NEWOBJ) free((char*)buf3);
  return NULL;
}


SWIGINTERN PyObject *_wrap_Context_selectors_from_epr(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WS_CONTEXT *arg1 = 0 ;
  WsXmlNodeH arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  hash_t *result = 0 ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "Context_selectors_from_epr", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WS_CONTEXT, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Context_selectors_from_epr" "', argument " "1"" of type '" "struct _WS_CONTEXT *""'"); 
  }
  arg1 = (struct _WS_CONTEXT *)(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p___WsXmlNode, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Context_selectors_from_epr" "', argument " "2"" of type '" "WsXmlNodeH""'"); 
  }
  arg2 = (WsXmlNodeH)(argp2);
  result = (hash_t *)_WS_CONTEXT_selectors_from_epr(arg1,arg2);
  {
    resultobj = hash2value(result);
    
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Context_selectors(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WS_CONTEXT *arg1 = 0 ;
  WsXmlDocH arg2 = NULL ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  hash_t *result = 0 ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "Context_selectors", 1, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WS_CONTEXT, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Context_selectors" "', argument " "1"" of type '" "struct _WS_CONTEXT *""'"); 
  }
  arg1 = (struct _WS_CONTEXT *)(argp1);
  if (swig_obj[1]) {
    res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p__WsXmlDoc, 0 |  0 );
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Context_selectors" "', argument " "2"" of type '" "WsXmlDocH""'"); 
    }
    arg2 = (WsXmlDocH)(argp2);
  }
  result = (hash_t *)_WS_CONTEXT_selectors(arg1,arg2);
  {
    resultobj = hash2value(result);
    
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Context_selectors_from_filter(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WS_CONTEXT *arg1 = 0 ;
  WsXmlDocH arg2 = NULL ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  hash_t *result = 0 ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "Context_selectors_from_filter", 1, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WS_CONTEXT, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Context_selectors_from_filter" "', argument " "1"" of type '" "struct _WS_CONTEXT *""'"); 
  }
  arg1 = (struct _WS_CONTEXT *)(argp1);
  if (swig_obj[1]) {
    res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p__WsXmlDoc, 0 |  0 );
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Context_selectors_from_filter" "', argument " "2"" of type '" "WsXmlDocH""'"); 
    }
    arg2 = (WsXmlDocH)(argp2);
  }
  result = (hash_t *)_WS_CONTEXT_selectors_from_filter(arg1,arg2);
  {
    resultobj = hash2value(result);
    
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Context_action(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WS_CONTEXT *arg1 = 0 ;
  WsXmlDocH arg2 = NULL ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  char *result = 0 ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "Context_action", 1, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WS_CONTEXT, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Context_action" "', argument " "1"" of type '" "struct _WS_CONTEXT *""'"); 
  }
  arg1 = (struct _WS_CONTEXT *)(argp1);
  if (swig_obj[1]) {
    res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p__WsXmlDoc, 0 |  0 );
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Context_action" "', argument " "2"" of type '" "WsXmlDocH""'"); 
    }
    arg2 = (WsXmlDocH)(argp2);
  }
  result = (char *)_WS_CONTEXT_action(arg1,arg2);
  resultobj = SWIG_FromCharPtr((const char *)result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Context_resource_uri(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WS_CONTEXT *arg1 = 0 ;
  WsXmlDocH arg2 = NULL ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  char *result = 0 ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "Context_resource_uri", 1, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WS_CONTEXT, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Context_resource_uri" "', argument " "1"" of type '" "struct _WS_CONTEXT *""'"); 
  }
  arg1 = (struct _WS_CONTEXT *)(argp1);
  if (swig_obj[1]) {
    res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p__WsXmlDoc, 0 |  0 );
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Context_resource_uri" "', argument " "2"" of type '" "WsXmlDocH""'"); 
    }
    arg2 = (WsXmlDocH)(argp2);
  }
  result = (char *)_WS_CONTEXT_resource_uri(arg1,arg2);
  resultobj = SWIG_FromCharPtr((const char *)result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Context_option_set(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WS_CONTEXT *arg1 = 0 ;
  WsXmlDocH arg2 = 0 ;
  char *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  int res3 ;
  char *buf3 = 0 ;
  int alloc3 = 0 ;
  PyObject *swig_obj[3] ;
  char *result = 0 ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "Context_option_set", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WS_CONTEXT, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Context_option_set" "', argument " "1"" of type '" "struct _WS_CONTEXT *""'"); 
  }
  arg1 = (struct _WS_CONTEXT *)(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p__WsXmlDoc, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Context_option_set" "', argument " "2"" of type '" "WsXmlDocH""'"); 
  }
  arg2 = (WsXmlDocH)(argp2);
  res3 = SWIG_AsCharPtrAndSize(swig_obj[2], &buf3, NULL, &alloc3);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Context_option_set" "', argument " "3"" of type '" "char const *""'");
  }
  arg3 = (char *)(buf3);
  result = (char *)_WS_CONTEXT_option_set(arg1,arg2,(char const *)arg3);
  resultobj = SWIG_FromCharPtr((const char *)result);
  if (alloc3 == SWIG_NEWOBJ) free((char*)buf3);
  return resultobj;
fail:
  if (alloc3 == SWIG_NEWOBJ) free((char*)buf3);
  return NULL;
}


SWIGINTERN PyObject *_wrap_Context_parse_enum_request(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WS_CONTEXT *arg1 = 0 ;
  WsEnumerateInfo *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  int result;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "Context_parse_enum_request", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WS_CONTEXT, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Context_parse_enum_request" "', argument " "1"" of type '" "struct _WS_CONTEXT *""'"); 
  }
  arg1 = (struct _WS_CONTEXT *)(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_WsEnumerateInfo, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Context_parse_enum_request" "', argument " "2"" of type '" "WsEnumerateInfo *""'"); 
  }
  arg2 = (WsEnumerateInfo *)(argp2);
  result = (int)_WS_CONTEXT_parse_enum_request(arg1,arg2);
  resultobj = SWIG_From_int((int)(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *Context_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj = NULL;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p__WS_CONTEXT, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_Status(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  int arg1 = 0 ;
  int arg2 = 0 ;
  char *arg3 = (char *)NULL ;
  int val1 ;
  int ecode1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  int res3 ;
  char *buf3 = 0 ;
  int alloc3 = 0 ;
  PyObject *swig_obj[3] ;
  struct _WsmanStatus *result = 0 ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "new_Status", 0, 3, swig_obj)) SWIG_fail;
  if (swig_obj[0]) {
    ecode1 = SWIG_AsVal_int(swig_obj[0], &val1);
    if (!SWIG_IsOK(ecode1)) {
      SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_Status" "', argument " "1"" of type '" "int""'");
    } 
    arg1 = (int)(val1);
  }
  if (swig_obj[1]) {
    ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
    if (!SWIG_IsOK(ecode2)) {
      SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "new_Status" "', argument " "2"" of type '" "int""'");
    } 
    arg2 = (int)(val2);
  }
  if (swig_obj[2]) {
    res3 = SWIG_AsCharPtrAndSize(swig_obj[2], &buf3, NULL, &alloc3);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "new_Status" "', argument " "3"" of type '" "char const *""'");
    }
    arg3 = (char *)(buf3);
  }
  result = (struct _WsmanStatus *)new__WsmanStatus(arg1,arg2,(char const *)arg3);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p__WsmanStatus, SWIG_POINTER_NEW |  0 );
  if (alloc3 == SWIG_NEWOBJ) free((char*)buf3);
  return resultobj;
fail:
  if (alloc3 == SWIG_NEWOBJ) free((char*)buf3);
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_Status(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsmanStatus *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsmanStatus, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Status" "', argument " "1"" of type '" "struct _WsmanStatus *""'"); 
  }
  arg1 = (struct _WsmanStatus *)(argp1);
  delete__WsmanStatus(arg1);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Status_to_s(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsmanStatus *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsmanStatus, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Status_to_s" "', argument " "1"" of type '" "struct _WsmanStatus *""'"); 
  }
  arg1 = (struct _WsmanStatus *)(argp1);
  result = (char *)_WsmanStatus_to_s(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Status_set_code(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsmanStatus *arg1 = 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "Status_set_code", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsmanStatus, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Status_set_code" "', argument " "1"" of type '" "struct _WsmanStatus *""'"); 
  }
  arg1 = (struct _WsmanStatus *)(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Status_set_code" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = (int)(val2);
  _WsmanStatus_set_code(arg1,arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Status_code(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsmanStatus *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsmanStatus, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Status_code" "', argument " "1"" of type '" "struct _WsmanStatus *""'"); 
  }
  arg1 = (struct _WsmanStatus *)(argp1);
  result = (int)_WsmanStatus_code(arg1);
  resultobj = SWIG_From_int((int)(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Status_set_detail(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsmanStatus *arg1 = 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "Status_set_detail", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsmanStatus, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Status_set_detail" "', argument " "1"" of type '" "struct _WsmanStatus *""'"); 
  }
  arg1 = (struct _WsmanStatus *)(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Status_set_detail" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = (int)(val2);
  _WsmanStatus_set_detail(arg1,arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Status_detail(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsmanStatus *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsmanStatus, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Status_detail" "', argument " "1"" of type '" "struct _WsmanStatus *""'"); 
  }
  arg1 = (struct _WsmanStatus *)(argp1);
  result = (int)_WsmanStatus_detail(arg1);
  resultobj = SWIG_From_int((int)(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Status_set_msg(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsmanStatus *arg1 = 0 ;
  char *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "Status_set_msg", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsmanStatus, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Status_set_msg" "', argument " "1"" of type '" "struct _WsmanStatus *""'"); 
  }
  arg1 = (struct _WsmanStatus *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Status_set_msg" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = (char *)(buf2);
  _WsmanStatus_set_msg(arg1,(char const *)arg2);
  resultobj = SWIG_Py_Void();
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return NULL;
}


SWIGINTERN PyObject *_wrap_Status_msg(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsmanStatus *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsmanStatus, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Status_msg" "', argument " "1"" of type '" "struct _WsmanStatus *""'"); 
  }
  arg1 = (struct _WsmanStatus *)(argp1);
  result = (char *)_WsmanStatus_msg(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Status_generate_fault(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsmanStatus *arg1 = 0 ;
  WsXmlDocH arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  WsXmlDocH result;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "Status_generate_fault", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsmanStatus, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Status_generate_fault" "', argument " "1"" of type '" "struct _WsmanStatus *""'"); 
  }
  arg1 = (struct _WsmanStatus *)(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p__WsXmlDoc, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Status_generate_fault" "', argument " "2"" of type '" "WsXmlDocH""'"); 
  }
  arg2 = (WsXmlDocH)(argp2);
  result = (WsXmlDocH)_WsmanStatus_generate_fault(arg1,arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p__WsXmlDoc, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *Status_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj = NULL;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p__WsmanStatus, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *Status_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_new_Fault(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  WsXmlDocH arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  struct _WsManFault *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsXmlDoc, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_Fault" "', argument " "1"" of type '" "WsXmlDocH""'"); 
  }
  arg1 = (WsXmlDocH)(argp1);
  result = (struct _WsManFault *)new__WsManFault(arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p__WsManFault, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_Fault(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManFault *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManFault, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Fault" "', argument " "1"" of type '" "struct _WsManFault *""'"); 
  }
  arg1 = (struct _WsManFault *)(argp1);
  delete__WsManFault(arg1);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Fault_code(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManFault *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManFault, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Fault_code" "', argument " "1"" of type '" "struct _WsManFault *""'"); 
  }
  arg1 = (struct _WsManFault *)(argp1);
  result = (char *)_WsManFault_code(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Fault_subcode(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManFault *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManFault, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Fault_subcode" "', argument " "1"" of type '" "struct _WsManFault *""'"); 
  }
  arg1 = (struct _WsManFault *)(argp1);
  result = (char *)_WsManFault_subcode(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Fault_reason(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManFault *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManFault, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Fault_reason" "', argument " "1"" of type '" "struct _WsManFault *""'"); 
  }
  arg1 = (struct _WsManFault *)(argp1);
  result = (char *)_WsManFault_reason(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Fault_detail(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManFault *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManFault, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Fault_detail" "', argument " "1"" of type '" "struct _WsManFault *""'"); 
  }
  arg1 = (struct _WsManFault *)(argp1);
  result = (char *)_WsManFault_detail(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *Fault_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj = NULL;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p__WsManFault, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *Fault_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_Transport_is_auth_method(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManTransport *arg1 = 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  int result;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "Transport_is_auth_method", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManTransport, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Transport_is_auth_method" "', argument " "1"" of type '" "struct _WsManTransport *""'"); 
  }
  arg1 = (struct _WsManTransport *)(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Transport_is_auth_method" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = (int)(val2);
  result = (int)_WsManTransport_is_auth_method(arg1,arg2);
  resultobj = SWIG_From_int((int)(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Transport_close(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManTransport *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManTransport, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Transport_close" "', argument " "1"" of type '" "struct _WsManTransport *""'"); 
  }
  arg1 = (struct _WsManTransport *)(argp1);
  _WsManTransport_close(arg1);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Transport_set_agent(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManTransport *arg1 = 0 ;
  char *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "Transport_set_agent", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManTransport, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Transport_set_agent" "', argument " "1"" of type '" "struct _WsManTransport *""'"); 
  }
  arg1 = (struct _WsManTransport *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Transport_set_agent" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = (char *)(buf2);
  _WsManTransport_set_agent(arg1,(char const *)arg2);
  resultobj = SWIG_Py_Void();
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return NULL;
}


SWIGINTERN PyObject *_wrap_Transport_agent(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManTransport *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManTransport, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Transport_agent" "', argument " "1"" of type '" "struct _WsManTransport *""'"); 
  }
  arg1 = (struct _WsManTransport *)(argp1);
  result = (char *)_WsManTransport_agent(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  free(result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Transport_get_username(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManTransport *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManTransport, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Transport_get_username" "', argument " "1"" of type '" "struct _WsManTransport *""'"); 
  }
  arg1 = (struct _WsManTransport *)(argp1);
  result = (char *)_WsManTransport_get_username(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  free(result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Transport_set_username(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManTransport *arg1 = 0 ;
  char *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "Transport_set_username", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManTransport, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Transport_set_username" "', argument " "1"" of type '" "struct _WsManTransport *""'"); 
  }
  arg1 = (struct _WsManTransport *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Transport_set_username" "', argument " "2"" of type '" "char *""'");
  }
  arg2 = (char *)(buf2);
  _WsManTransport_set_username(arg1,arg2);
  resultobj = SWIG_Py_Void();
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return NULL;
}


SWIGINTERN PyObject *_wrap_Transport_get_password(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManTransport *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManTransport, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Transport_get_password" "', argument " "1"" of type '" "struct _WsManTransport *""'"); 
  }
  arg1 = (struct _WsManTransport *)(argp1);
  result = (char *)_WsManTransport_get_password(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  free(result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Transport_set_password(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManTransport *arg1 = 0 ;
  char *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "Transport_set_password", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManTransport, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Transport_set_password" "', argument " "1"" of type '" "struct _WsManTransport *""'"); 
  }
  arg1 = (struct _WsManTransport *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Transport_set_password" "', argument " "2"" of type '" "char *""'");
  }
  arg2 = (char *)(buf2);
  _WsManTransport_set_password(arg1,arg2);
  resultobj = SWIG_Py_Void();
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return NULL;
}


SWIGINTERN PyObject *_wrap_Transport_get_proxy_username(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManTransport *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManTransport, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Transport_get_proxy_username" "', argument " "1"" of type '" "struct _WsManTransport *""'"); 
  }
  arg1 = (struct _WsManTransport *)(argp1);
  result = (char *)_WsManTransport_get_proxy_username(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  free(result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Transport_set_proxy_username(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManTransport *arg1 = 0 ;
  char *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "Transport_set_proxy_username", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManTransport, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Transport_set_proxy_username" "', argument " "1"" of type '" "struct _WsManTransport *""'"); 
  }
  arg1 = (struct _WsManTransport *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Transport_set_proxy_username" "', argument " "2"" of type '" "char *""'");
  }
  arg2 = (char *)(buf2);
  _WsManTransport_set_proxy_username(arg1,arg2);
  resultobj = SWIG_Py_Void();
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return NULL;
}


SWIGINTERN PyObject *_wrap_Transport_get_proxy_password(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManTransport *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManTransport, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Transport_get_proxy_password" "', argument " "1"" of type '" "struct _WsManTransport *""'"); 
  }
  arg1 = (struct _WsManTransport *)(argp1);
  result = (char *)_WsManTransport_get_proxy_password(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  free(result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Transport_set_proxy_password(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManTransport *arg1 = 0 ;
  char *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "Transport_set_proxy_password", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManTransport, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Transport_set_proxy_password" "', argument " "1"" of type '" "struct _WsManTransport *""'"); 
  }
  arg1 = (struct _WsManTransport *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Transport_set_proxy_password" "', argument " "2"" of type '" "char *""'");
  }
  arg2 = (char *)(buf2);
  _WsManTransport_set_proxy_password(arg1,arg2);
  resultobj = SWIG_Py_Void();
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return NULL;
}


SWIGINTERN PyObject *_wrap_Transport_set_auth_method(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManTransport *arg1 = 0 ;
  char *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "Transport_set_auth_method", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManTransport, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Transport_set_auth_method" "', argument " "1"" of type '" "struct _WsManTransport *""'"); 
  }
  arg1 = (struct _WsManTransport *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Transport_set_auth_method" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = (char *)(buf2);
  _WsManTransport_set_auth_method(arg1,(char const *)arg2);
  resultobj = SWIG_Py_Void();
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return NULL;
}


SWIGINTERN PyObject *_wrap_Transport_auth_method(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManTransport *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManTransport, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Transport_auth_method" "', argument " "1"" of type '" "struct _WsManTransport *""'"); 
  }
  arg1 = (struct _WsManTransport *)(argp1);
  result = (char *)_WsManTransport_auth_method(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  free(result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Transport_auth_name(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  int arg1 ;
  int val1 ;
  int ecode1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  ecode1 = SWIG_AsVal_int(swig_obj[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Transport_auth_name" "', argument " "1"" of type '" "int""'");
  } 
  arg1 = (int)(val1);
  result = (char *)_WsManTransport_auth_name(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Transport_auth_value(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManTransport *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManTransport, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Transport_auth_value" "', argument " "1"" of type '" "struct _WsManTransport *""'"); 
  }
  arg1 = (struct _WsManTransport *)(argp1);
  result = (int)_WsManTransport_auth_value(arg1);
  resultobj = SWIG_From_int((int)(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Transport_error_string(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  int arg1 ;
  int val1 ;
  int ecode1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  ecode1 = SWIG_AsVal_int(swig_obj[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Transport_error_string" "', argument " "1"" of type '" "int""'");
  } 
  arg1 = (int)(val1);
  result = (char *)_WsManTransport_error_string(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Transport_set_timeout(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManTransport *arg1 = 0 ;
  unsigned long arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned long val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "Transport_set_timeout", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManTransport, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Transport_set_timeout" "', argument " "1"" of type '" "struct _WsManTransport *""'"); 
  }
  arg1 = (struct _WsManTransport *)(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_long(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Transport_set_timeout" "', argument " "2"" of type '" "unsigned long""'");
  } 
  arg2 = (unsigned long)(val2);
  _WsManTransport_set_timeout(arg1,arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Transport_timeout(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManTransport *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned long result;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManTransport, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Transport_timeout" "', argument " "1"" of type '" "struct _WsManTransport *""'"); 
  }
  arg1 = (struct _WsManTransport *)(argp1);
  result = (unsigned long)_WsManTransport_timeout(arg1);
  resultobj = SWIG_From_unsigned_SS_long((unsigned long)(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Transport_set_verify_peer(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManTransport *arg1 = 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "Transport_set_verify_peer", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManTransport, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Transport_set_verify_peer" "', argument " "1"" of type '" "struct _WsManTransport *""'"); 
  }
  arg1 = (struct _WsManTransport *)(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Transport_set_verify_peer" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = (unsigned int)(val2);
  _WsManTransport_set_verify_peer(arg1,arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Transport_verify_peer(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManTransport *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManTransport, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Transport_verify_peer" "', argument " "1"" of type '" "struct _WsManTransport *""'"); 
  }
  arg1 = (struct _WsManTransport *)(argp1);
  result = (unsigned int)_WsManTransport_verify_peer(arg1);
  resultobj = SWIG_From_unsigned_SS_int((unsigned int)(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Transport_set_verify_host(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManTransport *arg1 = 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "Transport_set_verify_host", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManTransport, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Transport_set_verify_host" "', argument " "1"" of type '" "struct _WsManTransport *""'"); 
  }
  arg1 = (struct _WsManTransport *)(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Transport_set_verify_host" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = (unsigned int)(val2);
  _WsManTransport_set_verify_host(arg1,arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Transport_verify_host(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManTransport *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManTransport, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Transport_verify_host" "', argument " "1"" of type '" "struct _WsManTransport *""'"); 
  }
  arg1 = (struct _WsManTransport *)(argp1);
  result = (unsigned int)_WsManTransport_verify_host(arg1);
  resultobj = SWIG_From_unsigned_SS_int((unsigned int)(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Transport_set_proxy(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManTransport *arg1 = 0 ;
  char *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "Transport_set_proxy", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManTransport, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Transport_set_proxy" "', argument " "1"" of type '" "struct _WsManTransport *""'"); 
  }
  arg1 = (struct _WsManTransport *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Transport_set_proxy" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = (char *)(buf2);
  _WsManTransport_set_proxy(arg1,(char const *)arg2);
  resultobj = SWIG_Py_Void();
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return NULL;
}


SWIGINTERN PyObject *_wrap_Transport_proxy(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManTransport *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManTransport, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Transport_proxy" "', argument " "1"" of type '" "struct _WsManTransport *""'"); 
  }
  arg1 = (struct _WsManTransport *)(argp1);
  result = (char *)_WsManTransport_proxy(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  free(result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Transport_set_proxyauth(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManTransport *arg1 = 0 ;
  char *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "Transport_set_proxyauth", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManTransport, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Transport_set_proxyauth" "', argument " "1"" of type '" "struct _WsManTransport *""'"); 
  }
  arg1 = (struct _WsManTransport *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Transport_set_proxyauth" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = (char *)(buf2);
  _WsManTransport_set_proxyauth(arg1,(char const *)arg2);
  resultobj = SWIG_Py_Void();
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return NULL;
}


SWIGINTERN PyObject *_wrap_Transport_proxyauth(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManTransport *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManTransport, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Transport_proxyauth" "', argument " "1"" of type '" "struct _WsManTransport *""'"); 
  }
  arg1 = (struct _WsManTransport *)(argp1);
  result = (char *)_WsManTransport_proxyauth(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  free(result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Transport_set_cainfo(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManTransport *arg1 = 0 ;
  char *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "Transport_set_cainfo", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManTransport, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Transport_set_cainfo" "', argument " "1"" of type '" "struct _WsManTransport *""'"); 
  }
  arg1 = (struct _WsManTransport *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Transport_set_cainfo" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = (char *)(buf2);
  _WsManTransport_set_cainfo(arg1,(char const *)arg2);
  resultobj = SWIG_Py_Void();
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return NULL;
}


SWIGINTERN PyObject *_wrap_Transport_cainfo(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManTransport *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManTransport, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Transport_cainfo" "', argument " "1"" of type '" "struct _WsManTransport *""'"); 
  }
  arg1 = (struct _WsManTransport *)(argp1);
  result = (char *)_WsManTransport_cainfo(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  free(result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Transport_set_certhumbprint(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManTransport *arg1 = 0 ;
  char *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "Transport_set_certhumbprint", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManTransport, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Transport_set_certhumbprint" "', argument " "1"" of type '" "struct _WsManTransport *""'"); 
  }
  arg1 = (struct _WsManTransport *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Transport_set_certhumbprint" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = (char *)(buf2);
  _WsManTransport_set_certhumbprint(arg1,(char const *)arg2);
  resultobj = SWIG_Py_Void();
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return NULL;
}


SWIGINTERN PyObject *_wrap_Transport_certhumbprint(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManTransport *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManTransport, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Transport_certhumbprint" "', argument " "1"" of type '" "struct _WsManTransport *""'"); 
  }
  arg1 = (struct _WsManTransport *)(argp1);
  result = (char *)_WsManTransport_certhumbprint(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  free(result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Transport_set_capath(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManTransport *arg1 = 0 ;
  char *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "Transport_set_capath", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManTransport, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Transport_set_capath" "', argument " "1"" of type '" "struct _WsManTransport *""'"); 
  }
  arg1 = (struct _WsManTransport *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Transport_set_capath" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = (char *)(buf2);
  _WsManTransport_set_capath(arg1,(char const *)arg2);
  resultobj = SWIG_Py_Void();
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return NULL;
}


SWIGINTERN PyObject *_wrap_Transport_capath(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManTransport *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManTransport, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Transport_capath" "', argument " "1"" of type '" "struct _WsManTransport *""'"); 
  }
  arg1 = (struct _WsManTransport *)(argp1);
  result = (char *)_WsManTransport_capath(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  free(result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Transport_set_caoid(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManTransport *arg1 = 0 ;
  char *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "Transport_set_caoid", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManTransport, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Transport_set_caoid" "', argument " "1"" of type '" "struct _WsManTransport *""'"); 
  }
  arg1 = (struct _WsManTransport *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Transport_set_caoid" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = (char *)(buf2);
  _WsManTransport_set_caoid(arg1,(char const *)arg2);
  resultobj = SWIG_Py_Void();
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return NULL;
}


SWIGINTERN PyObject *_wrap_Transport_caoid(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManTransport *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManTransport, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Transport_caoid" "', argument " "1"" of type '" "struct _WsManTransport *""'"); 
  }
  arg1 = (struct _WsManTransport *)(argp1);
  result = (char *)_WsManTransport_caoid(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  free(result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Transport_set_cert(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManTransport *arg1 = 0 ;
  char *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "Transport_set_cert", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManTransport, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Transport_set_cert" "', argument " "1"" of type '" "struct _WsManTransport *""'"); 
  }
  arg1 = (struct _WsManTransport *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Transport_set_cert" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = (char *)(buf2);
  _WsManTransport_set_cert(arg1,(char const *)arg2);
  resultobj = SWIG_Py_Void();
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return NULL;
}


SWIGINTERN PyObject *_wrap_Transport_cert(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManTransport *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManTransport, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Transport_cert" "', argument " "1"" of type '" "struct _WsManTransport *""'"); 
  }
  arg1 = (struct _WsManTransport *)(argp1);
  result = (char *)_WsManTransport_cert(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  free(result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Transport_set_key(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManTransport *arg1 = 0 ;
  char *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "Transport_set_key", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManTransport, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Transport_set_key" "', argument " "1"" of type '" "struct _WsManTransport *""'"); 
  }
  arg1 = (struct _WsManTransport *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Transport_set_key" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = (char *)(buf2);
  _WsManTransport_set_key(arg1,(char const *)arg2);
  resultobj = SWIG_Py_Void();
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return NULL;
}


SWIGINTERN PyObject *_wrap_Transport_key(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManTransport *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManTransport, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Transport_key" "', argument " "1"" of type '" "struct _WsManTransport *""'"); 
  }
  arg1 = (struct _WsManTransport *)(argp1);
  result = (char *)_WsManTransport_key(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  free(result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *Transport_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj = NULL;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p__WsManTransport, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_wsman_send_request(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  WsManClient *arg1 = 0 ;
  WsXmlDocH arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  int result;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "wsman_send_request", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "wsman_send_request" "', argument " "1"" of type '" "WsManClient *""'"); 
  }
  arg1 = (WsManClient *)(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p__WsXmlDoc, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "wsman_send_request" "', argument " "2"" of type '" "WsXmlDocH""'"); 
  }
  arg2 = (WsXmlDocH)(argp2);
  result = (int)wsman_send_request(arg1,arg2);
  resultobj = SWIG_From_int((int)(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_wsmc_transport_set_auth_request_func(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  WsManClient *arg1 = 0 ;
  wsman_auth_request_func_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "wsmc_transport_set_auth_request_func", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "wsmc_transport_set_auth_request_func" "', argument " "1"" of type '" "WsManClient *""'"); 
  }
  arg1 = (WsManClient *)(argp1);
  {
    res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_wsman_auth_request_func_t,  0 );
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "wsmc_transport_set_auth_request_func" "', argument " "2"" of type '" "wsman_auth_request_func_t""'"); 
    }  
    if (!argp2) {
      SWIG_exception_fail(SWIG_NullReferenceError, "invalid null reference " "in method '" "wsmc_transport_set_auth_request_func" "', argument " "2"" of type '" "wsman_auth_request_func_t""'");
    } else {
      arg2 = *((wsman_auth_request_func_t *)(argp2));
    }
  }
  wsmc_transport_set_auth_request_func(arg1,arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_wsman_is_auth_method(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  WsManClient *arg1 = 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  int result;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "wsman_is_auth_method", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "wsman_is_auth_method" "', argument " "1"" of type '" "WsManClient *""'"); 
  }
  arg1 = (WsManClient *)(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "wsman_is_auth_method" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = (int)(val2);
  result = (int)wsman_is_auth_method(arg1,arg2);
  resultobj = SWIG_From_int((int)(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_wsmc_transport_init(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  WsManClient *arg1 = 0 ;
  void *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  PyObject *swig_obj[2] ;
  int result;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "wsmc_transport_init", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "wsmc_transport_init" "', argument " "1"" of type '" "WsManClient *""'"); 
  }
  arg1 = (WsManClient *)(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1],SWIG_as_voidptrptr(&arg2), 0, 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "wsmc_transport_init" "', argument " "2"" of type '" "void *""'"); 
  }
  result = (int)wsmc_transport_init(arg1,arg2);
  resultobj = SWIG_From_int((int)(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_wsman_transport_close_transport(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  WsManClient *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "wsman_transport_close_transport" "', argument " "1"" of type '" "WsManClient *""'"); 
  }
  arg1 = (WsManClient *)(argp1);
  wsman_transport_close_transport(arg1);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_wsmc_transport_fini(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  WsManClient *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "wsmc_transport_fini" "', argument " "1"" of type '" "WsManClient *""'"); 
  }
  arg1 = (WsManClient *)(argp1);
  wsmc_transport_fini(arg1);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_wsman_transport_set_agent(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  WsManClient *arg1 = 0 ;
  char *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "wsman_transport_set_agent", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "wsman_transport_set_agent" "', argument " "1"" of type '" "WsManClient *""'"); 
  }
  arg1 = (WsManClient *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "wsman_transport_set_agent" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = (char *)(buf2);
  wsman_transport_set_agent(arg1,(char const *)arg2);
  resultobj = SWIG_Py_Void();
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return NULL;
}


SWIGINTERN PyObject *_wrap_wsman_transport_get_agent(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  WsManClient *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "wsman_transport_get_agent" "', argument " "1"" of type '" "WsManClient *""'"); 
  }
  arg1 = (WsManClient *)(argp1);
  result = (char *)wsman_transport_get_agent(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_wsman_transport_set_userName(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  WsManClient *arg1 = 0 ;
  char *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "wsman_transport_set_userName", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "wsman_transport_set_userName" "', argument " "1"" of type '" "WsManClient *""'"); 
  }
  arg1 = (WsManClient *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "wsman_transport_set_userName" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = (char *)(buf2);
  wsman_transport_set_userName(arg1,(char const *)arg2);
  resultobj = SWIG_Py_Void();
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return NULL;
}


SWIGINTERN PyObject *_wrap_wsman_transport_get_userName(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  WsManClient *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "wsman_transport_get_userName" "', argument " "1"" of type '" "WsManClient *""'"); 
  }
  arg1 = (WsManClient *)(argp1);
  result = (char *)wsman_transport_get_userName(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_wsman_transport_set_password(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  WsManClient *arg1 = 0 ;
  char *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "wsman_transport_set_password", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "wsman_transport_set_password" "', argument " "1"" of type '" "WsManClient *""'"); 
  }
  arg1 = (WsManClient *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "wsman_transport_set_password" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = (char *)(buf2);
  wsman_transport_set_password(arg1,(char const *)arg2);
  resultobj = SWIG_Py_Void();
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return NULL;
}


SWIGINTERN PyObject *_wrap_wsman_transport_get_password(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  WsManClient *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "wsman_transport_get_password" "', argument " "1"" of type '" "WsManClient *""'"); 
  }
  arg1 = (WsManClient *)(argp1);
  result = (char *)wsman_transport_get_password(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_wsman_transport_set_proxy_username(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  WsManClient *arg1 = 0 ;
  char *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "wsman_transport_set_proxy_username", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "wsman_transport_set_proxy_username" "', argument " "1"" of type '" "WsManClient *""'"); 
  }
  arg1 = (WsManClient *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "wsman_transport_set_proxy_username" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = (char *)(buf2);
  wsman_transport_set_proxy_username(arg1,(char const *)arg2);
  resultobj = SWIG_Py_Void();
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return NULL;
}


SWIGINTERN PyObject *_wrap_wsman_transport_get_proxy_username(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  WsManClient *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "wsman_transport_get_proxy_username" "', argument " "1"" of type '" "WsManClient *""'"); 
  }
  arg1 = (WsManClient *)(argp1);
  result = (char *)wsman_transport_get_proxy_username(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_wsman_transport_set_proxy_password(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  WsManClient *arg1 = 0 ;
  char *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "wsman_transport_set_proxy_password", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "wsman_transport_set_proxy_password" "', argument " "1"" of type '" "WsManClient *""'"); 
  }
  arg1 = (WsManClient *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "wsman_transport_set_proxy_password" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = (char *)(buf2);
  wsman_transport_set_proxy_password(arg1,(char const *)arg2);
  resultobj = SWIG_Py_Void();
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return NULL;
}


SWIGINTERN PyObject *_wrap_wsman_transport_get_proxy_password(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  WsManClient *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "wsman_transport_get_proxy_password" "', argument " "1"" of type '" "WsManClient *""'"); 
  }
  arg1 = (WsManClient *)(argp1);
  result = (char *)wsman_transport_get_proxy_password(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_wsman_transport_set_auth_method(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  WsManClient *arg1 = 0 ;
  char *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "wsman_transport_set_auth_method", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "wsman_transport_set_auth_method" "', argument " "1"" of type '" "WsManClient *""'"); 
  }
  arg1 = (WsManClient *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "wsman_transport_set_auth_method" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = (char *)(buf2);
  wsman_transport_set_auth_method(arg1,(char const *)arg2);
  resultobj = SWIG_Py_Void();
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return NULL;
}


SWIGINTERN PyObject *_wrap_wsman_transport_get_auth_method(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  WsManClient *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "wsman_transport_get_auth_method" "', argument " "1"" of type '" "WsManClient *""'"); 
  }
  arg1 = (WsManClient *)(argp1);
  result = (char *)wsman_transport_get_auth_method(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_wsmc_transport_get_auth_name(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  wsman_auth_type_t arg1 ;
  void *argp1 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  {
    res1 = SWIG_ConvertPtr(swig_obj[0], &argp1, SWIGTYPE_p_wsman_auth_type_t,  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "wsmc_transport_get_auth_name" "', argument " "1"" of type '" "wsman_auth_type_t""'"); 
    }  
    if (!argp1) {
      SWIG_exception_fail(SWIG_NullReferenceError, "invalid null reference " "in method '" "wsmc_transport_get_auth_name" "', argument " "1"" of type '" "wsman_auth_type_t""'");
    } else {
      arg1 = *((wsman_auth_type_t *)(argp1));
    }
  }
  result = (char *)wsmc_transport_get_auth_name(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_wsmc_transport_get_auth_value(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  WsManClient *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  wsman_auth_type_t result;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "wsmc_transport_get_auth_value" "', argument " "1"" of type '" "WsManClient *""'"); 
  }
  arg1 = (WsManClient *)(argp1);
  result = wsmc_transport_get_auth_value(arg1);
  resultobj = SWIG_NewPointerObj((wsman_auth_type_t *)memcpy((wsman_auth_type_t *)calloc(1,sizeof(wsman_auth_type_t)),&result,sizeof(wsman_auth_type_t)), SWIGTYPE_p_wsman_auth_type_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_wsman_transport_get_last_error_string(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  WS_LASTERR_Code arg1 ;
  void *argp1 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  {
    res1 = SWIG_ConvertPtr(swig_obj[0], &argp1, SWIGTYPE_p_WS_LASTERR_Code,  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "wsman_transport_get_last_error_string" "', argument " "1"" of type '" "WS_LASTERR_Code""'"); 
    }  
    if (!argp1) {
      SWIG_exception_fail(SWIG_NullReferenceError, "invalid null reference " "in method '" "wsman_transport_get_last_error_string" "', argument " "1"" of type '" "WS_LASTERR_Code""'");
    } else {
      arg1 = *((WS_LASTERR_Code *)(argp1));
    }
  }
  result = (char *)wsman_transport_get_last_error_string(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_wsman_transport_set_timeout(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  WsManClient *arg1 = 0 ;
  unsigned long arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned long val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "wsman_transport_set_timeout", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "wsman_transport_set_timeout" "', argument " "1"" of type '" "WsManClient *""'"); 
  }
  arg1 = (WsManClient *)(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_long(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "wsman_transport_set_timeout" "', argument " "2"" of type '" "unsigned long""'");
  } 
  arg2 = (unsigned long)(val2);
  wsman_transport_set_timeout(arg1,arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_wsman_transport_get_timeout(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  WsManClient *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned long result;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "wsman_transport_get_timeout" "', argument " "1"" of type '" "WsManClient *""'"); 
  }
  arg1 = (WsManClient *)(argp1);
  result = (unsigned long)wsman_transport_get_timeout(arg1);
  resultobj = SWIG_From_unsigned_SS_long((unsigned long)(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_wsman_transport_set_verify_peer(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  WsManClient *arg1 = 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "wsman_transport_set_verify_peer", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "wsman_transport_set_verify_peer" "', argument " "1"" of type '" "WsManClient *""'"); 
  }
  arg1 = (WsManClient *)(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "wsman_transport_set_verify_peer" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = (unsigned int)(val2);
  wsman_transport_set_verify_peer(arg1,arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_wsman_transport_get_verify_peer(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  WsManClient *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "wsman_transport_get_verify_peer" "', argument " "1"" of type '" "WsManClient *""'"); 
  }
  arg1 = (WsManClient *)(argp1);
  result = (unsigned int)wsman_transport_get_verify_peer(arg1);
  resultobj = SWIG_From_unsigned_SS_int((unsigned int)(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_wsman_transport_set_verify_host(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  WsManClient *arg1 = 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "wsman_transport_set_verify_host", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "wsman_transport_set_verify_host" "', argument " "1"" of type '" "WsManClient *""'"); 
  }
  arg1 = (WsManClient *)(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "wsman_transport_set_verify_host" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = (unsigned int)(val2);
  wsman_transport_set_verify_host(arg1,arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_wsman_transport_get_verify_host(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  WsManClient *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "wsman_transport_get_verify_host" "', argument " "1"" of type '" "WsManClient *""'"); 
  }
  arg1 = (WsManClient *)(argp1);
  result = (unsigned int)wsman_transport_get_verify_host(arg1);
  resultobj = SWIG_From_unsigned_SS_int((unsigned int)(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_wsman_transport_set_crlcheck(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  WsManClient *arg1 = 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "wsman_transport_set_crlcheck", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "wsman_transport_set_crlcheck" "', argument " "1"" of type '" "WsManClient *""'"); 
  }
  arg1 = (WsManClient *)(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "wsman_transport_set_crlcheck" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = (unsigned int)(val2);
  wsman_transport_set_crlcheck(arg1,arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_wsman_transport_get_crlcheck(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  WsManClient *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "wsman_transport_get_crlcheck" "', argument " "1"" of type '" "WsManClient *""'"); 
  }
  arg1 = (WsManClient *)(argp1);
  result = (unsigned int)wsman_transport_get_crlcheck(arg1);
  resultobj = SWIG_From_unsigned_SS_int((unsigned int)(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_wsman_transport_set_crlfile(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  WsManClient *arg1 = 0 ;
  char *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "wsman_transport_set_crlfile", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "wsman_transport_set_crlfile" "', argument " "1"" of type '" "WsManClient *""'"); 
  }
  arg1 = (WsManClient *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "wsman_transport_set_crlfile" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = (char *)(buf2);
  wsman_transport_set_crlfile(arg1,(char const *)arg2);
  resultobj = SWIG_Py_Void();
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return NULL;
}


SWIGINTERN PyObject *_wrap_wsman_transport_get_crlfile(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  WsManClient *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "wsman_transport_get_crlfile" "', argument " "1"" of type '" "WsManClient *""'"); 
  }
  arg1 = (WsManClient *)(argp1);
  result = (char *)wsman_transport_get_crlfile(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_wsman_transport_set_proxy(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  WsManClient *arg1 = 0 ;
  char *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "wsman_transport_set_proxy", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "wsman_transport_set_proxy" "', argument " "1"" of type '" "WsManClient *""'"); 
  }
  arg1 = (WsManClient *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "wsman_transport_set_proxy" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = (char *)(buf2);
  wsman_transport_set_proxy(arg1,(char const *)arg2);
  resultobj = SWIG_Py_Void();
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return NULL;
}


SWIGINTERN PyObject *_wrap_wsman_transport_get_proxy(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  WsManClient *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "wsman_transport_get_proxy" "', argument " "1"" of type '" "WsManClient *""'"); 
  }
  arg1 = (WsManClient *)(argp1);
  result = (char *)wsman_transport_get_proxy(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_wsman_transport_set_proxyauth(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  WsManClient *arg1 = 0 ;
  char *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "wsman_transport_set_proxyauth", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "wsman_transport_set_proxyauth" "', argument " "1"" of type '" "WsManClient *""'"); 
  }
  arg1 = (WsManClient *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "wsman_transport_set_proxyauth" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = (char *)(buf2);
  wsman_transport_set_proxyauth(arg1,(char const *)arg2);
  resultobj = SWIG_Py_Void();
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return NULL;
}


SWIGINTERN PyObject *_wrap_wsman_transport_get_proxyauth(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  WsManClient *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "wsman_transport_get_proxyauth" "', argument " "1"" of type '" "WsManClient *""'"); 
  }
  arg1 = (WsManClient *)(argp1);
  result = (char *)wsman_transport_get_proxyauth(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_wsman_transport_set_cainfo(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  WsManClient *arg1 = 0 ;
  char *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "wsman_transport_set_cainfo", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "wsman_transport_set_cainfo" "', argument " "1"" of type '" "WsManClient *""'"); 
  }
  arg1 = (WsManClient *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "wsman_transport_set_cainfo" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = (char *)(buf2);
  wsman_transport_set_cainfo(arg1,(char const *)arg2);
  resultobj = SWIG_Py_Void();
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return NULL;
}


SWIGINTERN PyObject *_wrap_wsman_transport_get_cainfo(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  WsManClient *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "wsman_transport_get_cainfo" "', argument " "1"" of type '" "WsManClient *""'"); 
  }
  arg1 = (WsManClient *)(argp1);
  result = (char *)wsman_transport_get_cainfo(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_wsman_transport_set_certhumbprint(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  WsManClient *arg1 = 0 ;
  char *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "wsman_transport_set_certhumbprint", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "wsman_transport_set_certhumbprint" "', argument " "1"" of type '" "WsManClient *""'"); 
  }
  arg1 = (WsManClient *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "wsman_transport_set_certhumbprint" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = (char *)(buf2);
  wsman_transport_set_certhumbprint(arg1,(char const *)arg2);
  resultobj = SWIG_Py_Void();
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return NULL;
}


SWIGINTERN PyObject *_wrap_wsman_transport_get_certhumbprint(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  WsManClient *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "wsman_transport_get_certhumbprint" "', argument " "1"" of type '" "WsManClient *""'"); 
  }
  arg1 = (WsManClient *)(argp1);
  result = (char *)wsman_transport_get_certhumbprint(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_wsman_transport_set_capath(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  WsManClient *arg1 = 0 ;
  char *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "wsman_transport_set_capath", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "wsman_transport_set_capath" "', argument " "1"" of type '" "WsManClient *""'"); 
  }
  arg1 = (WsManClient *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "wsman_transport_set_capath" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = (char *)(buf2);
  wsman_transport_set_capath(arg1,(char const *)arg2);
  resultobj = SWIG_Py_Void();
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return NULL;
}


SWIGINTERN PyObject *_wrap_wsman_transport_get_capath(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  WsManClient *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "wsman_transport_get_capath" "', argument " "1"" of type '" "WsManClient *""'"); 
  }
  arg1 = (WsManClient *)(argp1);
  result = (char *)wsman_transport_get_capath(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_wsman_transport_set_caoid(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  WsManClient *arg1 = 0 ;
  char *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "wsman_transport_set_caoid", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "wsman_transport_set_caoid" "', argument " "1"" of type '" "WsManClient *""'"); 
  }
  arg1 = (WsManClient *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "wsman_transport_set_caoid" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = (char *)(buf2);
  wsman_transport_set_caoid(arg1,(char const *)arg2);
  resultobj = SWIG_Py_Void();
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return NULL;
}


SWIGINTERN PyObject *_wrap_wsman_transport_get_caoid(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  WsManClient *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "wsman_transport_get_caoid" "', argument " "1"" of type '" "WsManClient *""'"); 
  }
  arg1 = (WsManClient *)(argp1);
  result = (char *)wsman_transport_get_caoid(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_wsman_transport_set_cert(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  WsManClient *arg1 = 0 ;
  char *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "wsman_transport_set_cert", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "wsman_transport_set_cert" "', argument " "1"" of type '" "WsManClient *""'"); 
  }
  arg1 = (WsManClient *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "wsman_transport_set_cert" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = (char *)(buf2);
  wsman_transport_set_cert(arg1,(char const *)arg2);
  resultobj = SWIG_Py_Void();
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return NULL;
}


SWIGINTERN PyObject *_wrap_wsman_transport_get_cert(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  WsManClient *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "wsman_transport_get_cert" "', argument " "1"" of type '" "WsManClient *""'"); 
  }
  arg1 = (WsManClient *)(argp1);
  result = (char *)wsman_transport_get_cert(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_wsman_transport_set_key(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  WsManClient *arg1 = 0 ;
  char *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "wsman_transport_set_key", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "wsman_transport_set_key" "', argument " "1"" of type '" "WsManClient *""'"); 
  }
  arg1 = (WsManClient *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "wsman_transport_set_key" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = (char *)(buf2);
  wsman_transport_set_key(arg1,(char const *)arg2);
  resultobj = SWIG_Py_Void();
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return NULL;
}


SWIGINTERN PyObject *_wrap_wsman_transport_get_key(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  WsManClient *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "wsman_transport_get_key" "', argument " "1"" of type '" "WsManClient *""'"); 
  }
  arg1 = (WsManClient *)(argp1);
  result = (char *)wsman_transport_get_key(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_ClientOptions(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  client_opt_t *result = 0 ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "new_ClientOptions", 0, 0, 0)) SWIG_fail;
  result = (client_opt_t *)new_client_opt_t();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_client_opt_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_ClientOptions(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  client_opt_t *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_client_opt_t, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_ClientOptions" "', argument " "1"" of type '" "client_opt_t *""'"); 
  }
  arg1 = (client_opt_t *)(argp1);
  delete_client_opt_t(arg1);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ClientOptions_set_dump_request(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  client_opt_t *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_client_opt_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ClientOptions_set_dump_request" "', argument " "1"" of type '" "client_opt_t *""'"); 
  }
  arg1 = (client_opt_t *)(argp1);
  client_opt_t_set_dump_request(arg1);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ClientOptions_clear_dump_request(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  client_opt_t *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_client_opt_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ClientOptions_clear_dump_request" "', argument " "1"" of type '" "client_opt_t *""'"); 
  }
  arg1 = (client_opt_t *)(argp1);
  client_opt_t_clear_dump_request(arg1);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ClientOptions_set_flags(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  client_opt_t *arg1 = 0 ;
  unsigned long arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned long val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "ClientOptions_set_flags", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_client_opt_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ClientOptions_set_flags" "', argument " "1"" of type '" "client_opt_t *""'"); 
  }
  arg1 = (client_opt_t *)(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_long(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "ClientOptions_set_flags" "', argument " "2"" of type '" "unsigned long""'");
  } 
  arg2 = (unsigned long)(val2);
  client_opt_t_set_flags(arg1,arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ClientOptions_get_flags(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  client_opt_t *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned long result;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_client_opt_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ClientOptions_get_flags" "', argument " "1"" of type '" "client_opt_t *""'"); 
  }
  arg1 = (client_opt_t *)(argp1);
  result = (unsigned long)client_opt_t_get_flags(arg1);
  resultobj = SWIG_From_unsigned_SS_long((unsigned long)(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ClientOptions_clear_flags(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  client_opt_t *arg1 = 0 ;
  unsigned long arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned long val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "ClientOptions_clear_flags", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_client_opt_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ClientOptions_clear_flags" "', argument " "1"" of type '" "client_opt_t *""'"); 
  }
  arg1 = (client_opt_t *)(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_long(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "ClientOptions_clear_flags" "', argument " "2"" of type '" "unsigned long""'");
  } 
  arg2 = (unsigned long)(val2);
  client_opt_t_clear_flags(arg1,arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ClientOptions_reset_flags(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  client_opt_t *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_client_opt_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ClientOptions_reset_flags" "', argument " "1"" of type '" "client_opt_t *""'"); 
  }
  arg1 = (client_opt_t *)(argp1);
  client_opt_t_reset_flags(arg1);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ClientOptions_set_max_envelope_size(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  client_opt_t *arg1 = 0 ;
  unsigned long arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned long val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "ClientOptions_set_max_envelope_size", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_client_opt_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ClientOptions_set_max_envelope_size" "', argument " "1"" of type '" "client_opt_t *""'"); 
  }
  arg1 = (client_opt_t *)(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_long(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "ClientOptions_set_max_envelope_size" "', argument " "2"" of type '" "unsigned long""'");
  } 
  arg2 = (unsigned long)(val2);
  client_opt_t_set_max_envelope_size(arg1,arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ClientOptions_get_max_envelope_size(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  client_opt_t *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned long result;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_client_opt_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ClientOptions_get_max_envelope_size" "', argument " "1"" of type '" "client_opt_t *""'"); 
  }
  arg1 = (client_opt_t *)(argp1);
  result = (unsigned long)client_opt_t_get_max_envelope_size(arg1);
  resultobj = SWIG_From_unsigned_SS_long((unsigned long)(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ClientOptions_set_max_elements(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  client_opt_t *arg1 = 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "ClientOptions_set_max_elements", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_client_opt_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ClientOptions_set_max_elements" "', argument " "1"" of type '" "client_opt_t *""'"); 
  }
  arg1 = (client_opt_t *)(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "ClientOptions_set_max_elements" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = (int)(val2);
  client_opt_t_set_max_elements(arg1,arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ClientOptions_get_max_elements(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  client_opt_t *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_client_opt_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ClientOptions_get_max_elements" "', argument " "1"" of type '" "client_opt_t *""'"); 
  }
  arg1 = (client_opt_t *)(argp1);
  result = (int)client_opt_t_get_max_elements(arg1);
  resultobj = SWIG_From_int((int)(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ClientOptions_set_timeout(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  client_opt_t *arg1 = 0 ;
  unsigned long arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned long val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "ClientOptions_set_timeout", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_client_opt_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ClientOptions_set_timeout" "', argument " "1"" of type '" "client_opt_t *""'"); 
  }
  arg1 = (client_opt_t *)(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_long(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "ClientOptions_set_timeout" "', argument " "2"" of type '" "unsigned long""'");
  } 
  arg2 = (unsigned long)(val2);
  client_opt_t_set_timeout(arg1,arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ClientOptions_get_timeout(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  client_opt_t *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned long result;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_client_opt_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ClientOptions_get_timeout" "', argument " "1"" of type '" "client_opt_t *""'"); 
  }
  arg1 = (client_opt_t *)(argp1);
  result = (unsigned long)client_opt_t_get_timeout(arg1);
  resultobj = SWIG_From_unsigned_SS_long((unsigned long)(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ClientOptions_set_fragment(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  client_opt_t *arg1 = 0 ;
  char *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "ClientOptions_set_fragment", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_client_opt_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ClientOptions_set_fragment" "', argument " "1"" of type '" "client_opt_t *""'"); 
  }
  arg1 = (client_opt_t *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "ClientOptions_set_fragment" "', argument " "2"" of type '" "char *""'");
  }
  arg2 = (char *)(buf2);
  client_opt_t_set_fragment(arg1,arg2);
  resultobj = SWIG_Py_Void();
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return NULL;
}


SWIGINTERN PyObject *_wrap_ClientOptions_get_fragment(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  client_opt_t *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_client_opt_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ClientOptions_get_fragment" "', argument " "1"" of type '" "client_opt_t *""'"); 
  }
  arg1 = (client_opt_t *)(argp1);
  result = (char *)client_opt_t_get_fragment(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ClientOptions_set_cim_namespace(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  client_opt_t *arg1 = 0 ;
  char *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "ClientOptions_set_cim_namespace", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_client_opt_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ClientOptions_set_cim_namespace" "', argument " "1"" of type '" "client_opt_t *""'"); 
  }
  arg1 = (client_opt_t *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "ClientOptions_set_cim_namespace" "', argument " "2"" of type '" "char *""'");
  }
  arg2 = (char *)(buf2);
  client_opt_t_set_cim_namespace(arg1,arg2);
  resultobj = SWIG_Py_Void();
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return NULL;
}


SWIGINTERN PyObject *_wrap_ClientOptions_get_cim_namespace(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  client_opt_t *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_client_opt_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ClientOptions_get_cim_namespace" "', argument " "1"" of type '" "client_opt_t *""'"); 
  }
  arg1 = (client_opt_t *)(argp1);
  result = (char *)client_opt_t_get_cim_namespace(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ClientOptions_set_reference(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  client_opt_t *arg1 = 0 ;
  char *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "ClientOptions_set_reference", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_client_opt_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ClientOptions_set_reference" "', argument " "1"" of type '" "client_opt_t *""'"); 
  }
  arg1 = (client_opt_t *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "ClientOptions_set_reference" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = (char *)(buf2);
  client_opt_t_set_reference(arg1,(char const *)arg2);
  resultobj = SWIG_Py_Void();
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return NULL;
}


SWIGINTERN PyObject *_wrap_ClientOptions_get_reference(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  client_opt_t *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_client_opt_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ClientOptions_get_reference" "', argument " "1"" of type '" "client_opt_t *""'"); 
  }
  arg1 = (client_opt_t *)(argp1);
  result = (char *)client_opt_t_get_reference(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ClientOptions_add_option(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  client_opt_t *arg1 = 0 ;
  char *arg2 = 0 ;
  char *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  int res3 ;
  char *buf3 = 0 ;
  int alloc3 = 0 ;
  PyObject *swig_obj[3] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "ClientOptions_add_option", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_client_opt_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ClientOptions_add_option" "', argument " "1"" of type '" "client_opt_t *""'"); 
  }
  arg1 = (client_opt_t *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "ClientOptions_add_option" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = (char *)(buf2);
  res3 = SWIG_AsCharPtrAndSize(swig_obj[2], &buf3, NULL, &alloc3);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "ClientOptions_add_option" "', argument " "3"" of type '" "char const *""'");
  }
  arg3 = (char *)(buf3);
  client_opt_t_add_option(arg1,(char const *)arg2,(char const *)arg3);
  resultobj = SWIG_Py_Void();
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  if (alloc3 == SWIG_NEWOBJ) free((char*)buf3);
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  if (alloc3 == SWIG_NEWOBJ) free((char*)buf3);
  return NULL;
}


SWIGINTERN PyObject *_wrap_ClientOptions_add_selector(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  client_opt_t *arg1 = 0 ;
  char *arg2 = 0 ;
  char *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  int res3 ;
  char *buf3 = 0 ;
  int alloc3 = 0 ;
  PyObject *swig_obj[3] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "ClientOptions_add_selector", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_client_opt_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ClientOptions_add_selector" "', argument " "1"" of type '" "client_opt_t *""'"); 
  }
  arg1 = (client_opt_t *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "ClientOptions_add_selector" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = (char *)(buf2);
  res3 = SWIG_AsCharPtrAndSize(swig_obj[2], &buf3, NULL, &alloc3);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "ClientOptions_add_selector" "', argument " "3"" of type '" "char const *""'");
  }
  arg3 = (char *)(buf3);
  client_opt_t_add_selector(arg1,(char const *)arg2,(char const *)arg3);
  resultobj = SWIG_Py_Void();
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  if (alloc3 == SWIG_NEWOBJ) free((char*)buf3);
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  if (alloc3 == SWIG_NEWOBJ) free((char*)buf3);
  return NULL;
}


SWIGINTERN PyObject *_wrap_ClientOptions_add_property__SWIG_0(PyObject *self, Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  client_opt_t *arg1 = 0 ;
  char *arg2 = 0 ;
  char *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  int res3 ;
  char *buf3 = 0 ;
  int alloc3 = 0 ;
  
  (void)self;
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_client_opt_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ClientOptions_add_property" "', argument " "1"" of type '" "client_opt_t *""'"); 
  }
  arg1 = (client_opt_t *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "ClientOptions_add_property" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = (char *)(buf2);
  res3 = SWIG_AsCharPtrAndSize(swig_obj[2], &buf3, NULL, &alloc3);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "ClientOptions_add_property" "', argument " "3"" of type '" "char const *""'");
  }
  arg3 = (char *)(buf3);
  client_opt_t_add_property__SWIG_0(arg1,(char const *)arg2,(char const *)arg3);
  resultobj = SWIG_Py_Void();
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  if (alloc3 == SWIG_NEWOBJ) free((char*)buf3);
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  if (alloc3 == SWIG_NEWOBJ) free((char*)buf3);
  return NULL;
}


SWIGINTERN PyObject *_wrap_ClientOptions_add_property_array_item(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  client_opt_t *arg1 = 0 ;
  char *arg2 = 0 ;
  char *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  int res3 ;
  char *buf3 = 0 ;
  int alloc3 = 0 ;
  PyObject *swig_obj[3] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "ClientOptions_add_property_array_item", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_client_opt_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ClientOptions_add_property_array_item" "', argument " "1"" of type '" "client_opt_t *""'"); 
  }
  arg1 = (client_opt_t *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "ClientOptions_add_property_array_item" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = (char *)(buf2);
  res3 = SWIG_AsCharPtrAndSize(swig_obj[2], &buf3, NULL, &alloc3);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "ClientOptions_add_property_array_item" "', argument " "3"" of type '" "char const *""'");
  }
  arg3 = (char *)(buf3);
  client_opt_t_add_property_array_item(arg1,(char const *)arg2,(char const *)arg3);
  resultobj = SWIG_Py_Void();
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  if (alloc3 == SWIG_NEWOBJ) free((char*)buf3);
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  if (alloc3 == SWIG_NEWOBJ) free((char*)buf3);
  return NULL;
}


SWIGINTERN PyObject *_wrap_ClientOptions_add_property__SWIG_1(PyObject *self, Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  client_opt_t *arg1 = 0 ;
  char *arg2 = 0 ;
  epr_t *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  
  (void)self;
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_client_opt_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ClientOptions_add_property" "', argument " "1"" of type '" "client_opt_t *""'"); 
  }
  arg1 = (client_opt_t *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "ClientOptions_add_property" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = (char *)(buf2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3,SWIGTYPE_p_epr_t, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "ClientOptions_add_property" "', argument " "3"" of type '" "epr_t const *""'"); 
  }
  arg3 = (epr_t *)(argp3);
  client_opt_t_add_property__SWIG_1(arg1,(char const *)arg2,(epr_t const *)arg3);
  resultobj = SWIG_Py_Void();
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return NULL;
}


SWIGINTERN PyObject *_wrap_ClientOptions_add_property(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "ClientOptions_add_property", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 3) {
    int _v = 0;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_client_opt_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_AsCharPtrAndSize(argv[1], 0, NULL, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_epr_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_ClientOptions_add_property__SWIG_1(self, argc, argv);
        }
      }
    }
  }
  if (argc == 3) {
    int _v = 0;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_client_opt_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_AsCharPtrAndSize(argv[1], 0, NULL, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        int res = SWIG_AsCharPtrAndSize(argv[2], 0, NULL, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_ClientOptions_add_property__SWIG_0(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'ClientOptions_add_property'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    client_opt_t::add_property(char const *,char const *)\n"
    "    client_opt_t::add_property(char const *,epr_t const *)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_ClientOptions_set_delivery_uri(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  client_opt_t *arg1 = 0 ;
  char *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "ClientOptions_set_delivery_uri", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_client_opt_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ClientOptions_set_delivery_uri" "', argument " "1"" of type '" "client_opt_t *""'"); 
  }
  arg1 = (client_opt_t *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "ClientOptions_set_delivery_uri" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = (char *)(buf2);
  client_opt_t_set_delivery_uri(arg1,(char const *)arg2);
  resultobj = SWIG_Py_Void();
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return NULL;
}


SWIGINTERN PyObject *_wrap_ClientOptions_delivery_uri(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  client_opt_t *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_client_opt_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ClientOptions_delivery_uri" "', argument " "1"" of type '" "client_opt_t *""'"); 
  }
  arg1 = (client_opt_t *)(argp1);
  result = (char *)client_opt_t_delivery_uri(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ClientOptions_set_sub_expiry(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  client_opt_t *arg1 = 0 ;
  float arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  float val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "ClientOptions_set_sub_expiry", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_client_opt_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ClientOptions_set_sub_expiry" "', argument " "1"" of type '" "client_opt_t *""'"); 
  }
  arg1 = (client_opt_t *)(argp1);
  ecode2 = SWIG_AsVal_float(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "ClientOptions_set_sub_expiry" "', argument " "2"" of type '" "float""'");
  } 
  arg2 = (float)(val2);
  client_opt_t_set_sub_expiry(arg1,arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ClientOptions_sub_expiry(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  client_opt_t *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  float result;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_client_opt_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ClientOptions_sub_expiry" "', argument " "1"" of type '" "client_opt_t *""'"); 
  }
  arg1 = (client_opt_t *)(argp1);
  result = (float)client_opt_t_sub_expiry(arg1);
  resultobj = SWIG_From_float((float)(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ClientOptions_set_heartbeat_interval(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  client_opt_t *arg1 = 0 ;
  float arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  float val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "ClientOptions_set_heartbeat_interval", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_client_opt_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ClientOptions_set_heartbeat_interval" "', argument " "1"" of type '" "client_opt_t *""'"); 
  }
  arg1 = (client_opt_t *)(argp1);
  ecode2 = SWIG_AsVal_float(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "ClientOptions_set_heartbeat_interval" "', argument " "2"" of type '" "float""'");
  } 
  arg2 = (float)(val2);
  client_opt_t_set_heartbeat_interval(arg1,arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ClientOptions_heartbeat_interval(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  client_opt_t *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  float result;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_client_opt_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ClientOptions_heartbeat_interval" "', argument " "1"" of type '" "client_opt_t *""'"); 
  }
  arg1 = (client_opt_t *)(argp1);
  result = (float)client_opt_t_heartbeat_interval(arg1);
  resultobj = SWIG_From_float((float)(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ClientOptions_set_delivery_mode(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  client_opt_t *arg1 = 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "ClientOptions_set_delivery_mode", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_client_opt_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ClientOptions_set_delivery_mode" "', argument " "1"" of type '" "client_opt_t *""'"); 
  }
  arg1 = (client_opt_t *)(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "ClientOptions_set_delivery_mode" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = (unsigned int)(val2);
  client_opt_t_set_delivery_mode(arg1,arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ClientOptions_delivery_mode(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  client_opt_t *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_client_opt_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ClientOptions_delivery_mode" "', argument " "1"" of type '" "client_opt_t *""'"); 
  }
  arg1 = (client_opt_t *)(argp1);
  result = (int)client_opt_t_delivery_mode(arg1);
  resultobj = SWIG_From_int((int)(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ClientOptions_set_delivery_security_mode(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  client_opt_t *arg1 = 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "ClientOptions_set_delivery_security_mode", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_client_opt_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ClientOptions_set_delivery_security_mode" "', argument " "1"" of type '" "client_opt_t *""'"); 
  }
  arg1 = (client_opt_t *)(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "ClientOptions_set_delivery_security_mode" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = (unsigned int)(val2);
  client_opt_t_set_delivery_security_mode(arg1,arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ClientOptions_delivery_sec_mode(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  client_opt_t *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_client_opt_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ClientOptions_delivery_sec_mode" "', argument " "1"" of type '" "client_opt_t *""'"); 
  }
  arg1 = (client_opt_t *)(argp1);
  result = (int)client_opt_t_delivery_sec_mode(arg1);
  resultobj = SWIG_From_int((int)(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ClientOptions_set_locale(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  client_opt_t *arg1 = 0 ;
  char *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "ClientOptions_set_locale", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_client_opt_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ClientOptions_set_locale" "', argument " "1"" of type '" "client_opt_t *""'"); 
  }
  arg1 = (client_opt_t *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "ClientOptions_set_locale" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = (char *)(buf2);
  client_opt_t_set_locale(arg1,(char const *)arg2);
  resultobj = SWIG_Py_Void();
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return NULL;
}


SWIGINTERN PyObject *_wrap_ClientOptions_locale(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  client_opt_t *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_client_opt_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ClientOptions_locale" "', argument " "1"" of type '" "client_opt_t *""'"); 
  }
  arg1 = (client_opt_t *)(argp1);
  result = (char *)client_opt_t_locale(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *ClientOptions_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj = NULL;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_client_opt_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *ClientOptions_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_new_Client__SWIG_0(PyObject *self, Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  char *arg1 = 0 ;
  int res1 ;
  char *buf1 = 0 ;
  int alloc1 = 0 ;
  struct _WsManClient *result = 0 ;
  
  (void)self;
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  res1 = SWIG_AsCharPtrAndSize(swig_obj[0], &buf1, NULL, &alloc1);
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_Client" "', argument " "1"" of type '" "char const *""'");
  }
  arg1 = (char *)(buf1);
  result = (struct _WsManClient *)new__WsManClient__SWIG_0((char const *)arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p__WsManClient, SWIG_POINTER_NEW |  0 );
  if (alloc1 == SWIG_NEWOBJ) free((char*)buf1);
  return resultobj;
fail:
  if (alloc1 == SWIG_NEWOBJ) free((char*)buf1);
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_Client__SWIG_1(PyObject *self, Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  char *arg1 = 0 ;
  int arg2 ;
  char *arg3 = 0 ;
  char *arg4 = 0 ;
  char *arg5 = 0 ;
  char *arg6 = 0 ;
  int res1 ;
  char *buf1 = 0 ;
  int alloc1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  int res3 ;
  char *buf3 = 0 ;
  int alloc3 = 0 ;
  int res4 ;
  char *buf4 = 0 ;
  int alloc4 = 0 ;
  int res5 ;
  char *buf5 = 0 ;
  int alloc5 = 0 ;
  int res6 ;
  char *buf6 = 0 ;
  int alloc6 = 0 ;
  struct _WsManClient *result = 0 ;
  
  (void)self;
  if ((nobjs < 6) || (nobjs > 6)) SWIG_fail;
  res1 = SWIG_AsCharPtrAndSize(swig_obj[0], &buf1, NULL, &alloc1);
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_Client" "', argument " "1"" of type '" "char const *""'");
  }
  arg1 = (char *)(buf1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "new_Client" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = (int)(val2);
  res3 = SWIG_AsCharPtrAndSize(swig_obj[2], &buf3, NULL, &alloc3);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "new_Client" "', argument " "3"" of type '" "char const *""'");
  }
  arg3 = (char *)(buf3);
  res4 = SWIG_AsCharPtrAndSize(swig_obj[3], &buf4, NULL, &alloc4);
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "new_Client" "', argument " "4"" of type '" "char const *""'");
  }
  arg4 = (char *)(buf4);
  res5 = SWIG_AsCharPtrAndSize(swig_obj[4], &buf5, NULL, &alloc5);
  if (!SWIG_IsOK(res5)) {
    SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "new_Client" "', argument " "5"" of type '" "char const *""'");
  }
  arg5 = (char *)(buf5);
  res6 = SWIG_AsCharPtrAndSize(swig_obj[5], &buf6, NULL, &alloc6);
  if (!SWIG_IsOK(res6)) {
    SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "new_Client" "', argument " "6"" of type '" "char const *""'");
  }
  arg6 = (char *)(buf6);
  result = (struct _WsManClient *)new__WsManClient__SWIG_1((char const *)arg1,arg2,(char const *)arg3,(char const *)arg4,(char const *)arg5,(char const *)arg6);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p__WsManClient, SWIG_POINTER_NEW |  0 );
  if (alloc1 == SWIG_NEWOBJ) free((char*)buf1);
  if (alloc3 == SWIG_NEWOBJ) free((char*)buf3);
  if (alloc4 == SWIG_NEWOBJ) free((char*)buf4);
  if (alloc5 == SWIG_NEWOBJ) free((char*)buf5);
  if (alloc6 == SWIG_NEWOBJ) free((char*)buf6);
  return resultobj;
fail:
  if (alloc1 == SWIG_NEWOBJ) free((char*)buf1);
  if (alloc3 == SWIG_NEWOBJ) free((char*)buf3);
  if (alloc4 == SWIG_NEWOBJ) free((char*)buf4);
  if (alloc5 == SWIG_NEWOBJ) free((char*)buf5);
  if (alloc6 == SWIG_NEWOBJ) free((char*)buf6);
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_Client(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[7] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "new_Client", 0, 6, argv))) SWIG_fail;
  --argc;
  if (argc == 1) {
    int _v = 0;
    int res = SWIG_AsCharPtrAndSize(argv[0], 0, NULL, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_new_Client__SWIG_0(self, argc, argv);
    }
  }
  if (argc == 6) {
    int _v = 0;
    int res = SWIG_AsCharPtrAndSize(argv[0], 0, NULL, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_AsCharPtrAndSize(argv[2], 0, NULL, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          int res = SWIG_AsCharPtrAndSize(argv[3], 0, NULL, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            int res = SWIG_AsCharPtrAndSize(argv[4], 0, NULL, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              int res = SWIG_AsCharPtrAndSize(argv[5], 0, NULL, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_new_Client__SWIG_1(self, argc, argv);
              }
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'new_Client'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    _WsManClient::_WsManClient(char const *)\n"
    "    _WsManClient::_WsManClient(char const *,int const,char const *,char const *,char const *,char const *)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_delete_Client(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManClient *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Client" "', argument " "1"" of type '" "struct _WsManClient *""'"); 
  }
  arg1 = (struct _WsManClient *)(argp1);
  delete__WsManClient(arg1);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Client_set_dumpfile(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManClient *arg1 = 0 ;
  FILE *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "Client_set_dumpfile", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Client_set_dumpfile" "', argument " "1"" of type '" "struct _WsManClient *""'"); 
  }
  arg1 = (struct _WsManClient *)(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_FILE, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Client_set_dumpfile" "', argument " "2"" of type '" "FILE *""'"); 
  }
  arg2 = (FILE *)(argp2);
  _WsManClient_set_dumpfile(arg1,arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Client_response_code(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManClient *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  long result;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Client_response_code" "', argument " "1"" of type '" "struct _WsManClient *""'"); 
  }
  arg1 = (struct _WsManClient *)(argp1);
  result = (long)_WsManClient_response_code(arg1);
  resultobj = SWIG_From_long((long)(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Client_scheme(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManClient *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Client_scheme" "', argument " "1"" of type '" "struct _WsManClient *""'"); 
  }
  arg1 = (struct _WsManClient *)(argp1);
  result = (char *)_WsManClient_scheme(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  free(result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Client_host(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManClient *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Client_host" "', argument " "1"" of type '" "struct _WsManClient *""'"); 
  }
  arg1 = (struct _WsManClient *)(argp1);
  result = (char *)_WsManClient_host(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  free(result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Client_port(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManClient *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Client_port" "', argument " "1"" of type '" "struct _WsManClient *""'"); 
  }
  arg1 = (struct _WsManClient *)(argp1);
  result = (int)_WsManClient_port(arg1);
  resultobj = SWIG_From_int((int)(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Client_path(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManClient *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Client_path" "', argument " "1"" of type '" "struct _WsManClient *""'"); 
  }
  arg1 = (struct _WsManClient *)(argp1);
  result = (char *)_WsManClient_path(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  free(result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Client_user(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManClient *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Client_user" "', argument " "1"" of type '" "struct _WsManClient *""'"); 
  }
  arg1 = (struct _WsManClient *)(argp1);
  result = (char *)_WsManClient_user(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  free(result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Client_password(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManClient *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Client_password" "', argument " "1"" of type '" "struct _WsManClient *""'"); 
  }
  arg1 = (struct _WsManClient *)(argp1);
  result = (char *)_WsManClient_password(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  free(result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Client_transport(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManClient *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  WsManTransport *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Client_transport" "', argument " "1"" of type '" "struct _WsManClient *""'"); 
  }
  arg1 = (struct _WsManClient *)(argp1);
  result = (WsManTransport *)_WsManClient_transport(arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p__WsManTransport, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Client_send_request(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManClient *arg1 = 0 ;
  WsXmlDocH arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  int result;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "Client_send_request", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Client_send_request" "', argument " "1"" of type '" "struct _WsManClient *""'"); 
  }
  arg1 = (struct _WsManClient *)(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p__WsXmlDoc, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Client_send_request" "', argument " "2"" of type '" "WsXmlDocH""'"); 
  }
  arg2 = (WsXmlDocH)(argp2);
  result = (int)_WsManClient_send_request(arg1,arg2);
  resultobj = SWIG_From_int((int)(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Client_build_envelope_from_response(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManClient *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  WsXmlDocH result;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Client_build_envelope_from_response" "', argument " "1"" of type '" "struct _WsManClient *""'"); 
  }
  arg1 = (struct _WsManClient *)(argp1);
  result = (WsXmlDocH)_WsManClient_build_envelope_from_response(arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p__WsXmlDoc, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Client_encoding(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManClient *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Client_encoding" "', argument " "1"" of type '" "struct _WsManClient *""'"); 
  }
  arg1 = (struct _WsManClient *)(argp1);
  result = (char *)_WsManClient_encoding(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Client_set_encoding(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManClient *arg1 = 0 ;
  char *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  PyObject *swig_obj[2] ;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "Client_set_encoding", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Client_set_encoding" "', argument " "1"" of type '" "struct _WsManClient *""'"); 
  }
  arg1 = (struct _WsManClient *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Client_set_encoding" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = (char *)(buf2);
  _WsManClient_set_encoding(arg1,(char const *)arg2);
  resultobj = SWIG_Py_Void();
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return NULL;
}


SWIGINTERN PyObject *_wrap_Client_identify(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManClient *arg1 = 0 ;
  client_opt_t *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  WsXmlDocH result;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "Client_identify", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Client_identify" "', argument " "1"" of type '" "struct _WsManClient *""'"); 
  }
  arg1 = (struct _WsManClient *)(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_client_opt_t, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Client_identify" "', argument " "2"" of type '" "client_opt_t *""'"); 
  }
  arg2 = (client_opt_t *)(argp2);
  result = (WsXmlDocH)_WsManClient_identify(arg1,arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p__WsXmlDoc, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Client_get_from_epr(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManClient *arg1 = 0 ;
  client_opt_t *arg2 = 0 ;
  epr_t *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject *swig_obj[3] ;
  WsXmlDocH result;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "Client_get_from_epr", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Client_get_from_epr" "', argument " "1"" of type '" "struct _WsManClient *""'"); 
  }
  arg1 = (struct _WsManClient *)(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_client_opt_t, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Client_get_from_epr" "', argument " "2"" of type '" "client_opt_t *""'"); 
  }
  arg2 = (client_opt_t *)(argp2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3,SWIGTYPE_p_epr_t, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Client_get_from_epr" "', argument " "3"" of type '" "epr_t *""'"); 
  }
  arg3 = (epr_t *)(argp3);
  result = (WsXmlDocH)_WsManClient_get_from_epr(arg1,arg2,arg3);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p__WsXmlDoc, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Client_delete_from_epr(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManClient *arg1 = 0 ;
  client_opt_t *arg2 = 0 ;
  epr_t *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject *swig_obj[3] ;
  WsXmlDocH result;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "Client_delete_from_epr", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Client_delete_from_epr" "', argument " "1"" of type '" "struct _WsManClient *""'"); 
  }
  arg1 = (struct _WsManClient *)(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_client_opt_t, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Client_delete_from_epr" "', argument " "2"" of type '" "client_opt_t *""'"); 
  }
  arg2 = (client_opt_t *)(argp2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3,SWIGTYPE_p_epr_t, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Client_delete_from_epr" "', argument " "3"" of type '" "epr_t *""'"); 
  }
  arg3 = (epr_t *)(argp3);
  result = (WsXmlDocH)_WsManClient_delete_from_epr(arg1,arg2,arg3);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p__WsXmlDoc, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Client_enumerate(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManClient *arg1 = 0 ;
  client_opt_t *arg2 = 0 ;
  filter_t *arg3 = 0 ;
  char *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  int res4 ;
  char *buf4 = 0 ;
  int alloc4 = 0 ;
  PyObject *swig_obj[4] ;
  WsXmlDocH result;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "Client_enumerate", 4, 4, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Client_enumerate" "', argument " "1"" of type '" "struct _WsManClient *""'"); 
  }
  arg1 = (struct _WsManClient *)(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_client_opt_t, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Client_enumerate" "', argument " "2"" of type '" "client_opt_t *""'"); 
  }
  arg2 = (client_opt_t *)(argp2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3,SWIGTYPE_p_filter_t, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Client_enumerate" "', argument " "3"" of type '" "filter_t *""'"); 
  }
  arg3 = (filter_t *)(argp3);
  res4 = SWIG_AsCharPtrAndSize(swig_obj[3], &buf4, NULL, &alloc4);
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Client_enumerate" "', argument " "4"" of type '" "char *""'");
  }
  arg4 = (char *)(buf4);
  result = (WsXmlDocH)_WsManClient_enumerate(arg1,arg2,arg3,arg4);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p__WsXmlDoc, 0 |  0 );
  if (alloc4 == SWIG_NEWOBJ) free((char*)buf4);
  return resultobj;
fail:
  if (alloc4 == SWIG_NEWOBJ) free((char*)buf4);
  return NULL;
}


SWIGINTERN PyObject *_wrap_Client_pull(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManClient *arg1 = 0 ;
  client_opt_t *arg2 = 0 ;
  filter_t *arg3 = 0 ;
  char *arg4 = 0 ;
  char *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  int res4 ;
  char *buf4 = 0 ;
  int alloc4 = 0 ;
  int res5 ;
  char *buf5 = 0 ;
  int alloc5 = 0 ;
  PyObject *swig_obj[5] ;
  WsXmlDocH result;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "Client_pull", 5, 5, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Client_pull" "', argument " "1"" of type '" "struct _WsManClient *""'"); 
  }
  arg1 = (struct _WsManClient *)(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_client_opt_t, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Client_pull" "', argument " "2"" of type '" "client_opt_t *""'"); 
  }
  arg2 = (client_opt_t *)(argp2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3,SWIGTYPE_p_filter_t, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Client_pull" "', argument " "3"" of type '" "filter_t *""'"); 
  }
  arg3 = (filter_t *)(argp3);
  res4 = SWIG_AsCharPtrAndSize(swig_obj[3], &buf4, NULL, &alloc4);
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Client_pull" "', argument " "4"" of type '" "char const *""'");
  }
  arg4 = (char *)(buf4);
  res5 = SWIG_AsCharPtrAndSize(swig_obj[4], &buf5, NULL, &alloc5);
  if (!SWIG_IsOK(res5)) {
    SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "Client_pull" "', argument " "5"" of type '" "char const *""'");
  }
  arg5 = (char *)(buf5);
  result = (WsXmlDocH)_WsManClient_pull(arg1,arg2,arg3,(char const *)arg4,(char const *)arg5);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p__WsXmlDoc, 0 |  0 );
  if (alloc4 == SWIG_NEWOBJ) free((char*)buf4);
  if (alloc5 == SWIG_NEWOBJ) free((char*)buf5);
  return resultobj;
fail:
  if (alloc4 == SWIG_NEWOBJ) free((char*)buf4);
  if (alloc5 == SWIG_NEWOBJ) free((char*)buf5);
  return NULL;
}


SWIGINTERN PyObject *_wrap_Client_create(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManClient *arg1 = 0 ;
  client_opt_t *arg2 = 0 ;
  char *arg3 = 0 ;
  char *arg4 = 0 ;
  size_t arg5 ;
  char *arg6 = (char *)"utf-8" ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  int res3 ;
  char *buf3 = 0 ;
  int alloc3 = 0 ;
  int res4 ;
  char *buf4 = 0 ;
  int alloc4 = 0 ;
  size_t val5 ;
  int ecode5 = 0 ;
  int res6 ;
  char *buf6 = 0 ;
  int alloc6 = 0 ;
  PyObject *swig_obj[6] ;
  WsXmlDocH result;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "Client_create", 5, 6, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Client_create" "', argument " "1"" of type '" "struct _WsManClient *""'"); 
  }
  arg1 = (struct _WsManClient *)(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_client_opt_t, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Client_create" "', argument " "2"" of type '" "client_opt_t *""'"); 
  }
  arg2 = (client_opt_t *)(argp2);
  res3 = SWIG_AsCharPtrAndSize(swig_obj[2], &buf3, NULL, &alloc3);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Client_create" "', argument " "3"" of type '" "char const *""'");
  }
  arg3 = (char *)(buf3);
  res4 = SWIG_AsCharPtrAndSize(swig_obj[3], &buf4, NULL, &alloc4);
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Client_create" "', argument " "4"" of type '" "char const *""'");
  }
  arg4 = (char *)(buf4);
  ecode5 = SWIG_AsVal_size_t(swig_obj[4], &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "Client_create" "', argument " "5"" of type '" "size_t""'");
  } 
  arg5 = (size_t)(val5);
  if (swig_obj[5]) {
    res6 = SWIG_AsCharPtrAndSize(swig_obj[5], &buf6, NULL, &alloc6);
    if (!SWIG_IsOK(res6)) {
      SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "Client_create" "', argument " "6"" of type '" "char const *""'");
    }
    arg6 = (char *)(buf6);
  }
  result = (WsXmlDocH)_WsManClient_create(arg1,arg2,(char const *)arg3,(char const *)arg4,arg5,(char const *)arg6);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p__WsXmlDoc, 0 |  0 );
  if (alloc3 == SWIG_NEWOBJ) free((char*)buf3);
  if (alloc4 == SWIG_NEWOBJ) free((char*)buf4);
  if (alloc6 == SWIG_NEWOBJ) free((char*)buf6);
  return resultobj;
fail:
  if (alloc3 == SWIG_NEWOBJ) free((char*)buf3);
  if (alloc4 == SWIG_NEWOBJ) free((char*)buf4);
  if (alloc6 == SWIG_NEWOBJ) free((char*)buf6);
  return NULL;
}


SWIGINTERN PyObject *_wrap_Client_put(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManClient *arg1 = 0 ;
  client_opt_t *arg2 = 0 ;
  char *arg3 = 0 ;
  char *arg4 = 0 ;
  size_t arg5 ;
  char *arg6 = (char *)"utf-8" ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  int res3 ;
  char *buf3 = 0 ;
  int alloc3 = 0 ;
  int res4 ;
  char *buf4 = 0 ;
  int alloc4 = 0 ;
  size_t val5 ;
  int ecode5 = 0 ;
  int res6 ;
  char *buf6 = 0 ;
  int alloc6 = 0 ;
  PyObject *swig_obj[6] ;
  WsXmlDocH result;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "Client_put", 5, 6, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Client_put" "', argument " "1"" of type '" "struct _WsManClient *""'"); 
  }
  arg1 = (struct _WsManClient *)(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_client_opt_t, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Client_put" "', argument " "2"" of type '" "client_opt_t *""'"); 
  }
  arg2 = (client_opt_t *)(argp2);
  res3 = SWIG_AsCharPtrAndSize(swig_obj[2], &buf3, NULL, &alloc3);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Client_put" "', argument " "3"" of type '" "char const *""'");
  }
  arg3 = (char *)(buf3);
  res4 = SWIG_AsCharPtrAndSize(swig_obj[3], &buf4, NULL, &alloc4);
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Client_put" "', argument " "4"" of type '" "char const *""'");
  }
  arg4 = (char *)(buf4);
  ecode5 = SWIG_AsVal_size_t(swig_obj[4], &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "Client_put" "', argument " "5"" of type '" "size_t""'");
  } 
  arg5 = (size_t)(val5);
  if (swig_obj[5]) {
    res6 = SWIG_AsCharPtrAndSize(swig_obj[5], &buf6, NULL, &alloc6);
    if (!SWIG_IsOK(res6)) {
      SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "Client_put" "', argument " "6"" of type '" "char const *""'");
    }
    arg6 = (char *)(buf6);
  }
  result = (WsXmlDocH)_WsManClient_put(arg1,arg2,(char const *)arg3,(char const *)arg4,arg5,(char const *)arg6);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p__WsXmlDoc, 0 |  0 );
  if (alloc3 == SWIG_NEWOBJ) free((char*)buf3);
  if (alloc4 == SWIG_NEWOBJ) free((char*)buf4);
  if (alloc6 == SWIG_NEWOBJ) free((char*)buf6);
  return resultobj;
fail:
  if (alloc3 == SWIG_NEWOBJ) free((char*)buf3);
  if (alloc4 == SWIG_NEWOBJ) free((char*)buf4);
  if (alloc6 == SWIG_NEWOBJ) free((char*)buf6);
  return NULL;
}


SWIGINTERN PyObject *_wrap_Client_release(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManClient *arg1 = 0 ;
  client_opt_t *arg2 = 0 ;
  char *arg3 = 0 ;
  char *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  int res3 ;
  char *buf3 = 0 ;
  int alloc3 = 0 ;
  int res4 ;
  char *buf4 = 0 ;
  int alloc4 = 0 ;
  PyObject *swig_obj[4] ;
  WsXmlDocH result;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "Client_release", 4, 4, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Client_release" "', argument " "1"" of type '" "struct _WsManClient *""'"); 
  }
  arg1 = (struct _WsManClient *)(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_client_opt_t, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Client_release" "', argument " "2"" of type '" "client_opt_t *""'"); 
  }
  arg2 = (client_opt_t *)(argp2);
  res3 = SWIG_AsCharPtrAndSize(swig_obj[2], &buf3, NULL, &alloc3);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Client_release" "', argument " "3"" of type '" "char const *""'");
  }
  arg3 = (char *)(buf3);
  res4 = SWIG_AsCharPtrAndSize(swig_obj[3], &buf4, NULL, &alloc4);
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Client_release" "', argument " "4"" of type '" "char const *""'");
  }
  arg4 = (char *)(buf4);
  result = (WsXmlDocH)_WsManClient_release(arg1,arg2,(char const *)arg3,(char const *)arg4);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p__WsXmlDoc, 0 |  0 );
  if (alloc3 == SWIG_NEWOBJ) free((char*)buf3);
  if (alloc4 == SWIG_NEWOBJ) free((char*)buf4);
  return resultobj;
fail:
  if (alloc3 == SWIG_NEWOBJ) free((char*)buf3);
  if (alloc4 == SWIG_NEWOBJ) free((char*)buf4);
  return NULL;
}


SWIGINTERN PyObject *_wrap_Client_get(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManClient *arg1 = 0 ;
  client_opt_t *arg2 = 0 ;
  char *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  int res3 ;
  char *buf3 = 0 ;
  int alloc3 = 0 ;
  PyObject *swig_obj[3] ;
  WsXmlDocH result;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "Client_get", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Client_get" "', argument " "1"" of type '" "struct _WsManClient *""'"); 
  }
  arg1 = (struct _WsManClient *)(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_client_opt_t, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Client_get" "', argument " "2"" of type '" "client_opt_t *""'"); 
  }
  arg2 = (client_opt_t *)(argp2);
  res3 = SWIG_AsCharPtrAndSize(swig_obj[2], &buf3, NULL, &alloc3);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Client_get" "', argument " "3"" of type '" "char const *""'");
  }
  arg3 = (char *)(buf3);
  result = (WsXmlDocH)_WsManClient_get(arg1,arg2,(char const *)arg3);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p__WsXmlDoc, 0 |  0 );
  if (alloc3 == SWIG_NEWOBJ) free((char*)buf3);
  return resultobj;
fail:
  if (alloc3 == SWIG_NEWOBJ) free((char*)buf3);
  return NULL;
}


SWIGINTERN PyObject *_wrap_Client_delete(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManClient *arg1 = 0 ;
  client_opt_t *arg2 = 0 ;
  char *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  int res3 ;
  char *buf3 = 0 ;
  int alloc3 = 0 ;
  PyObject *swig_obj[3] ;
  WsXmlDocH result;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "Client_delete", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Client_delete" "', argument " "1"" of type '" "struct _WsManClient *""'"); 
  }
  arg1 = (struct _WsManClient *)(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_client_opt_t, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Client_delete" "', argument " "2"" of type '" "client_opt_t *""'"); 
  }
  arg2 = (client_opt_t *)(argp2);
  res3 = SWIG_AsCharPtrAndSize(swig_obj[2], &buf3, NULL, &alloc3);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Client_delete" "', argument " "3"" of type '" "char const *""'");
  }
  arg3 = (char *)(buf3);
  result = (WsXmlDocH)_WsManClient_delete(arg1,arg2,(char const *)arg3);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p__WsXmlDoc, 0 |  0 );
  if (alloc3 == SWIG_NEWOBJ) free((char*)buf3);
  return resultobj;
fail:
  if (alloc3 == SWIG_NEWOBJ) free((char*)buf3);
  return NULL;
}


SWIGINTERN PyObject *_wrap_Client_invoke(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManClient *arg1 = 0 ;
  client_opt_t *arg2 = 0 ;
  char *arg3 = 0 ;
  char *arg4 = 0 ;
  WsXmlDocH arg5 = NULL ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  int res3 ;
  char *buf3 = 0 ;
  int alloc3 = 0 ;
  int res4 ;
  char *buf4 = 0 ;
  int alloc4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  PyObject *swig_obj[5] ;
  WsXmlDocH result;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "Client_invoke", 4, 5, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Client_invoke" "', argument " "1"" of type '" "struct _WsManClient *""'"); 
  }
  arg1 = (struct _WsManClient *)(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_client_opt_t, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Client_invoke" "', argument " "2"" of type '" "client_opt_t *""'"); 
  }
  arg2 = (client_opt_t *)(argp2);
  res3 = SWIG_AsCharPtrAndSize(swig_obj[2], &buf3, NULL, &alloc3);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Client_invoke" "', argument " "3"" of type '" "char const *""'");
  }
  arg3 = (char *)(buf3);
  res4 = SWIG_AsCharPtrAndSize(swig_obj[3], &buf4, NULL, &alloc4);
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Client_invoke" "', argument " "4"" of type '" "char const *""'");
  }
  arg4 = (char *)(buf4);
  if (swig_obj[4]) {
    res5 = SWIG_ConvertPtr(swig_obj[4], &argp5,SWIGTYPE_p__WsXmlDoc, 0 |  0 );
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "Client_invoke" "', argument " "5"" of type '" "WsXmlDocH""'"); 
    }
    arg5 = (WsXmlDocH)(argp5);
  }
  result = (WsXmlDocH)_WsManClient_invoke(arg1,arg2,(char const *)arg3,(char const *)arg4,arg5);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p__WsXmlDoc, 0 |  0 );
  if (alloc3 == SWIG_NEWOBJ) free((char*)buf3);
  if (alloc4 == SWIG_NEWOBJ) free((char*)buf4);
  return resultobj;
fail:
  if (alloc3 == SWIG_NEWOBJ) free((char*)buf3);
  if (alloc4 == SWIG_NEWOBJ) free((char*)buf4);
  return NULL;
}


SWIGINTERN PyObject *_wrap_Client_subscribe(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManClient *arg1 = 0 ;
  client_opt_t *arg2 = 0 ;
  filter_t *arg3 = 0 ;
  char *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  int res4 ;
  char *buf4 = 0 ;
  int alloc4 = 0 ;
  PyObject *swig_obj[4] ;
  WsXmlDocH result;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "Client_subscribe", 4, 4, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Client_subscribe" "', argument " "1"" of type '" "struct _WsManClient *""'"); 
  }
  arg1 = (struct _WsManClient *)(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_client_opt_t, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Client_subscribe" "', argument " "2"" of type '" "client_opt_t *""'"); 
  }
  arg2 = (client_opt_t *)(argp2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3,SWIGTYPE_p_filter_t, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Client_subscribe" "', argument " "3"" of type '" "filter_t *""'"); 
  }
  arg3 = (filter_t *)(argp3);
  res4 = SWIG_AsCharPtrAndSize(swig_obj[3], &buf4, NULL, &alloc4);
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Client_subscribe" "', argument " "4"" of type '" "char const *""'");
  }
  arg4 = (char *)(buf4);
  result = (WsXmlDocH)_WsManClient_subscribe(arg1,arg2,arg3,(char const *)arg4);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p__WsXmlDoc, 0 |  0 );
  if (alloc4 == SWIG_NEWOBJ) free((char*)buf4);
  return resultobj;
fail:
  if (alloc4 == SWIG_NEWOBJ) free((char*)buf4);
  return NULL;
}


SWIGINTERN PyObject *_wrap_Client_unsubscribe(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManClient *arg1 = 0 ;
  client_opt_t *arg2 = 0 ;
  filter_t *arg3 = 0 ;
  char *arg4 = 0 ;
  char *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  int res4 ;
  char *buf4 = 0 ;
  int alloc4 = 0 ;
  int res5 ;
  char *buf5 = 0 ;
  int alloc5 = 0 ;
  PyObject *swig_obj[5] ;
  WsXmlDocH result;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "Client_unsubscribe", 5, 5, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Client_unsubscribe" "', argument " "1"" of type '" "struct _WsManClient *""'"); 
  }
  arg1 = (struct _WsManClient *)(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_client_opt_t, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Client_unsubscribe" "', argument " "2"" of type '" "client_opt_t *""'"); 
  }
  arg2 = (client_opt_t *)(argp2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3,SWIGTYPE_p_filter_t, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Client_unsubscribe" "', argument " "3"" of type '" "filter_t *""'"); 
  }
  arg3 = (filter_t *)(argp3);
  res4 = SWIG_AsCharPtrAndSize(swig_obj[3], &buf4, NULL, &alloc4);
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Client_unsubscribe" "', argument " "4"" of type '" "char const *""'");
  }
  arg4 = (char *)(buf4);
  res5 = SWIG_AsCharPtrAndSize(swig_obj[4], &buf5, NULL, &alloc5);
  if (!SWIG_IsOK(res5)) {
    SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "Client_unsubscribe" "', argument " "5"" of type '" "char const *""'");
  }
  arg5 = (char *)(buf5);
  result = (WsXmlDocH)_WsManClient_unsubscribe(arg1,arg2,arg3,(char const *)arg4,(char const *)arg5);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p__WsXmlDoc, 0 |  0 );
  if (alloc4 == SWIG_NEWOBJ) free((char*)buf4);
  if (alloc5 == SWIG_NEWOBJ) free((char*)buf5);
  return resultobj;
fail:
  if (alloc4 == SWIG_NEWOBJ) free((char*)buf4);
  if (alloc5 == SWIG_NEWOBJ) free((char*)buf5);
  return NULL;
}


SWIGINTERN PyObject *_wrap_Client_renew(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManClient *arg1 = 0 ;
  client_opt_t *arg2 = 0 ;
  char *arg3 = 0 ;
  char *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  int res3 ;
  char *buf3 = 0 ;
  int alloc3 = 0 ;
  int res4 ;
  char *buf4 = 0 ;
  int alloc4 = 0 ;
  PyObject *swig_obj[4] ;
  WsXmlDocH result;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "Client_renew", 4, 4, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Client_renew" "', argument " "1"" of type '" "struct _WsManClient *""'"); 
  }
  arg1 = (struct _WsManClient *)(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_client_opt_t, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Client_renew" "', argument " "2"" of type '" "client_opt_t *""'"); 
  }
  arg2 = (client_opt_t *)(argp2);
  res3 = SWIG_AsCharPtrAndSize(swig_obj[2], &buf3, NULL, &alloc3);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Client_renew" "', argument " "3"" of type '" "char *""'");
  }
  arg3 = (char *)(buf3);
  res4 = SWIG_AsCharPtrAndSize(swig_obj[3], &buf4, NULL, &alloc4);
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Client_renew" "', argument " "4"" of type '" "char *""'");
  }
  arg4 = (char *)(buf4);
  result = (WsXmlDocH)_WsManClient_renew(arg1,arg2,arg3,arg4);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p__WsXmlDoc, 0 |  0 );
  if (alloc3 == SWIG_NEWOBJ) free((char*)buf3);
  if (alloc4 == SWIG_NEWOBJ) free((char*)buf4);
  return resultobj;
fail:
  if (alloc3 == SWIG_NEWOBJ) free((char*)buf3);
  if (alloc4 == SWIG_NEWOBJ) free((char*)buf4);
  return NULL;
}


SWIGINTERN PyObject *_wrap_Client_fault_string(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManClient *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Client_fault_string" "', argument " "1"" of type '" "struct _WsManClient *""'"); 
  }
  arg1 = (struct _WsManClient *)(argp1);
  result = (char *)_WsManClient_fault_string(arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Client_last_error(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  struct _WsManClient *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p__WsManClient, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Client_last_error" "', argument " "1"" of type '" "struct _WsManClient *""'"); 
  }
  arg1 = (struct _WsManClient *)(argp1);
  result = (int)_WsManClient_last_error(arg1);
  resultobj = SWIG_From_int((int)(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *Client_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj = NULL;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p__WsManClient, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *Client_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_set_debug(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  int arg1 ;
  int val1 ;
  int ecode1 = 0 ;
  PyObject *swig_obj[1] ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  ecode1 = SWIG_AsVal_int(swig_obj[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "set_debug" "', argument " "1"" of type '" "int""'");
  } 
  arg1 = (int)(val1);
  set_debug(arg1);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_get_debug(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  int result;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "get_debug", 0, 0, 0)) SWIG_fail;
  result = (int)get_debug();
  resultobj = SWIG_From_int((int)(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_create_soap_envelope(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  WsXmlDocH result;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "create_soap_envelope", 0, 0, 0)) SWIG_fail;
  result = (WsXmlDocH)create_soap_envelope();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p__WsXmlDoc, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_create_doc_from_file(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  char *arg1 = 0 ;
  char *arg2 = (char *)"UTF-8" ;
  int res1 ;
  char *buf1 = 0 ;
  int alloc1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  PyObject *swig_obj[2] ;
  WsXmlDocH result;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "create_doc_from_file", 1, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_AsCharPtrAndSize(swig_obj[0], &buf1, NULL, &alloc1);
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "create_doc_from_file" "', argument " "1"" of type '" "char const *""'");
  }
  arg1 = (char *)(buf1);
  if (swig_obj[1]) {
    res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "create_doc_from_file" "', argument " "2"" of type '" "char const *""'");
    }
    arg2 = (char *)(buf2);
  }
  result = (WsXmlDocH)create_doc_from_file((char const *)arg1,(char const *)arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p__WsXmlDoc, 0 |  0 );
  if (alloc1 == SWIG_NEWOBJ) free((char*)buf1);
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return resultobj;
fail:
  if (alloc1 == SWIG_NEWOBJ) free((char*)buf1);
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return NULL;
}


SWIGINTERN PyObject *_wrap_create_doc_from_string(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  char *arg1 = 0 ;
  char *arg2 = (char *)"UTF-8" ;
  int res1 ;
  char *buf1 = 0 ;
  int alloc1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  PyObject *swig_obj[2] ;
  WsXmlDocH result;
  
  (void)self;
  if (!SWIG_Python_UnpackTuple(args, "create_doc_from_string", 1, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_AsCharPtrAndSize(swig_obj[0], &buf1, NULL, &alloc1);
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "create_doc_from_string" "', argument " "1"" of type '" "char const *""'");
  }
  arg1 = (char *)(buf1);
  if (swig_obj[1]) {
    res2 = SWIG_AsCharPtrAndSize(swig_obj[1], &buf2, NULL, &alloc2);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "create_doc_from_string" "', argument " "2"" of type '" "char const *""'");
    }
    arg2 = (char *)(buf2);
  }
  result = (WsXmlDocH)create_doc_from_string((char const *)arg1,(char const *)arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p__WsXmlDoc, 0 |  0 );
  if (alloc1 == SWIG_NEWOBJ) free((char*)buf1);
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return resultobj;
fail:
  if (alloc1 == SWIG_NEWOBJ) free((char*)buf1);
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return NULL;
}


SWIGINTERN PyObject *_wrap_uri_prefix(PyObject *self, PyObject *args) {
  PyObject *resultobj = 0;
  char *arg1 = 0 ;
  int res1 ;
  char *buf1 = 0 ;
  int alloc1 = 0 ;
  PyObject *swig_obj[1] ;
  char *result = 0 ;
  
  (void)self;
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_AsCharPtrAndSize(swig_obj[0], &buf1, NULL, &alloc1);
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "uri_prefix" "', argument " "1"" of type '" "char const *""'");
  }
  arg1 = (char *)(buf1);
  result = (char *)uri_prefix((char const *)arg1);
  resultobj = SWIG_FromCharPtr((const char *)result);
  if (alloc1 == SWIG_NEWOBJ) free((char*)buf1);
  return resultobj;
fail:
  if (alloc1 == SWIG_NEWOBJ) free((char*)buf1);
  return NULL;
}


static PyMethodDef SwigMethods[] = {
	 { "fopen", _wrap_fopen, METH_VARARGS, "fopen(char * arg1, char * arg2) -> FILE *"},
	 { "fclose", _wrap_fclose, METH_O, "fclose(FILE * f)"},
	 { "XmlNs_swigregister", XmlNs_swigregister, METH_O, NULL},
	 { "new_XmlDoc", _wrap_new_XmlDoc, METH_VARARGS, "new_XmlDoc(char const * name, char const * ns=None) -> XmlDoc"},
	 { "delete_XmlDoc", _wrap_delete_XmlDoc, METH_O, "delete_XmlDoc(XmlDoc self)"},
	 { "XmlDoc___str__", _wrap_XmlDoc___str__, METH_O, "XmlDoc___str__(XmlDoc self) -> char *"},
	 { "XmlDoc_encode", _wrap_XmlDoc_encode, METH_VARARGS, "XmlDoc_encode(XmlDoc self, char const * encoding=\"utf-8\") -> char *"},
	 { "XmlDoc_dump_file", _wrap_XmlDoc_dump_file, METH_VARARGS, "XmlDoc_dump_file(XmlDoc self, FILE * fp)"},
	 { "XmlDoc_root", _wrap_XmlDoc_root, METH_O, "XmlDoc_root(XmlDoc self) -> XmlNode"},
	 { "XmlDoc_envelope", _wrap_XmlDoc_envelope, METH_O, "XmlDoc_envelope(XmlDoc self) -> XmlNode"},
	 { "XmlDoc_header", _wrap_XmlDoc_header, METH_O, "XmlDoc_header(XmlDoc self) -> XmlNode"},
	 { "XmlDoc_body", _wrap_XmlDoc_body, METH_O, "XmlDoc_body(XmlDoc self) -> XmlNode"},
	 { "XmlDoc_element", _wrap_XmlDoc_element, METH_VARARGS, "XmlDoc_element(XmlDoc self, char const * name) -> XmlNode"},
	 { "XmlDoc_context", _wrap_XmlDoc_context, METH_O, "XmlDoc_context(XmlDoc self) -> char const *"},
	 { "XmlDoc_generate_fault", _wrap_XmlDoc_generate_fault, METH_VARARGS, "XmlDoc_generate_fault(XmlDoc self, Status s) -> XmlDoc"},
	 { "XmlDoc_is_fault", _wrap_XmlDoc_is_fault, METH_O, "XmlDoc_is_fault(XmlDoc self) -> int"},
	 { "XmlDoc_fault", _wrap_XmlDoc_fault, METH_O, "XmlDoc_fault(XmlDoc self) -> Fault"},
	 { "XmlDoc_create_response_envelope", _wrap_XmlDoc_create_response_envelope, METH_VARARGS, "XmlDoc_create_response_envelope(XmlDoc self, char const * action=None) -> XmlDoc"},
	 { "XmlDoc_is_end_of_sequence", _wrap_XmlDoc_is_end_of_sequence, METH_O, "XmlDoc_is_end_of_sequence(XmlDoc self) -> int"},
	 { "XmlDoc_swigregister", XmlDoc_swigregister, METH_O, NULL},
	 { "XmlDoc_swiginit", XmlDoc_swiginit, METH_VARARGS, NULL},
	 { "delete_XmlNode", _wrap_delete_XmlNode, METH_O, "delete_XmlNode(XmlNode self)"},
	 { "XmlNode_string", _wrap_XmlNode_string, METH_O, "XmlNode_string(XmlNode self) -> char *"},
	 { "XmlNode_dump_file", _wrap_XmlNode_dump_file, METH_VARARGS, "XmlNode_dump_file(XmlNode self, FILE * fp)"},
	 { "XmlNode_equal", _wrap_XmlNode_equal, METH_VARARGS, "XmlNode_equal(XmlNode self, XmlNode n) -> int"},
	 { "XmlNode___str__", _wrap_XmlNode___str__, METH_O, "XmlNode___str__(XmlNode self) -> char *"},
	 { "XmlNode_set_text", _wrap_XmlNode_set_text, METH_VARARGS, "XmlNode_set_text(XmlNode self, char const * text)"},
	 { "XmlNode_doc", _wrap_XmlNode_doc, METH_O, "XmlNode_doc(XmlNode self) -> XmlDoc"},
	 { "XmlNode_parent", _wrap_XmlNode_parent, METH_O, "XmlNode_parent(XmlNode self) -> XmlNode"},
	 { "XmlNode_child", _wrap_XmlNode_child, METH_O, "XmlNode_child(XmlNode self) -> XmlNode"},
	 { "XmlNode_name", _wrap_XmlNode_name, METH_O, "XmlNode_name(XmlNode self) -> char *"},
	 { "XmlNode_set_name", _wrap_XmlNode_set_name, METH_VARARGS, "XmlNode_set_name(XmlNode self, char const * name)"},
	 { "XmlNode_ns", _wrap_XmlNode_ns, METH_O, "XmlNode_ns(XmlNode self) -> char *"},
	 { "XmlNode_set_ns", _wrap_XmlNode_set_ns, METH_VARARGS, "XmlNode_set_ns(XmlNode self, char const * ns)"},
	 { "XmlNode_prefix", _wrap_XmlNode_prefix, METH_O, "XmlNode_prefix(XmlNode self) -> char const *"},
	 { "XmlNode_set_lang", _wrap_XmlNode_set_lang, METH_VARARGS, "XmlNode_set_lang(XmlNode self, char const * lang)"},
	 { "XmlNode_find", _wrap_XmlNode_find, METH_VARARGS, "XmlNode_find(XmlNode self, char const * ns, char const * name, int recursive=1) -> XmlNode"},
	 { "XmlNode_next", _wrap_XmlNode_next, METH_VARARGS, "XmlNode_next(XmlNode self, int all=0) -> XmlNode"},
	 { "XmlNode_size", _wrap_XmlNode_size, METH_VARARGS, "XmlNode_size(XmlNode self, char const * name=None, char const * ns=None) -> int"},
	 { "XmlNode_add_before", _wrap_XmlNode_add_before, METH_VARARGS, "XmlNode_add_before(XmlNode self, char const * ns, char const * name, char const * text=None) -> XmlNode"},
	 { "XmlNode_add", _wrap_XmlNode_add, METH_VARARGS, "\n"
		"XmlNode_add(XmlNode self, char const * ns, char const * name, char const * text=None) -> XmlNode\n"
		"XmlNode_add(XmlNode self, XmlNode node) -> XmlNode\n"
		""},
	 { "XmlNode_get", _wrap_XmlNode_get, METH_VARARGS, "\n"
		"XmlNode_get(XmlNode self, int i, char const * name=None, char const * ns=None) -> XmlNode\n"
		"XmlNode_get(XmlNode self, char const * name, char const * ns=None) -> XmlNode\n"
		""},
	 { "XmlNode_attr", _wrap_XmlNode_attr, METH_VARARGS, "XmlNode_attr(XmlNode self, int index=0) -> XmlAttr"},
	 { "XmlNode_attr_count", _wrap_XmlNode_attr_count, METH_O, "XmlNode_attr_count(XmlNode self) -> int"},
	 { "XmlNode_attr_find", _wrap_XmlNode_attr_find, METH_VARARGS, "XmlNode_attr_find(XmlNode self, char const * ns, char const * name) -> XmlAttr"},
	 { "XmlNode_attr_add", _wrap_XmlNode_attr_add, METH_VARARGS, "XmlNode_attr_add(XmlNode self, char const * ns, char const * name, char const * value) -> XmlAttr"},
	 { "XmlNode_epr", _wrap_XmlNode_epr, METH_VARARGS, "XmlNode_epr(XmlNode self, char const * ns, char const * epr_node_name, int embedded) -> EndPointReference"},
	 { "XmlNode_swigregister", XmlNode_swigregister, METH_O, NULL},
	 { "XmlAttr_name", _wrap_XmlAttr_name, METH_O, "XmlAttr_name(XmlAttr self) -> char *"},
	 { "XmlAttr_ns", _wrap_XmlAttr_ns, METH_O, "XmlAttr_ns(XmlAttr self) -> char *"},
	 { "XmlAttr_value", _wrap_XmlAttr_value, METH_O, "XmlAttr_value(XmlAttr self) -> char *"},
	 { "XmlAttr_remove", _wrap_XmlAttr_remove, METH_O, "XmlAttr_remove(XmlAttr self)"},
	 { "XmlAttr_swigregister", XmlAttr_swigregister, METH_O, NULL},
	 { "new_EndPointReference", _wrap_new_EndPointReference, METH_VARARGS, "\n"
		"EndPointReference(char const * uri, char const * address)\n"
		"new_EndPointReference(char const * uri) -> EndPointReference\n"
		""},
	 { "delete_EndPointReference", _wrap_delete_EndPointReference, METH_O, "delete_EndPointReference(EndPointReference self)"},
	 { "EndPointReference_add_selector", _wrap_EndPointReference_add_selector, METH_VARARGS, "EndPointReference_add_selector(EndPointReference self, char const * name, char const * text)"},
	 { "EndPointReference_serialize", _wrap_EndPointReference_serialize, METH_VARARGS, "EndPointReference_serialize(EndPointReference self, XmlNode node, char const * ns, char const * epr_node_name, int embedded) -> int"},
	 { "EndPointReference_cmp", _wrap_EndPointReference_cmp, METH_VARARGS, "EndPointReference_cmp(EndPointReference self, EndPointReference epr2) -> int"},
	 { "EndPointReference_to_xml", _wrap_EndPointReference_to_xml, METH_VARARGS, "EndPointReference_to_xml(EndPointReference self, char const * ns=None, char const * epr_node_name=None) -> char *"},
	 { "EndPointReference_string", _wrap_EndPointReference_string, METH_O, "EndPointReference_string(EndPointReference self) -> char *"},
	 { "EndPointReference_selector_count", _wrap_EndPointReference_selector_count, METH_O, "EndPointReference_selector_count(EndPointReference self) -> int"},
	 { "EndPointReference_resource_uri", _wrap_EndPointReference_resource_uri, METH_O, "EndPointReference_resource_uri(EndPointReference self) -> char *"},
	 { "EndPointReference_selector", _wrap_EndPointReference_selector, METH_VARARGS, "EndPointReference_selector(EndPointReference self, char const * name) -> char *"},
	 { "EndPointReference_selector_names", _wrap_EndPointReference_selector_names, METH_O, "EndPointReference_selector_names(EndPointReference self) -> PyObject *"},
	 { "EndPointReference_classname", _wrap_EndPointReference_classname, METH_O, "EndPointReference_classname(EndPointReference self) -> char *"},
	 { "EndPointReference_namespace", _wrap_EndPointReference_namespace, METH_O, "EndPointReference_namespace(EndPointReference self) -> char *"},
	 { "EndPointReference_prefix", _wrap_EndPointReference_prefix, METH_O, "EndPointReference_prefix(EndPointReference self) -> char *"},
	 { "EndPointReference_swigregister", EndPointReference_swigregister, METH_O, NULL},
	 { "EndPointReference_swiginit", EndPointReference_swiginit, METH_VARARGS, NULL},
	 { "Filter_resultClass_set", _wrap_Filter_resultClass_set, METH_VARARGS, "Filter_resultClass_set(Filter self, char * resultClass)"},
	 { "Filter_resultClass_get", _wrap_Filter_resultClass_get, METH_O, "Filter_resultClass_get(Filter self) -> char *"},
	 { "Filter_assocClass_set", _wrap_Filter_assocClass_set, METH_VARARGS, "Filter_assocClass_set(Filter self, char * assocClass)"},
	 { "Filter_assocClass_get", _wrap_Filter_assocClass_get, METH_O, "Filter_assocClass_get(Filter self) -> char *"},
	 { "new_Filter", _wrap_new_Filter, METH_NOARGS, "new_Filter() -> Filter"},
	 { "delete_Filter", _wrap_delete_Filter, METH_O, "delete_Filter(Filter self)"},
	 { "Filter_associators", _wrap_Filter_associators, METH_VARARGS, "Filter_associators(Filter self, EndPointReference epr, char const * assocClass, char const * resultClass, char const * role, char const * resultRole, char ** resultProp, int const propNum) -> int"},
	 { "Filter_references", _wrap_Filter_references, METH_VARARGS, "Filter_references(Filter self, EndPointReference epr, char const * assocClass, char const * resultClass, char const * role, char const * resultRole, char ** resultProp, int const propNum) -> int"},
	 { "Filter_simple", _wrap_Filter_simple, METH_VARARGS, "Filter_simple(Filter self, char const * dialect, char const * query) -> int"},
	 { "Filter_xpath", _wrap_Filter_xpath, METH_VARARGS, "Filter_xpath(Filter self, char const * query) -> int"},
	 { "Filter_cql", _wrap_Filter_cql, METH_VARARGS, "Filter_cql(Filter self, char const * query) -> int"},
	 { "Filter_wql", _wrap_Filter_wql, METH_VARARGS, "Filter_wql(Filter self, char const * query) -> int"},
	 { "Filter_swigregister", Filter_swigregister, METH_O, NULL},
	 { "Filter_swiginit", Filter_swiginit, METH_VARARGS, NULL},
	 { "delete_EnumerateInfo", _wrap_delete_EnumerateInfo, METH_O, "delete_EnumerateInfo(EnumerateInfo self)"},
	 { "EnumerateInfo_max_items", _wrap_EnumerateInfo_max_items, METH_O, "EnumerateInfo_max_items(EnumerateInfo self) -> int"},
	 { "EnumerateInfo_set_max_items", _wrap_EnumerateInfo_set_max_items, METH_VARARGS, "EnumerateInfo_set_max_items(EnumerateInfo self, int mi)"},
	 { "EnumerateInfo_flags", _wrap_EnumerateInfo_flags, METH_O, "EnumerateInfo_flags(EnumerateInfo self) -> int"},
	 { "EnumerateInfo_epr_to", _wrap_EnumerateInfo_epr_to, METH_O, "EnumerateInfo_epr_to(EnumerateInfo self) -> char const *"},
	 { "EnumerateInfo_epr_uri", _wrap_EnumerateInfo_epr_uri, METH_O, "EnumerateInfo_epr_uri(EnumerateInfo self) -> char const *"},
	 { "EnumerateInfo_encoding", _wrap_EnumerateInfo_encoding, METH_O, "EnumerateInfo_encoding(EnumerateInfo self) -> char const *"},
	 { "EnumerateInfo_filter", _wrap_EnumerateInfo_filter, METH_O, "EnumerateInfo_filter(EnumerateInfo self) -> Filter"},
	 { "EnumerateInfo_index", _wrap_EnumerateInfo_index, METH_O, "EnumerateInfo_index(EnumerateInfo self) -> int"},
	 { "EnumerateInfo_set_index", _wrap_EnumerateInfo_set_index, METH_VARARGS, "EnumerateInfo_set_index(EnumerateInfo self, int i)"},
	 { "EnumerateInfo_total_items", _wrap_EnumerateInfo_total_items, METH_O, "EnumerateInfo_total_items(EnumerateInfo self) -> int"},
	 { "EnumerateInfo_set_total_items", _wrap_EnumerateInfo_set_total_items, METH_VARARGS, "EnumerateInfo_set_total_items(EnumerateInfo self, int i)"},
	 { "EnumerateInfo_pull_result", _wrap_EnumerateInfo_pull_result, METH_O, "EnumerateInfo_pull_result(EnumerateInfo self) -> XmlDoc"},
	 { "EnumerateInfo_set_pull_result", _wrap_EnumerateInfo_set_pull_result, METH_VARARGS, "EnumerateInfo_set_pull_result(EnumerateInfo self, XmlDoc result)"},
	 { "EnumerateInfo_swigregister", EnumerateInfo_swigregister, METH_O, NULL},
	 { "SoapOp_indoc", _wrap_SoapOp_indoc, METH_O, "SoapOp_indoc(SoapOp self) -> XmlDoc"},
	 { "SoapOp_set_indoc", _wrap_SoapOp_set_indoc, METH_VARARGS, "SoapOp_set_indoc(SoapOp self, XmlDoc doc)"},
	 { "SoapOp_outdoc", _wrap_SoapOp_outdoc, METH_O, "SoapOp_outdoc(SoapOp self) -> XmlDoc"},
	 { "SoapOp_set_outdoc", _wrap_SoapOp_set_outdoc, METH_VARARGS, "SoapOp_set_outdoc(SoapOp self, XmlDoc doc)"},
	 { "SoapOp_soap", _wrap_SoapOp_soap, METH_O, "SoapOp_soap(SoapOp self) -> Soap"},
	 { "SoapOp_msg", _wrap_SoapOp_msg, METH_O, "SoapOp_msg(SoapOp self) -> WsmanMessage *"},
	 { "SoapOp_maxsize", _wrap_SoapOp_maxsize, METH_O, "SoapOp_maxsize(SoapOp self) -> unsigned long"},
	 { "SoapOp_swigregister", SoapOp_swigregister, METH_O, NULL},
	 { "delete_Soap", _wrap_delete_Soap, METH_O, "delete_Soap(Soap self)"},
	 { "Soap_create_context", _wrap_Soap_create_context, METH_O, "Soap_create_context(Soap self) -> Context"},
	 { "Soap_context", _wrap_Soap_context, METH_O, "Soap_context(Soap self) -> Context"},
	 { "Soap_create_ep_context", _wrap_Soap_create_ep_context, METH_VARARGS, "Soap_create_ep_context(Soap self, XmlDoc doc) -> Context"},
	 { "Soap_swigregister", Soap_swigregister, METH_O, NULL},
	 { "delete_Context", _wrap_delete_Context, METH_O, "delete_Context(Context self)"},
	 { "Context_indoc", _wrap_Context_indoc, METH_O, "Context_indoc(Context self) -> XmlDoc"},
	 { "Context_runtime", _wrap_Context_runtime, METH_O, "Context_runtime(Context self) -> Soap"},
	 { "Context_set_enumIdleTimeout", _wrap_Context_set_enumIdleTimeout, METH_VARARGS, "Context_set_enumIdleTimeout(Context self, unsigned long timeout)"},
	 { "Context_classname", _wrap_Context_classname, METH_O, "Context_classname(Context self) -> char const *"},
	 { "Context_method", _wrap_Context_method, METH_O, "Context_method(Context self) -> char const *"},
	 { "Context_method_args", _wrap_Context_method_args, METH_VARARGS, "Context_method_args(Context self, char const * resource_uri) -> hash_t *"},
	 { "Context_max_elements", _wrap_Context_max_elements, METH_VARARGS, "Context_max_elements(Context self, XmlDoc doc=None) -> int"},
	 { "Context_max_envelope_size", _wrap_Context_max_envelope_size, METH_VARARGS, "Context_max_envelope_size(Context self, XmlDoc doc=None) -> unsigned long"},
	 { "Context_fragment_string", _wrap_Context_fragment_string, METH_VARARGS, "Context_fragment_string(Context self, XmlDoc doc=None) -> char const *"},
	 { "Context_selector", _wrap_Context_selector, METH_VARARGS, "Context_selector(Context self, XmlDoc doc, char const * name, int index) -> char const *"},
	 { "Context_selectors_from_epr", _wrap_Context_selectors_from_epr, METH_VARARGS, "Context_selectors_from_epr(Context self, XmlNode epr_node) -> hash_t *"},
	 { "Context_selectors", _wrap_Context_selectors, METH_VARARGS, "Context_selectors(Context self, XmlDoc doc=None) -> hash_t *"},
	 { "Context_selectors_from_filter", _wrap_Context_selectors_from_filter, METH_VARARGS, "Context_selectors_from_filter(Context self, XmlDoc doc=None) -> hash_t *"},
	 { "Context_action", _wrap_Context_action, METH_VARARGS, "Context_action(Context self, XmlDoc doc=None) -> char const *"},
	 { "Context_resource_uri", _wrap_Context_resource_uri, METH_VARARGS, "Context_resource_uri(Context self, XmlDoc doc=None) -> char const *"},
	 { "Context_option_set", _wrap_Context_option_set, METH_VARARGS, "Context_option_set(Context self, XmlDoc doc, char const * op) -> char const *"},
	 { "Context_parse_enum_request", _wrap_Context_parse_enum_request, METH_VARARGS, "Context_parse_enum_request(Context self, WsEnumerateInfo * enumInfo) -> int"},
	 { "Context_swigregister", Context_swigregister, METH_O, NULL},
	 { "new_Status", _wrap_new_Status, METH_VARARGS, "new_Status(int code=0, int detail=0, char const * msg=None) -> Status"},
	 { "delete_Status", _wrap_delete_Status, METH_O, "delete_Status(Status self)"},
	 { "Status_to_s", _wrap_Status_to_s, METH_O, "Status_to_s(Status self) -> char const *"},
	 { "Status_set_code", _wrap_Status_set_code, METH_VARARGS, "Status_set_code(Status self, int code)"},
	 { "Status_code", _wrap_Status_code, METH_O, "Status_code(Status self) -> int"},
	 { "Status_set_detail", _wrap_Status_set_detail, METH_VARARGS, "Status_set_detail(Status self, int detail)"},
	 { "Status_detail", _wrap_Status_detail, METH_O, "Status_detail(Status self) -> int"},
	 { "Status_set_msg", _wrap_Status_set_msg, METH_VARARGS, "Status_set_msg(Status self, char const * msg)"},
	 { "Status_msg", _wrap_Status_msg, METH_O, "Status_msg(Status self) -> char const *"},
	 { "Status_generate_fault", _wrap_Status_generate_fault, METH_VARARGS, "Status_generate_fault(Status self, XmlDoc doc) -> XmlDoc"},
	 { "Status_swigregister", Status_swigregister, METH_O, NULL},
	 { "Status_swiginit", Status_swiginit, METH_VARARGS, NULL},
	 { "new_Fault", _wrap_new_Fault, METH_O, "new_Fault(XmlDoc doc) -> Fault"},
	 { "delete_Fault", _wrap_delete_Fault, METH_O, "delete_Fault(Fault self)"},
	 { "Fault_code", _wrap_Fault_code, METH_O, "Fault_code(Fault self) -> char const *"},
	 { "Fault_subcode", _wrap_Fault_subcode, METH_O, "Fault_subcode(Fault self) -> char const *"},
	 { "Fault_reason", _wrap_Fault_reason, METH_O, "Fault_reason(Fault self) -> char const *"},
	 { "Fault_detail", _wrap_Fault_detail, METH_O, "Fault_detail(Fault self) -> char const *"},
	 { "Fault_swigregister", Fault_swigregister, METH_O, NULL},
	 { "Fault_swiginit", Fault_swiginit, METH_VARARGS, NULL},
	 { "Transport_is_auth_method", _wrap_Transport_is_auth_method, METH_VARARGS, "Transport_is_auth_method(Transport self, int method) -> int"},
	 { "Transport_close", _wrap_Transport_close, METH_O, "Transport_close(Transport self)"},
	 { "Transport_set_agent", _wrap_Transport_set_agent, METH_VARARGS, "Transport_set_agent(Transport self, char const * agent)"},
	 { "Transport_agent", _wrap_Transport_agent, METH_O, "Transport_agent(Transport self) -> char *"},
	 { "Transport_get_username", _wrap_Transport_get_username, METH_O, "Transport_get_username(Transport self) -> char *"},
	 { "Transport_set_username", _wrap_Transport_set_username, METH_VARARGS, "Transport_set_username(Transport self, char * user_name)"},
	 { "Transport_get_password", _wrap_Transport_get_password, METH_O, "Transport_get_password(Transport self) -> char *"},
	 { "Transport_set_password", _wrap_Transport_set_password, METH_VARARGS, "Transport_set_password(Transport self, char * password)"},
	 { "Transport_get_proxy_username", _wrap_Transport_get_proxy_username, METH_O, "Transport_get_proxy_username(Transport self) -> char *"},
	 { "Transport_set_proxy_username", _wrap_Transport_set_proxy_username, METH_VARARGS, "Transport_set_proxy_username(Transport self, char * proxy_username)"},
	 { "Transport_get_proxy_password", _wrap_Transport_get_proxy_password, METH_O, "Transport_get_proxy_password(Transport self) -> char *"},
	 { "Transport_set_proxy_password", _wrap_Transport_set_proxy_password, METH_VARARGS, "Transport_set_proxy_password(Transport self, char * proxy_password)"},
	 { "Transport_set_auth_method", _wrap_Transport_set_auth_method, METH_VARARGS, "Transport_set_auth_method(Transport self, char const * am)"},
	 { "Transport_auth_method", _wrap_Transport_auth_method, METH_O, "Transport_auth_method(Transport self) -> char *"},
	 { "Transport_auth_name", _wrap_Transport_auth_name, METH_O, "Transport_auth_name(int auth) -> char const *"},
	 { "Transport_auth_value", _wrap_Transport_auth_value, METH_O, "Transport_auth_value(Transport self) -> int"},
	 { "Transport_error_string", _wrap_Transport_error_string, METH_O, "Transport_error_string(int err) -> char *"},
	 { "Transport_set_timeout", _wrap_Transport_set_timeout, METH_VARARGS, "Transport_set_timeout(Transport self, unsigned long timeout)"},
	 { "Transport_timeout", _wrap_Transport_timeout, METH_O, "Transport_timeout(Transport self) -> unsigned long"},
	 { "Transport_set_verify_peer", _wrap_Transport_set_verify_peer, METH_VARARGS, "Transport_set_verify_peer(Transport self, unsigned int value)"},
	 { "Transport_verify_peer", _wrap_Transport_verify_peer, METH_O, "Transport_verify_peer(Transport self) -> unsigned int"},
	 { "Transport_set_verify_host", _wrap_Transport_set_verify_host, METH_VARARGS, "Transport_set_verify_host(Transport self, unsigned int value)"},
	 { "Transport_verify_host", _wrap_Transport_verify_host, METH_O, "Transport_verify_host(Transport self) -> unsigned int"},
	 { "Transport_set_proxy", _wrap_Transport_set_proxy, METH_VARARGS, "Transport_set_proxy(Transport self, char const * proxy)"},
	 { "Transport_proxy", _wrap_Transport_proxy, METH_O, "Transport_proxy(Transport self) -> char *"},
	 { "Transport_set_proxyauth", _wrap_Transport_set_proxyauth, METH_VARARGS, "Transport_set_proxyauth(Transport self, char const * pauth)"},
	 { "Transport_proxyauth", _wrap_Transport_proxyauth, METH_O, "Transport_proxyauth(Transport self) -> char *"},
	 { "Transport_set_cainfo", _wrap_Transport_set_cainfo, METH_VARARGS, "Transport_set_cainfo(Transport self, char const * cainfo)"},
	 { "Transport_cainfo", _wrap_Transport_cainfo, METH_O, "Transport_cainfo(Transport self) -> char *"},
	 { "Transport_set_certhumbprint", _wrap_Transport_set_certhumbprint, METH_VARARGS, "Transport_set_certhumbprint(Transport self, char const * arg)"},
	 { "Transport_certhumbprint", _wrap_Transport_certhumbprint, METH_O, "Transport_certhumbprint(Transport self) -> char *"},
	 { "Transport_set_capath", _wrap_Transport_set_capath, METH_VARARGS, "Transport_set_capath(Transport self, char const * capath)"},
	 { "Transport_capath", _wrap_Transport_capath, METH_O, "Transport_capath(Transport self) -> char *"},
	 { "Transport_set_caoid", _wrap_Transport_set_caoid, METH_VARARGS, "Transport_set_caoid(Transport self, char const * oid)"},
	 { "Transport_caoid", _wrap_Transport_caoid, METH_O, "Transport_caoid(Transport self) -> char *"},
	 { "Transport_set_cert", _wrap_Transport_set_cert, METH_VARARGS, "Transport_set_cert(Transport self, char const * cert)"},
	 { "Transport_cert", _wrap_Transport_cert, METH_O, "Transport_cert(Transport self) -> char *"},
	 { "Transport_set_key", _wrap_Transport_set_key, METH_VARARGS, "Transport_set_key(Transport self, char const * key)"},
	 { "Transport_key", _wrap_Transport_key, METH_O, "Transport_key(Transport self) -> char *"},
	 { "Transport_swigregister", Transport_swigregister, METH_O, NULL},
	 { "wsman_send_request", _wrap_wsman_send_request, METH_VARARGS, "wsman_send_request(Client cl, XmlDoc request) -> int"},
	 { "wsmc_transport_set_auth_request_func", _wrap_wsmc_transport_set_auth_request_func, METH_VARARGS, "wsmc_transport_set_auth_request_func(Client cl, wsman_auth_request_func_t f)"},
	 { "wsman_is_auth_method", _wrap_wsman_is_auth_method, METH_VARARGS, "wsman_is_auth_method(Client cl, int method) -> int"},
	 { "wsmc_transport_init", _wrap_wsmc_transport_init, METH_VARARGS, "wsmc_transport_init(Client cl, void * arg) -> int"},
	 { "wsman_transport_close_transport", _wrap_wsman_transport_close_transport, METH_O, "wsman_transport_close_transport(Client cl)"},
	 { "wsmc_transport_fini", _wrap_wsmc_transport_fini, METH_O, "wsmc_transport_fini(Client cl)"},
	 { "wsman_transport_set_agent", _wrap_wsman_transport_set_agent, METH_VARARGS, "wsman_transport_set_agent(Client cl, char const * agent)"},
	 { "wsman_transport_get_agent", _wrap_wsman_transport_get_agent, METH_O, "wsman_transport_get_agent(Client cl) -> char *"},
	 { "wsman_transport_set_userName", _wrap_wsman_transport_set_userName, METH_VARARGS, "wsman_transport_set_userName(Client cl, char const * user_name)"},
	 { "wsman_transport_get_userName", _wrap_wsman_transport_get_userName, METH_O, "wsman_transport_get_userName(Client cl) -> char *"},
	 { "wsman_transport_set_password", _wrap_wsman_transport_set_password, METH_VARARGS, "wsman_transport_set_password(Client cl, char const * password)"},
	 { "wsman_transport_get_password", _wrap_wsman_transport_get_password, METH_O, "wsman_transport_get_password(Client cl) -> char *"},
	 { "wsman_transport_set_proxy_username", _wrap_wsman_transport_set_proxy_username, METH_VARARGS, "wsman_transport_set_proxy_username(Client cl, char const * proxy_username)"},
	 { "wsman_transport_get_proxy_username", _wrap_wsman_transport_get_proxy_username, METH_O, "wsman_transport_get_proxy_username(Client cl) -> char *"},
	 { "wsman_transport_set_proxy_password", _wrap_wsman_transport_set_proxy_password, METH_VARARGS, "wsman_transport_set_proxy_password(Client cl, char const * proxy_password)"},
	 { "wsman_transport_get_proxy_password", _wrap_wsman_transport_get_proxy_password, METH_O, "wsman_transport_get_proxy_password(Client cl) -> char *"},
	 { "wsman_transport_set_auth_method", _wrap_wsman_transport_set_auth_method, METH_VARARGS, "wsman_transport_set_auth_method(Client cl, char const * am)"},
	 { "wsman_transport_get_auth_method", _wrap_wsman_transport_get_auth_method, METH_O, "wsman_transport_get_auth_method(Client cl) -> char *"},
	 { "wsmc_transport_get_auth_name", _wrap_wsmc_transport_get_auth_name, METH_O, "wsmc_transport_get_auth_name(wsman_auth_type_t auth) -> char const *"},
	 { "wsmc_transport_get_auth_value", _wrap_wsmc_transport_get_auth_value, METH_O, "wsmc_transport_get_auth_value(Client cl) -> wsman_auth_type_t"},
	 { "wsman_transport_get_last_error_string", _wrap_wsman_transport_get_last_error_string, METH_O, "wsman_transport_get_last_error_string(WS_LASTERR_Code err) -> char *"},
	 { "wsman_transport_set_timeout", _wrap_wsman_transport_set_timeout, METH_VARARGS, "wsman_transport_set_timeout(Client cl, unsigned long timeout)"},
	 { "wsman_transport_get_timeout", _wrap_wsman_transport_get_timeout, METH_O, "wsman_transport_get_timeout(Client cl) -> unsigned long"},
	 { "wsman_transport_set_verify_peer", _wrap_wsman_transport_set_verify_peer, METH_VARARGS, "wsman_transport_set_verify_peer(Client cl, unsigned int value)"},
	 { "wsman_transport_get_verify_peer", _wrap_wsman_transport_get_verify_peer, METH_O, "wsman_transport_get_verify_peer(Client cl) -> unsigned int"},
	 { "wsman_transport_set_verify_host", _wrap_wsman_transport_set_verify_host, METH_VARARGS, "wsman_transport_set_verify_host(Client cl, unsigned int value)"},
	 { "wsman_transport_get_verify_host", _wrap_wsman_transport_get_verify_host, METH_O, "wsman_transport_get_verify_host(Client cl) -> unsigned int"},
	 { "wsman_transport_set_crlcheck", _wrap_wsman_transport_set_crlcheck, METH_VARARGS, "wsman_transport_set_crlcheck(Client cl, unsigned int value)"},
	 { "wsman_transport_get_crlcheck", _wrap_wsman_transport_get_crlcheck, METH_O, "wsman_transport_get_crlcheck(Client cl) -> unsigned int"},
	 { "wsman_transport_set_crlfile", _wrap_wsman_transport_set_crlfile, METH_VARARGS, "wsman_transport_set_crlfile(Client cl, char const * arg)"},
	 { "wsman_transport_get_crlfile", _wrap_wsman_transport_get_crlfile, METH_O, "wsman_transport_get_crlfile(Client cl) -> char *"},
	 { "wsman_transport_set_proxy", _wrap_wsman_transport_set_proxy, METH_VARARGS, "wsman_transport_set_proxy(Client cl, char const * proxy)"},
	 { "wsman_transport_get_proxy", _wrap_wsman_transport_get_proxy, METH_O, "wsman_transport_get_proxy(Client cl) -> char *"},
	 { "wsman_transport_set_proxyauth", _wrap_wsman_transport_set_proxyauth, METH_VARARGS, "wsman_transport_set_proxyauth(Client cl, char const * pauth)"},
	 { "wsman_transport_get_proxyauth", _wrap_wsman_transport_get_proxyauth, METH_O, "wsman_transport_get_proxyauth(Client cl) -> char *"},
	 { "wsman_transport_set_cainfo", _wrap_wsman_transport_set_cainfo, METH_VARARGS, "wsman_transport_set_cainfo(Client cl, char const * cainfo)"},
	 { "wsman_transport_get_cainfo", _wrap_wsman_transport_get_cainfo, METH_O, "wsman_transport_get_cainfo(Client cl) -> char *"},
	 { "wsman_transport_set_certhumbprint", _wrap_wsman_transport_set_certhumbprint, METH_VARARGS, "wsman_transport_set_certhumbprint(Client cl, char const * arg)"},
	 { "wsman_transport_get_certhumbprint", _wrap_wsman_transport_get_certhumbprint, METH_O, "wsman_transport_get_certhumbprint(Client cl) -> char *"},
	 { "wsman_transport_set_capath", _wrap_wsman_transport_set_capath, METH_VARARGS, "wsman_transport_set_capath(Client cl, char const * capath)"},
	 { "wsman_transport_get_capath", _wrap_wsman_transport_get_capath, METH_O, "wsman_transport_get_capath(Client cl) -> char *"},
	 { "wsman_transport_set_caoid", _wrap_wsman_transport_set_caoid, METH_VARARGS, "wsman_transport_set_caoid(Client cl, char const * oid)"},
	 { "wsman_transport_get_caoid", _wrap_wsman_transport_get_caoid, METH_O, "wsman_transport_get_caoid(Client cl) -> char *"},
	 { "wsman_transport_set_cert", _wrap_wsman_transport_set_cert, METH_VARARGS, "wsman_transport_set_cert(Client cl, char const * cert)"},
	 { "wsman_transport_get_cert", _wrap_wsman_transport_get_cert, METH_O, "wsman_transport_get_cert(Client cl) -> char *"},
	 { "wsman_transport_set_key", _wrap_wsman_transport_set_key, METH_VARARGS, "wsman_transport_set_key(Client cl, char const * key)"},
	 { "wsman_transport_get_key", _wrap_wsman_transport_get_key, METH_O, "wsman_transport_get_key(Client cl) -> char *"},
	 { "new_ClientOptions", _wrap_new_ClientOptions, METH_NOARGS, "new_ClientOptions() -> ClientOptions"},
	 { "delete_ClientOptions", _wrap_delete_ClientOptions, METH_O, "delete_ClientOptions(ClientOptions self)"},
	 { "ClientOptions_set_dump_request", _wrap_ClientOptions_set_dump_request, METH_O, "ClientOptions_set_dump_request(ClientOptions self)"},
	 { "ClientOptions_clear_dump_request", _wrap_ClientOptions_clear_dump_request, METH_O, "ClientOptions_clear_dump_request(ClientOptions self)"},
	 { "ClientOptions_set_flags", _wrap_ClientOptions_set_flags, METH_VARARGS, "ClientOptions_set_flags(ClientOptions self, unsigned long flags)"},
	 { "ClientOptions_get_flags", _wrap_ClientOptions_get_flags, METH_O, "ClientOptions_get_flags(ClientOptions self) -> unsigned long"},
	 { "ClientOptions_clear_flags", _wrap_ClientOptions_clear_flags, METH_VARARGS, "ClientOptions_clear_flags(ClientOptions self, unsigned long flags)"},
	 { "ClientOptions_reset_flags", _wrap_ClientOptions_reset_flags, METH_O, "ClientOptions_reset_flags(ClientOptions self)"},
	 { "ClientOptions_set_max_envelope_size", _wrap_ClientOptions_set_max_envelope_size, METH_VARARGS, "ClientOptions_set_max_envelope_size(ClientOptions self, unsigned long size)"},
	 { "ClientOptions_get_max_envelope_size", _wrap_ClientOptions_get_max_envelope_size, METH_O, "ClientOptions_get_max_envelope_size(ClientOptions self) -> unsigned long"},
	 { "ClientOptions_set_max_elements", _wrap_ClientOptions_set_max_elements, METH_VARARGS, "ClientOptions_set_max_elements(ClientOptions self, int elements)"},
	 { "ClientOptions_get_max_elements", _wrap_ClientOptions_get_max_elements, METH_O, "ClientOptions_get_max_elements(ClientOptions self) -> int"},
	 { "ClientOptions_set_timeout", _wrap_ClientOptions_set_timeout, METH_VARARGS, "ClientOptions_set_timeout(ClientOptions self, unsigned long timeout)"},
	 { "ClientOptions_get_timeout", _wrap_ClientOptions_get_timeout, METH_O, "ClientOptions_get_timeout(ClientOptions self) -> unsigned long"},
	 { "ClientOptions_set_fragment", _wrap_ClientOptions_set_fragment, METH_VARARGS, "ClientOptions_set_fragment(ClientOptions self, char * fragment)"},
	 { "ClientOptions_get_fragment", _wrap_ClientOptions_get_fragment, METH_O, "ClientOptions_get_fragment(ClientOptions self) -> char const *"},
	 { "ClientOptions_set_cim_namespace", _wrap_ClientOptions_set_cim_namespace, METH_VARARGS, "ClientOptions_set_cim_namespace(ClientOptions self, char * cim_namespace)"},
	 { "ClientOptions_get_cim_namespace", _wrap_ClientOptions_get_cim_namespace, METH_O, "ClientOptions_get_cim_namespace(ClientOptions self) -> char const *"},
	 { "ClientOptions_set_reference", _wrap_ClientOptions_set_reference, METH_VARARGS, "ClientOptions_set_reference(ClientOptions self, char const * reference)"},
	 { "ClientOptions_get_reference", _wrap_ClientOptions_get_reference, METH_O, "ClientOptions_get_reference(ClientOptions self) -> char const *"},
	 { "ClientOptions_add_option", _wrap_ClientOptions_add_option, METH_VARARGS, "ClientOptions_add_option(ClientOptions self, char const * key, char const * value)"},
	 { "ClientOptions_add_selector", _wrap_ClientOptions_add_selector, METH_VARARGS, "ClientOptions_add_selector(ClientOptions self, char const * key, char const * value)"},
	 { "ClientOptions_add_property_array_item", _wrap_ClientOptions_add_property_array_item, METH_VARARGS, "ClientOptions_add_property_array_item(ClientOptions self, char const * key, char const * value)"},
	 { "ClientOptions_add_property", _wrap_ClientOptions_add_property, METH_VARARGS, "\n"
		"ClientOptions_add_property(ClientOptions self, char const * key, char const * value)\n"
		"ClientOptions_add_property(ClientOptions self, char const * key, EndPointReference epr)\n"
		""},
	 { "ClientOptions_set_delivery_uri", _wrap_ClientOptions_set_delivery_uri, METH_VARARGS, "ClientOptions_set_delivery_uri(ClientOptions self, char const * delivery_uri)"},
	 { "ClientOptions_delivery_uri", _wrap_ClientOptions_delivery_uri, METH_O, "ClientOptions_delivery_uri(ClientOptions self) -> char const *"},
	 { "ClientOptions_set_sub_expiry", _wrap_ClientOptions_set_sub_expiry, METH_VARARGS, "ClientOptions_set_sub_expiry(ClientOptions self, float event_subscription_expire)"},
	 { "ClientOptions_sub_expiry", _wrap_ClientOptions_sub_expiry, METH_O, "ClientOptions_sub_expiry(ClientOptions self) -> float"},
	 { "ClientOptions_set_heartbeat_interval", _wrap_ClientOptions_set_heartbeat_interval, METH_VARARGS, "ClientOptions_set_heartbeat_interval(ClientOptions self, float heartbeat_interval)"},
	 { "ClientOptions_heartbeat_interval", _wrap_ClientOptions_heartbeat_interval, METH_O, "ClientOptions_heartbeat_interval(ClientOptions self) -> float"},
	 { "ClientOptions_set_delivery_mode", _wrap_ClientOptions_set_delivery_mode, METH_VARARGS, "ClientOptions_set_delivery_mode(ClientOptions self, unsigned int delivery_mode)"},
	 { "ClientOptions_delivery_mode", _wrap_ClientOptions_delivery_mode, METH_O, "ClientOptions_delivery_mode(ClientOptions self) -> int"},
	 { "ClientOptions_set_delivery_security_mode", _wrap_ClientOptions_set_delivery_security_mode, METH_VARARGS, "ClientOptions_set_delivery_security_mode(ClientOptions self, unsigned int delivery_sec_mode)"},
	 { "ClientOptions_delivery_sec_mode", _wrap_ClientOptions_delivery_sec_mode, METH_O, "ClientOptions_delivery_sec_mode(ClientOptions self) -> int"},
	 { "ClientOptions_set_locale", _wrap_ClientOptions_set_locale, METH_VARARGS, "ClientOptions_set_locale(ClientOptions self, char const * locale)"},
	 { "ClientOptions_locale", _wrap_ClientOptions_locale, METH_O, "ClientOptions_locale(ClientOptions self) -> char const *"},
	 { "ClientOptions_swigregister", ClientOptions_swigregister, METH_O, NULL},
	 { "ClientOptions_swiginit", ClientOptions_swiginit, METH_VARARGS, NULL},
	 { "new_Client", _wrap_new_Client, METH_VARARGS, "\n"
		"Client(char const * uri)\n"
		"new_Client(char const * hostname, int const port, char const * path, char const * scheme, char const * username, char const * password) -> Client\n"
		""},
	 { "delete_Client", _wrap_delete_Client, METH_O, "delete_Client(Client self)"},
	 { "Client_set_dumpfile", _wrap_Client_set_dumpfile, METH_VARARGS, "Client_set_dumpfile(Client self, FILE * f)"},
	 { "Client_response_code", _wrap_Client_response_code, METH_O, "Client_response_code(Client self) -> long"},
	 { "Client_scheme", _wrap_Client_scheme, METH_O, "Client_scheme(Client self) -> char *"},
	 { "Client_host", _wrap_Client_host, METH_O, "Client_host(Client self) -> char *"},
	 { "Client_port", _wrap_Client_port, METH_O, "Client_port(Client self) -> int"},
	 { "Client_path", _wrap_Client_path, METH_O, "Client_path(Client self) -> char *"},
	 { "Client_user", _wrap_Client_user, METH_O, "Client_user(Client self) -> char *"},
	 { "Client_password", _wrap_Client_password, METH_O, "Client_password(Client self) -> char *"},
	 { "Client_transport", _wrap_Client_transport, METH_O, "Client_transport(Client self) -> Transport"},
	 { "Client_send_request", _wrap_Client_send_request, METH_VARARGS, "Client_send_request(Client self, XmlDoc request) -> int"},
	 { "Client_build_envelope_from_response", _wrap_Client_build_envelope_from_response, METH_O, "Client_build_envelope_from_response(Client self) -> XmlDoc"},
	 { "Client_encoding", _wrap_Client_encoding, METH_O, "Client_encoding(Client self) -> char *"},
	 { "Client_set_encoding", _wrap_Client_set_encoding, METH_VARARGS, "Client_set_encoding(Client self, char const * encoding)"},
	 { "Client_identify", _wrap_Client_identify, METH_VARARGS, "Client_identify(Client self, ClientOptions options) -> XmlDoc"},
	 { "Client_get_from_epr", _wrap_Client_get_from_epr, METH_VARARGS, "Client_get_from_epr(Client self, ClientOptions options, EndPointReference epr) -> XmlDoc"},
	 { "Client_delete_from_epr", _wrap_Client_delete_from_epr, METH_VARARGS, "Client_delete_from_epr(Client self, ClientOptions options, EndPointReference epr) -> XmlDoc"},
	 { "Client_enumerate", _wrap_Client_enumerate, METH_VARARGS, "Client_enumerate(Client self, ClientOptions options, Filter filter, char * resource_uri) -> XmlDoc"},
	 { "Client_pull", _wrap_Client_pull, METH_VARARGS, "Client_pull(Client self, ClientOptions options, Filter filter, char const * resource_uri, char const * context) -> XmlDoc"},
	 { "Client_create", _wrap_Client_create, METH_VARARGS, "Client_create(Client self, ClientOptions options, char const * resource_uri, char const * data, size_t size, char const * encoding=\"utf-8\") -> XmlDoc"},
	 { "Client_put", _wrap_Client_put, METH_VARARGS, "Client_put(Client self, ClientOptions options, char const * resource_uri, char const * data, size_t size, char const * encoding=\"utf-8\") -> XmlDoc"},
	 { "Client_release", _wrap_Client_release, METH_VARARGS, "Client_release(Client self, ClientOptions options, char const * resource_uri, char const * context) -> XmlDoc"},
	 { "Client_get", _wrap_Client_get, METH_VARARGS, "Client_get(Client self, ClientOptions options, char const * resource_uri) -> XmlDoc"},
	 { "Client_delete", _wrap_Client_delete, METH_VARARGS, "Client_delete(Client self, ClientOptions options, char const * resource_uri) -> XmlDoc"},
	 { "Client_invoke", _wrap_Client_invoke, METH_VARARGS, "Client_invoke(Client self, ClientOptions options, char const * resource_uri, char const * method, XmlDoc data=None) -> XmlDoc"},
	 { "Client_subscribe", _wrap_Client_subscribe, METH_VARARGS, "Client_subscribe(Client self, ClientOptions options, Filter filter, char const * resource_uri) -> XmlDoc"},
	 { "Client_unsubscribe", _wrap_Client_unsubscribe, METH_VARARGS, "Client_unsubscribe(Client self, ClientOptions options, Filter filter, char const * resource_uri, char const * identifier) -> XmlDoc"},
	 { "Client_renew", _wrap_Client_renew, METH_VARARGS, "Client_renew(Client self, ClientOptions options, char * resource_uri, char * identifier) -> XmlDoc"},
	 { "Client_fault_string", _wrap_Client_fault_string, METH_O, "Client_fault_string(Client self) -> char *"},
	 { "Client_last_error", _wrap_Client_last_error, METH_O, "Client_last_error(Client self) -> int"},
	 { "Client_swigregister", Client_swigregister, METH_O, NULL},
	 { "Client_swiginit", Client_swiginit, METH_VARARGS, NULL},
	 { "set_debug", _wrap_set_debug, METH_O, "set_debug(int dbg)"},
	 { "get_debug", _wrap_get_debug, METH_NOARGS, "get_debug() -> int"},
	 { "create_soap_envelope", _wrap_create_soap_envelope, METH_NOARGS, "create_soap_envelope() -> XmlDoc"},
	 { "create_doc_from_file", _wrap_create_doc_from_file, METH_VARARGS, "create_doc_from_file(char const * filename, char const * encoding=\"UTF-8\") -> XmlDoc"},
	 { "create_doc_from_string", _wrap_create_doc_from_string, METH_VARARGS, "create_doc_from_string(char const * buf, char const * encoding=\"UTF-8\") -> XmlDoc"},
	 { "uri_prefix", _wrap_uri_prefix, METH_O, "uri_prefix(char const * classname) -> char const *"},
	 { NULL, NULL, 0, NULL }
};


/* -------- TYPE CONVERSION AND EQUIVALENCE RULES (BEGIN) -------- */

static swig_type_info _swigt__p_FILE = {"_p_FILE", "FILE *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_WS_LASTERR_Code = {"_p_WS_LASTERR_Code", "WS_LASTERR_Code *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_WsEnumerateInfo = {"_p_WsEnumerateInfo", "WsEnumerateInfo *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_WsmanKnownStatusCode = {"_p_WsmanKnownStatusCode", "WsmanKnownStatusCode *|enum WsmanKnownStatusCode *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_WsmanMessage = {"_p_WsmanMessage", "WsmanMessage *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p__WS_CONTEXT = {"_p__WS_CONTEXT", "WsContextH|struct _WS_CONTEXT *|_WS_CONTEXT *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p__WsManClient = {"_p__WsManClient", "WsManClient *|struct _WsManClient *|_WsManClient *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p__WsManFault = {"_p__WsManFault", "WsManFault *|struct _WsManFault *|_WsManFault *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p__WsManTransport = {"_p__WsManTransport", "WsManTransport *|struct _WsManTransport *|_WsManTransport *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p__WsXmlDoc = {"_p__WsXmlDoc", "WsXmlDocH|struct _WsXmlDoc *|_WsXmlDoc *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p__WsmanStatus = {"_p__WsmanStatus", "WsmanStatus *|struct _WsmanStatus *|_WsmanStatus *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p___Soap = {"_p___Soap", "struct __Soap *|__Soap *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p___SoapOp = {"_p___SoapOp", "struct __SoapOp *|__SoapOp *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p___WsEnumerateInfo = {"_p___WsEnumerateInfo", "struct __WsEnumerateInfo *|__WsEnumerateInfo *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p___WsXmlAttr = {"_p___WsXmlAttr", "WsXmlAttrH|struct __WsXmlAttr *|__WsXmlAttr *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p___WsXmlNode = {"_p___WsXmlNode", "WsXmlNodeH|struct __WsXmlNode *|__WsXmlNode *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p___WsXmlNs = {"_p___WsXmlNs", "__WsXmlNs *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p___WsmanFaultCodeTable = {"_p___WsmanFaultCodeTable", "WsmanFaultCodeTable *|struct __WsmanFaultCodeTable *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p___WsmanFaultCodeType = {"_p___WsmanFaultCodeType", "WsmanFaultCodeType *|enum __WsmanFaultCodeType *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p___WsmanFaultDetailTable = {"_p___WsmanFaultDetailTable", "WsmanFaultDetailTable *|struct __WsmanFaultDetailTable *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p___WsmanFaultDetailType = {"_p___WsmanFaultDetailType", "WsmanFaultDetailType *|enum __WsmanFaultDetailType *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_char = {"_p_char", "char *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_client_opt_t = {"_p_client_opt_t", "client_opt_t *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_epr_t = {"_p_epr_t", "epr_t *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_filter_t = {"_p_filter_t", "filter_t *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_p_char = {"_p_p_char", "char **", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_void = {"_p_void", "void *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_wsman_auth_request_func_t = {"_p_wsman_auth_request_func_t", "wsman_auth_request_func_t *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_wsman_auth_type_t = {"_p_wsman_auth_type_t", "wsman_auth_type_t *", 0, 0, (void*)0, 0};

static swig_type_info *swig_type_initial[] = {
  &_swigt__p_FILE,
  &_swigt__p_WS_LASTERR_Code,
  &_swigt__p_WsEnumerateInfo,
  &_swigt__p_WsmanKnownStatusCode,
  &_swigt__p_WsmanMessage,
  &_swigt__p__WS_CONTEXT,
  &_swigt__p__WsManClient,
  &_swigt__p__WsManFault,
  &_swigt__p__WsManTransport,
  &_swigt__p__WsXmlDoc,
  &_swigt__p__WsmanStatus,
  &_swigt__p___Soap,
  &_swigt__p___SoapOp,
  &_swigt__p___WsEnumerateInfo,
  &_swigt__p___WsXmlAttr,
  &_swigt__p___WsXmlNode,
  &_swigt__p___WsXmlNs,
  &_swigt__p___WsmanFaultCodeTable,
  &_swigt__p___WsmanFaultCodeType,
  &_swigt__p___WsmanFaultDetailTable,
  &_swigt__p___WsmanFaultDetailType,
  &_swigt__p_char,
  &_swigt__p_client_opt_t,
  &_swigt__p_epr_t,
  &_swigt__p_filter_t,
  &_swigt__p_p_char,
  &_swigt__p_void,
  &_swigt__p_wsman_auth_request_func_t,
  &_swigt__p_wsman_auth_type_t,
};

static swig_cast_info _swigc__p_FILE[] = {  {&_swigt__p_FILE, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_WS_LASTERR_Code[] = {  {&_swigt__p_WS_LASTERR_Code, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_WsEnumerateInfo[] = {  {&_swigt__p_WsEnumerateInfo, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_WsmanKnownStatusCode[] = {  {&_swigt__p_WsmanKnownStatusCode, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_WsmanMessage[] = {  {&_swigt__p_WsmanMessage, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p__WS_CONTEXT[] = {  {&_swigt__p__WS_CONTEXT, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p__WsManClient[] = {  {&_swigt__p__WsManClient, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p__WsManFault[] = {  {&_swigt__p__WsManFault, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p__WsManTransport[] = {  {&_swigt__p__WsManTransport, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p__WsXmlDoc[] = {  {&_swigt__p__WsXmlDoc, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p__WsmanStatus[] = {  {&_swigt__p__WsmanStatus, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p___Soap[] = {  {&_swigt__p___Soap, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p___SoapOp[] = {  {&_swigt__p___SoapOp, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p___WsEnumerateInfo[] = {  {&_swigt__p___WsEnumerateInfo, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p___WsXmlAttr[] = {  {&_swigt__p___WsXmlAttr, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p___WsXmlNode[] = {  {&_swigt__p___WsXmlNode, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p___WsXmlNs[] = {  {&_swigt__p___WsXmlNs, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p___WsmanFaultCodeTable[] = {  {&_swigt__p___WsmanFaultCodeTable, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p___WsmanFaultCodeType[] = {  {&_swigt__p___WsmanFaultCodeType, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p___WsmanFaultDetailTable[] = {  {&_swigt__p___WsmanFaultDetailTable, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p___WsmanFaultDetailType[] = {  {&_swigt__p___WsmanFaultDetailType, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_char[] = {  {&_swigt__p_char, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_client_opt_t[] = {  {&_swigt__p_client_opt_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_epr_t[] = {  {&_swigt__p_epr_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_filter_t[] = {  {&_swigt__p_filter_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_p_char[] = {  {&_swigt__p_p_char, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_void[] = {  {&_swigt__p_void, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_wsman_auth_request_func_t[] = {  {&_swigt__p_wsman_auth_request_func_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_wsman_auth_type_t[] = {  {&_swigt__p_wsman_auth_type_t, 0, 0, 0},{0, 0, 0, 0}};

static swig_cast_info *swig_cast_initial[] = {
  _swigc__p_FILE,
  _swigc__p_WS_LASTERR_Code,
  _swigc__p_WsEnumerateInfo,
  _swigc__p_WsmanKnownStatusCode,
  _swigc__p_WsmanMessage,
  _swigc__p__WS_CONTEXT,
  _swigc__p__WsManClient,
  _swigc__p__WsManFault,
  _swigc__p__WsManTransport,
  _swigc__p__WsXmlDoc,
  _swigc__p__WsmanStatus,
  _swigc__p___Soap,
  _swigc__p___SoapOp,
  _swigc__p___WsEnumerateInfo,
  _swigc__p___WsXmlAttr,
  _swigc__p___WsXmlNode,
  _swigc__p___WsXmlNs,
  _swigc__p___WsmanFaultCodeTable,
  _swigc__p___WsmanFaultCodeType,
  _swigc__p___WsmanFaultDetailTable,
  _swigc__p___WsmanFaultDetailType,
  _swigc__p_char,
  _swigc__p_client_opt_t,
  _swigc__p_epr_t,
  _swigc__p_filter_t,
  _swigc__p_p_char,
  _swigc__p_void,
  _swigc__p_wsman_auth_request_func_t,
  _swigc__p_wsman_auth_type_t,
};


/* -------- TYPE CONVERSION AND EQUIVALENCE RULES (END) -------- */

static swig_const_info swig_const_table[] = {
{0, 0, 0, 0.0, 0, 0}};

#ifdef __cplusplus
}
#endif
/* -----------------------------------------------------------------------------
 * Type initialization:
 * This problem is made tough by the requirement that no dynamic
 * memory is used. Also, since swig_type_info structures store pointers to
 * swig_cast_info structures and swig_cast_info structures store pointers back
 * to swig_type_info structures, we need some lookup code at initialization.
 * The idea is that swig generates all the structures that are needed.
 * The runtime then collects these partially filled structures.
 * The SWIG_InitializeModule function takes these initial arrays out of
 * swig_module, and does all the lookup, filling in the swig_module.types
 * array with the correct data and linking the correct swig_cast_info
 * structures together.
 *
 * The generated swig_type_info structures are assigned statically to an initial
 * array. We just loop through that array, and handle each type individually.
 * First we lookup if this type has been already loaded, and if so, use the
 * loaded structure instead of the generated one. Then we have to fill in the
 * cast dependencies. The cast data is initially stored in something like a
 * two-dimensional array. Each row corresponds to a type (there are the same
 * number of rows as there are in the swig_type_initial array). Each entry in
 * a column is one of the swig_cast_info structures for that type.
 * The cast_initial array is actually an array of arrays, because each row has
 * a variable number of columns.
 *
 * We loop through the cast[] array associated with the type and mark casts
 * which have not been defined in previously loaded modules by assigning
 * cast pointer value to cast->next. We also hash cast->type->name string
 * and store the value in the cast->value field. If we encounter swig_cast_info
 * structure that represents a cast to self we move it to the beginning
 * of the cast array. One trick we need to do is making sure the type pointer
 * in the swig_cast_info struct is correct.
 *
 * First off, we lookup the cast->type name to see if it is already loaded.
 * There are three cases to handle:
 *  1) If the cast->type has already been loaded AND the type we are adding
 *     casting info to has not been loaded (it is in this module), THEN we
 *     replace the cast->type pointer with the type pointer that has already
 *     been loaded.
 *  2) If BOTH types (the one we are adding casting info to, and the
 *     cast->type) are loaded, THEN the cast info has already been loaded by
 *     the previous module so we just ignore it.
 *  3) Finally, if cast->type has not already been loaded, then we add that
 *     swig_cast_info to the list (because the cast->type) pointer will
 *     be correct.
 *
 * Once the cast array has been set up AND it does have new casts that need
 * to be added we sort non-self cast entries to move filtered out entries
 * to the end of the array and to arrange the rest in the increasing order
 * of their type pointer values. We store the index of the last added entry
 * in the cast->value field of the entry[0] (overwriting the name hash). Then
 * we sort <next|value> fields of the remaining entries to arrange hash values
 * in the increasing order. This way cast->next->type->name field matches
 * the cast->value hash.
 *
 * Example:
 * Array of casts for type stored at 0x5000, cast to type stored at 0x3000
 * has already been loaded
 *
 *      After sweep-and-hash:   After sort-by-type:    After sort-by-hash:
 *        ________________       ________________       ________________
 *       |                |     |                |     |                |
 * Entry |  type = 0x5000 |     |  type = 0x5000 |     |  type = 0x5000 |
 *   0   |                |     |                |     |                |
 *       |  next = Entry0 |     |  next = Entry0 |     |  next = Entry0 |
 *       | value = 1212   |     | value = 3      |     | value = 3      |
 *       |                |     |                |     |                |
 *       |================|     |================|     |================|
 *       |                |     |                |     |                |
 * Entry |  type = 0x2000 |     |  type = 0x1000 |     |  type = 0x1000 |
 *   1   |                |     |                |     |                |
 *       |  next = Entry1 |     |  next = Entry1 |     |  next = Entry3 |
 *       | value = 3434   |     | value = 4545   |     | value = 2323   |
 *       |________________|     |________________|     |________________|
 *       |                |     |                |     |                |
 * Entry |  type = 0x3000 |     |  type = 0x2000 |     |  type = 0x2000 |
 *   2   |                |     |                |     |                |
 *       |  next = 0      |     |  next = Entry2 |     |  next = Entry2 |
 *       | value = 0      |     | value = 3434   |     | value = 3434   |
 *       |________________|     |________________|     |________________|
 *       |                |     |                |     |                |
 * Entry |  type = 0x1000 |     |  type = 0x4000 |     |  type = 0x4000 |
 *   3   |                |     |                |     |                |
 *       |  next = Entry3 |     |  next = Entry3 |     |  next = Entry1 |
 *       | value = 4545   |     | value = 2323   |     | value = 4545   |
 *       |________________|     |________________|     |________________|
 *       |                |     |                |     |                |
 * Entry |  type = 0x4000 |     |  type = 0x3000 |     |  type = 0x3000 |
 *   4   |                |     |                |     |                |
 *       |  next = Entry4 |     |  next = 0      |     |  next = 0      |
 *       | value = 2323   |     | value = 0      |     | value = 0      |
 *       |________________|     |________________|     |________________|
 *
 * Once the cast array has been initialized, we use cast[0]->next field to link
 * it into the list of cast arrays for the type.
 *              ____    ____    ____
 * type->cast->|next|->|next|->|next|->0
 *             |----|  |----|  |----|
 *             |----|  |----|  |----|
 *             |----|  |----|  |----|
 *
 * Subsequent cast resolution works as follows:
 *
 * 1. Check whether the type matches the first entry in the current cast array.
 * 2. If not, then do a binary search over the (0:cast->value] interval using
 *    either type address or the hash value of the type name.
 * 3. If not found, then move over to the next cast array (cast[0]->next).
 *
 * ----------------------------------------------------------------------------- */

#ifdef __cplusplus
extern "C" {
#if 0
} /* c-mode */
#endif
#endif

#if 0
#define SWIGRUNTIME_DEBUG
#endif

#ifndef SWIG_INIT_CLIENT_DATA_TYPE
#define SWIG_INIT_CLIENT_DATA_TYPE void *
#endif

/*
 * Sort function that puts cast entries with nonzero 'next' at the front
 * of the array while ordering them by addresses of their 'type' structs.
 */
SWIGINTERN int SWIG_CastCmpStruct(const void *pa, const void *pb) {
  swig_cast_info *pca = (swig_cast_info *)pa;
  swig_cast_info *pcb = (swig_cast_info *)pb;
  if (pca->type < pcb->type)
  return (pca->next || pcb->next == 0) ? -1 : 1;
  if (pca->type > pcb->type)
  return (pcb->next || pca->next == 0) ? 1 : -1;
  return 0;
}

/*
 * Shell-sort 'next' and 'value' field pairs to order them by 'value'.
 */
SWIGINTERN void SWIG_CastHashSort(swig_cast_info *cast, int size) {
  const int hmax = size/9;
  int h, i;
  for(h = 1; h <= hmax; h = 3*h+1);
  for(; h > 0; h /= 3)
  {
    for(i = h; i < size; ++i)
    {
      swig_cast_info *p = cast[i].next;
      unsigned int hash = cast[i].value;
      int j = i;
      while(j >= h && hash < cast[j-h].value)
      {
        cast[j].next = cast[j-h].next;
        cast[j].value = cast[j-h].value;
        j -= h;
      }
      cast[j].next = p;
      cast[j].value = hash;
    }
  }
}

SWIGRUNTIME void
SWIG_InitializeModule(SWIG_INIT_CLIENT_DATA_TYPE clientdata) {
  size_t i;
  swig_module_info *module_head, *iter;
  int init;
  
  /* check to see if the circular list has been setup, if not, set it up */
  if (swig_module.next==0) {
    /* Initialize the swig_module */
    swig_module.type_initial = swig_type_initial;
    swig_module.cast_initial = swig_cast_initial;
    swig_module.next = &swig_module;
    init = 1;
  } else {
    init = 0;
  }
  
  /* Try and load any already created modules */
  module_head = SWIG_GetModule(clientdata);
  if (!module_head) {
    /* This is the first module loaded for this interpreter */
    /* so set the swig module into the interpreter */
    SWIG_SetModule(clientdata, &swig_module);
  } else {
    /* the interpreter has loaded a SWIG module, but has it loaded this one? */
    iter=module_head;
    do {
      if (iter==&swig_module) {
        /* Our module is already in the list, so there's nothing more to do. */
        return;
      }
      iter=iter->next;
    } while (iter!= module_head);
    
    /* otherwise we must add our module into the list */
    swig_module.next = module_head->next;
    module_head->next = &swig_module;
  }
  
  /* When multiple interpreters are used, a module could have already been initialized in
       a different interpreter, but not yet have a pointer in this interpreter.
       In this case, we do not want to continue adding types... everything should be
       set up already */
  if (init == 0) return;
  
  /* Now work on filling in swig_module.types */
#ifdef SWIGRUNTIME_DEBUG
  printf("SWIG_InitializeModule: size %lu\n", (unsigned long)swig_module.size);
#endif
  for (i = 0; i < swig_module.size; ++i) {
    swig_type_info *type = 0;
    swig_type_info *target_type;
    swig_cast_info *cast, *first;
    int num_mapped = 0;
    
#ifdef SWIGRUNTIME_DEBUG
    printf("SWIG_InitializeModule: type %lu %s\n", (unsigned long)i, swig_module.type_initial[i]->name);
#endif
    
    /* if there is another module already loaded */
    if (swig_module.next != &swig_module) {
      type = SWIG_MangledTypeQueryModule(swig_module.next, &swig_module, swig_module.type_initial[i]->name);
    }
    if (type) {
      /* Overwrite clientdata field */
#ifdef SWIGRUNTIME_DEBUG
      printf("SWIG_InitializeModule: found type %s\n", type->name);
#endif
      if (swig_module.type_initial[i]->clientdata) {
        type->clientdata = swig_module.type_initial[i]->clientdata;
#ifdef SWIGRUNTIME_DEBUG
        printf("SWIG_InitializeModule: found and overwrite type %s \n", type->name);
#endif
      }
    } else {
      type = swig_module.type_initial[i];
    }
    
    /* Insert casting types */
    cast = first = swig_module.cast_initial[i];
    while (cast->type) {
      /* Don't need to add information already in the list */
      target_type = 0;
#ifdef SWIGRUNTIME_DEBUG
      printf("SWIG_InitializeModule: look cast %s\n", cast->type->name);
#endif
      if (swig_module.next != &swig_module) {
        target_type = SWIG_MangledTypeQueryModule(swig_module.next, &swig_module, cast->type->name);
        if (target_type) {
          /* Target type already defined in another module */
#ifdef SWIGRUNTIME_DEBUG
          printf("SWIG_InitializeModule: found cast %s\n", target_type->name);
#endif
          if (type == swig_module.type_initial[i]) {
#ifdef SWIGRUNTIME_DEBUG
            printf("SWIG_InitializeModule: skip old type %s\n", target_type->name);
#endif
            cast->type = target_type;
            target_type = 0;
          } else {
            /* Check if this cast is already in the list */
            swig_cast_info *ocast = SWIG_TypeCheck(target_type->name, type);
#ifdef SWIGRUNTIME_DEBUG
            if (ocast) printf("SWIG_InitializeModule: skip old cast %s\n", target_type->name);
#endif
            if (!ocast) target_type = 0;
          }
        }
      }
      
      if (!target_type) {
#ifdef SWIGRUNTIME_DEBUG
        printf("SWIG_InitializeModule: adding cast %s\n", cast->type->name);
#endif
        /* Set inclusion mark for sorting */
        cast->next = cast;
        num_mapped++;
        
        if (type == cast->type) {
#ifdef SWIGRUNTIME_DEBUG
          printf("%s : self cast at pos [%li]\n", type->name, cast - first);
#endif
          if (cast - first) {
            /* Move cast to itself to the first entry in the array */
            
            swig_cast_info tmp = *cast;
            *cast = *first;
            *first = tmp;
          }
          first++;
          
        } else {
          cast->value = SWIG_Hash(cast->type->name, (unsigned int)strlen(cast->type->name));
        }
      }
      cast++;
    }
    
    if (num_mapped) {
      if (cast - first) {
        swig_cast_info *tmp;
        
        /* Sort casts by type address for binary search in SWIG_TypeCheckStruct */
        qsort(first, cast - first, sizeof(swig_cast_info), SWIG_CastCmpStruct);
        
        /* Remap back links for added entries */
        cast = swig_module.cast_initial[i] + num_mapped;
        for (tmp = first; tmp < cast; tmp++) {
          tmp->next = tmp;
        }
      }
      
      /* Set the value field of the first entry to the index of the last added entry */
      cast = swig_module.cast_initial[i];
      cast->value = num_mapped - 1;
      
      num_mapped -= (int)(first - cast);
      if (num_mapped > 1) {
        /* Sort <'next','value'> pairs by 'value' for binary search in SWIG_TypeCheck */
        
        SWIG_CastHashSort(first, num_mapped);
      }
      
      first = type->cast;
      if (first) {
        /* Link the current set into the list of cast arrays */
        cast->next = first->next;
        first->next = cast;
      } else {
        cast->next = 0;
        type->cast = cast;
      }
    }
    
    /* Set entry in modules->types array equal to the type */
    swig_module.types[i] = type;
  }
  swig_module.types[i] = 0;
  
#ifdef SWIGRUNTIME_DEBUG
  printf("**** SWIG_InitializeModule: Cast List ******\n");
  for (i = 0; i < swig_module.size; ++i) {
    int j = 0;
    swig_cast_info *cast = swig_module.cast_initial[i];
    printf("SWIG_InitializeModule: type %lu %s\n", (unsigned long)i, swig_module.type_initial[i]->name);
    while (cast->type) {
      printf("SWIG_InitializeModule: cast type %s\n", cast->type->name);
      cast++;
      ++j;
    }
    printf("---- Total casts: %d\n",j);
  }
  printf("**** SWIG_InitializeModule: Cast List ******\n");
#endif
}

/* This function will propagate the clientdata field of type to
* any new swig_type_info structures that have been added into the list
* of equivalent types.  It is like calling
* SWIG_TypeClientData(type, clientdata) a second time.
*/
SWIGRUNTIME void
SWIG_PropagateClientData(void) {
  size_t i;
  static int init_run = 0;
  
  if (init_run) return;
  init_run = 1;
  
  for (i = 0; i < swig_module.size; i++) {
    if (swig_module.types[i]->clientdata) {
      swig_cast_info *head, *cast;
      head = swig_module.types[i]->cast;
      while (head) {
        for (cast = head; (cast - head) <= head->value; cast++) {
          if (!cast->converter) {
            if (cast->type && !cast->type->clientdata)
            SWIG_TypeClientData(cast->type, swig_module.types[i]->clientdata);
          }
        }
        head = head->next;
      }
    }
  }
}

#ifdef __cplusplus
#if 0
{
  /* c-mode */
#endif
}
#endif



#ifdef __cplusplus
extern "C" {
#endif
  
  /* -----------------------------------------------------------------------------
   * constants/methods manipulation
   * ----------------------------------------------------------------------------- */
  
  /* Install Constants */
  SWIGINTERN void
  SWIG_Python_InstallConstants(PyObject *d, swig_const_info constants[]) {
    PyObject *obj = 0;
    size_t i;
    for (i = 0; constants[i].type; ++i) {
      switch(constants[i].type) {
      case SWIG_PY_POINTER:
        obj = SWIG_InternalNewPointerObj(constants[i].pvalue, *(constants[i]).ptype,0);
        break;
      case SWIG_PY_BINARY:
        obj = SWIG_NewPackedObj(constants[i].pvalue, constants[i].lvalue, *(constants[i].ptype));
        break;
      default:
        obj = 0;
        break;
      }
      if (obj) {
        PyDict_SetItemString(d, constants[i].name, obj);
        SWIG_Py_DECREF(obj);
      }
    }
  }
  
  /* -----------------------------------------------------------------------------
   * Patch %callback methods' docstrings to hold the callback ptrs
   * -----------------------------------------------------------------------------*/
  
  SWIGINTERN void
  SWIG_Python_FixMethods(PyMethodDef *methods, const swig_const_info *const_table, swig_type_info **types, swig_type_info **types_initial) {
    size_t i;
    for (i = 0; methods[i].ml_name; ++i) {
      const char *c = methods[i].ml_doc;
      if (!c) continue;
      c = strstr(c, "swig_ptr: ");
      if (c) {
        int j;
        const swig_const_info *ci = 0;
        const char *name = c + 10;
        for (j = 0; const_table[j].type; ++j) {
          if (strncmp(const_table[j].name, name, 
              strlen(const_table[j].name)) == 0) {
            ci = &(const_table[j]);
            break;
          }
        }
        if (ci) {
          void *ptr = (ci->type == SWIG_PY_POINTER) ? ci->pvalue : 0;
          if (ptr) {
            size_t shift = (ci->ptype) - types;
            swig_type_info *ty = types_initial[shift];
            size_t ldoc = (c - methods[i].ml_doc);
            size_t lptr = strlen(ty->name)+2*sizeof(void*)+2;
            char *ndoc = (char*)malloc(ldoc + lptr + 10);
            if (ndoc) {
              char *buff = ndoc;
              memcpy(buff, methods[i].ml_doc, ldoc);
              buff += ldoc;
              memcpy(buff, "swig_ptr: ", 10);
              buff += 10;
              SWIG_PackVoidPtr(buff, ptr, ty->name, lptr);
              methods[i].ml_doc = ndoc;
            }
          }
        }
      }
    }
  } 
  
#ifdef __cplusplus
}
#endif




/* -----------------------------------------------------------------------------*
 *  Partial Init method
 * -----------------------------------------------------------------------------*/

SWIGINTERN int SWIG_mod_exec(PyObject *module);

#ifdef __cplusplus
extern "C"
#endif

SWIGEXPORT 
#if PY_VERSION_HEX >= 0x03000000
PyObject*
#else
void
#endif
SWIG_init(void) {
#if PY_VERSION_HEX >= 0x03000000
  static PyModuleDef_Slot SwigSlots[] = {
    {
      Py_mod_exec, (void *)SWIG_mod_exec 
    },
#ifdef SWIGPYTHON_NOGIL
#ifdef Py_GIL_DISABLED
    {
      Py_mod_gil, Py_MOD_GIL_NOT_USED 
    },
#endif
#endif
    {
      0, NULL 
    }
  };
  
  static struct PyModuleDef SWIG_module = {
    PyModuleDef_HEAD_INIT,
    SWIG_name,
    NULL,
    0,
    SwigMethods,
    SwigSlots,
    NULL,
    NULL,
    NULL
  };
  
  return PyModuleDef_Init(&SWIG_module);
#else
  PyObject *m = Py_InitModule(SWIG_name, SwigMethods);
  if (m && SWIG_mod_exec(m) != 0) {
    Py_DECREF(m);
  }
#endif
}

SWIGINTERN int SWIG_mod_exec(PyObject *m) {
  PyObject *d, *md, *globals;
  
#if defined(SWIGPYTHON_BUILTIN)
  static SwigPyClientData SwigPyObject_clientdata = {
    0, 0, 0, 0, 0, 0, 0
  };
  static PyGetSetDef this_getset_def = {
    (char *)"this", &SwigPyBuiltin_ThisClosure, NULL, NULL, NULL
  };
  static SwigPyGetSet thisown_getset_closure = {
    SwigPyObject_own,
    SwigPyObject_own
  };
  static PyGetSetDef thisown_getset_def = {
    (char *)"thisown", SwigPyBuiltin_GetterClosure, SwigPyBuiltin_SetterClosure, NULL, &thisown_getset_closure
  };
  PyTypeObject *builtin_pytype;
  int builtin_base_count;
  swig_type_info *builtin_basetype;
  PyObject *tuple;
  PyGetSetDescrObject *static_getset;
  PyTypeObject *metatype;
  PyTypeObject *swigpyobject;
  SwigPyClientData *cd;
  PyObject *public_interface, *public_symbol;
  PyObject *this_descr;
  PyObject *thisown_descr;
  PyObject *self = 0;
  int i;
  
  (void)builtin_pytype;
  (void)builtin_base_count;
  (void)builtin_basetype;
  (void)tuple;
  (void)static_getset;
  (void)self;
  
  /* Metaclass is used to implement static member variables */
  metatype = SwigPyObjectType_Type();
  assert(metatype);
  
  SwigPyStaticVar_Type();
#endif
  
  (void)globals;
  
  /* Create singletons now to avoid potential deadlocks with multi-threaded usage after module initialization */
  SWIG_runtime_data_module();
  SWIG_This();
  SWIG_Python_TypeCache();
  SwigPyPacked_Type();
  SwigVarLink_Type();
#ifndef SWIGPYTHON_BUILTIN
  SwigPyObject_Type();
#endif
  
  /* Fix SwigMethods to carry the callback ptrs when needed */
  SWIG_Python_FixMethods(SwigMethods, swig_const_table, swig_types, swig_type_initial);
  
#ifdef SWIGPYTHON_NOGIL
#ifdef Py_GIL_DISABLED
  PyUnstable_Module_SetGIL(m, Py_MOD_GIL_NOT_USED);
#endif
#endif
  
  md = d = PyModule_GetDict(m);
  (void)md;
  
  SWIG_InitializeModule(0);
  
#ifdef SWIGPYTHON_BUILTIN
  swigpyobject = SwigPyObject_TypeOnce();
  
  SwigPyObject_stype = SWIG_MangledTypeQuery("_p_SwigPyObject");
  assert(SwigPyObject_stype);
  cd = (SwigPyClientData*) SwigPyObject_stype->clientdata;
  if (!cd) {
    SwigPyObject_stype->clientdata = &SwigPyObject_clientdata;
    SwigPyObject_clientdata.pytype = swigpyobject;
  } else if (swigpyobject->tp_basicsize != cd->pytype->tp_basicsize) {
    PyErr_SetString(PyExc_RuntimeError, "Import error: attempted to load two incompatible swig-generated modules.");
    return -1;
  }
  
  /* All objects have a 'this' attribute */
  this_descr = PyDescr_NewGetSet(SwigPyObject_Type(), &this_getset_def);
  (void)this_descr;
  
  /* All objects have a 'thisown' attribute */
  thisown_descr = PyDescr_NewGetSet(SwigPyObject_Type(), &thisown_getset_def);
  (void)thisown_descr;
  
  public_interface = PyList_New(0);
  public_symbol = 0;
  (void)public_symbol;
  
  PyDict_SetItemString(md, "__all__", public_interface);
  SWIG_Py_DECREF(public_interface);
  for (i = 0; SwigMethods[i].ml_name != NULL; ++i)
  SwigPyBuiltin_AddPublicSymbol(public_interface, SwigMethods[i].ml_name);
  for (i = 0; swig_const_table[i].name != 0; ++i)
  SwigPyBuiltin_AddPublicSymbol(public_interface, swig_const_table[i].name);
#endif
  
  SWIG_InstallConstants(d,swig_const_table);
  
  SWIG_Python_SetConstant(d, "OPENWSMAN_MAJOR",SWIG_From_int((int)(2)));
  SWIG_Python_SetConstant(d, "OPENWSMAN_MINOR",SWIG_From_int((int)(8)));
  SWIG_Python_SetConstant(d, "OPENWSMAN_PATCH",SWIG_From_int((int)(1)));
  SWIG_Python_SetConstant(d, "OPENWSMAN_VERSION",SWIG_FromCharPtr("2.8.1"));
  SWIG_Python_SetConstant(d, "XML_NS_SOAP_1_1",SWIG_FromCharPtr("http://schemas.xmlsoap.org/soap/envelope"));
  SWIG_Python_SetConstant(d, "XML_NS_SOAP_1_2",SWIG_FromCharPtr("http://www.w3.org/2003/05/soap-envelope"));
  SWIG_Python_SetConstant(d, "XML_NS_XML_NAMESPACES",SWIG_FromCharPtr("http://www.w3.org/XML/1998/namespace"));
  SWIG_Python_SetConstant(d, "XML_NS_ADDRESSING",SWIG_FromCharPtr("http://schemas.xmlsoap.org/ws/2004/08/addressing"));
  SWIG_Python_SetConstant(d, "XML_NS_DISCOVERY",SWIG_FromCharPtr("http://schemas.xmlsoap.org/ws/2004/10/discovery"));
  SWIG_Python_SetConstant(d, "XML_NS_EVENTING",SWIG_FromCharPtr("http://schemas.xmlsoap.org/ws/2004/08/eventing"));
  SWIG_Python_SetConstant(d, "XML_NS_ENUMERATION",SWIG_FromCharPtr("http://schemas.xmlsoap.org/ws/2004/09/enumeration"));
  SWIG_Python_SetConstant(d, "XML_NS_TRANSFER",SWIG_FromCharPtr("http://schemas.xmlsoap.org/ws/2004/09/transfer"));
  SWIG_Python_SetConstant(d, "XML_NS_XML_SCHEMA",SWIG_FromCharPtr("http://www.w3.org/2001/XMLSchema"));
  SWIG_Python_SetConstant(d, "XML_NS_SCHEMA_INSTANCE",SWIG_FromCharPtr("http://www.w3.org/2001/XMLSchema-instance"));
  SWIG_Python_SetConstant(d, "XML_NS_POLICY",SWIG_FromCharPtr("http://schemas.xmlsoap.org/ws/2004/09/policy"));
  SWIG_Python_SetConstant(d, "XML_NS_TRUST",SWIG_FromCharPtr("http://schemas.xmlsoap.org/ws/2005/02/trust"));
  SWIG_Python_SetConstant(d, "XML_NS_SE",SWIG_FromCharPtr("http://docs.oasis-open.org/wss/2004/01/oasis-200401-wss-wssecurity-secext-1.0.xsd"));
  SWIG_Python_SetConstant(d, "XML_NS_SCHEMA_INSTANCE_PREFIX",SWIG_FromCharPtr("xsi"));
  SWIG_Python_SetConstant(d, "XML_NS_SCHEMA_INSTANCE_NIL",SWIG_FromCharPtr("nil"));
  SWIG_Python_SetConstant(d, "XML_NS_OPENWSMAN",SWIG_FromCharPtr("http://schema.openwsman.org/2006/openwsman"));
  SWIG_Python_SetConstant(d, "XML_NS_CIM_SCHEMA",SWIG_FromCharPtr("http://schemas.dmtf.org/wbem/wscim/1/common"));
  SWIG_Python_SetConstant(d, "XML_NS_CIM_CLASS",SWIG_FromCharPtr("http://schemas.dmtf.org/wbem/wscim/1/cim-schema/2"));
  SWIG_Python_SetConstant(d, "XML_NS_CIM_BINDING",SWIG_FromCharPtr("http://schemas.dmtf.org/wbem/wsman/1/cimbinding.xsd"));
  SWIG_Python_SetConstant(d, "XML_NS_CIM_INTRINSIC",SWIG_FromCharPtr("http://schemas.openwsman.org/wbem/wscim/1/intrinsic"));
  SWIG_Python_SetConstant(d, "XML_NS_WS_MAN",SWIG_FromCharPtr("http://schemas.dmtf.org/wbem/wsman/1/wsman.xsd"));
  SWIG_Python_SetConstant(d, "XML_NS_WSMAN_FAULT_DETAIL",SWIG_FromCharPtr("http://schemas.dmtf.org/wbem/wsman/1/wsman/faultDetail"));
  SWIG_Python_SetConstant(d, "XML_NS_WS_MAN_CAT",SWIG_FromCharPtr("http://schemas.xmlsoap.org/ws/2005/06/wsmancat"));
  SWIG_Python_SetConstant(d, "XML_NS_WSMAN_ID",SWIG_FromCharPtr("http://schemas.dmtf.org/wbem/wsman/identity/1/wsmanidentity.xsd"));
  SWIG_Python_SetConstant(d, "SOAP1_2_CONTENT_TYPE",SWIG_FromCharPtr("application/soap+xml;charset=UTF-8"));
  SWIG_Python_SetConstant(d, "SOAP_CONTENT_TYPE",SWIG_FromCharPtr("application/soap+xml"));
  SWIG_Python_SetConstant(d, "CIMXML_CONTENT_TYPE",SWIG_FromCharPtr("application/xml"));
  SWIG_Python_SetConstant(d, "SOAP_SKIP_DEF_FILTERS",SWIG_From_int((int)(0x01)));
  SWIG_Python_SetConstant(d, "SOAP_ACTION_PREFIX",SWIG_From_int((int)(0x02)));
  SWIG_Python_SetConstant(d, "SOAP_ONE_WAY_OP",SWIG_From_int((int)(0x04)));
  SWIG_Python_SetConstant(d, "SOAP_NO_RESP_OP",SWIG_From_int((int)(0x08)));
  SWIG_Python_SetConstant(d, "SOAP_DONT_KEEP_INDOC",SWIG_From_int((int)(0x10)));
  SWIG_Python_SetConstant(d, "SOAP_CLIENT_RESPONSE",SWIG_From_int((int)(0x20)));
  SWIG_Python_SetConstant(d, "SOAP_CUSTOM_DISPATCHER",SWIG_From_int((int)(0x40)));
  SWIG_Python_SetConstant(d, "SOAP_IDENTIFY_DISPATCH",SWIG_From_int((int)(0x80)));
  SWIG_Python_SetConstant(d, "WSMID_IDENTIFY",SWIG_FromCharPtr("Identify"));
  SWIG_Python_SetConstant(d, "WSMID_IDENTIFY_RESPONSE",SWIG_FromCharPtr("IdentifyResponse"));
  SWIG_Python_SetConstant(d, "WSMID_PROTOCOL_VERSION",SWIG_FromCharPtr("ProtocolVersion"));
  SWIG_Python_SetConstant(d, "WSMID_PRODUCT_VENDOR",SWIG_FromCharPtr("ProductVendor"));
  SWIG_Python_SetConstant(d, "WSMID_PRODUCT_VERSION",SWIG_FromCharPtr("ProductVersion"));
  SWIG_Python_SetConstant(d, "XML_SCHEMA_NIL",SWIG_FromCharPtr("nil"));
  SWIG_Python_SetConstant(d, "WSA_TO_ANONYMOUS",SWIG_FromCharPtr("http://schemas.xmlsoap.org/ws/2004/08/addressing/role/anonymous"));
  SWIG_Python_SetConstant(d, "WSA_MESSAGE_ID",SWIG_FromCharPtr("MessageID"));
  SWIG_Python_SetConstant(d, "WSA_ADDRESS",SWIG_FromCharPtr("Address"));
  SWIG_Python_SetConstant(d, "WSA_EPR",SWIG_FromCharPtr("EndpointReference"));
  SWIG_Python_SetConstant(d, "WSA_ACTION",SWIG_FromCharPtr("Action"));
  SWIG_Python_SetConstant(d, "WSA_RELATES_TO",SWIG_FromCharPtr("RelatesTo"));
  SWIG_Python_SetConstant(d, "WSA_TO",SWIG_FromCharPtr("To"));
  SWIG_Python_SetConstant(d, "WSA_REPLY_TO",SWIG_FromCharPtr("ReplyTo"));
  SWIG_Python_SetConstant(d, "WSA_FROM",SWIG_FromCharPtr("From"));
  SWIG_Python_SetConstant(d, "WSA_FAULT_TO",SWIG_FromCharPtr("FaultTo"));
  SWIG_Python_SetConstant(d, "WSA_REFERENCE_PROPERTIES",SWIG_FromCharPtr("ReferenceProperties"));
  SWIG_Python_SetConstant(d, "WSA_REFERENCE_PARAMETERS",SWIG_FromCharPtr("ReferenceParameters"));
  SWIG_Python_SetConstant(d, "WSA_ACTION_FAULT",SWIG_FromCharPtr("http://schemas.xmlsoap.org/ws/2004/08/addressing/fault"));
  SWIG_Python_SetConstant(d, "SOAP_ENVELOPE",SWIG_FromCharPtr("Envelope"));
  SWIG_Python_SetConstant(d, "SOAP_HEADER",SWIG_FromCharPtr("Header"));
  SWIG_Python_SetConstant(d, "SOAP_BODY",SWIG_FromCharPtr("Body"));
  SWIG_Python_SetConstant(d, "SOAP_FAULT",SWIG_FromCharPtr("Fault"));
  SWIG_Python_SetConstant(d, "SOAP_CODE",SWIG_FromCharPtr("Code"));
  SWIG_Python_SetConstant(d, "SOAP_VALUE",SWIG_FromCharPtr("Value"));
  SWIG_Python_SetConstant(d, "SOAP_SUBCODE",SWIG_FromCharPtr("Subcode"));
  SWIG_Python_SetConstant(d, "SOAP_REASON",SWIG_FromCharPtr("Reason"));
  SWIG_Python_SetConstant(d, "SOAP_TEXT",SWIG_FromCharPtr("Text"));
  SWIG_Python_SetConstant(d, "SOAP_LANG",SWIG_FromCharPtr("lang"));
  SWIG_Python_SetConstant(d, "SOAP_DETAIL",SWIG_FromCharPtr("Detail"));
  SWIG_Python_SetConstant(d, "SOAP_FAULT_DETAIL",SWIG_FromCharPtr("FaultDetail"));
  SWIG_Python_SetConstant(d, "SOAP_MUST_UNDERSTAND",SWIG_FromCharPtr("mustUnderstand"));
  SWIG_Python_SetConstant(d, "SOAP_VERSION_MISMATCH",SWIG_FromCharPtr("VersionMismatch"));
  SWIG_Python_SetConstant(d, "SOAP_UPGRADE",SWIG_FromCharPtr("Upgrade"));
  SWIG_Python_SetConstant(d, "SOAP_SUPPORTED_ENVELOPE",SWIG_FromCharPtr("SupportedEnvelope"));
  SWIG_Python_SetConstant(d, "TRANSFER_ACTION_GET",SWIG_FromCharPtr("http://schemas.xmlsoap.org/ws/2004/09/transfer/Get"));
  SWIG_Python_SetConstant(d, "TRANSFER_ACTION_GETRESPONSE",SWIG_FromCharPtr("http://schemas.xmlsoap.org/ws/2004/09/transfer/GetResponse"));
  SWIG_Python_SetConstant(d, "TRANSFER_GET",SWIG_FromCharPtr("Get"));
  SWIG_Python_SetConstant(d, "TRANSFER_GET_RESP",SWIG_FromCharPtr("GetResponse"));
  SWIG_Python_SetConstant(d, "TRANSFER_ACTION_PUT",SWIG_FromCharPtr("http://schemas.xmlsoap.org/ws/2004/09/transfer/Put"));
  SWIG_Python_SetConstant(d, "TRANSFER_ACTION_PUTRESPONSE",SWIG_FromCharPtr("http://schemas.xmlsoap.org/ws/2004/09/transfer/PutResponse"));
  SWIG_Python_SetConstant(d, "TRANSFER_PUT",SWIG_FromCharPtr("Put"));
  SWIG_Python_SetConstant(d, "TRANSFER_PUT_RESP",SWIG_FromCharPtr("PutResponse"));
  SWIG_Python_SetConstant(d, "TRANSFER_ACTION_CREATE",SWIG_FromCharPtr("http://schemas.xmlsoap.org/ws/2004/09/transfer/Create"));
  SWIG_Python_SetConstant(d, "TRANSFER_CREATE",SWIG_FromCharPtr("Create"));
  SWIG_Python_SetConstant(d, "TRANSFER_ACTION_DELETE",SWIG_FromCharPtr("http://schemas.xmlsoap.org/ws/2004/09/transfer/Delete"));
  SWIG_Python_SetConstant(d, "TRANSFER_DELETE",SWIG_FromCharPtr("Delete"));
  SWIG_Python_SetConstant(d, "TRANSFER_ACTION_DELETERESPONSE",SWIG_FromCharPtr("http://schemas.xmlsoap.org/ws/2004/09/transfer/DeleteResponse"));
  SWIG_Python_SetConstant(d, "TRANSFER_DELETE_RESP",SWIG_FromCharPtr("DeleteResponse"));
  SWIG_Python_SetConstant(d, "WSXF_ACTION_FAULT",SWIG_FromCharPtr("http://schemas.xmlsoap.org/ws/2004/09/transfer/fault"));
  SWIG_Python_SetConstant(d, "ENUM_ACTION_ENUMERATE",SWIG_FromCharPtr("http://schemas.xmlsoap.org/ws/2004/09/enumeration/Enumerate"));
  SWIG_Python_SetConstant(d, "ENUM_ACTION_ENUMERATERESPONSE",SWIG_FromCharPtr("http://schemas.xmlsoap.org/ws/2004/09/enumeration/EnumerateResponse"));
  SWIG_Python_SetConstant(d, "WSENUM_ENUMERATE",SWIG_FromCharPtr("Enumerate"));
  SWIG_Python_SetConstant(d, "WSENUM_ENUMERATE_RESP",SWIG_FromCharPtr("EnumerateResponse"));
  SWIG_Python_SetConstant(d, "ENUM_ACTION_RELEASE",SWIG_FromCharPtr("http://schemas.xmlsoap.org/ws/2004/09/enumeration/Release"));
  SWIG_Python_SetConstant(d, "WSENUM_RELEASE",SWIG_FromCharPtr("Release"));
  SWIG_Python_SetConstant(d, "WSENUM_RELEASE_RESP",SWIG_FromCharPtr("ReleaseResponse"));
  SWIG_Python_SetConstant(d, "ENUM_ACTION_PULL",SWIG_FromCharPtr("http://schemas.xmlsoap.org/ws/2004/09/enumeration/Pull"));
  SWIG_Python_SetConstant(d, "WSENUM_PULL",SWIG_FromCharPtr("Pull"));
  SWIG_Python_SetConstant(d, "WSENUM_PULL_RESP",SWIG_FromCharPtr("PullResponse"));
  SWIG_Python_SetConstant(d, "ENUM_ACTION_RENEW",SWIG_FromCharPtr("http://schemas.xmlsoap.org/ws/2004/09/enumeration/Renew"));
  SWIG_Python_SetConstant(d, "ENUM_ACTION_GETSTATUS",SWIG_FromCharPtr("http://schemas.xmlsoap.org/ws/2004/09/enumeration/GetStatus"));
  SWIG_Python_SetConstant(d, "ENUM_ACTION_ENUMEND",SWIG_FromCharPtr("http://schemas.xmlsoap.org/ws/2004/09/enumeration/EnumerationEnd"));
  SWIG_Python_SetConstant(d, "EVT_ACTION_SUBSCRIBE",SWIG_FromCharPtr("http://schemas.xmlsoap.org/ws/2004/08/eventing/Subscribe"));
  SWIG_Python_SetConstant(d, "WSEVENT_SUBSCRIBE",SWIG_FromCharPtr("Subscribe"));
  SWIG_Python_SetConstant(d, "WSEVENT_SUBSCRIBE_RESP",SWIG_FromCharPtr("SubscribeResponse"));
  SWIG_Python_SetConstant(d, "EVT_ACTION_PULL",SWIG_FromCharPtr("http://schemas.dmtf.org/wbem/wsman/1/wsman/Pull"));
  SWIG_Python_SetConstant(d, "EVT_ACTION_GETSTATUS",SWIG_FromCharPtr("http://schemas.xmlsoap.org/ws/2004/08/eventing/GetStaus"));
  SWIG_Python_SetConstant(d, "EVT_ACTION_UNSUBSCRIBE",SWIG_FromCharPtr("http://schemas.xmlsoap.org/ws/2004/08/eventing/Unsubscribe"));
  SWIG_Python_SetConstant(d, "WSEVENT_UNSUBSCRIBE",SWIG_FromCharPtr("Unsubscribe"));
  SWIG_Python_SetConstant(d, "WSEVENT_UNSUBSCRIBE_RESP",SWIG_FromCharPtr("UnsubscribeResponse"));
  SWIG_Python_SetConstant(d, "EVT_ACTION_SUBEND",SWIG_FromCharPtr("http://schemas.xmlsoap.org/ws/2004/08/eventing/SubscriptionEnd"));
  SWIG_Python_SetConstant(d, "EVT_ACTION_RENEW",SWIG_FromCharPtr("http://schemas.xmlsoap.org/ws/2004/08/eventing/Renew"));
  SWIG_Python_SetConstant(d, "WSEVENT_RENEW",SWIG_FromCharPtr("Renew"));
  SWIG_Python_SetConstant(d, "WSEVENT_RENEW_RESP",SWIG_FromCharPtr("RenewResponse"));
  SWIG_Python_SetConstant(d, "WSMAN_ACTION_EVENTS",SWIG_FromCharPtr("http://schemas.xmlsoap.org/wbmem/wsman/1/wsman/Events"));
  SWIG_Python_SetConstant(d, "WSMAN_ACTION_HEARTBEAT",SWIG_FromCharPtr("http://schemas.xmlsoap.org/wbmem/wsman/1/wsman/Heartbeat"));
  SWIG_Python_SetConstant(d, "WSMAN_ACTION_DROPPEDEVENTS",SWIG_FromCharPtr("http://schemas.xmlsoap.org/wbmem/wsman/1/wsman/DroppedEvents"));
  SWIG_Python_SetConstant(d, "WSMAN_ACTION_ACK",SWIG_FromCharPtr("http://schemas.xmlsoap.org/wbmem/wsman/1/wsman/Ack"));
  SWIG_Python_SetConstant(d, "WSMAN_ACTION_EVENT",SWIG_FromCharPtr("http://schemas.xmlsoap.org/wbmem/wsman/1/wsman/Event"));
  SWIG_Python_SetConstant(d, "WSENUM_ACTION_FAULT",SWIG_FromCharPtr("http://schemas.xmlsoap.org/ws/2004/09/enumeration/fault"));
  SWIG_Python_SetConstant(d, "WSENUM_RENEW",SWIG_FromCharPtr("Renew"));
  SWIG_Python_SetConstant(d, "WSENUM_RENEW_RESP",SWIG_FromCharPtr("RenewResponse"));
  SWIG_Python_SetConstant(d, "WSENUM_GET_STATUS",SWIG_FromCharPtr("GetStatus"));
  SWIG_Python_SetConstant(d, "WSENUM_GET_STATUS_RESP",SWIG_FromCharPtr("GetStatusResponse"));
  SWIG_Python_SetConstant(d, "WSMAN_ACTION_FAULT",SWIG_FromCharPtr("http://schemas.dmtf.org/wbem/wsman/1/wsman/fault"));
  SWIG_Python_SetConstant(d, "WSENUM_END_TO",SWIG_FromCharPtr("EndTo"));
  SWIG_Python_SetConstant(d, "WSENUM_EXPIRES",SWIG_FromCharPtr("Expires"));
  SWIG_Python_SetConstant(d, "WSENUM_FILTER",SWIG_FromCharPtr("Filter"));
  SWIG_Python_SetConstant(d, "WSENUM_DIALECT",SWIG_FromCharPtr("Dialect"));
  SWIG_Python_SetConstant(d, "WSENUM_ENUMERATION_CONTEXT",SWIG_FromCharPtr("EnumerationContext"));
  SWIG_Python_SetConstant(d, "WSENUM_MAX_TIME",SWIG_FromCharPtr("MaxTime"));
  SWIG_Python_SetConstant(d, "WSENUM_MAX_ELEMENTS",SWIG_FromCharPtr("MaxElements"));
  SWIG_Python_SetConstant(d, "WSENUM_MAX_CHARACTERS",SWIG_FromCharPtr("MaxCharacters"));
  SWIG_Python_SetConstant(d, "WSENUM_ITEMS",SWIG_FromCharPtr("Items"));
  SWIG_Python_SetConstant(d, "WSENUM_END_OF_SEQUENCE",SWIG_FromCharPtr("EndOfSequence"));
  SWIG_Python_SetConstant(d, "WSENUM_ENUMERATION_END",SWIG_FromCharPtr("EnumerationEnd"));
  SWIG_Python_SetConstant(d, "WSENUM_REASON",SWIG_FromCharPtr("Reason"));
  SWIG_Python_SetConstant(d, "WSENUM_CODE",SWIG_FromCharPtr("Code"));
  SWIG_Python_SetConstant(d, "WSENUM_SOURCE_SHUTTING_DOWN",SWIG_FromCharPtr("SourceShuttingDown"));
  SWIG_Python_SetConstant(d, "WSENUM_SOURCE_CANCELING",SWIG_FromCharPtr("SourceCanceling"));
  SWIG_Python_SetConstant(d, "WSEVENT_DELIVERY",SWIG_FromCharPtr("Delivery"));
  SWIG_Python_SetConstant(d, "WSEVENT_NOTIFY_TO",SWIG_FromCharPtr("NotifyTo"));
  SWIG_Python_SetConstant(d, "WSEVENT_ENDTO",SWIG_FromCharPtr("EndTo"));
  SWIG_Python_SetConstant(d, "WSEVENT_EXPIRES",SWIG_FromCharPtr("Expires"));
  SWIG_Python_SetConstant(d, "WSEVENT_DELIVERY_MODE",SWIG_FromCharPtr("Mode"));
  SWIG_Python_SetConstant(d, "WSEVENT_SUBSCRIPTION_MANAGER",SWIG_FromCharPtr("SubscriptionManager"));
  SWIG_Python_SetConstant(d, "WSEVENT_IDENTIFIER",SWIG_FromCharPtr("Identifier"));
  SWIG_Python_SetConstant(d, "WSEVENT_FILTER",SWIG_FromCharPtr("Filter"));
  SWIG_Python_SetConstant(d, "WSEVENT_DIALECT",SWIG_FromCharPtr("Dialect"));
  SWIG_Python_SetConstant(d, "WSEVENT_ACTION_FAULT",SWIG_FromCharPtr("http://schemas.xmlsoap.org/ws/2004/08/eventing/fault"));
  SWIG_Python_SetConstant(d, "WSEVENT_DELIVERY_MODE_PUSH",SWIG_FromCharPtr("http://schemas.xmlsoap.org/ws/2004/08/eventing/DeliveryModes/Push"));
  SWIG_Python_SetConstant(d, "WSEVENT_DELIVERY_MODE_PUSHWITHACK",SWIG_FromCharPtr("http://schemas.dmtf.org/wbem/wsman/1/wsman/PushWithAck"));
  SWIG_Python_SetConstant(d, "WSEVENT_DELIVERY_MODE_EVENTS",SWIG_FromCharPtr("http://schemas.dmtf.org/wbem/wsman/1/wsman/Events"));
  SWIG_Python_SetConstant(d, "WSEVENT_DELIVERY_MODE_PULL",SWIG_FromCharPtr("http://schemas.dmtf.org/wbem/wsman/1/wsman/Pull"));
  SWIG_Python_SetConstant(d, "WSMB_ASSOCIATED_INSTANCES",SWIG_FromCharPtr("AssociatedInstances"));
  SWIG_Python_SetConstant(d, "WSMB_ASSOCIATION_INSTANCES",SWIG_FromCharPtr("AssociationInstances"));
  SWIG_Python_SetConstant(d, "WSMB_OBJECT",SWIG_FromCharPtr("Object"));
  SWIG_Python_SetConstant(d, "WSMB_ASSOCIATION_CLASS_NAME",SWIG_FromCharPtr("AssociationClassName"));
  SWIG_Python_SetConstant(d, "WSMB_RESULT_CLASS_NAME",SWIG_FromCharPtr("ResultClassName"));
  SWIG_Python_SetConstant(d, "WSMB_ROLE",SWIG_FromCharPtr("Role"));
  SWIG_Python_SetConstant(d, "WSMB_RESULT_ROLE",SWIG_FromCharPtr("ResultRole"));
  SWIG_Python_SetConstant(d, "WSMB_INCLUDE_RESULT_PROPERTY",SWIG_FromCharPtr("IncludeResultProperty"));
  SWIG_Python_SetConstant(d, "CIM_RESOURCE_NS_PREFIX",SWIG_FromCharPtr("p"));
  SWIG_Python_SetConstant(d, "WSM_SYSTEM",SWIG_FromCharPtr("System"));
  SWIG_Python_SetConstant(d, "WSM_LOCALE",SWIG_FromCharPtr("Locale"));
  SWIG_Python_SetConstant(d, "WSM_RESOURCE_URI",SWIG_FromCharPtr("ResourceURI"));
  SWIG_Python_SetConstant(d, "WSM_SELECTOR_SET",SWIG_FromCharPtr("SelectorSet"));
  SWIG_Python_SetConstant(d, "WSM_SELECTOR",SWIG_FromCharPtr("Selector"));
  SWIG_Python_SetConstant(d, "WSM_NAME",SWIG_FromCharPtr("Name"));
  SWIG_Python_SetConstant(d, "WSM_REQUEST_TOTAL",SWIG_FromCharPtr("RequestTotalItemsCountEstimate"));
  SWIG_Python_SetConstant(d, "WSM_TOTAL_ESTIMATE",SWIG_FromCharPtr("TotalItemsCountEstimate"));
  SWIG_Python_SetConstant(d, "WSM_OPTIMIZE_ENUM",SWIG_FromCharPtr("OptimizeEnumeration"));
  SWIG_Python_SetConstant(d, "WSM_MAX_ELEMENTS",SWIG_FromCharPtr("MaxElements"));
  SWIG_Python_SetConstant(d, "WSM_ENUM_EPR",SWIG_FromCharPtr("EnumerateEPR"));
  SWIG_Python_SetConstant(d, "WSM_ENUM_OBJ_AND_EPR",SWIG_FromCharPtr("EnumerateObjectAndEPR"));
  SWIG_Python_SetConstant(d, "WSM_ENUM_MODE",SWIG_FromCharPtr("EnumerationMode"));
  SWIG_Python_SetConstant(d, "WSM_ITEM",SWIG_FromCharPtr("Item"));
  SWIG_Python_SetConstant(d, "WSM_FRAGMENT_TRANSFER",SWIG_FromCharPtr("FragmentTransfer"));
  SWIG_Python_SetConstant(d, "WSM_XML_FRAGMENT",SWIG_FromCharPtr("XmlFragment"));
  SWIG_Python_SetConstant(d, "WSM_OPTION_SET",SWIG_FromCharPtr("OptionSet"));
  SWIG_Python_SetConstant(d, "WSM_OPTION",SWIG_FromCharPtr("Option"));
  SWIG_Python_SetConstant(d, "WSM_TOTAL",SWIG_FromCharPtr("Total"));
  SWIG_Python_SetConstant(d, "WSM_HEARTBEATS",SWIG_FromCharPtr("Heartbeats"));
  SWIG_Python_SetConstant(d, "WSM_EVENTS",SWIG_FromCharPtr("Events"));
  SWIG_Python_SetConstant(d, "WSM_ACTION",SWIG_FromCharPtr("Action"));
  SWIG_Python_SetConstant(d, "WSM_EVENT",SWIG_FromCharPtr("Event"));
  SWIG_Python_SetConstant(d, "WSM_ACKREQUESTED",SWIG_FromCharPtr("AckRequested"));
  SWIG_Python_SetConstant(d, "WSM_MAX_ENVELOPE_SIZE",SWIG_FromCharPtr("MaxEnvelopeSize"));
  SWIG_Python_SetConstant(d, "WSM_OPERATION_TIMEOUT",SWIG_FromCharPtr("OperationTimeout"));
  SWIG_Python_SetConstant(d, "WSM_FAULT_SUBCODE",SWIG_FromCharPtr("FaultSubCode"));
  SWIG_Python_SetConstant(d, "WSM_FILTER",SWIG_FromCharPtr("Filter"));
  SWIG_Python_SetConstant(d, "WSM_DIALECT",SWIG_FromCharPtr("Dialect"));
  SWIG_Python_SetConstant(d, "WSM_CONTENTCODING",SWIG_FromCharPtr("ContentEncoding"));
  SWIG_Python_SetConstant(d, "WSM_CONNECTIONRETRY",SWIG_FromCharPtr("ConnectionRetry"));
  SWIG_Python_SetConstant(d, "WSM_SENDBOOKMARKS",SWIG_FromCharPtr("SendBookmarks"));
  SWIG_Python_SetConstant(d, "WSM_BOOKMARK",SWIG_FromCharPtr("Bookmark"));
  SWIG_Python_SetConstant(d, "WSM_DROPPEDEVENTS",SWIG_FromCharPtr("DroppedEvents"));
  SWIG_Python_SetConstant(d, "WSM_AUTH",SWIG_FromCharPtr("Auth"));
  SWIG_Python_SetConstant(d, "WSM_PROFILE",SWIG_FromCharPtr("Profile"));
  SWIG_Python_SetConstant(d, "WSM_CERTIFICATETHUMBPRINT",SWIG_FromCharPtr("CertificateThumbprint"));
  SWIG_Python_SetConstant(d, "WSM_DEFAULTBOOKMARK",SWIG_FromCharPtr("http://schemas.dmtf.org/wbem/wsman/1/wsman/bookmark/earliest"));
  SWIG_Python_SetConstant(d, "WXF_RESOURCE_CREATED",SWIG_FromCharPtr("ResourceCreated"));
  SWIG_Python_SetConstant(d, "WSMB_POLYMORPHISM_MODE",SWIG_FromCharPtr("PolymorphismMode"));
  SWIG_Python_SetConstant(d, "WSMB_INCLUDE_SUBCLASS_PROP",SWIG_FromCharPtr("IncludeSubClassProperties"));
  SWIG_Python_SetConstant(d, "WSMB_EXCLUDE_SUBCLASS_PROP",SWIG_FromCharPtr("ExcludeSubClassProperties"));
  SWIG_Python_SetConstant(d, "WSMB_NONE",SWIG_FromCharPtr("None"));
  SWIG_Python_SetConstant(d, "WSMB_DERIVED_REPRESENTATION",SWIG_FromCharPtr("DerivedRepresentation"));
  SWIG_Python_SetConstant(d, "WSMB_ACTION_FAULT",SWIG_FromCharPtr("http://schemas.dmtf.org/wbem/wsman/1/cimbinding/fault"));
  SWIG_Python_SetConstant(d, "WSMB_SHOW_EXTENSION",SWIG_FromCharPtr("ShowExtensions"));
  SWIG_Python_SetConstant(d, "WSMB_EXCLUDE_NIL_PROPS",SWIG_FromCharPtr("ExcludeNilProperties"));
  SWIG_Python_SetConstant(d, "WSMANCAT_RESOURCE",SWIG_FromCharPtr("Resource"));
  SWIG_Python_SetConstant(d, "WSMANCAT_RESOURCE_URI",SWIG_FromCharPtr("ResourceUri"));
  SWIG_Python_SetConstant(d, "WSMANCAT_VERSION",SWIG_FromCharPtr("Version"));
  SWIG_Python_SetConstant(d, "WSMANCAT_NOTES",SWIG_FromCharPtr("Notes"));
  SWIG_Python_SetConstant(d, "WSMANCAT_VENDOR",SWIG_FromCharPtr("Vendor"));
  SWIG_Python_SetConstant(d, "WSMANCAT_DISPLAY_NAME",SWIG_FromCharPtr("DisplayName"));
  SWIG_Python_SetConstant(d, "WSMANCAT_KEYWORDS",SWIG_FromCharPtr("Keywords"));
  SWIG_Python_SetConstant(d, "WSMANCAT_ACCESS",SWIG_FromCharPtr("Access"));
  SWIG_Python_SetConstant(d, "WSMANCAT_RELATIONSHIPS",SWIG_FromCharPtr("Relationsships"));
  SWIG_Python_SetConstant(d, "WSMANCAT_COMPLIANCE",SWIG_FromCharPtr("Compliance"));
  SWIG_Python_SetConstant(d, "WSMANCAT_OPERATION",SWIG_FromCharPtr("Operation"));
  SWIG_Python_SetConstant(d, "WSMANCAT_SELECTOR_SET",SWIG_FromCharPtr("SelectorSet"));
  SWIG_Python_SetConstant(d, "WSMANCAT_SELECTOR",SWIG_FromCharPtr("Selector"));
  SWIG_Python_SetConstant(d, "WSMANCAT_OPTION_SET",SWIG_FromCharPtr("OptionSet"));
  SWIG_Python_SetConstant(d, "WSMANCAT_ACTION",SWIG_FromCharPtr("Action"));
  SWIG_Python_SetConstant(d, "WSMANCAT_SELECTOR_SET_REF",SWIG_FromCharPtr("SelectorSetRef"));
  SWIG_Python_SetConstant(d, "WSMANCAT_LOCATION",SWIG_FromCharPtr("Location"));
  SWIG_Python_SetConstant(d, "WSMANCAT_NAME",SWIG_FromCharPtr("Name"));
  SWIG_Python_SetConstant(d, "WSMANCAT_TYPE",SWIG_FromCharPtr("Type"));
  SWIG_Python_SetConstant(d, "WSM_SELECTOR_FILTER_DIALECT",SWIG_FromCharPtr("http://schemas.dmtf.org/wbem/wsman/1/wsman/SelectorFilter"));
  SWIG_Python_SetConstant(d, "WSM_WQL_FILTER_DIALECT",SWIG_FromCharPtr("http://schemas.microsoft.com/wbem/wsman/1/WQL"));
  SWIG_Python_SetConstant(d, "WSM_XPATH_FILTER_DIALECT",SWIG_FromCharPtr("http://www.w3.org/TR/1999/REC-xpath-19991116"));
  SWIG_Python_SetConstant(d, "WSM_CQL_FILTER_DIALECT",SWIG_FromCharPtr("http://schemas.dmtf.org/wbem/cql/1/dsp0202.pdf"));
  SWIG_Python_SetConstant(d, "WSM_ASSOCIATION_FILTER_DIALECT",SWIG_FromCharPtr("http://schemas.dmtf.org/wbem/wsman/1/cimbinding/associationFilter"));
  SWIG_Python_SetConstant(d, "WSM_XPATH_EVENTROOT_FILTER",SWIG_FromCharPtr("http://schemas.dmtf.org/wbem/wsman/1/wsman/filter/eventRootXPath"));
  SWIG_Python_SetConstant(d, "WSFW_RESPONSE_STR",SWIG_FromCharPtr("Response"));
  SWIG_Python_SetConstant(d, "WSFW_INDOC",SWIG_FromCharPtr("indoc"));
  SWIG_Python_SetConstant(d, "WSFW_ENUM_PREFIX",SWIG_FromCharPtr("_en."));
  SWIG_Python_SetConstant(d, "CIM_NAMESPACE_SELECTOR",SWIG_FromCharPtr("__cimnamespace"));
  SWIG_Python_SetConstant(d, "CIM_ALL_AVAILABLE_CLASSES",SWIG_FromCharPtr("http://schemas.dmtf.org/wbem/wscim/1/*"));
  SWIG_Python_SetConstant(d, "XML_NS_CIM_ALL_CLASS",SWIG_FromCharPtr("http://schemas.dmtf.org/wbem/wscim/1"));
  SWIG_Python_SetConstant(d, "CIM_ACTION_ENUMERATE_CLASS_NAMES",SWIG_FromCharPtr("EnumerateClassNames"));
  SWIG_Python_SetConstant(d, "CIM_ACTION_ENUMERATE_INSTANCE_NAMES",SWIG_FromCharPtr("EnumerateInstanceNames"));
  SWIG_Python_SetConstant(d, "CIM_ACTION_ENUMERATE_CLASSES",SWIG_FromCharPtr("EnumerateClasses"));
  SWIG_Python_SetConstant(d, "CIM_ACTION_GET_CLASS",SWIG_FromCharPtr("GetClass"));
  SWIG_Python_SetConstant(d, "CIM_ACTION_DELETE_CLASS",SWIG_FromCharPtr("DeleteClass"));
  SWIG_Python_SetConstant(d, "WST_ISSUEDTOKENS",SWIG_FromCharPtr("IssuedTokens"));
  SWIG_Python_SetConstant(d, "WST_REQUESTSECURITYTOKENRESPONSE",SWIG_FromCharPtr("RequestSecurityTokenResponse"));
  SWIG_Python_SetConstant(d, "WST_TOKENTYPE",SWIG_FromCharPtr("TokenType"));
  SWIG_Python_SetConstant(d, "WST_REQUESTEDSECURITYTOKEN",SWIG_FromCharPtr("RequestedSecurityToken"));
  SWIG_Python_SetConstant(d, "WSSE_USERNAMETOKEN",SWIG_FromCharPtr("UsernameToken"));
  SWIG_Python_SetConstant(d, "WSSE_USERNAME",SWIG_FromCharPtr("Username"));
  SWIG_Python_SetConstant(d, "WSSE_PASSWORD",SWIG_FromCharPtr("Password"));
  SWIG_Python_SetConstant(d, "WSP_APPLIESTO",SWIG_FromCharPtr("AppliesTo"));
  SWIG_Python_SetConstant(d, "WST_USERNAMETOKEN",SWIG_FromCharPtr("http://docs.oasis-open.org/wss/2004/01/oasis-200401-wss-username-token-profile-1.0#UsernameToken"));
  SWIG_Python_SetConstant(d, "WST_CERTIFICATETHUMBPRINT",SWIG_FromCharPtr("http://schemas.dmtf.org/wbem/wsman/1/wsman/token/certificateThumbprint"));
  SWIG_Python_SetConstant(d, "WSMAN_SECURITY_PROFILE_HTTP_BASIC",SWIG_FromCharPtr("http://schemas.dmtf.org/wbem/wsman/1/wsman/secprofile/http/basic"));
  SWIG_Python_SetConstant(d, "WSMAN_SECURITY_PROFILE_HTTP_DIGEST",SWIG_FromCharPtr("http://schemas.dmtf.org/wbem/wsman/1/wsman/secprofile/http/digest"));
  SWIG_Python_SetConstant(d, "WSMAN_SECURITY_PROFILE_HTTPS_BASIC",SWIG_FromCharPtr("http://schemas.dmtf.org/wbem/wsman/1/wsman/secprofile/https/basic"));
  SWIG_Python_SetConstant(d, "WSMAN_SECURITY_PROFILE_HTTPS_DIGEST",SWIG_FromCharPtr("http://schemas.dmtf.org/wbem/wsman/1/wsman/secprofile/https/digest"));
  SWIG_Python_SetConstant(d, "WSMAN_SECURITY_PROFILE_HTTPS_MUTUAL",SWIG_FromCharPtr("http://schemas.dmtf.org/wbem/wsman/1/wsman/secprofile/https/mutual"));
  SWIG_Python_SetConstant(d, "WSMAN_SECURITY_PROFILE_HTTPS_MUTUAL_BASIC",SWIG_FromCharPtr("http://schemas.dmtf.org/wbem/wsman/1/wsman/secprofile/https/mutual/basic"));
  SWIG_Python_SetConstant(d, "WSMAN_SECURITY_PROFILE_HTTPS_MUTUAL_DIGEST",SWIG_FromCharPtr("http://schemas.dmtf.org/wbem/wsman/1/wsman/secprofile/https/mutual/digest"));
  SWIG_Python_SetConstant(d, "WSMAN_SECURITY_PROFILE_HTTPS_SPNEGO_KERBEROS",SWIG_FromCharPtr("http://schemas.dmtf.org/wbem/wsman/1/wsman/secprofile/https/spnego-kerberos"));
  SWIG_Python_SetConstant(d, "WSMAN_SECURITY_PROFILE_HTTPS_MUTUAL_SPNEGO_KERBEROS",SWIG_FromCharPtr("http://schemas.dmtf.org/wbem/wsman/1/wsman/secprofile/https/mutual/spnego-kerberos"));
  SWIG_Python_SetConstant(d, "WSMAN_SECURITY_PROFILE_HTTP_SPNEGO_KERBEROS",SWIG_FromCharPtr("http://schemas.dmtf.org/wbem/wsman/1/wsman/secprofile/http/spnego-kerberos"));
  SWIG_Python_SetConstant(d, "FLAG_NONE",SWIG_From_int((int)(0x0000)));
  SWIG_Python_SetConstant(d, "FLAG_ENUMERATION_COUNT_ESTIMATION",SWIG_From_int((int)(0x0001)));
  SWIG_Python_SetConstant(d, "FLAG_ENUMERATION_OPTIMIZATION",SWIG_From_int((int)(0x0002)));
  SWIG_Python_SetConstant(d, "FLAG_ENUMERATION_ENUM_EPR",SWIG_From_int((int)(0x0004)));
  SWIG_Python_SetConstant(d, "FLAG_ENUMERATION_ENUM_OBJ_AND_EPR",SWIG_From_int((int)(0x0008)));
  SWIG_Python_SetConstant(d, "FLAG_DUMP_REQUEST",SWIG_From_int((int)(0x0010)));
  SWIG_Python_SetConstant(d, "FLAG_INCLUDESUBCLASSPROPERTIES",SWIG_From_int((int)(0x0020)));
  SWIG_Python_SetConstant(d, "FLAG_EXCLUDESUBCLASSPROPERTIES",SWIG_From_int((int)(0x0040)));
  SWIG_Python_SetConstant(d, "FLAG_POLYMORPHISM_NONE",SWIG_From_int((int)(0x0080)));
  SWIG_Python_SetConstant(d, "FLAG_MUND_MAX_ESIZE",SWIG_From_int((int)(0x0100)));
  SWIG_Python_SetConstant(d, "FLAG_MUND_LOCALE",SWIG_From_int((int)(0x0200)));
  SWIG_Python_SetConstant(d, "FLAG_MUND_OPTIONSET",SWIG_From_int((int)(0x0400)));
  SWIG_Python_SetConstant(d, "FLAG_MUND_FRAGMENT",SWIG_From_int((int)(0x0800)));
  SWIG_Python_SetConstant(d, "FLAG_CIM_EXTENSIONS",SWIG_From_int((int)(0x1000)));
  SWIG_Python_SetConstant(d, "FLAG_CIM_REFERENCES",SWIG_From_int((int)(0x2000)));
  SWIG_Python_SetConstant(d, "FLAG_CIM_ASSOCIATORS",SWIG_From_int((int)(0x4000)));
  SWIG_Python_SetConstant(d, "FLAG_EVENT_SENDBOOKMARK",SWIG_From_int((int)(0X8000)));
  SWIG_Python_SetConstant(d, "FLAG_CIM_SCHEMA_OPT",SWIG_From_int((int)(0X10000)));
  SWIG_Python_SetConstant(d, "WSMAN_DELIVERY_PUSH",SWIG_From_int((int)(0)));
  SWIG_Python_SetConstant(d, "WSMAN_DELIVERY_PUSHWITHACK",SWIG_From_int((int)(1)));
  SWIG_Python_SetConstant(d, "WSMAN_DELIVERY_EVENTS",SWIG_From_int((int)(2)));
  SWIG_Python_SetConstant(d, "WSMAN_DELIVERY_PULL",SWIG_From_int((int)(3)));
  SWIG_Python_SetConstant(d, "WS_NO_AUTH",SWIG_From_int((int)(0)));
  SWIG_Python_SetConstant(d, "WS_BASIC_AUTH",SWIG_From_int((int)(1)));
  SWIG_Python_SetConstant(d, "WS_DIGEST_AUTH",SWIG_From_int((int)(2)));
  SWIG_Python_SetConstant(d, "WS_PASS_AUTH",SWIG_From_int((int)(3)));
  SWIG_Python_SetConstant(d, "WS_NTLM_AUTH",SWIG_From_int((int)(4)));
  SWIG_Python_SetConstant(d, "WS_GSSNEGOTIATE_AUTH",SWIG_From_int((int)(5)));
  SWIG_Python_SetConstant(d, "WS_MAX_AUTH",SWIG_From_int((int)(6)));
  SWIG_Python_SetConstant(d, "WSMAN_DELIVERY_SEC_AUTO",SWIG_From_int((int)(0)));
  SWIG_Python_SetConstant(d, "WSMAN_DELIVERY_SEC_HTTP_BASIC",SWIG_From_int((int)(1)));
  SWIG_Python_SetConstant(d, "WSMAN_DELIVERY_SEC_HTTP_DIGEST",SWIG_From_int((int)(2)));
  SWIG_Python_SetConstant(d, "WSMAN_DELIVERY_SEC_HTTPS_BASIC",SWIG_From_int((int)(3)));
  SWIG_Python_SetConstant(d, "WSMAN_DELIVERY_SEC_HTTPS_DIGEST",SWIG_From_int((int)(4)));
  SWIG_Python_SetConstant(d, "WSMAN_DELIVERY_SEC_HTTPS_MUTUAL",SWIG_From_int((int)(5)));
  SWIG_Python_SetConstant(d, "WSMAN_DELIVERY_SEC_HTTPS_MUTUAL_BASIC",SWIG_From_int((int)(6)));
  SWIG_Python_SetConstant(d, "WSMAN_DELIVERY_SEC_HTTPS_MUTUAL_DIGEST",SWIG_From_int((int)(7)));
  SWIG_Python_SetConstant(d, "WSMAN_DELIVERY_SEC_HTTPS_SPNEGO_KERBEROS",SWIG_From_int((int)(8)));
  SWIG_Python_SetConstant(d, "WSMAN_DELIVERY_SEC_HTTPS_MUTUAL_SPNEGO_KERBEROS",SWIG_From_int((int)(9)));
  SWIG_Python_SetConstant(d, "WSMAN_DELIVERY_SEC_HTTP_SPNEGO_KERBEROS",SWIG_From_int((int)(10)));
  SWIG_Python_SetConstant(d, "FAULT_SENDER_CODE",SWIG_FromCharPtr("Sender"));
  SWIG_Python_SetConstant(d, "FAULT_MUSTUNDERSTAND_CODE",SWIG_FromCharPtr("MustUnderstand"));
  SWIG_Python_SetConstant(d, "FAULT_RECEIVER_CODE",SWIG_FromCharPtr("Receiver"));
  SWIG_Python_SetConstant(d, "FAULT_SENDER_CODE_NS",SWIG_FromCharPtr("s:Sender"));
  SWIG_Python_SetConstant(d, "FAULT_RECEIVER_CODE_NS",SWIG_FromCharPtr("s:Receiver"));
  SWIG_Python_SetConstant(d, "FAULT_MUSTUNDERSTAND_CODE_NS",SWIG_FromCharPtr("s:MustUnderstand"));
  SWIG_Python_SetConstant(d, "WSMAN_RC_OK",SWIG_From_int((int)(WSMAN_RC_OK)));
  SWIG_Python_SetConstant(d, "WSMAN_ACCESS_DENIED",SWIG_From_int((int)(WSMAN_ACCESS_DENIED)));
  SWIG_Python_SetConstant(d, "WSA_ACTION_NOT_SUPPORTED",SWIG_From_int((int)(WSA_ACTION_NOT_SUPPORTED)));
  SWIG_Python_SetConstant(d, "WSMAN_ALREADY_EXISTS",SWIG_From_int((int)(WSMAN_ALREADY_EXISTS)));
  SWIG_Python_SetConstant(d, "WSEN_CANNOT_PROCESS_FILTER",SWIG_From_int((int)(WSEN_CANNOT_PROCESS_FILTER)));
  SWIG_Python_SetConstant(d, "WSMAN_CANNOT_PROCESS_FILTER",SWIG_From_int((int)(WSMAN_CANNOT_PROCESS_FILTER)));
  SWIG_Python_SetConstant(d, "WSMAN_CONCURRENCY",SWIG_From_int((int)(WSMAN_CONCURRENCY)));
  SWIG_Python_SetConstant(d, "WSE_DELIVERY_MODE_REQUESTED_UNAVAILABLE",SWIG_From_int((int)(WSE_DELIVERY_MODE_REQUESTED_UNAVAILABLE)));
  SWIG_Python_SetConstant(d, "WSMAN_DELIVERY_REFUSED",SWIG_From_int((int)(WSMAN_DELIVERY_REFUSED)));
  SWIG_Python_SetConstant(d, "WSA_DESTINATION_UNREACHABLE",SWIG_From_int((int)(WSA_DESTINATION_UNREACHABLE)));
  SWIG_Python_SetConstant(d, "WSMAN_ENCODING_LIMIT",SWIG_From_int((int)(WSMAN_ENCODING_LIMIT)));
  SWIG_Python_SetConstant(d, "WSA_ENDPOINT_UNAVAILABLE",SWIG_From_int((int)(WSA_ENDPOINT_UNAVAILABLE)));
  SWIG_Python_SetConstant(d, "WSMAN_EVENT_DELIVER_TO_UNUSABLE",SWIG_From_int((int)(WSMAN_EVENT_DELIVER_TO_UNUSABLE)));
  SWIG_Python_SetConstant(d, "WSE_EVENT_SOURCE_UNABLE_TO_PROCESS",SWIG_From_int((int)(WSE_EVENT_SOURCE_UNABLE_TO_PROCESS)));
  SWIG_Python_SetConstant(d, "WSEN_FILTER_DIALECT_REQUESTED_UNAVAILABLE",SWIG_From_int((int)(WSEN_FILTER_DIALECT_REQUESTED_UNAVAILABLE)));
  SWIG_Python_SetConstant(d, "WSE_FILTERING_NOT_SUPPORTED",SWIG_From_int((int)(WSE_FILTERING_NOT_SUPPORTED)));
  SWIG_Python_SetConstant(d, "WSEN_FILTERING_NOT_SUPPORTED",SWIG_From_int((int)(WSEN_FILTERING_NOT_SUPPORTED)));
  SWIG_Python_SetConstant(d, "WSE_FILTERING_REQUESTED_UNAVAILABLE",SWIG_From_int((int)(WSE_FILTERING_REQUESTED_UNAVAILABLE)));
  SWIG_Python_SetConstant(d, "WSMAN_FRAGMENT_DIALECT_NOT_SUPPORTED",SWIG_From_int((int)(WSMAN_FRAGMENT_DIALECT_NOT_SUPPORTED)));
  SWIG_Python_SetConstant(d, "WSMAN_INTERNAL_ERROR",SWIG_From_int((int)(WSMAN_INTERNAL_ERROR)));
  SWIG_Python_SetConstant(d, "WSMAN_INVALID_BOOKMARK",SWIG_From_int((int)(WSMAN_INVALID_BOOKMARK)));
  SWIG_Python_SetConstant(d, "WSEN_INVALID_ENUMERATION_CONTEXT",SWIG_From_int((int)(WSEN_INVALID_ENUMERATION_CONTEXT)));
  SWIG_Python_SetConstant(d, "WSE_INVALID_EXPIRATION_TIME",SWIG_From_int((int)(WSE_INVALID_EXPIRATION_TIME)));
  SWIG_Python_SetConstant(d, "WSEN_INVALID_EXPIRATION_TIME",SWIG_From_int((int)(WSEN_INVALID_EXPIRATION_TIME)));
  SWIG_Python_SetConstant(d, "WSE_INVALID_MESSAGE",SWIG_From_int((int)(WSE_INVALID_MESSAGE)));
  SWIG_Python_SetConstant(d, "WSA_INVALID_MESSAGE_INFORMATION_HEADER",SWIG_From_int((int)(WSA_INVALID_MESSAGE_INFORMATION_HEADER)));
  SWIG_Python_SetConstant(d, "WSMAN_INVALID_OPTIONS",SWIG_From_int((int)(WSMAN_INVALID_OPTIONS)));
  SWIG_Python_SetConstant(d, "WSMAN_INVALID_PARAMETER",SWIG_From_int((int)(WSMAN_INVALID_PARAMETER)));
  SWIG_Python_SetConstant(d, "WXF_INVALID_REPRESENTATION",SWIG_From_int((int)(WXF_INVALID_REPRESENTATION)));
  SWIG_Python_SetConstant(d, "WSMAN_INVALID_SELECTORS",SWIG_From_int((int)(WSMAN_INVALID_SELECTORS)));
  SWIG_Python_SetConstant(d, "WSA_MESSAGE_INFORMATION_HEADER_REQUIRED",SWIG_From_int((int)(WSA_MESSAGE_INFORMATION_HEADER_REQUIRED)));
  SWIG_Python_SetConstant(d, "WSMAN_NO_ACK",SWIG_From_int((int)(WSMAN_NO_ACK)));
  SWIG_Python_SetConstant(d, "WSMAN_QUOTA_LIMIT",SWIG_From_int((int)(WSMAN_QUOTA_LIMIT)));
  SWIG_Python_SetConstant(d, "WSMAN_SCHEMA_VALIDATION_ERROR",SWIG_From_int((int)(WSMAN_SCHEMA_VALIDATION_ERROR)));
  SWIG_Python_SetConstant(d, "WSEN_TIMED_OUT",SWIG_From_int((int)(WSEN_TIMED_OUT)));
  SWIG_Python_SetConstant(d, "WSMAN_TIMED_OUT",SWIG_From_int((int)(WSMAN_TIMED_OUT)));
  SWIG_Python_SetConstant(d, "WSE_UNABLE_TO_RENEW",SWIG_From_int((int)(WSE_UNABLE_TO_RENEW)));
  SWIG_Python_SetConstant(d, "WSE_UNSUPPORTED_EXPIRATION_TYPE",SWIG_From_int((int)(WSE_UNSUPPORTED_EXPIRATION_TYPE)));
  SWIG_Python_SetConstant(d, "WSEN_UNSUPPORTED_EXPIRATION_TYPE",SWIG_From_int((int)(WSEN_UNSUPPORTED_EXPIRATION_TYPE)));
  SWIG_Python_SetConstant(d, "WSMAN_UNSUPPORTED_FEATURE",SWIG_From_int((int)(WSMAN_UNSUPPORTED_FEATURE)));
  SWIG_Python_SetConstant(d, "SOAP_FAULT_VERSION_MISMATCH",SWIG_From_int((int)(SOAP_FAULT_VERSION_MISMATCH)));
  SWIG_Python_SetConstant(d, "SOAP_FAULT_MUSTUNDERSTAND",SWIG_From_int((int)(SOAP_FAULT_MUSTUNDERSTAND)));
  SWIG_Python_SetConstant(d, "WSMB_POLYMORPHISM_MODE_NOT_SUPPORTED",SWIG_From_int((int)(WSMB_POLYMORPHISM_MODE_NOT_SUPPORTED)));
  SWIG_Python_SetConstant(d, "WSMAN_UNKNOWN",SWIG_From_int((int)(WSMAN_UNKNOWN)));
  SWIG_Python_SetConstant(d, "WSMAN_DETAIL_OK",SWIG_From_int((int)(WSMAN_DETAIL_OK)));
  SWIG_Python_SetConstant(d, "WSMAN_DETAIL_ACK",SWIG_From_int((int)(WSMAN_DETAIL_ACK)));
  SWIG_Python_SetConstant(d, "WSMAN_DETAIL_ACTION_MISMATCH",SWIG_From_int((int)(WSMAN_DETAIL_ACTION_MISMATCH)));
  SWIG_Python_SetConstant(d, "WSMAN_DETAIL_ALREADY_EXISTS",SWIG_From_int((int)(WSMAN_DETAIL_ALREADY_EXISTS)));
  SWIG_Python_SetConstant(d, "WSMAN_DETAIL_AMBIGUOUS_SELECTORS",SWIG_From_int((int)(WSMAN_DETAIL_AMBIGUOUS_SELECTORS)));
  SWIG_Python_SetConstant(d, "WSMAN_DETAIL_ASYNCHRONOUS_REQUEST",SWIG_From_int((int)(WSMAN_DETAIL_ASYNCHRONOUS_REQUEST)));
  SWIG_Python_SetConstant(d, "WSMAN_DETAIL_ADDRESSING_MODE",SWIG_From_int((int)(WSMAN_DETAIL_ADDRESSING_MODE)));
  SWIG_Python_SetConstant(d, "WSMAN_DETAIL_AUTHERIZATION_MODE",SWIG_From_int((int)(WSMAN_DETAIL_AUTHERIZATION_MODE)));
  SWIG_Python_SetConstant(d, "WSMAN_DETAIL_BOOKMARKS",SWIG_From_int((int)(WSMAN_DETAIL_BOOKMARKS)));
  SWIG_Python_SetConstant(d, "WSMAN_DETAIL_CHARECHTER_SET",SWIG_From_int((int)(WSMAN_DETAIL_CHARECHTER_SET)));
  SWIG_Python_SetConstant(d, "WSMAN_DETAIL_DELIVERY_RETRIES",SWIG_From_int((int)(WSMAN_DETAIL_DELIVERY_RETRIES)));
  SWIG_Python_SetConstant(d, "WSMAN_DETAIL_DUPLICATE_SELECTORS",SWIG_From_int((int)(WSMAN_DETAIL_DUPLICATE_SELECTORS)));
  SWIG_Python_SetConstant(d, "WSMAN_DETAIL_ENCODING_TYPE",SWIG_From_int((int)(WSMAN_DETAIL_ENCODING_TYPE)));
  SWIG_Python_SetConstant(d, "WSMAN_DETAIL_ENUMERATION_MODE",SWIG_From_int((int)(WSMAN_DETAIL_ENUMERATION_MODE)));
  SWIG_Python_SetConstant(d, "WSMAN_DETAIL_EXPIRATION_TIME",SWIG_From_int((int)(WSMAN_DETAIL_EXPIRATION_TIME)));
  SWIG_Python_SetConstant(d, "WSMAN_DETAIL_EXPIRED",SWIG_From_int((int)(WSMAN_DETAIL_EXPIRED)));
  SWIG_Python_SetConstant(d, "WSMAN_DETAIL_FILTERING_REQUIRED",SWIG_From_int((int)(WSMAN_DETAIL_FILTERING_REQUIRED)));
  SWIG_Python_SetConstant(d, "WSMAN_DETAIL_FORMAT_MISMATCH",SWIG_From_int((int)(WSMAN_DETAIL_FORMAT_MISMATCH)));
  SWIG_Python_SetConstant(d, "WSMAN_DETAIL_FORMAT_SECURITY_TOKEN",SWIG_From_int((int)(WSMAN_DETAIL_FORMAT_SECURITY_TOKEN)));
  SWIG_Python_SetConstant(d, "WSMAN_DETAIL_FRAGMENT_LEVEL_ACCESS",SWIG_From_int((int)(WSMAN_DETAIL_FRAGMENT_LEVEL_ACCESS)));
  SWIG_Python_SetConstant(d, "WSMAN_DETAIL_HEARTBEATS",SWIG_From_int((int)(WSMAN_DETAIL_HEARTBEATS)));
  SWIG_Python_SetConstant(d, "WSMAN_DETAIL_INSECURE_ADDRESS",SWIG_From_int((int)(WSMAN_DETAIL_INSECURE_ADDRESS)));
  SWIG_Python_SetConstant(d, "WSMAN_DETAIL_INSUFFICIENT_SELECTORS",SWIG_From_int((int)(WSMAN_DETAIL_INSUFFICIENT_SELECTORS)));
  SWIG_Python_SetConstant(d, "WSMAN_DETAIL_INVALID",SWIG_From_int((int)(WSMAN_DETAIL_INVALID)));
  SWIG_Python_SetConstant(d, "WSMAN_DETAIL_INVALID_ADDRESS",SWIG_From_int((int)(WSMAN_DETAIL_INVALID_ADDRESS)));
  SWIG_Python_SetConstant(d, "WSMAN_DETAIL_INVALID_FORMAT",SWIG_From_int((int)(WSMAN_DETAIL_INVALID_FORMAT)));
  SWIG_Python_SetConstant(d, "WSMAN_DETAIL_INVALID_FRAGMENT",SWIG_From_int((int)(WSMAN_DETAIL_INVALID_FRAGMENT)));
  SWIG_Python_SetConstant(d, "WSMAN_DETAIL_INVALID_NAME",SWIG_From_int((int)(WSMAN_DETAIL_INVALID_NAME)));
  SWIG_Python_SetConstant(d, "WSMAN_DETAIL_INVALID_NAMESPACE",SWIG_From_int((int)(WSMAN_DETAIL_INVALID_NAMESPACE)));
  SWIG_Python_SetConstant(d, "WSMAN_DETAIL_INVALID_RESOURCEURI",SWIG_From_int((int)(WSMAN_DETAIL_INVALID_RESOURCEURI)));
  SWIG_Python_SetConstant(d, "WSMAN_DETAIL_INVALID_SELECTOR_ASSIGNMENT",SWIG_From_int((int)(WSMAN_DETAIL_INVALID_SELECTOR_ASSIGNMENT)));
  SWIG_Python_SetConstant(d, "WSMAN_DETAIL_INVALID_SYSTEM",SWIG_From_int((int)(WSMAN_DETAIL_INVALID_SYSTEM)));
  SWIG_Python_SetConstant(d, "WSMAN_DETAIL_INVALID_TIMEOUT",SWIG_From_int((int)(WSMAN_DETAIL_INVALID_TIMEOUT)));
  SWIG_Python_SetConstant(d, "WSMAN_DETAIL_INVALID_VALUE",SWIG_From_int((int)(WSMAN_DETAIL_INVALID_VALUE)));
  SWIG_Python_SetConstant(d, "WSMAN_DETAIL_INVALID_VALUES",SWIG_From_int((int)(WSMAN_DETAIL_INVALID_VALUES)));
  SWIG_Python_SetConstant(d, "WSMAN_DETAIL_LOCALE",SWIG_From_int((int)(WSMAN_DETAIL_LOCALE)));
  SWIG_Python_SetConstant(d, "WSMAN_DETAIL_MAX_ELEMENTS",SWIG_From_int((int)(WSMAN_DETAIL_MAX_ELEMENTS)));
  SWIG_Python_SetConstant(d, "WSMAN_DETAIL_MAX_ENVELOPE_POLICY",SWIG_From_int((int)(WSMAN_DETAIL_MAX_ENVELOPE_POLICY)));
  SWIG_Python_SetConstant(d, "WSMAN_DETAIL_MAX_ENVELOPE_SIZE",SWIG_From_int((int)(WSMAN_DETAIL_MAX_ENVELOPE_SIZE)));
  SWIG_Python_SetConstant(d, "WSMAN_DETAIL_MAX_TIME",SWIG_From_int((int)(WSMAN_DETAIL_MAX_TIME)));
  SWIG_Python_SetConstant(d, "WSMAN_DETAIL_MINIMUM_ENVELOPE_LIMIT",SWIG_From_int((int)(WSMAN_DETAIL_MINIMUM_ENVELOPE_LIMIT)));
  SWIG_Python_SetConstant(d, "WSMAN_DETAIL_MISSING_VALUES",SWIG_From_int((int)(WSMAN_DETAIL_MISSING_VALUES)));
  SWIG_Python_SetConstant(d, "WSMAN_DETAIL_NOT_SUPPORTED",SWIG_From_int((int)(WSMAN_DETAIL_NOT_SUPPORTED)));
  SWIG_Python_SetConstant(d, "WSMAN_DETAIL_OPERATION_TIMEOUT",SWIG_From_int((int)(WSMAN_DETAIL_OPERATION_TIMEOUT)));
  SWIG_Python_SetConstant(d, "WSMAN_DETAIL_OPTION_LIMIT",SWIG_From_int((int)(WSMAN_DETAIL_OPTION_LIMIT)));
  SWIG_Python_SetConstant(d, "WSMAN_DETAIL_OPTION_SET",SWIG_From_int((int)(WSMAN_DETAIL_OPTION_SET)));
  SWIG_Python_SetConstant(d, "WSMAN_DETAIL_READ_ONLY",SWIG_From_int((int)(WSMAN_DETAIL_READ_ONLY)));
  SWIG_Python_SetConstant(d, "WSMAN_DETAIL_RESOURCE_OFFLINE",SWIG_From_int((int)(WSMAN_DETAIL_RESOURCE_OFFLINE)));
  SWIG_Python_SetConstant(d, "WSMAN_DETAIL_RENAME",SWIG_From_int((int)(WSMAN_DETAIL_RENAME)));
  SWIG_Python_SetConstant(d, "WSMAN_DETAIL_SELECTOR_LIMIT",SWIG_From_int((int)(WSMAN_DETAIL_SELECTOR_LIMIT)));
  SWIG_Python_SetConstant(d, "WSMAN_DETAIL_SERVICE_ENVELOPE_LIMIT",SWIG_From_int((int)(WSMAN_DETAIL_SERVICE_ENVELOPE_LIMIT)));
  SWIG_Python_SetConstant(d, "WSMAN_DETAIL_TARGET_ALREADY_EXISTS",SWIG_From_int((int)(WSMAN_DETAIL_TARGET_ALREADY_EXISTS)));
  SWIG_Python_SetConstant(d, "WSMAN_DETAIL_TYPE_MISMATCH",SWIG_From_int((int)(WSMAN_DETAIL_TYPE_MISMATCH)));
  SWIG_Python_SetConstant(d, "WSMAN_DETAIL_UNEXPECTED_SELECTORS",SWIG_From_int((int)(WSMAN_DETAIL_UNEXPECTED_SELECTORS)));
  SWIG_Python_SetConstant(d, "WSMAN_DETAIL_UNREPORTABLE_SUCCESS",SWIG_From_int((int)(WSMAN_DETAIL_UNREPORTABLE_SUCCESS)));
  SWIG_Python_SetConstant(d, "WSMAN_DETAIL_UNUSABLE_ADDRESS",SWIG_From_int((int)(WSMAN_DETAIL_UNUSABLE_ADDRESS)));
  SWIG_Python_SetConstant(d, "WSMAN_DETAIL_URI_LIMIT_EXCEEDED",SWIG_From_int((int)(WSMAN_DETAIL_URI_LIMIT_EXCEEDED)));
  SWIG_Python_SetConstant(d, "WSMAN_DETAIL_WHITESPACE",SWIG_From_int((int)(WSMAN_DETAIL_WHITESPACE)));
  SWIG_Python_SetConstant(d, "WSA_DETAIL_DUPLICATE_MESSAGE_ID",SWIG_From_int((int)(WSA_DETAIL_DUPLICATE_MESSAGE_ID)));
  SWIG_Python_SetConstant(d, "SOAP_DETAIL_HEADER_NOT_UNDERSTOOD",SWIG_From_int((int)(SOAP_DETAIL_HEADER_NOT_UNDERSTOOD)));
  SWIG_Python_SetConstant(d, "WST_DETAIL_UNSUPPORTED_TOKENTYPE",SWIG_From_int((int)(WST_DETAIL_UNSUPPORTED_TOKENTYPE)));
  SWIG_Python_SetConstant(d, "WSP_DETAIL_INVALID_EPR",SWIG_From_int((int)(WSP_DETAIL_INVALID_EPR)));
  SWIG_Python_SetConstant(d, "OWSMAN_DETAIL_ENDPOINT_ERROR",SWIG_From_int((int)(OWSMAN_DETAIL_ENDPOINT_ERROR)));
  SWIG_Python_SetConstant(d, "OWSMAN_NO_DETAILS",SWIG_From_int((int)(OWSMAN_NO_DETAILS)));
  SWIG_Python_SetConstant(d, "OWSMAN_SYSTEM_ERROR",SWIG_From_int((int)(OWSMAN_SYSTEM_ERROR)));
  SWIG_Python_SetConstant(d, "WSMAN_STATUS_NONE",SWIG_From_int((int)(WSMAN_STATUS_NONE)));
  SWIG_Python_SetConstant(d, "WSMAN_STATUS_CANCELLED",SWIG_From_int((int)(WSMAN_STATUS_CANCELLED)));
  SWIG_Python_SetConstant(d, "WSMAN_STATUS_CANT_RESOLVE",SWIG_From_int((int)(WSMAN_STATUS_CANT_RESOLVE)));
  SWIG_Python_SetConstant(d, "WSMAN_STATUS_CANT_RESOLVE_PROXY",SWIG_From_int((int)(WSMAN_STATUS_CANT_RESOLVE_PROXY)));
  SWIG_Python_SetConstant(d, "WSMAN_STATUS_CANT_CONNECT",SWIG_From_int((int)(WSMAN_STATUS_CANT_CONNECT)));
  SWIG_Python_SetConstant(d, "WSMAN_STATUS_CANT_CONNECT_PROXY",SWIG_From_int((int)(WSMAN_STATUS_CANT_CONNECT_PROXY)));
  SWIG_Python_SetConstant(d, "WSMAN_STATUS_SSL_FAILED",SWIG_From_int((int)(WSMAN_STATUS_SSL_FAILED)));
  SWIG_Python_SetConstant(d, "WSMAN_STATUS_IO_ERROR",SWIG_From_int((int)(WSMAN_STATUS_IO_ERROR)));
  SWIG_Python_SetConstant(d, "WSMAN_STATUS_MALFORMED",SWIG_From_int((int)(WSMAN_STATUS_MALFORMED)));
  SWIG_Python_SetConstant(d, "WSMAN_STATUS_TRY_AGAIN",SWIG_From_int((int)(WSMAN_STATUS_TRY_AGAIN)));
  SWIG_Python_SetConstant(d, "WSMAN_STATUS_CONTINUE",SWIG_From_int((int)(WSMAN_STATUS_CONTINUE)));
  SWIG_Python_SetConstant(d, "WSMAN_STATUS_SWITCHING_PROTOCOLS",SWIG_From_int((int)(WSMAN_STATUS_SWITCHING_PROTOCOLS)));
  SWIG_Python_SetConstant(d, "WSMAN_STATUS_PROCESSING",SWIG_From_int((int)(WSMAN_STATUS_PROCESSING)));
  SWIG_Python_SetConstant(d, "WSMAN_STATUS_OK",SWIG_From_int((int)(WSMAN_STATUS_OK)));
  SWIG_Python_SetConstant(d, "WSMAN_STATUS_CREATED",SWIG_From_int((int)(WSMAN_STATUS_CREATED)));
  SWIG_Python_SetConstant(d, "WSMAN_STATUS_ACCEPTED",SWIG_From_int((int)(WSMAN_STATUS_ACCEPTED)));
  SWIG_Python_SetConstant(d, "WSMAN_STATUS_NON_AUTHORITATIVE",SWIG_From_int((int)(WSMAN_STATUS_NON_AUTHORITATIVE)));
  SWIG_Python_SetConstant(d, "WSMAN_STATUS_NO_CONTENT",SWIG_From_int((int)(WSMAN_STATUS_NO_CONTENT)));
  SWIG_Python_SetConstant(d, "WSMAN_STATUS_RESET_CONTENT",SWIG_From_int((int)(WSMAN_STATUS_RESET_CONTENT)));
  SWIG_Python_SetConstant(d, "WSMAN_STATUS_PARTIAL_CONTENT",SWIG_From_int((int)(WSMAN_STATUS_PARTIAL_CONTENT)));
  SWIG_Python_SetConstant(d, "WSMAN_STATUS_MULTI_STATUS",SWIG_From_int((int)(WSMAN_STATUS_MULTI_STATUS)));
  SWIG_Python_SetConstant(d, "WSMAN_STATUS_MULTIPLE_CHOICES",SWIG_From_int((int)(WSMAN_STATUS_MULTIPLE_CHOICES)));
  SWIG_Python_SetConstant(d, "WSMAN_STATUS_MOVED_PERMANENTLY",SWIG_From_int((int)(WSMAN_STATUS_MOVED_PERMANENTLY)));
  SWIG_Python_SetConstant(d, "WSMAN_STATUS_FOUND",SWIG_From_int((int)(WSMAN_STATUS_FOUND)));
  SWIG_Python_SetConstant(d, "WSMAN_STATUS_MOVED_TEMPORARILY",SWIG_From_int((int)(WSMAN_STATUS_MOVED_TEMPORARILY)));
  SWIG_Python_SetConstant(d, "WSMAN_STATUS_SEE_OTHER",SWIG_From_int((int)(WSMAN_STATUS_SEE_OTHER)));
  SWIG_Python_SetConstant(d, "WSMAN_STATUS_NOT_MODIFIED",SWIG_From_int((int)(WSMAN_STATUS_NOT_MODIFIED)));
  SWIG_Python_SetConstant(d, "WSMAN_STATUS_USE_PROXY",SWIG_From_int((int)(WSMAN_STATUS_USE_PROXY)));
  SWIG_Python_SetConstant(d, "WSMAN_STATUS_NOT_APPEARING_IN_THIS_PROTOCOL",SWIG_From_int((int)(WSMAN_STATUS_NOT_APPEARING_IN_THIS_PROTOCOL)));
  SWIG_Python_SetConstant(d, "WSMAN_STATUS_TEMPORARY_REDIRECT",SWIG_From_int((int)(WSMAN_STATUS_TEMPORARY_REDIRECT)));
  SWIG_Python_SetConstant(d, "WSMAN_STATUS_BAD_REQUEST",SWIG_From_int((int)(WSMAN_STATUS_BAD_REQUEST)));
  SWIG_Python_SetConstant(d, "WSMAN_STATUS_UNAUTHORIZED",SWIG_From_int((int)(WSMAN_STATUS_UNAUTHORIZED)));
  SWIG_Python_SetConstant(d, "WSMAN_STATUS_PAYMENT_REQUIRED",SWIG_From_int((int)(WSMAN_STATUS_PAYMENT_REQUIRED)));
  SWIG_Python_SetConstant(d, "WSMAN_STATUS_FORBIDDEN",SWIG_From_int((int)(WSMAN_STATUS_FORBIDDEN)));
  SWIG_Python_SetConstant(d, "WSMAN_STATUS_NOT_FOUND",SWIG_From_int((int)(WSMAN_STATUS_NOT_FOUND)));
  SWIG_Python_SetConstant(d, "WSMAN_STATUS_METHOD_NOT_ALLOWED",SWIG_From_int((int)(WSMAN_STATUS_METHOD_NOT_ALLOWED)));
  SWIG_Python_SetConstant(d, "WSMAN_STATUS_NOT_ACCEPTABLE",SWIG_From_int((int)(WSMAN_STATUS_NOT_ACCEPTABLE)));
  SWIG_Python_SetConstant(d, "WSMAN_STATUS_PROXY_AUTHENTICATION_REQUIRED",SWIG_From_int((int)(WSMAN_STATUS_PROXY_AUTHENTICATION_REQUIRED)));
  SWIG_Python_SetConstant(d, "WSMAN_STATUS_PROXY_UNAUTHORIZED",SWIG_From_int((int)(WSMAN_STATUS_PROXY_UNAUTHORIZED)));
  SWIG_Python_SetConstant(d, "WSMAN_STATUS_REQUEST_TIMEOUT",SWIG_From_int((int)(WSMAN_STATUS_REQUEST_TIMEOUT)));
  SWIG_Python_SetConstant(d, "WSMAN_STATUS_CONFLICT",SWIG_From_int((int)(WSMAN_STATUS_CONFLICT)));
  SWIG_Python_SetConstant(d, "WSMAN_STATUS_GONE",SWIG_From_int((int)(WSMAN_STATUS_GONE)));
  SWIG_Python_SetConstant(d, "WSMAN_STATUS_LENGTH_REQUIRED",SWIG_From_int((int)(WSMAN_STATUS_LENGTH_REQUIRED)));
  SWIG_Python_SetConstant(d, "WSMAN_STATUS_PRECONDITION_FAILED",SWIG_From_int((int)(WSMAN_STATUS_PRECONDITION_FAILED)));
  SWIG_Python_SetConstant(d, "WSMAN_STATUS_REQUEST_ENTITY_TOO_LARGE",SWIG_From_int((int)(WSMAN_STATUS_REQUEST_ENTITY_TOO_LARGE)));
  SWIG_Python_SetConstant(d, "WSMAN_STATUS_REQUEST_URI_TOO_LONG",SWIG_From_int((int)(WSMAN_STATUS_REQUEST_URI_TOO_LONG)));
  SWIG_Python_SetConstant(d, "WSMAN_STATUS_UNSUPPORTED_MEDIA_TYPE",SWIG_From_int((int)(WSMAN_STATUS_UNSUPPORTED_MEDIA_TYPE)));
  SWIG_Python_SetConstant(d, "WSMAN_STATUS_REQUESTED_RANGE_NOT_SATISFIABLE",SWIG_From_int((int)(WSMAN_STATUS_REQUESTED_RANGE_NOT_SATISFIABLE)));
  SWIG_Python_SetConstant(d, "WSMAN_STATUS_INVALID_RANGE",SWIG_From_int((int)(WSMAN_STATUS_INVALID_RANGE)));
  SWIG_Python_SetConstant(d, "WSMAN_STATUS_EXPECTATION_FAILED",SWIG_From_int((int)(WSMAN_STATUS_EXPECTATION_FAILED)));
  SWIG_Python_SetConstant(d, "WSMAN_STATUS_UNPROCESSABLE_ENTITY",SWIG_From_int((int)(WSMAN_STATUS_UNPROCESSABLE_ENTITY)));
  SWIG_Python_SetConstant(d, "WSMAN_STATUS_LOCKED",SWIG_From_int((int)(WSMAN_STATUS_LOCKED)));
  SWIG_Python_SetConstant(d, "WSMAN_STATUS_FAILED_DEPENDENCY",SWIG_From_int((int)(WSMAN_STATUS_FAILED_DEPENDENCY)));
  SWIG_Python_SetConstant(d, "WSMAN_STATUS_INTERNAL_SERVER_ERROR",SWIG_From_int((int)(WSMAN_STATUS_INTERNAL_SERVER_ERROR)));
  SWIG_Python_SetConstant(d, "WSMAN_STATUS_NOT_IMPLEMENTED",SWIG_From_int((int)(WSMAN_STATUS_NOT_IMPLEMENTED)));
  SWIG_Python_SetConstant(d, "WSMAN_STATUS_BAD_GATEWAY",SWIG_From_int((int)(WSMAN_STATUS_BAD_GATEWAY)));
  SWIG_Python_SetConstant(d, "WSMAN_STATUS_SERVICE_UNAVAILABLE",SWIG_From_int((int)(WSMAN_STATUS_SERVICE_UNAVAILABLE)));
  SWIG_Python_SetConstant(d, "WSMAN_STATUS_GATEWAY_TIMEOUT",SWIG_From_int((int)(WSMAN_STATUS_GATEWAY_TIMEOUT)));
  SWIG_Python_SetConstant(d, "WSMAN_STATUS_HTTP_VERSION_NOT_SUPPORTED",SWIG_From_int((int)(WSMAN_STATUS_HTTP_VERSION_NOT_SUPPORTED)));
  SWIG_Python_SetConstant(d, "WSMAN_STATUS_INSUFFICIENT_STORAGE",SWIG_From_int((int)(WSMAN_STATUS_INSUFFICIENT_STORAGE)));
  SWIG_Python_SetConstant(d, "WSMAN_STATUS_NOT_EXTENDED",SWIG_From_int((int)(WSMAN_STATUS_NOT_EXTENDED)));
  SWIG_Python_SetConstant(d, "NO_AUTH",SWIG_From_int((int)(0)));
  SWIG_Python_SetConstant(d, "BASIC_AUTH",SWIG_From_int((int)(1)));
  SWIG_Python_SetConstant(d, "DIGEST_AUTH",SWIG_From_int((int)(2)));
  SWIG_Python_SetConstant(d, "PASS_AUTH",SWIG_From_int((int)(3)));
  SWIG_Python_SetConstant(d, "NTLM_AUTH",SWIG_From_int((int)(4)));
  SWIG_Python_SetConstant(d, "GSSNEGOTIATE_AUTH",SWIG_From_int((int)(5)));
  SWIG_Python_SetConstant(d, "NO_AUTH_STR",SWIG_FromCharPtr("No Auth"));
  SWIG_Python_SetConstant(d, "BASIC_AUTH_STR",SWIG_FromCharPtr("Basic"));
  SWIG_Python_SetConstant(d, "DIGEST_AUTH_STR",SWIG_FromCharPtr("Digest"));
  SWIG_Python_SetConstant(d, "PASS_AUTH_STR",SWIG_FromCharPtr("Passport"));
  SWIG_Python_SetConstant(d, "NTLM_AUTH_STR",SWIG_FromCharPtr("NTLM"));
  SWIG_Python_SetConstant(d, "GSSNEGOTIATE_AUTH_STR",SWIG_FromCharPtr("GSS-Negotiate"));
  SWIG_Python_SetConstant(d, "TRUE",SWIG_From_int((int)(1)));
  SWIG_Python_SetConstant(d, "FALSE",SWIG_From_int((int)(0)));
  SWIG_Python_SetConstant(d, "DEFAULT_USER_AGENT",SWIG_FromCharPtr("Openwsman"));
  return 0;
}

